@@ -1,17 +1,12 @@
 #!/bin/sh
 #
-#	$Id: do_examples.sh,v 1.5 2006/01/09 21:51:46 remko Exp $
+#	$Id: do_examples.sh,v 1.8 2007/03/28 03:02:12 pwessel Exp $
 #
 # Bourne script to test all GMT examples (sh versions).
 # If one argument is given it is used as the bin path
 # If a second arguemnt is used it is added to the library path
 
 # Temporary change LANG to C
-if [ "X$LANG" = "X" ]; then
-	OLDLANG=
-else
-	OLDLANG=$LANG
-fi
 LANG=C
 
 # First determine if awk is buggy:
@@ -28,41 +23,31 @@ else
 	export AWK=awk
 fi
 
+# Extend executable and library path if requested
+
 if [ $# -ge 1 ]; then
 	cd ..
 	top=`pwd`
 	cd examples
-	OLDPATH=$PATH
-	OLDGMTHOME=${GMTHOME:-$top}
-	export PATH=$1:$OLDPATH
+	export PATH=$1:$PATH
 	if [ $# = 2 ]; then
-		OLDLD=${LD_LIBRARY_PATH:-/usr/lib}
-		export LD_LIBRARY_PATH=$2:$OLDLD
+		export LD_LIBRARY_PATH=$2:${LD_LIBRARY_PATH:-/usr/lib}
 	fi
-	export GMTHOME=$top
 fi
 
 # Loop over all examples and run each job
 
-for dir in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25
+for dir in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
 do
 	if [ -e ex${dir}/job${dir}.sh ]; then
 		echo -n "Doing example ${dir}..."
 		cd ex${dir}
-		cp ../.gmtdefaults4.doc .gmtdefaults4
+		\cp -f ../.gmtdefaults4.doc .gmtdefaults4
 		sh job${dir}.sh
-		rm -f .gmtdefaults4
+		\rm -f .gmtdefaults4
 		cd ..
 		echo "done"
 	fi
 done
-if [ $# -ge 1 ]; then
-	export PATH=$OLDPATH
-	export GMTHOME=$OLDGMTHOME
-	if [ $# = 2 ]; then
-		export LD_LIBRARY_PATH=$OLDLD
-	fi
-fi
-LANG=$OLDLANG
 
 echo "Completed all examples"
