@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdraster.c,v 1.31 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: grdraster.c,v 1.42 2007/03/24 01:42:07 pwessel Exp $
  *
- *    Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* grdraster.c -- read a rasterfile and extract a region as a grdfile.
@@ -13,7 +13,7 @@
  *
  * Author:	Walter H. F. Smith
  * Date:	20 January, 1995
- * Update:	10 March 1999 PW: Now use new default dir $GMTHOME/share/dbase
+ * Update:	10 March 1999 PW: Now use new default dir $GMT_SHAREDIR/dbase
  *		05 April 1999 PW: Now deals with DOS/UNIX directory signs
  *		07 April 1999 PW: ...and DOS drive letters.
  *		27 April 1999 PW: Added option to swap via #define GMTSWAP
@@ -29,6 +29,7 @@
  *		12 Jan 2001   PW: Dynamically allocate info structures; no longer hardwired.
  *		27 Jun 2005   PW: Allow modifiers G(ographic) and C(artesian) in registration flag.
  *		19 Sep 2005   PW: Allow optional H<bytes> at end of line for skipping headers.
+ *		07 Sep 2006   PW: Only do 360 wrap if geographic grid.
  */
 
 #include "gmt.h"
@@ -223,8 +224,6 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	GMT_io.in_col_type[0] = GMT_io.out_col_type[0] = (myras.geo) ? GMT_IS_LON : GMT_IS_FLOAT;
 	GMT_io.in_col_type[1] = GMT_io.out_col_type[1] = (myras.geo) ? GMT_IS_LAT : GMT_IS_FLOAT;
 
@@ -250,7 +249,7 @@ int main (int argc, char **argv)
 
 	if (!project_info.region && project_info.projection >= 0) {
 	
-		GMT_map_setup (h.x_min, h.x_max, h.y_min, h.y_max);
+		GMT_err_fail (GMT_map_setup (h.x_min, h.x_max, h.y_min, h.y_max), "");
 		
 		h.x_min = floor (project_info.w / h.x_inc) * h.x_inc;
 		h.x_max = ceil (project_info.e / h.x_inc) * h.x_inc;
@@ -313,8 +312,14 @@ int main (int argc, char **argv)
 	strcpy(h.title, myras.h.title);
 	strcpy(h.z_units, myras.h.z_units);
 	strcpy(h.remark, myras.h.remark);
-	strcpy(h.x_units, "Longitude in degrees");
-	strcpy(h.y_units, "Latitude in degrees");
+	if (myras.geo) {
+		strcpy(h.x_units, "Longitude [degrees_east]");
+		strcpy(h.y_units, "Latitude [degrees_north]");
+	}
+	else {
+		strcpy(h.x_units, "x");
+		strcpy(h.y_units, "y");
+	}
 	h.node_offset = myras.h.node_offset;
 	h.z_min = DBL_MAX;
 	h.z_max = -DBL_MAX;
@@ -514,7 +519,7 @@ int main (int argc, char **argv)
 		GMT_free ((void *)x);
 	}
 	else
-		GMT_write_grd (grdfilename, &h, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+		GMT_err_fail (GMT_write_grd (grdfilename, &h, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), grdfilename);
 		
 	GMT_free ((void *)grd);
 	GMT_free ((void *)rasinfo);
@@ -617,7 +622,7 @@ void convert_l_row(struct GRDRASTER_INFO ras, float *row, int *buffer)
 
 int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 {
-	/* Read the file $(GMT_GRIDDIR)/grdraster.info
+	/* Read the file grdraster.info
 		Store the i'th row of the file in rasinfo[i].h.command.
 		Store the filename in rasinfo[i].h.remark.
 		Store the description in rasinfo[i].h.title.
@@ -633,22 +638,26 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 	int	i, j, length, stop_point, nfound = 0;
 	size_t	n_alloc;
 	double	global_lon, lon_tol;
-	char	buf[GRD_REMARK_LEN], *d, dir[GRD_REMARK_LEN];
+	char	buf[GRD_REMARK_LEN], dir[GRD_REMARK_LEN], *l;
 	FILE	*fp;
 	struct GRDRASTER_INFO *rasinfo;
 
-	if ((d = getenv ("GMT_GRIDDIR")) == CNULL)	/* Look in default location */
-		sprintf (dir, "%s%cshare%cdbase", GMTHOME, DIR_DELIM, DIR_DELIM);
-	else
-		strcpy (dir, d);
+	/* Find and open the file grdraster.info */
 
-	sprintf(buf, "%s%cgrdraster.info", dir, DIR_DELIM);
+	if (!(GMT_getdatapath("grdraster.info", dir) || GMT_getsharepath("dbase", "grdraster", ".info", dir))) {
+		fprintf(stderr, "%s: ERROR cannot find file grdraster.info", GMT_program);
+		return (0);
+	}
 
-	if ( (fp = fopen(buf, "r")) == NULL) {
-		fprintf(stderr, "%s: ERROR cannot open r %s\n", GMT_program, buf);
+	if ( (fp = fopen(dir, "r")) == NULL) {
+		fprintf(stderr, "%s: ERROR cannot open file %s\n", GMT_program, dir);
 		return(0);
 	}
 
+	/* Truncate the pathname of grdraster.info to just the directory name */
+
+	if ((l = strstr (dir, "grdraster.info"))) *l = '\0';
+
 	n_alloc = GMT_SMALL_CHUNK;
 	rasinfo = (struct GRDRASTER_INFO *) GMT_memory (VNULL, n_alloc, sizeof (struct GRDRASTER_INFO), GMT_program);
 	
@@ -765,7 +774,7 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 			return(0);
 		}
 		rasinfo[nfound].geo = (fabs (rasinfo[nfound].h.x_min) > 360.0 || fabs (rasinfo[nfound].h.x_max) > 360.0 || fabs (rasinfo[nfound].h.y_min) > 90.0 || fabs (rasinfo[nfound].h.y_max) > 90.0) ? FALSE : TRUE;
-		GMT_processed_option[8] = FALSE;
+		GMT->R.processed = FALSE;
 		/* Now find the -I string:  */
 		i = j+1;
 		while (i < length && (rasinfo[nfound].h.command[i] != '-') ) i++;
@@ -938,7 +947,7 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 			strcpy(rasinfo[nfound].h.remark, buf);
 		}
 		else {
-			sprintf(rasinfo[nfound].h.remark, "%s%c%s", dir, DIR_DELIM, buf);
+			sprintf(rasinfo[nfound].h.remark, "%s%s", dir, buf);
 		}
 
 		/* Decode SWAP flag or SKIP command, if present  */
@@ -994,7 +1003,7 @@ int	load_rasinfo(struct GRDRASTER_INFO **ras, char endian)
 		global_lon = 360.0 - (1 - rasinfo[nfound].h.node_offset)*rasinfo[nfound].h.x_inc;
 		lon_tol = 0.01 * rasinfo[nfound].h.x_inc;
 		global_lon -= lon_tol;	/* make sure we don't fail to find a truly global file  */
-		if (rasinfo[nfound].h.x_max - rasinfo[nfound].h.x_min >= global_lon) {
+		if (rasinfo[nfound].geo && rasinfo[nfound].h.x_max - rasinfo[nfound].h.x_min >= global_lon) {
 			rasinfo[nfound].nglobal = irint(360.0/rasinfo[nfound].h.x_inc);
 		}
 		else {
