@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: filter1d.c,v 1.33 2006/06/27 01:10:43 pwessel Exp $
+ *    $Id: filter1d.c,v 1.40 2007/03/31 18:06:32 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -147,7 +147,7 @@ int main (int argc, char **argv)
 {
 	BOOLEAN error = FALSE;
 	
-	char	c;
+	char	c, txt_a[GMT_TEXT_LEN], txt_b[GMT_TEXT_LEN];
 	char	buffer[BUFSIZ];		/* Used to scan input lines  */
 	
 	int	i, n_fields, n_expected_fields;
@@ -255,14 +255,18 @@ int main (int argc, char **argv)
 					Ctrl->S.value = atof (&argv[i][2]);
 					break;
 				case 'T':
-					if (sscanf (&argv[i][2], "%lf/%lf/%lf", &Ctrl->T.min, &Ctrl->T.max, &Ctrl->T.inc) != 3) {
+					if (sscanf (&argv[i][2], "%[^/]/%[^/]/%lf", txt_a, txt_b, &Ctrl->T.inc) != 3) {
 						fprintf (stderr, "%s: GMT SYNTAX ERROR -T option:  Syntax is -T<start>/<stop>/<inc>\n", GMT_program);
+						error++;
 					}
-					else
+					else {
+						GMT_scanf_arg (txt_a, GMT_IS_UNKNOWN, &Ctrl->T.min);
+						GMT_scanf_arg (txt_b, GMT_IS_UNKNOWN, &Ctrl->T.max);
 						Ctrl->T.active = TRUE;
+					}
 					break;
 				default:
-					error = TRUE;
+					error++;
                                         GMT_default_error (argv[i][1]);
 					break;
 			}
@@ -377,8 +381,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -557,6 +559,7 @@ int set_up_filter (struct FILTER1D_INFO *F)
 {
 	int	i, i1, i2;
 	double	t_0, t_1, time, w_sum;
+	char buffer[BUFSIZ];
 	BOOLEAN	normalize = FALSE;
 	PFD get_weight[3];		/* Selects desired weight function.  */
 
@@ -572,7 +575,11 @@ int set_up_filter (struct FILTER1D_INFO *F)
 		F->f_wt = (double *) GMT_memory (VNULL, (size_t)F->n_work_alloc, sizeof(double), GMT_program);
 		F->n_f_wts = 0;
 		w_sum = 0.0;
-		while (fscanf (F->fp_wt,"%lf\n", &F->f_wt[F->n_f_wts]) != EOF) {
+		while (GMT_fgets (buffer, BUFSIZ, F->fp_wt)) {
+			if (sscanf (buffer, "%lf", &F->f_wt[F->n_f_wts]) != 1) {
+				fprintf (stderr, "%s: Error decoding filter weights from file\n", GMT_program);
+				exit (EXIT_FAILURE);
+			}
 			w_sum += F->f_wt[F->n_f_wts];
 			F->n_f_wts++;
 			if (F->n_f_wts == F->n_work_alloc) {	/* Need more memory */
