@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt.h,v 1.136 2006/10/29 07:18:54 pwessel Exp $
+ *	$Id: gmt.h,v 1.146 2007/03/28 03:10:38 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,10 @@
  * Version:	4.x
  */
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifndef _GMT_H
 #define _GMT_H
 
@@ -34,6 +38,10 @@
 #define _POSIX_SOURCE 1
 #endif
 
+/* Activate the extended -JG option */
+
+#define _GENPER
+
 /* Declaration modifiers for DLL support (MSC et al) */
 
 #if defined(DLL_GMT)		/* define when library is a DLL */
@@ -188,6 +196,7 @@
 #define sind(x) sin ((x) * D2R)
 #define cosd(x) cos ((x) * D2R)
 #define tand(x) tan ((x) * D2R)
+#define sincosd(x,s,c) sincos((x) * D2R,s,c)
 
 /* Macros for swapping misc data types */
 
@@ -217,6 +226,14 @@
 #define PRINT_SIZE_T(fp,u) fprintf(fp, "%lu", (unsigned long)u)
 #endif
 
+/* Macro for exit since this should be returned when called from Matlab */
+
+#ifdef DO_NOT_EXIT
+#define GMT_exit(code) return(code)
+#else
+#define GMT_exit(code) exit(code)
+#endif
+
 /*--------------------------------------------------------------------
  *			GMT TYPEDEF DEFINITIONS
  *--------------------------------------------------------------------*/
@@ -481,11 +498,10 @@ EXTERN_MSC struct GMT_COMMON *GMT;
 
 EXTERN_MSC struct GMT_DEFAULTS gmtdefs;
 
-EXTERN_MSC int GMT_N_FONTS;				/* Number of fonts loaded from share/pslib */
-EXTERN_MSC char *GMTHOME;			/* Points to the GMT home directory with lib subdir */
+EXTERN_MSC int GMT_N_FONTS;			/* Number of fonts loaded from $GMT_SHAREDIR/pslib */
+EXTERN_MSC char *GMT_SHAREDIR;			/* Points to the GMT the shared data files */
 EXTERN_MSC char *GMT_HOMEDIR;			/* Points to the GMT user home directory [~] */
 EXTERN_MSC char *GMT_USERDIR;			/* Points to the GMT user .gmt directory [~/.gmt] */
-EXTERN_MSC char *GMT_CPTDIR;			/* Points to the GMT cpt directory [if set] */
 EXTERN_MSC char *GMT_DATADIR;			/* Points to the GMT misc directory [if set] */
 EXTERN_MSC char *GMT_GRIDDIR;			/* Points to the GMT grids directory [if set] */
 EXTERN_MSC char *GMT_IMGDIR;			/* Points to the GMT img directory [if set] */
@@ -500,9 +516,9 @@ EXTERN_MSC float GMT_f_NaN;		/* Holds IEEE not-a-number float */
 EXTERN_MSC double GMT_d_NaN;		/* Holds IEEE not-a-number double */
 EXTERN_MSC BOOLEAN GMT_give_synopsis_and_exit;		/* TRUE if short usage message is desired (must say program - ) */
 EXTERN_MSC char *GMT_program;		/* Name of current GMT program */
-EXTERN_MSC int GMT_no_rgb[];
 EXTERN_MSC int GMT_oldargc;
 EXTERN_MSC char *GMT_oldargv[];		/* Pointers to old common arguments */
+EXTERN_MSC int GMT_no_rgb[];
 EXTERN_MSC char *GMT_degree_symbol[4][3];	/* Contains the two octal codes for small and large degree symbols, for each char encoding */
 EXTERN_MSC char *GMT_minute_symbol[4][2];	/* Standard encoding minute symbol */
 EXTERN_MSC char *GMT_second_symbol[4][2];	/* Standard encoding second symbol */
@@ -519,11 +535,8 @@ EXTERN_MSC int GMT_n_file_suffix;
 EXTERN_MSC int *GMT_file_id;
 EXTERN_MSC double *GMT_file_scale, *GMT_file_offset, *GMT_file_nan;
 EXTERN_MSC char **GMT_file_suffix;
-EXTERN_MSC int GMT_fd_history;	/* File descriptor for .gmtcommands4 */
-EXTERN_MSC BOOLEAN GMT_lock;	/*T/F for advisory file locking */
 EXTERN_MSC int GMT_pad[4];
 EXTERN_MSC int GMT_inc_code[2];	/* For adjusting -R -I */
-EXTERN_MSC void check_nc_status (int status);
 EXTERN_MSC void nc_nopipe (char *file);
 
 /*--------------------------------------------------------------------*/
@@ -587,6 +600,7 @@ EXTERN_MSC PFD GMT_scan_time_string;		/*	pointer to functions that converts time
 #include "gmt_common.h"		/* For holding the GMT common option settings */
 #include "gmt_math.h"		/* Machine-dependent macros for non-POSIX math functions */
 #include "gmt_nan.h"		/* Machine-dependent macros for making and testing NaNs */
+#include "gmt_error.h"       	/* Only contains error codes */
 #include "gmt_synopsis.h"       /* Only contains macros for synopsis lines */
 #include "gmt_version.h"        /* Only contains the current GMT version number */
 #include "gmt_project.h"        /* Define project_info and frame_info structures */
@@ -608,3 +622,6 @@ EXTERN_MSC PFD GMT_scan_time_string;		/*	pointer to functions that converts time
 #include "gmt_vector.h"      	/* extern functions defined in gmt_vector.c */
 
 #endif  /* _GMT_H */
+#ifdef __cplusplus
+}
+#endif
