@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_colors.h,v 1.20 2006/04/10 04:43:31 pwessel Exp $
+ *	$Id: gmt_colors.h,v 1.23 2007/01/30 20:37:08 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
  * Date:	10-AUG-1995
  * Revised:	10-MAY-1998
  *		29-APR-2000 PW: Sped-up calculations of colors
- * Version:	3.4
+ * Version:	4.1.x
  */
 
 #ifndef _GMT_COLORS_H
@@ -80,12 +80,13 @@ EXTERN_MSC struct GMT_HASH GMT_rgb_hashnode[GMT_N_COLOR_NAMES];	/* Used to trans
 EXTERN_MSC struct GMT_LUT *GMT_lut;
 EXTERN_MSC struct GMT_BFN_COLOR GMT_bfn[3];
 EXTERN_MSC int GMT_n_colors;
+EXTERN_MSC int GMT_cpt_flags;
 EXTERN_MSC BOOLEAN GMT_gray;		/* TRUE if only grayshades are used */
 EXTERN_MSC BOOLEAN GMT_b_and_w;		/* TRUE if only black OR white is used */
 EXTERN_MSC BOOLEAN GMT_continuous;	/* TRUE if colors change continuously within slice */
 EXTERN_MSC BOOLEAN GMT_cpt_pattern;	/* TRUE if cpt file contains any patterns */
 EXTERN_MSC BOOLEAN GMT_cpt_skip;	/* TRUE if current z-slice is to be skipped */
 
-EXTERN_MSC void GMT_sample_cpt (double z[], int nz, BOOLEAN continuous, BOOLEAN reverse, int log_mode, int cpt_flag);
+EXTERN_MSC void GMT_sample_cpt (double z[], int nz, BOOLEAN continuous, BOOLEAN reverse, int log_mode);
 
 #endif /* _GMT_COLORS_H */
