@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_globals.h,v 1.10 2006/10/17 20:26:46 remko Exp $
+ *	$Id: gmt_globals.h,v 1.14 2007/01/31 21:51:03 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -169,12 +169,6 @@ PFI GMT_io_writegrd[GMT_N_GRD_FORMATS];
 double *GMT_file_scale, *GMT_file_offset, *GMT_file_nan;
 int *GMT_file_id;
 char **GMT_file_suffix;
-int GMT_fd_history = 0;	/* File descriptor for .gmtcommands4 */
-#ifdef NO_LOCK
-BOOLEAN GMT_lock = FALSE;
-#else
-BOOLEAN GMT_lock = TRUE;
-#endif
 double GMT_data[BUFSIZ];
 int GMT_pad[4] = {0, 0, 0, 0};
 int GMT_inc_code[2] = {0, 0};
@@ -184,10 +178,9 @@ int GMT_inc_code[2] = {0, 0};
 /*--------------------------------------------------------------------*/
 
 
-char *GMTHOME = CNULL;
+char *GMT_SHAREDIR = CNULL;
 char *GMT_HOMEDIR = CNULL;
 char *GMT_USERDIR = CNULL;
-char *GMT_CPTDIR = CNULL;
 char *GMT_DATADIR = CNULL;
 char *GMT_GRIDDIR = CNULL;
 char *GMT_IMGDIR = CNULL;
@@ -206,9 +199,9 @@ double GMT_u2u[4][4] = {
 };
 char *GMT_unit_names[4] = {"cm", "inch", "m", "point"};
 int GMT_no_rgb[3] = {-1, -1, -1};
-
 int GMT_oldargc;
 char *GMT_oldargv[GMT_N_UNIQUE];	/* Pointers to old common arguments */
+
 BOOLEAN GMT_give_synopsis_and_exit = FALSE;
 
 struct GMT_TIME_LANGUAGE GMT_time_language;	/* For time axis */
