@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_notunix.h,v 1.3.4.5 2004/01/02 22:23:11 pwessel Exp $
+ *	$Id: gmt_notunix.h,v 1.15 2007/01/30 20:37:08 pwessel Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@
  *
  * Author:	Paul Wessel
  * Date:	09-NOV-1999
- * Version:	3.4.3
+ * Version:	4.1.x
  *
  */
 
@@ -52,7 +52,7 @@
  *
  *	   W I N D O W S   1 9 9 5,  1 9 9 8,  2 0 0 0,  N T
  *
- *	 THis section applies to Microsoft Windows 95, 98, NT
+ *	 This section applies to Microsoft Windows 95, 98, NT
  *
  *--------------------------------------------------------------------*/
 
@@ -85,6 +85,8 @@
 #define HAVE_YN 1
 #define HAVE_ERF 0
 #define HAVE_ERFC 0
+#define HAVE_STRDUP 1
+#define HAVE_STRTOD 1
 #define HAVE_SINCOS 0
 #define HAVE_ALPHASINCOS 0
 #define WORDS_BIGENDIAN 0
@@ -100,6 +102,8 @@
 #define y0(x) _y0(x)
 #define y1(x) _y1(x)
 #define yn(n,x) _yn(n,x)
+#define strdup(s) _strdup(s)
+#define STAT _stat
 
 /* WIN32 versus _WIN32:
  *
@@ -143,8 +147,8 @@ struct passwd {
 /* These two functions prototypes are normally in pwd.h & unistd.h;
  * Here, they are defined as dummies at the bottom of gmt_init.c */
 
-struct passwd *getpwuid (const int uid);
-int getuid (void);
+EXTERN_MSC struct passwd *getpwuid (const int uid);
+EXTERN_MSC int getuid (void);
 
 /* getcwd is usually in unistd.h; we use a macro here
  * since the same function under WIN32 is prefixed with _ */
@@ -208,6 +212,8 @@ EXTERN_MSC void GMT_setmode (int i_or_o);
 #define HAVE_YN 1
 #define HAVE_ERF 1
 #define HAVE_ERFC 1
+#define HAVE_STRDUP 1
+#define HAVE_STRTOD 1
 #define HAVE_SINCOS 0
 #define HAVE_ALPHASINCOS 0
 #define WORDS_BIGENDIAN 0
@@ -217,6 +223,7 @@ EXTERN_MSC void GMT_setmode (int i_or_o);
 #define NO_LOCK		/* Do not support file locking */
 #define SET_IO_MODE	/* Need to force binary i/o upon request */
 #define NO_FCNTL	/* fcntl.h does not exist here */
+#define STAT _stat
 
 EXTERN_MSC void GMT_setmode (int i_or_o);
 
@@ -255,4 +262,8 @@ EXTERN_MSC void GMT_setmode (int i_or_o);
 #include <fcntl.h>
 #endif
 
+#ifndef STAT
+#define STAT stat
+#endif
+
 #endif /* _GMT_NOTUNIX_H */
