@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_stat.c,v 1.42 2006/10/27 23:45:23 pwessel Exp $
+ *	$Id: gmt_stat.c,v 1.47 2007/04/02 22:25:29 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -1252,9 +1252,6 @@ int     GMT_f_q (double chisq1, int nu1, double chisq2, int nu2, double *prob)
 		I decided to go back to the GMT_inc_beta way of doing things.
 
 	*/
-		double	t, p, x, y, theta, term, sum, c, s, csq, ssq;
-		int	kt, kb, k, kstop;
-
 
 	/* Check range of arguments:  */
 
@@ -1282,162 +1279,9 @@ int     GMT_f_q (double chisq1, int nu1, double chisq2, int nu2, double *prob)
 		fprintf(stderr,"GMT_q_p:  Trouble in GMT_inc_beta call.\n");
 		return(-1);
 	}
-	return(0);	/* REVISION Oct 27, 2000:  All code below here is not used.  */
-
-	/* If nu1 == 1, sqrt(F) is distributed as Student's t;
-		if nu2 == 1, use reflexive property to swap 1 and 2.  */
-
-	if (nu1 == 1) {
-		t = sqrt(nu2 * chisq1 / chisq2);
-		if (GMT_student_t_a(t, nu2, &p) ) {
-			fprintf (stderr, "GMT_f_q:  Error calling GMT_student_t_a()\n");
-			return (-1);
-		}
-		*prob = 1.0 - p;
-	}
-	else if (nu2 == 1) {
-		t = sqrt(nu1 * chisq2 / chisq1);
-		if (GMT_student_t_a(t, nu1, &p) ) {
-			fprintf (stderr, "GMT_f_q:  Error calling GMT_student_t_a()\n");
-			return (-1);
-		}
-		*prob = p;
-	}
-
-	/* if nu1 == nu2, this reduces to a case of Student's t by using
-		A & S 26.5.14 and swapping chisq1, chisq2 if needed, using
-		the reflexive property:  */
-
-	else if (nu1 == nu2) {
-		t = 0.5 * fabs(chisq1 - chisq2) * sqrt(nu1/(chisq1*chisq2));
-		GMT_student_t_a(t, nu1, &p);
-		if (chisq1 >= chisq2) {
-			*prob = 0.5 * (1.0 - p);
-		}
-		else {
-			*prob = 0.5 * (1.0 + p);
-		}
-	}
-
-	/* General cases  */
-
-	else if (nu1%2 == 1) {
-		if (nu2%2 == 1) {
-			/* Both odd.  Use Abramowitz and Stegun 26.6.8  */
-			theta = atan(sqrt(chisq1/chisq2));
-			sincos (theta, &s, &c);
-			csq = c * c;
-			ssq = s * s;
-
-			term = 1.0;
-			sum = 1.0;
-			kt = nu2 - 1;
-			kb = 1;
-			k = 0;	/* k is the power on sin in the sum  */
-			while (k < nu1 - 3) {
-				k += 2;
-				kt += 2;
-				kb += 2;
-				term *= (kt * ssq)/kb;
-				sum += term;
-			}
-
-			term = 2.0 * s * c / M_PI;
-			kt = 0;
-			kb = -1;
-			k = 1;
-			while (k < nu2) {
-				k += 2;
-				kt += 2;
-				kb += 2;
-				term *= (kt * csq)/kb;
-			}
-
-			t = sqrt(nu2 * chisq1 / chisq2);
-			if (GMT_student_t_a(t, nu2, &p) ) {
-				fprintf (stderr, "GMT_f_q:  Error calling GMT_student_t_a()\n");
-				return (-1);
-			}
-
-			*prob = 1.0 - p + term * sum;
-		}
-		else {
-
-			/* Get here when nu2 is even and both are greater than 1.
-				Use Abramowitz and Stegun 26.6.5  */
-
-			x = chisq2 / (chisq1 + chisq2);
-			y = chisq1 / (chisq1 + chisq2);		/* y = 1 - x  */
-			kstop = (nu2 - 2)/2;
-			k = 0;
-			term = 1.0;
-			sum = 1.0;
-			kt = nu1 - 2;
-			kb = 0;
-			while (k < kstop) {
-				k++;
-				kt += 2;
-				kb += 2;
-				term *= (kt * x)/kb;
-				sum += term;
-			}
-
-			term = sqrt(y);
-			k = 0;
-			kstop = (nu1 - 1)/2;
-			while (k < kstop) {
-				k++;
-				term *= y;
-			}
-
-			*prob = 1.0 - term * sum;
-		}
-	}
-	else {
-		/* nu1 is even.  Use Abramowitz & Stegun 26.6.4  */
-
-		x = chisq2 / (chisq1 + chisq2);
-		y = chisq1 / (chisq1 + chisq2);		/* y = 1 - x  */
-		kstop = (nu1 - 2)/2;
-		k = 0;
-		term = 1.0;
-		sum = 1.0;
-		kt = nu2 - 2;
-		kb = 0;
-		while (k < kstop) {
-			k++;
-			kt += 2;
-			kb += 2;
-			term *= (kt * y)/kb;
-			sum += term;
-		}
-
-		if (nu2%2) {
-			kstop = (nu2 - 1)/2;
-			term = sqrt(x);
-		}
-		else {
-			kstop = nu2/2;
-			term = 1.0;
-		}
-		k = 0;
-		while (k < kstop) {
-			k++;
-			term *= x;
-		}
-
-		*prob = term * sum;
-	}
-
-	/* Get here when prob has been assigned.  Adjust range
-		in case it went slightly out due to roundoff:  */
-
-	if (*prob < 0.0) *prob = 0.0;
-	if (*prob > 1.0) *prob = 1.0;
 	return (0);
 }
 
-
 int	GMT_student_t_a(double t, int n, double *prob)
 {
 	/* Probability integral called A(t,n) by Abramowitz &
@@ -2267,7 +2111,7 @@ int GMT_median (double *x, size_t n, double xmin, double xmax, double m_initial,
 		}
 		else {	/* If we get here, I made a mistake!  */
 			fprintf (stderr,"%s: GMT Fatal Error: Internal goof - please report to developers!\n", GMT_program);
-			exit (EXIT_FAILURE);
+			GMT_exit (EXIT_FAILURE);
 		}
 
 	} while (!finished);
@@ -2576,44 +2420,40 @@ double GMT_extreme (double x[], size_t n, double x_default, int kind, int way)
 	return ((k) ? x_select : x_default);
 }
 
-double GMT_chebyshev (double x, int n)
+int GMT_chebyshev (double x, int n, double *t)
 {
 	/* Calculates the n'th Chebyshev polynomial at x */
 
-	double t, x2;
+	double x2, a, b;
 	
-	if (n < 0) {
-		fprintf (stderr, "GMT: ERROR.  GMT_chebyshev given negative degree (%d)\n", n);
-		exit (EXIT_FAILURE);
-	}
-	if (fabs (x) > 1.0) {
-		fprintf (stderr, "GMT: ERROR.  GMT_chebyshev given |x| > 1 (%f)\n", x);
-		exit (EXIT_FAILURE);
-	}
+	if (n < 0) GMT_err_pass (GMT_CHEBYSHEV_NEG_ORDER, "");
+	if (fabs (x) > 1.0) GMT_err_pass (GMT_CHEBYSHEV_BAD_DOMAIN, "");
 	
 	switch (n) {	/* Testing the order of the polynomial */
 		case 0:
-			t = 1.0;
+			*t = 1.0;
 			break;
 		case 1:
-			t = x;
+			*t = x;
 			break;
 		case 2:
-			t = 2.0 * x * x - 1.0;
+			*t = 2.0 * x * x - 1.0;
 			break;
 		case 3:
-			t = x * (4.0 * x * x - 3.0);
+			*t = x * (4.0 * x * x - 3.0);
 			break;
 		case 4:
 			x2 = x * x;
-			t = 8.0 * x2 * (x2 - 1.0) + 1.0;
+			*t = 8.0 * x2 * (x2 - 1.0) + 1.0;
 			break;
 		default:	/* For higher degrees we do the recursion */
-			t = 2.0 * x * GMT_chebyshev (x, n-1) - GMT_chebyshev (x, n-2);
+			GMT_chebyshev (x, n-1, &a);
+			GMT_chebyshev (x, n-2, &b);
+			*t = 2.0 * x * a - b;
 			break;
 	}
 	
-	return (t);
+	return (GMT_NOERROR);
 }
 
 double GMT_corrcoeff (double *x, double *y, size_t n, int mode)
