@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtconvert.c,v 1.38 2006/04/13 06:20:35 pwessel Exp $
+ *	$Id: gmtconvert.c,v 1.47 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -37,10 +37,11 @@ struct GMTCONVERT_CTRL {
 	} A;
 	struct D {	/* -D[<template>] */
 		BOOLEAN active;
-		char *template;
+		char *name;
 	} D;
 	struct E {	/* -E */
 		BOOLEAN active;
+		int mode;
 	} E;
 	struct F {	/* -F<cols> */
 		BOOLEAN active;
@@ -103,11 +104,17 @@ int main (int argc, char **argv)
 					Ctrl->A.active = TRUE;
 					break;
 				case 'D':               /* Write each segment to a separate output file */
-					if (argv[i][2]) Ctrl->D.template = strdup (&argv[i][2]);
+					if (argv[i][2]) Ctrl->D.name = strdup (&argv[i][2]);
 					Ctrl->D.active = TRUE;
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
+					if (argv[i][2] == 'f')		/* Get first point only */
+						Ctrl->E.mode = 1;
+					else if (argv[i][2] == 'l')	/* Get last point only */
+						Ctrl->E.mode = 2;
+					else				/* Get first and point only */
+						Ctrl->E.mode = 3;
 					break;
 				case 'F':
 					pos = 0;
@@ -153,8 +160,8 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "gmtconvert %s - Convert format, Paste, and/or Extract columns from table data\n\n", GMT_VERSION);
-		fprintf(stderr,"usage:	gmtconvert [files] [-A] [-D[<template>]] [-E] [-F<cols>] [%s] [-I]\n", GMT_H_OPT);
-		fprintf(stderr,"\t[%s] [-N] [-S\"search string\"] [-V] [%s]\n\t[%s] [%s]\n\n", GMT_M_OPT, GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
+		fprintf(stderr,"usage:	gmtconvert [files] [-A] [-D[<template>]] [-E[f|l]] [-F<cols>] [%s] [-I]\n", GMT_H_OPT);
+		fprintf(stderr,"\t[-L] [%s] [-N] [-S\"search string\"] [-V] [%s]\n\t[%s] [%s]\n\n", GMT_M_OPT, GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -164,6 +171,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Append file name template which MUST contain a C-format specified for an integer (e.g., %%d).\n");
 		fprintf (stderr, "\t   [Default uses gmtconvert_segment_%%d.d]\n");
 		fprintf (stderr, "\t-E Extract first and last point per segment only [Default outputs all points]\n");
+		fprintf (stderr, "\t   Append f for first only or l for last only\n");
 		fprintf(stderr,"\t-F Give comma-separated list of desired columns or ranges (0 is first column) [Default is all]\n");
 		GMT_explain_option ('H');
 		fprintf (stderr,"\t-I Invert order of rows, i.e., outputting in reverse order\n");
@@ -192,14 +200,12 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  -L or -S requires multisegment files\n", GMT_program);
 		error++;
 	}
-	if (Ctrl->D.active && Ctrl->D.template && !strstr (Ctrl->D.template, "%")) {
+	if (Ctrl->D.active && Ctrl->D.name && !strstr (Ctrl->D.name, "%")) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  output template must contain %%d\n", GMT_program);
 		error++;
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -211,7 +217,7 @@ int main (int argc, char **argv)
 	on = (Ctrl->L.active) ? FALSE : TRUE;
 	ascii_in_bin_out = (!GMT_io.binary[GMT_IN] && GMT_io.binary[GMT_OUT]);
 	fp_out = (Ctrl->D.active) ? NULL : GMT_stdout;
-	if (Ctrl->D.active && !Ctrl->D.template) Ctrl->D.template = strdup ("gmtconvert_segment_%d.d");
+	if (Ctrl->D.active && !Ctrl->D.name) Ctrl->D.name = strdup ("gmtconvert_segment_%d.d");
 	out_seg = -1;
 
 	if (Ctrl->A.active) {	/* Do paste and probably cut as well */
@@ -303,7 +309,7 @@ int main (int argc, char **argv)
 					n_hdr_delay++;
 				else if (Ctrl->D.active) {
 					out_seg++;
-					sprintf (filename, Ctrl->D.template, out_seg);
+					sprintf (filename, Ctrl->D.name, out_seg);
 					if (fp_out != NULL) GMT_fclose (fp_out);
 					if ((fp_out = GMT_fopen (filename, GMT_io.w_mode)) == NULL ) {
 						fprintf (stderr, "%s: Error creating file %s\n", GMT_program, filename);
@@ -449,13 +455,13 @@ int main (int argc, char **argv)
 			while (! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
 				while (GMT_io.status & GMT_IO_SEGMENT_HEADER && !(GMT_io.status & GMT_IO_EOF)) {
-					if (Ctrl->E.active && n_in_seg > 0) fprintf (GMT_stdout, "%s", record_str);
+					if (Ctrl->E.active && (Ctrl->E.mode & 2) && n_in_seg > 0) fprintf (GMT_stdout, "%s", record_str);	/* Previous segments last point */
 					if (Ctrl->S.active) on = (strstr (GMT_io.segment_header, Ctrl->S.pattern) != NULL);	/* If match then we turn output ON */
 					if (ascii_in_bin_out && n_out == 0)
 						n_hdr_delay++;	/* Unable to write header yet since we dont know the field count... */
 					else if ((Ctrl->L.active || on) && Ctrl->D.active) {
 						out_seg++;
-						sprintf (filename, Ctrl->D.template, out_seg);
+						sprintf (filename, Ctrl->D.name, out_seg);
 						if (fp_out != NULL) GMT_fclose (fp_out);
 						if ((fp_out = GMT_fopen (filename, GMT_io.w_mode)) == NULL ) {
 							fprintf (stderr, "%s: Error creating file %s\n", GMT_program, filename);
@@ -506,7 +512,7 @@ int main (int argc, char **argv)
 						}
 					}
 					else if (Ctrl->E.active) {
-						if (n_in_seg == 0) fprintf (GMT_stdout, "%s", GMT_io.current_record);
+						if (n_in_seg == 0 && (Ctrl->E.mode & 1)) fprintf (GMT_stdout, "%s", GMT_io.current_record);
 						strcpy (record_str, GMT_io.current_record);
 						n_in_seg++;
 					}
@@ -518,7 +524,7 @@ int main (int argc, char **argv)
 					n_fields = GMT_input (fp, &n_expected_fields, &in);
 				}
 			}
-			if (Ctrl->E.active && n_in_seg > 1) fprintf (GMT_stdout, "%s", record_str);
+			if (Ctrl->E.active && (Ctrl->E.mode & 2) && n_in_seg > 0) fprintf (GMT_stdout, "%s", record_str);
 
 			if (fp != GMT_stdin) GMT_fclose(fp);
 		}
