@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtdefaults.c,v 1.9 2004/01/02 22:45:13 pwessel Exp $
+ *	$Id: gmtdefaults.c,v 1.21 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,23 +21,24 @@
  *
  * Author:	Paul Wessel
  * Date:	12-JUL-2000
- * Version:	3.4
+ * Version:	4.0
  */
  
+#define GMT_WITH_NO_PS
 #include "gmt.h"
 
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
-	int i, get;
-	
+	int i, get = 0;
+
 	BOOLEAN error = FALSE, get_sys_defaults = FALSE, get_user_defaults = FALSE;
-	
+
 	char *path;
-	
+
 	for (i = strlen(argv[0]); i >= 0 && argv[0][i] != '/'; i--);
 	GMT_program = &argv[0][i+1];	/* Name without full path */
 	GMT_set_home ();
-	GMT_init_fonts (&N_FONTS);
+	GMT_init_fonts (&GMT_N_FONTS);
 
 	GMT_stdout = stdout;	GMT_stdin = stdin;
 
@@ -45,7 +46,7 @@ main (int argc, char **argv)
 		if (argv[i][0] != '-') continue;
 		switch (argv[i][1]) {
 			case '\0':
-				error += GMT_get_common_args (argv[i], 0, 0, 0, 0);
+				error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 				break;
 			case 'D':	/* Get GMT defaults settings */
 				get_sys_defaults = TRUE;
@@ -73,34 +74,34 @@ main (int argc, char **argv)
 				break;
 		}
 	}
-	
-	if (argc == 1 || GMT_quick) {
+
+	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "gmtdefaults %s - List GMT-SYSTEM default parameters to stdout\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: gmtdefaults [-D[s|u] | -L]\n\n");
-		if (GMT_quick) exit (EXIT_FAILURE);
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 		fprintf (stderr, "\t-D prints the default settings for the GMT system\n");
 		fprintf (stderr, "\t   Append s to see the SI version of defaults\n");
 		fprintf (stderr, "\t   Append u to see the US version of defaults\n");
 		fprintf (stderr, "\t-L prints the users current GMT default settings\n");
 		exit (EXIT_FAILURE);
 	}
-	
+
 	if ((get_user_defaults + get_sys_defaults) != 1) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR: Must specify one of -D or -L\n", GMT_program);
 		error++;
 	}
-	
+
 	if (error) exit (EXIT_FAILURE);
-	
+
 	if (get_user_defaults) {
 		GMT_getdefaults (CNULL);
 	}
 	else {
-		path = GMT_getdefpath (get);
+		GMT_getdefpath (get, &path);
 		GMT_getdefaults (path);
 		GMT_free (path);
 	}
-	
+
 	GMT_savedefaults (CNULL);
 
 	exit (EXIT_SUCCESS);
