@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtselect.c,v 1.71 2006/05/14 23:31:46 pwessel Exp $
+ *	$Id: gmtselect.c,v 1.80 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -105,7 +105,7 @@ struct GMTSELECT_CTRL {	/* All control options for this program (except common a
 
 int main (int argc, char **argv)
 {
-	int i, j, k, fno, n_read = 0, n_pass = 0, n_files = 0, n_args;
+	int i, j, k, fno, n_read = 0, n_pass = 0, n_files = 0, n_args, err;
 	int n_fields, n_expected_fields, ind, bin, last_bin = -1, n_output = -1;
 	int np[2], base = 3, wd[2], id, this_node, side, is_inside, row, col, pos;
 
@@ -365,8 +365,6 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (Ctrl->C.active && !GMT_IS_MAPPING && !(GMT_io.in_col_type[0] == GMT_IS_LON && GMT_io.in_col_type[1] == GMT_IS_LAT)) cartesian = TRUE;
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
@@ -396,23 +394,25 @@ int main (int argc, char **argv)
 		else
 			do_project = TRUE;	/* Only TRUE when the USER selected -J, not when we supply dummy -Jx1d */
 		step = 0.01;
-		if (project_info.degree[0]) {
+		if (GMT_io.in_col_type[0] == GMT_IS_LON) {
 			if (west < 0.0 && east < 0.0) {
 				west += 360.0;
 				east += 360.0;
 			}
 			greenwich = (west < 0.0 && east > 0.0);
 		}
-		GMT_map_setup (west, east, south, north);
+		GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 	}
 
+	if (do_project && gmtdefs.verbose) fprintf (stderr, "%s: Warning: -J means all data will be projected before tests are applied\n", GMT_program);
+	 
 	if (Ctrl->N.active) {
 		if (Ctrl->D.active) base = GMT_set_resolution (&Ctrl->D.set, 'D');
 		if (dry_wet_only) {	/* Post-process -N choice */
 			Ctrl->N.mask[3] = Ctrl->N.mask[1];
 			Ctrl->N.mask[2] = Ctrl->N.mask[4] = Ctrl->N.mask[0];
 		}
-		if (GMT_init_shore (Ctrl->D.set, &c, west, east, south, north))  {
+		if (GMT_init_shore (Ctrl->D.set, &c, west, east, south, north)) {
 			fprintf (stderr, "%s: %s resolution shoreline data base not installed\n", GMT_program, shore_resolution[base]);
 			exit (EXIT_FAILURE);
 		}
@@ -652,7 +652,10 @@ int main (int argc, char **argv)
 					while (ind < c.nb && c.bins[ind] != bin) ind++;	/* Set ind to right bin */
 					if (ind == c.nb) continue;			/* Bin not among the chosen ones */
 					last_bin = bin;
-					GMT_get_shore_bin (ind, &c, Ctrl->A.area, Ctrl->A.low, Ctrl->A.high);
+					if ((err = GMT_get_shore_bin (ind, &c, Ctrl->A.area, Ctrl->A.low, Ctrl->A.high))) {
+						fprintf (stderr, "%s: %s [%s resolution shoreline]\n", GMT_program, GMT_strerror(err), shore_resolution[base]);
+						exit (EXIT_FAILURE);
+					}
 
 					/* Must use polygons.  Go in both directions to cover both land and sea */
 					for (id = 0; id < 2; id++) {
