@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdclip.c,v 1.6 2004/01/02 22:45:13 pwessel Exp $
+ *	$Id: grdclip.c,v 1.19 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,64 +29,79 @@
  
  */
 
-
 #include "gmt.h"
 
-float *data;
+struct GRDCLIP_CTRL {
+	struct G {	/* -G<output_grdfile> */
+		BOOLEAN active;
+		char *file;
+	} G;
+	struct SA {	/* -Sa<high/above> */
+		BOOLEAN active;
+		float high, above;
+	} Sa;
+	struct SB {	/* -Sb<low/below> */
+		BOOLEAN active;
+		float low, below;
+	} Sb;
+};
 
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
-
-	BOOLEAN	error, set_above, set_below;
+	BOOLEAN	error;
+	
+	char *infile = CNULL, format[BUFSIZ], txt[50];
 
 	int i, nxy, n_above, n_below, n;
-
-	float	above, below, low, high;
-
-	char *infile, *outfile, format[BUFSIZ], txt[50];
-
+	
+	float	*data;
+	
 	struct GRD_HEADER header;
+	struct GRDCLIP_CTRL *Ctrl;
 
+	void *New_Grdclip_Ctrl (), Free_Grdclip_Ctrl (struct GRDCLIP_CTRL *C);
+	
 	argc = GMT_begin (argc, argv);
 
-	error = set_above = set_below = FALSE;
+	Ctrl = (struct GRDCLIP_CTRL *) New_Grdclip_Ctrl ();	/* Allocate and initialize a new control structure */
+	
+	error = FALSE;
 	n_above = n_below = 0;
-	low = high = 0.0;
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
 				/* Common parameters */
-			
+
 				case 'V':
 				case '\0':
-					error += GMT_get_common_args (argv[i], 0, 0, 0, 0);
+					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
-				
+
 				/* Supplemental parameters */
-			
+
 				case 'S':
 					if (argv[i][2] == 'a') {
-						set_above = TRUE;
-						n = sscanf (&argv[i][3], "%f/%s", &high, txt);
+						Ctrl->Sa.active = TRUE;
+						n = sscanf (&argv[i][3], "%f/%s", &Ctrl->Sa.high, txt);
 						if (n != 2) {
 							fprintf (stderr, "%s: GMT SYNTAX ERROR -Sa option.  Correct syntax:\n", GMT_program);
 							fprintf (stderr, "\t-Sa<high>/<above>, <above> may be set to NaN\n");
 							error = TRUE;
 						}
 						else 
-							above = (txt[0] == 'N' || txt[0] == 'n') ? GMT_f_NaN : (float)atof (txt);
+							Ctrl->Sa.above = (txt[0] == 'N' || txt[0] == 'n') ? GMT_f_NaN : (float)atof (txt);
 					}
 					else if (argv[i][2] == 'b') {
-						set_below = TRUE;
-						n = sscanf (&argv[i][3], "%f/%s", &low, txt);
+						Ctrl->Sb.active = TRUE;
+						n = sscanf (&argv[i][3], "%f/%s", &Ctrl->Sb.low, txt);
 						if (n != 2) {
 							fprintf (stderr, "%s: GMT SYNTAX ERROR -Sb option.  Correct syntax:\n", GMT_program);
 							fprintf (stderr, "\t-Sb<low>/<below>, <below> may be set to NaN\n");
 							error = TRUE;
 						}
 						else
-							below = (txt[0] == 'N' || txt[0] == 'n') ? GMT_f_NaN : (float)atof (txt);
+							Ctrl->Sb.below = (txt[0] == 'N' || txt[0] == 'n') ? GMT_f_NaN : (float)atof (txt);
 					}
 					else {
 						fprintf (stderr, "%s: GMT SYNTAX ERROR -S option.  Correct syntax:\n", GMT_program);
@@ -95,7 +110,8 @@ main (int argc, char **argv)
 					}
 					break;
 				case 'G':
-					outfile = &argv[i][2];
+					Ctrl->G.active = TRUE;
+					Ctrl->G.file = strdup (&argv[i][2]);
 					break;
 
 				default:
@@ -107,14 +123,14 @@ main (int argc, char **argv)
 		else
 			infile = argv[i];
 	}
-	
-	if (GMT_quick || argc == 1) {
+
+	if (GMT_give_synopsis_and_exit || argc == 1) {
 		fprintf (stderr, "grdclip %s - Clipping of range in grdfiles\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdclip <input_grdfile> -G<output_grdfile>\n");
 		fprintf (stderr, "\t[-Sa<high/above>] [-Sb<low/below>] [-V]\n");
-		
-		if (GMT_quick) exit (EXIT_FAILURE);
-		
+
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
+
 		fprintf (stderr, "\tYou must choose at least one -S option.\n");
 		fprintf (stderr, "\t-G name of output grid.\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
@@ -126,7 +142,7 @@ main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (!outfile) {
+	if (!Ctrl->G.file) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G option:.  Must specify output file\n", GMT_program);
 		error++;
 	}
@@ -134,56 +150,63 @@ main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:.  Must specify input file\n", GMT_program);
 		error++;
 	}
-	
+
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
+	GMT_err_fail (GMT_read_grd_info (infile, &header), infile);
 
-		
-	if (GMT_read_grd_info (infile, &header)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, infile);
-		exit (EXIT_FAILURE);
-	}
-	
 	GMT_grd_init (&header, argc, argv, TRUE);
-	
+
 	nxy = header.nx * header.ny;
 	data = (float *) GMT_memory (VNULL, (size_t)nxy, sizeof (float), GMT_program);
-	
-	if (GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, infile);
-		exit (EXIT_FAILURE);
-	}
-	
+
+	GMT_err_fail (GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), infile);
+
 	for (i = 0; i < nxy; i++) {
-		if (set_above && (!GMT_is_fnan (data[i])) && data[i] > high) {
-			data[i] = above;
+		if (Ctrl->Sa.active && (!GMT_is_fnan (data[i])) && data[i] > Ctrl->Sa.high) {
+			data[i] = Ctrl->Sa.above;
 			n_above++;
 		}
-		else if (set_below && (!GMT_is_fnan (data[i])) && data[i] < low) {
-			data[i] = below;
+		else if (Ctrl->Sb.active && (!GMT_is_fnan (data[i])) && data[i] < Ctrl->Sb.low) {
+			data[i] = Ctrl->Sb.below;
 			n_below++;
 		}
 	}
-	
-	if (GMT_write_grd (outfile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, infile);
-		exit (EXIT_FAILURE);
-	}
-	
+
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
+
 	GMT_free ((void *) data);
 
 	if (gmtdefs.verbose) {
 		sprintf (format, "%s set to %s\n", gmtdefs.d_format, gmtdefs.d_format);
-		if (set_below) {
+		if (Ctrl->Sb.active) {
 			fprintf (stderr, "%s: %d values < ", GMT_program, n_below);
-			fprintf (stderr, format, (double)low, (double)below);
+			fprintf (stderr, format, (double)Ctrl->Sb.low, (double)Ctrl->Sb.below);
 		}
-		if (set_above) {
+		if (Ctrl->Sa.active) {
 			fprintf (stderr, "%s: %d values > ", GMT_program, n_above);
-			fprintf (stderr, format, (double)high, (double)above);
+			fprintf (stderr, format, (double)Ctrl->Sa.high, (double)Ctrl->Sa.above);
 		}
 	}
-	
+
+	Free_Grdclip_Ctrl (Ctrl);	/* Deallocate control structure */
+
 	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
+}
+
+void *New_Grdclip_Ctrl () {	/* Allocate and initialize a new control structure */
+	struct GRDCLIP_CTRL *C;
+	
+	C = (struct GRDCLIP_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GRDCLIP_CTRL), "New_Grdclip_Ctrl");
+	
+	/* Initialize values whose defaults are not 0/FALSE/NULL */
+			
+	return ((void *)C);
+}
+
+void Free_Grdclip_Ctrl (struct GRDCLIP_CTRL *C) {	/* Deallocate control structure */
+	if (C->G.file) GMT_free ((void *)C->G.file);	
+	GMT_free ((void *)C);	
 }
