@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c,v 1.94 2006/10/30 18:09:29 pwessel Exp $
+ *	$Id: grdcontour.c,v 1.111 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
  * Revised:	25-FEB-2000 for GMT 3.3.4
  * Revised:	25-JUN-2000 for GMT 3.3.5
  * Version:	3.4 Added Kaj Jancke's modification for transparent label boxes
- * Version:	4.0 15-JUL-2004 Implemented label clipping in PostScript. Expeanded -G option
+ * Version:	4.0 15-JUL-2004 Implemented label clipping in PostScript. Expanded -G option
  * Version:	4.1.x
  *
  */
@@ -64,6 +64,10 @@ struct GRDCONTOUR_CTRL {
 		BOOLEAN active;
 		double azimuth, elevation;
 	} E;
+	struct F {	/* -F<way> */
+		BOOLEAN active;
+		int value;
+	} F;
 	struct G {	/* -G[d|f|n|l|L|x|X]<params> */
 		BOOLEAN active;
 	} G;
@@ -118,7 +122,7 @@ int main (int argc, char **argv)
 	char cont_label[GMT_LONG_TEXT], format[GMT_LONG_TEXT];
 
 	double aval, west = 0.0, east = 0.0, south = 0.0, north = 0.0, *xp, *yp;
-	double *contour, cval, min, max, small, label_angle = 0.0, xyz[2][3];
+	double *contour, cval, min, max, small, xyz[2][3];
 	double small_x, small_y, data_west, data_east, data_south, data_north, tmp, *cont_angle;
 	double *x, *y;	/* Arrays holding the contour xy values */
 
@@ -187,7 +191,7 @@ int main (int argc, char **argv)
 					Ctrl->C.active = TRUE;
 					if (!GMT_access (&argv[i][2], R_OK)) {	/* Gave a readable file */
 						Ctrl->C.interval = 1.0;
-						Ctrl->C.cpt = (strstr (&argv[i][2], ".cpt") != NULL) ? TRUE : FALSE;
+						Ctrl->C.cpt = (!strncmp (&argv[i][strlen(argv[i])-4], ".cpt", 4)) ? TRUE : FALSE;
 						Ctrl->C.file = strdup (&argv[i][2]);
 					}
 					else
@@ -202,6 +206,23 @@ int main (int argc, char **argv)
 					Ctrl->E.active = TRUE;
 					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
+				case 'F':
+					Ctrl->F.active = TRUE;
+					switch (argv[i][2]) {
+						case '\0':
+						case 'l':
+						case 'L':
+							Ctrl->F.value = -1;
+							break;
+						case 'R':
+						case 'r':
+							Ctrl->F.value = +1;
+							break;
+						default:
+							fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Correct syntax is -F[l|r]:\n", GMT_program);
+							break;
+					}
+					break;
 				case 'G':
 					Ctrl->G.active = TRUE;
 					error += GMT_contlabel_info ('G', &argv[i][2], &Ctrl->contour);
@@ -310,7 +331,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"grdcontour %s - Contouring of 2-D gridded data sets\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdcontour <grdfile> -C<cont_int> %s\n", GMT_J_OPT);
-		fprintf (stderr, "\t[-A[-|<annot_int>][<labelinfo>] [%s] [-D<dumpfile>] [-Eazimuth/elevation] [%s]\n", GMT_B_OPT, GMT_CONTG);
+		fprintf (stderr, "\t[-A[-|<annot_int>][<labelinfo>] [%s] [-D<dumpfile>] [-Eazimuth/elevation] [-F[l|r]] [%s]\n", GMT_B_OPT, GMT_CONTG);
 		fprintf (stderr, "\t[-K] [-L<Low/high>] [%s] [-O] [-P] [-Q<cut>] [%s] [-S<smooth>]\n", GMT_Mo_OPT, GMT_Rgeo_OPT);
 		fprintf (stderr, "\t[-T[+|-][<gap>[c|i|m|p]/<length>[c|i|m|p]][:LH]] [%s] [-V] [-W[+]<type><pen>]\n", GMT_U_OPT);
 		fprintf (stderr, "\t[%s] [%s] [-Z[<fact>[/shift>]][p]] [%s] [%s]\n\n", GMT_X_OPT, GMT_Y_OPT, GMT_bo_OPT, GMT_c_OPT);
@@ -338,6 +359,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   _i is inserted for interior (closed) contours, with xyz (ascii) or b (binary) as extension.\n");
 		fprintf (stderr, "\t   However, if -D- is given then files are C#_e or C#_i plus extension, where # is a running number.\n");
 		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
+		fprintf (stderr, "\t-F force dumped contours to be oriented so that the higher z-values are to the left (-Fl [Default])\n");
+		fprintf (stderr, "\t   or right (-Fr) as we move along the contour [Default is not oriented]\n");
 		fprintf (stderr, "\t-G Controls placement of labels along contours.  Choose among five algorithms:\n");
 		GMT_cont_syntax (3, 0);
 		GMT_explain_option ('K');
@@ -383,6 +406,10 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -L option: lower limit >= upper!\n", GMT_program);
 		error++;
 	}
+	if (Ctrl->F.active && !Ctrl->D.active) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -F option: Must also specify -D\n", GMT_program);
+		error++;
+	}
 	if (Ctrl->S.value < 0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Smooth_factor must be > 0\n", GMT_program);
 		error++;
@@ -415,9 +442,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
-
 	if (Ctrl->D.active && Ctrl->D.file[0] == 0) {
 		fprintf (stderr, "%s: contours will be written to file contour\n", GMT_program);
 		strcpy (Ctrl->D.file,"contour");
@@ -432,10 +456,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (GMT_read_grd_info (grdfile, &header)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, grdfile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (grdfile, &header), grdfile);
 	if (!strcmp (Ctrl->contour.unit, "z")) strcpy (Ctrl->contour.unit, header.z_units);
 
 	/* Determine what wesn to pass to map_setup */
@@ -448,7 +469,7 @@ int main (int argc, char **argv)
 	}
 	else if (!(west == header.x_min && east == header.x_max && south == header.y_min && north == header.y_max))
 		subset = TRUE;
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	/* Determine the wesn to be used to read the grdfile */
 
@@ -483,10 +504,7 @@ int main (int argc, char **argv)
 	ny = GMT_get_n (data_south, data_north, header.y_inc, header.node_offset);
 	nm = nx * ny;
 	grd_original = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
-	if (GMT_read_grd (grdfile, &header, grd_original, data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grdfile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd (grdfile, &header, grd_original, data_west, data_east, data_south, data_north, GMT_pad, FALSE), grdfile);
 
 	n_edges = header.ny * (int )ceil (header.nx / 16.0);
 	edge = (int *) GMT_memory (VNULL, (size_t)n_edges, sizeof (int), GMT_program);
@@ -542,7 +560,7 @@ int main (int argc, char **argv)
 				cont_type[c] = 'A';
 			else
 				cont_type[c] = (Ctrl->contour.annot) ? 'A' : 'C';
-			cont_angle[c] = (Ctrl->contour.angle_type == 2) ? label_angle : GMT_d_NaN;
+			cont_angle[c] = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT_d_NaN;
 			cont_do_tick[c] = Ctrl->T.active;
 			c++;
 		}
@@ -553,7 +571,7 @@ int main (int argc, char **argv)
 			cont_type[c] = 'A';
 		else
 			cont_type[c] = (Ctrl->contour.annot) ? 'A' : 'C';
-		cont_angle[c] = (Ctrl->contour.angle_type == 2) ? label_angle : GMT_d_NaN;
+		cont_angle[c] = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT_d_NaN;
 		cont_do_tick[c] = Ctrl->T.active;
 		n_contours = c + 1;
 	}
@@ -565,12 +583,13 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: Error opening contour info file %s\n", GMT_program, Ctrl->C.file);
 			exit (EXIT_FAILURE);
 		}
-		while (fgets (line, BUFSIZ, fpc)) {
+		while (GMT_fgets (line, BUFSIZ, fpc)) {
 			if (line[0] == '#') continue;
 			got = sscanf (line, "%lf %c %lf", &contour[n_contours], &cont_type[n_contours], &tmp);
 			if (cont_type[n_contours] == 0) cont_type[n_contours] = 'C';
 			cont_do_tick[n_contours] = (Ctrl->T.active && ((cont_type[n_contours] == 'C') || (cont_type[n_contours] == 'A'))) ? 1 : 0;
 			cont_angle[n_contours] = (got == 3) ? tmp : GMT_d_NaN;
+			if (got == 3) Ctrl->contour.angle_type = 2;	/* Must set this directly if angles are provided */
 			n_contours++;
 			if (n_contours == n_alloc) {
 				n_alloc += GMT_CHUNK;
@@ -595,7 +614,7 @@ int main (int argc, char **argv)
 			contour[n_contours] = c * Ctrl->C.interval;
 			if (Ctrl->contour.annot && (contour[n_contours] - aval) > GMT_SMALL) aval += Ctrl->A.interval;
 			cont_type[n_contours] = (fabs (contour[n_contours] - aval) < GMT_SMALL) ? 'A' : 'C';
-			cont_angle[n_contours] = (Ctrl->contour.angle_type == 2) ? label_angle : GMT_d_NaN;
+			cont_angle[n_contours] = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT_d_NaN;
 			cont_do_tick[n_contours] = Ctrl->T.active;
 		}
 	}
@@ -613,6 +632,8 @@ int main (int argc, char **argv)
 	GMT_grd_minmax (grd_original, &header, xyz);
 	if (GMT_contlabel_prep (&Ctrl->contour, xyz)) exit (EXIT_FAILURE);	/* Prep for crossing lines, if any */
 
+	for (i = 0; i < 3; i++) GMT_io.out_col_type[i] = GMT_io.in_col_type[i];	/* Used if -D is set */
+	
 	/* Because we are doing single-precision, we cannot subtract incrementally but must start with the
 	 * original grid values and subtract the current contour value. */
 	 
@@ -638,15 +659,15 @@ int main (int argc, char **argv)
 
 		Ctrl->contour.line_pen = Ctrl->W.pen[id];	/* Load current pen into contour structure */
 		if (Ctrl->W.color) {	/* Override pen & label color according to cpt file */
-			GMT_get_rgb24 (cval, rgb);
+			GMT_get_rgb_from_z (cval, rgb);
 			memcpy ((void *)&Ctrl->contour.line_pen.rgb, (void *)rgb, (size_t)(3 * sizeof (int)));
 			if (!Ctrl->contour.got_font_rgb && Ctrl->contour.curved_text) memcpy ((void *)&Ctrl->contour.font_rgb, (void *)rgb, (size_t)(3 * sizeof (int)));
 		}
 
 		side = 0;
 		begin = TRUE;
-		while (side < 5) {
-			while ((n = GMT_contours (grd, &header, Ctrl->S.value, gmtdefs.interpolant, &side, edge, begin, &x, &y)) > 0) {
+		while (side <= GMT_LAST_CONTOUR_SIDE) {
+			while ((n = GMT_contours (grd, &header, Ctrl->S.value, gmtdefs.interpolant, Ctrl->F.value, &side, edge, begin, &x, &y)) > 0) {
 
 				if (fabs (x[0] - x[n-1]) < small_x && fabs (y[0] - y[n-1]) < small_y) {
 					interior = TRUE;
@@ -740,7 +761,7 @@ int main (int argc, char **argv)
 
 void sort_and_plot_ticks (struct SAVE *save, int n, struct GRD_HEADER *h, float *grd, double tick_gap, double tick_length, BOOLEAN tick_low, BOOLEAN tick_high, BOOLEAN tick_label, char Llabel, char Hlabel)
 {
-	int np, i, j, inside, ix, iy, done, n_ticks;
+	int np, i, j, inside, ix, iy, iy_s, done, n_ticks;
 	double x0, y0, add, sign, dx, dy, x_back, y_back, x_front, y_front;
 	double xmin, xmax, ymin, ymax, x_mean = 0.0, y_mean = 0.0, inc, dist, a, small, this_lon, this_lat, sa, ca, *s;
 	char txt[2][2];
@@ -779,18 +800,22 @@ void sort_and_plot_ticks (struct SAVE *save, int n, struct GRD_HEADER *h, float
 			ymax = MAX (ymax, save[i].y[j]);
 		}
 
-		/* Find a point inside the polygon to test for high or low */
+		/* Find a point inside the polygon to test for high or low.
+		 * We select the mid-top point and march down until we are inside
+		 */
 
 		GMT_xy_to_geo (&this_lon, &this_lat, 0.5 * (xmin + xmax), ymax);
-		ix = irint ((this_lon - h->x_min) / h->x_inc) + 1;
-		iy = irint ((h->y_max - this_lat) / h->y_inc) + 1;
-		this_lon = h->x_min + ix * h->x_inc;
+		ix = GMT_x_to_i (this_lon, h->x_min, h->x_inc, h->xy_off, h->nx);
+		iy = GMT_y_to_j (this_lat, h->y_min, h->y_inc, h->xy_off, h->ny);
+		this_lon = GMT_i_to_x (ix, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);	/* This is that mid longitude */
+		GMT_xy_to_geo (&a, &this_lat, 0.5 * (xmin + xmax), ymin);			/* Get bottom latitude */
+		iy_s = MIN (h->ny, GMT_y_to_j (this_lat, h->y_min, h->y_inc, h->xy_off, h->ny) + 1);	/* And its j-row */
 		done = FALSE;
-		while (!done && iy < h->ny) {
-			this_lat = h->y_max - iy * h->y_inc;
+		while (!done && iy < iy_s) {
+			this_lat = GMT_j_to_y (iy, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);
 			GMT_geo_to_xy (this_lon, this_lat, &x0, &y0);
 			inside = GMT_non_zero_winding (x0, y0, save[i].x, save[i].y, np);
-			if (inside == 2)
+			if (inside == 2)	/* OK, this point is inside */
 				done = TRUE;
 			else
 				iy++;
@@ -916,7 +941,7 @@ void adjust_hill_label (struct GMT_CONTOUR *G, struct GRD_HEADER *h, float *z)
 			if (i0 < 0 || i0 >= h->nx) continue;	/* Somehow, outside x range */
 			angle = fmod (2.0 * C->L[k].angle, 360.0) * 0.5;	/* 0-180 range */
 			if (angle > 90.0) angle -= 180.0;
-			sincos ((angle + 90) * D2R, &ny, &nx);	/* Coordinate of normal to label line */
+			sincosd (angle + 90, &ny, &nx);	/* Coordinate of normal to label line */
 			x_node = GMT_i_to_x (i0, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);
 			y_node = GMT_j_to_y (j0, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);
 			GMT_geo_to_xy (x_node, y_node, &x_node_p, &y_node_p);	/* Projected coordinates of nearest node point */
