@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcut.c,v 1.21 2006/04/12 21:55:46 pwessel Exp $
+ *	$Id: grdcut.c,v 1.27 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -36,7 +36,7 @@ struct GRDCUT_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, global = FALSE;
+	BOOLEAN	error = FALSE;
 
 	int	i, nx_old, ny_old, nx_new, ny_new, one_or_zero;
 
@@ -119,19 +119,11 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
-
-	if (GMT_read_grd_info (grd_in, &header)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, grd_in);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (grd_in, &header), grd_in);
 
 	if (s_new < header.y_min || s_new > header.y_max) error = TRUE;
 	if (n_new < header.y_min || n_new > header.y_max) error = TRUE;
-	global = (fabs (header.x_max - header.x_min) == 360.0);
 
-	if ( !global && ((w_new < header.x_min) || (e_new > header.x_max)) ) error = TRUE;
 	if (GMT_io.in_col_type[GMT_X] == GMT_IS_LON) {
 		if (w_new < header.x_min && e_new < header.x_min) {
 			header.x_min -= 360.0;
@@ -142,6 +134,8 @@ int main (int argc, char **argv)
 			header.x_max += 360.0;
 		}
 	}
+	if (w_new < header.x_min || e_new > header.x_max) error = TRUE;
+
 	if (error) {
 		fprintf (stderr, "%s: Subset exceeds data domain!\n", GMT_program);
 		exit (EXIT_FAILURE);
@@ -151,7 +145,7 @@ int main (int argc, char **argv)
 
 	test_header.x_min = w_new;	test_header.x_max = e_new;	test_header.x_inc = header.x_inc;
 	test_header.y_min = s_new;	test_header.y_max = n_new;	test_header.y_inc = header.y_inc;
-	GMT_grd_RI_verify (&test_header, 1);
+	GMT_err_fail (GMT_grd_RI_verify (&test_header, 1), Ctrl->G.file);
 
 	/* OK, so far so good. Check if new wesn differs from old wesn by integer dx/dy */
 
@@ -182,10 +176,7 @@ int main (int argc, char **argv)
 	ny_new = irint ((n_new - s_new) / header.y_inc) + one_or_zero;
 
 	grd = (float *) GMT_memory (VNULL, (size_t)(nx_new * ny_new), sizeof (float), GMT_program);
-	if (GMT_read_grd (grd_in, &header, grd, w_new, e_new, s_new, n_new, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_in);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd (grd_in, &header, grd, w_new, e_new, s_new, n_new, GMT_pad, FALSE), grd_in);
 
 	if (gmtdefs.verbose) {
 		sprintf (format, "\t%s\t%s\t%s\t%s\t%s\t%s\t%%d\t%%d\n", gmtdefs.d_format, gmtdefs.d_format,
@@ -197,10 +188,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, format, w_new, e_new, s_new, n_new, header.x_inc, header.y_inc, nx_new, ny_new);
 	}
 
-	if (GMT_write_grd (Ctrl->G.file, &header, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *) grd);
 
