@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfft.c,v 1.22 2006/05/12 04:15:12 pwessel Exp $
+ *	$Id: grdfft.c,v 1.32 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,12 +29,17 @@
  * 1 Sept 1998:  Fixed bug in -E argv[i][2] should be [i][j].
  *   Note to myself:  users want azimuthal power spectra, and
  *   cross-spectra between two grids.  --whfs
+ * 5/17/2006 PW: Added enhanced -F option for Gaussian band-pass.
  *
  * Version:	4
  */
 
 #include "gmt.h"
 
+#ifndef M_LN2
+#define M_LN2          0.69314718055994530942  /* log_e 2 */
+#endif
+
 struct GRDFFT_CTRL {
 	int n_op_count, n_par;
 	int *operation;
@@ -56,7 +61,7 @@ struct GRDFFT_CTRL {
 		BOOLEAN active;
 		int mode;
 	} E;
-	struct F {	/* -F[x_or_y]<lc>/<lp>/<hp>/<hc> */
+	struct F {	/* -F[x_or_y]<lc>/<lp>/<hp>/<hc> or -F[x_or_y]<lo>/<hi> */
 		BOOLEAN active;
 		int mode;
 		double lc, lp, hp, hc;
@@ -94,11 +99,12 @@ struct GRDFFT_CTRL {
 #endif
 #define UP_DOWN_CONTINUE 0
 #define AZIMUTHAL_DERIVATIVE 1
-#define DIFFERENTIATE 2
-#define INTEGRATE 3
-#define ISOSTASY 4
-#define FILTER 5
-#define SPECTRUM 6
+#define DIFFERENTIATE	2
+#define INTEGRATE	3
+#define ISOSTASY	4
+#define FILTER_COS	5
+#define FILTER_EXP	6
+#define SPECTRUM	7
 
 /* Macro definition ij_data(i,j) finds the array index to an element
 	containing the real data(i,j) in the padded complex array:  */
@@ -125,8 +131,11 @@ struct F_INFO {
 	double	hc[3];		/* High-cut frequency for r, x, and y	*/
 	double	ltaper[3];	/* Low taper width for r, x, and y	*/
 	double	htaper[3];	/* High taper width for r, x, and y	*/
+	double	llambda[3];	/* Low full-wavelength where Gauss amp = 0.5 for r, x, and y	*/
+	double	hlambda[3];	/* High full-wavelength where Gauss amp = 0.5  for r, x, and y	*/
 	int	do_this[3];	/* T/F this filter wanted for r, x, and y	*/
 	int	set_already;
+	int	kind;		/* 0 = cosine taper, 1 = Gaussian */
 } f_info;
 
 struct FFT_SUGGESTION {
@@ -144,13 +153,14 @@ double	scale_out = 1.0;
 
 int main (int argc, char **argv)
 {
-	int op_count = 0, par_count = 0;
+	int op_count = 0, par_count = 0, filter_type = 0;
 
 	BOOLEAN error = FALSE, stop, give_wavelength = FALSE;
 	struct GRDFFT_CTRL *Ctrl;
-	int parse_f_string (char *c), read_data(struct GRDFFT_CTRL *Ctrl, int argc, char **argv);
+	int parse_f_string (char *c), count_slashes (char *txt);
+	void read_data(struct GRDFFT_CTRL *Ctrl, int argc, char **argv);
 	void do_continuation(double *zlevel), do_azimuthal_derivative(double *azim), do_differentiate(double *par), do_integrate(double *par), do_isostasy(double *par);
-	void do_filter(void), do_spectrum(double *par, int give_wavelength);
+	void do_filter_cos(void), do_filter_exp(void), do_spectrum(double *par, int give_wavelength);
 
 	void *New_Grdfft_Ctrl (), Free_Grdfft_Ctrl (struct GRDFFT_CTRL *C);
 	
@@ -212,6 +222,7 @@ int main (int argc, char **argv)
 					op_count++;
 					Ctrl->n_par++;
 					Ctrl->par = (double *) GMT_memory ((void *)Ctrl->par, (size_t)Ctrl->n_par, sizeof(double), GMT_program);
+					Ctrl->par[par_count] = 0.0;
                                         if (argv[i][2]) {
 						Ctrl->par[par_count] = (argv[i][2] == 'g' || argv[i][2] == 'G') ? mGal_at_45 : atof (&argv[i][2]);
 						if (Ctrl->par[par_count] == 0.0) {
@@ -244,11 +255,13 @@ int main (int argc, char **argv)
                                         break;
                                 case 'F':
                                 	if (!(f_info.set_already)) {
+						filter_type = count_slashes (&argv[i][2]);
 						Ctrl->n_op_count++;
 						Ctrl->operation = (int *) GMT_memory ((void *)Ctrl->operation, (size_t)Ctrl->n_op_count, sizeof(int), GMT_program);
-                                        	Ctrl->operation[op_count] = FILTER;
+                                        	Ctrl->operation[op_count] = (filter_type > 2) ? FILTER_COS : FILTER_EXP;
                                         	op_count++;
                                         	f_info.set_already = TRUE;
+						f_info.kind = (filter_type == 1);
                                         }
                                         if (parse_f_string(&argv[i][2])) {
 						fprintf (stderr, "%s: GMT SYNTAX ERROR -F option: ", GMT_program);
@@ -265,7 +278,8 @@ int main (int argc, char **argv)
 					op_count++;
 					Ctrl->n_par++;
 					Ctrl->par = (double *) GMT_memory ((void *)Ctrl->par, (size_t)Ctrl->n_par, sizeof(double), GMT_program);
-                                        if (argv[i][2]) {
+   					Ctrl->par[par_count] = 0.0;
+					if (argv[i][2]) {
 						Ctrl->par[par_count] = (argv[i][2] == 'g' || argv[i][2] == 'G') ? mGal_at_45 : atof (&argv[i][2]);
 						if (Ctrl->par[par_count] == 0.0) {
 							fprintf (stderr, "%s: GMT SYNTAX ERROR -I option:  scale must be nonzero\n", GMT_program);
@@ -295,6 +309,7 @@ int main (int argc, char **argv)
                                         scale_out = (argv[i][2] == 'd' || argv[i][2] == 'D') ? 1.0e6: atof (&argv[i][2]);
                                         break;
                                 case 'T':
+                                        Ctrl->T.active = TRUE;
 					Ctrl->n_op_count++;
 					Ctrl->operation = (int *) GMT_memory ((void *)Ctrl->operation, (size_t)Ctrl->n_op_count, sizeof(int), GMT_program);
                                         Ctrl->operation[op_count] = ISOSTASY;
@@ -325,7 +340,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "grdfft %s - Perform mathematical operations on grdfiles in the wavenumber (or frequency) domain\n\n", GMT_VERSION);
 		fprintf (stderr,"usage: grdfft <in_grdfile> [-G<out_grdfile>] [-A<azimuth>] [-C<zlevel>]\n");
-		fprintf (stderr,"\t[-D[<scale>|g]] [-E[x_or_y][w]] [-F[x_or_y]<lc>/<lp>/<hp>/<hc>] [-I[<scale>|g]] [-L] [-M]\n");
+		fprintf (stderr,"\t[-D[<scale>|g]] [-E[x_or_y][w]] [-F[x_or_y]<parameters>] [-I[<scale>|g]] [-L] [-M]\n");
 		fprintf (stderr,"\t[-N<stuff>] [-S<scale>] [-T<te/rl/rm/rw/ri>] [-V]\n\n");
 		
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -338,9 +353,12 @@ int main (int argc, char **argv)
 		fprintf (stderr,"\t-D Differentiate, i.e., multiply by kr [ * scale].  Use -Dg to get mGal from m]\n");
 		fprintf (stderr,"\t-E Estimate spEctrum of r [x] [y].  Write f, power[f], 1 std dev(power[f]) to stdout.\n");
 		fprintf (stderr,"\t\tAppend w to write wavelength instead of frequency.\n");
-		fprintf (stderr,"\t-F Filter r [x] [y] freq according to four wavelengths <lc>/<lp>/<hp>/<hc>.\n");
-		fprintf (stderr,"\t   freq outside <lc>/<hc> are cut; inside <lp>/<hp> are passed, rest are tapered.\n");
-		fprintf (stderr,"\t   replace wavelength by - to skip, e.g.  -F-/-/500/100 is a low-pass filter.\n");
+		fprintf (stderr,"\t-F Filter r [x] [y] freq according to one of two kinds of filter specifications:.\n");
+		fprintf (stderr,"\t   a) Cosine band-pass: Append four wavelengths <lc>/<lp>/<hp>/<hc>.\n");
+		fprintf (stderr,"\t      freq outside <lc>/<hc> are cut; inside <lp>/<hp> are passed, rest are tapered.\n");
+		fprintf (stderr,"\t      Replace wavelength by - to skip, e.g.  -F-/-/500/100 is a low-pass filter.\n");
+		fprintf (stderr,"\t   b) Gaussian band-pass: Append two wavelengths <lo>/<hi> where filter amplitudes = 0.5.\n");
+		fprintf (stderr,"\t      Replace wavelength by - to skip, e.g.  -F300/- is a high-pass Gaussian filter.\n");
 		fprintf (stderr,"\t-I Integrate, i.e., divide by kr [ * scale].  Use -Ig to get m from mGal]\n");
 		fprintf (stderr,"\t-L Leave trend alone.  Do not remove least squares plane from data.  [Default removes plane].\n");
 		fprintf (stderr,"\t-M Map units used.  Convert grid dimensions from degrees to meters.\n");
@@ -386,13 +404,8 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
+	read_data (Ctrl, argc, argv);
 
-	if (read_data(Ctrl, argc, argv) ) {
-		fprintf (stderr,"%s: Fatal GMT_memory error.  Exiting.\n", GMT_program);
-		exit (EXIT_FAILURE);
-	}
-	
 	/* Check that no NaNs are present */
 	
 	stop = FALSE;
@@ -433,9 +446,13 @@ int main (int argc, char **argv)
 				do_isostasy (&Ctrl->par[par_count]);
 				par_count += 5;
 				break;
-			case FILTER:
+			case FILTER_COS:
 				if (gmtdefs.verbose) fprintf (stderr, "filter...");
-				do_filter ();
+				do_filter_cos ();
+				break;
+			case FILTER_EXP:
+				if (gmtdefs.verbose) fprintf (stderr, "filter...");
+				do_filter_exp ();
 				break;
 			case SPECTRUM:
 				if (gmtdefs.verbose) fprintf (stderr, "spectrum...");
@@ -456,10 +473,7 @@ int main (int argc, char **argv)
 
 		/* The data are in the middle of the padded array:  */
 
-		if (GMT_write_grd (Ctrl->G.file, &h, datac, h.x_min, h.x_max, h.y_min, h.y_max, GMT_pad, TRUE)) {
-			fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &h, datac, h.x_min, h.x_max, h.y_min, h.y_max, GMT_pad, TRUE), Ctrl->G.file);
 	}
 	
 	GMT_free ((void *)workc);
@@ -474,7 +488,7 @@ int main (int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-int read_data (struct GRDFFT_CTRL *Ctrl, int argc, char **argv)
+void read_data (struct GRDFFT_CTRL *Ctrl, int argc, char **argv)
 {
 	int	worksize, factors[32];
 	double	tdummy, edummy;
@@ -482,10 +496,7 @@ int read_data (struct GRDFFT_CTRL *Ctrl, int argc, char **argv)
 	void	fourt_stats(int nx, int ny, int *f, double *r, int *s, double *t);
 	void remove_plane(void), taper_edges(void);
 	
-	if (GMT_read_grd_info (infile, &h)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, infile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (infile, &h), infile);
 	
 	GMT_grd_init (&h, argc, argv, TRUE);
 
@@ -547,10 +558,7 @@ int read_data (struct GRDFFT_CTRL *Ctrl, int argc, char **argv)
 	GMT_pad[1] = nx2 - h.nx - GMT_pad[0];
 	GMT_pad[2] = ny2 - h.ny - GMT_pad[3];
 
-	if (GMT_read_grd (infile, &h, datac, h.x_min, h.x_max, h.y_min, h.y_max, GMT_pad, TRUE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, infile);
-		return (-1);
-	}
+	GMT_err_fail (GMT_read_grd (infile, &h, datac, h.x_min, h.x_max, h.y_min, h.y_max, GMT_pad, TRUE), infile);
 
 	if (!(Ctrl->L.active) )remove_plane();
 	if (!(force_narray) )taper_edges();
@@ -562,11 +570,9 @@ int read_data (struct GRDFFT_CTRL *Ctrl, int argc, char **argv)
 		delta_kx /= (project_info.M_PR_DEG * cosd (0.5 * (h.y_min + h.y_max)) );
 		delta_ky /= project_info.M_PR_DEG;
 	}
-
-	return(0);
 }
 
-void	remove_plane(void)
+void remove_plane (void)
 {
 	/* Remove the best-fitting plane by least squares.
 
@@ -620,7 +626,7 @@ void	remove_plane(void)
 	if(gmtdefs.verbose)fprintf (stderr,"%s: Plane removed.  Mean, S.D., Dx, Dy:  %.8g\t%.8g\t%.8g\t%.8g\n", GMT_program, a[0],data_var,a[1],a[2]);
 }
 
-void	taper_edges (void)
+void taper_edges (void)
 {
 	int	im, jm, il1, ir1, il2, ir2, jb1, jb2, jt1, jt2;
 	double	scale, cos_wt;
@@ -679,7 +685,7 @@ void	taper_edges (void)
 	}
 }
 
-double	kx(int k)
+double kx (int k)
 {
 	/* Return the value of kx given k,
 		where kx = 2 pi / lambda x,
@@ -693,7 +699,7 @@ double	kx(int k)
 	return(ii * delta_kx);
 }
 
-double	ky(int k)
+double ky (int k)
 {
 	/* Return the value of ky given k,
 		where ky = 2 pi / lambda y,
@@ -707,7 +713,7 @@ double	ky(int k)
 	return(jj * delta_ky);
 }
 
-double	modk(int k)
+double modk (int k)
 {
 	/* Return the value of sqrt(kx*kx + ky*ky),
 		given k, where k is array position.  */
@@ -715,7 +721,7 @@ double	modk(int k)
 	return (hypot (kx(k), ky(k)));
 }
 
-void	do_differentiate (double *par)
+void do_differentiate (double *par)
 {
 	int	k;
 	double scale, fact;
@@ -731,7 +737,7 @@ void	do_differentiate (double *par)
 	}
 }
 
-void	do_integrate (double *par)
+void do_integrate (double *par)
 {
 	/* Integrate in frequency domain by dividing by kr [scale optional] */
 	int	k;
@@ -746,7 +752,7 @@ void	do_integrate (double *par)
 	}
 }
 
-void	do_continuation (double *zlevel)
+void do_continuation (double *zlevel)
 {
 	int	k;
 	double tmp;
@@ -760,7 +766,7 @@ void	do_continuation (double *zlevel)
 	}
 }
 
-void	do_azimuthal_derivative (double *azim)
+void do_azimuthal_derivative (double *azim)
 {
 	int	k;
 	float	tempr, tempi, fact;
@@ -779,7 +785,7 @@ void	do_azimuthal_derivative (double *azim)
 	}
 }
 
-void	do_isostasy (double *par)
+void do_isostasy (double *par)
 {
 
 	/* Do the isostatic response function convolution in the Freq domain.
@@ -820,18 +826,29 @@ void	do_isostasy (double *par)
 	}
 }
 
-void	do_filter(void)
+void do_filter_cos (void)
 {
 	int	k;
-	double	weight, f_wt(int k);
+	double	weight, f_wt_cos(int k);
 	for (k = 0; k < ndatac; k += 2) {
-		weight = f_wt(k);
+		weight = f_wt_cos(k);
 		datac[k] *= (float)weight;
 		datac[k+1] *= (float)weight;
 	}
 }
 
-double	f_wt(int k)
+void do_filter_exp (void)
+{
+	int	k;
+	double	weight, f_wt_exp(int k);
+	for (k = 0; k < ndatac; k += 2) {
+		weight = f_wt_exp(k);
+		datac[k] *= (float)weight;
+		datac[k+1] *= (float)weight;
+	}
+}
+
+double f_wt_cos (int k)
 {
 	double	freq, return_value = 1.0;
 	int	j;
@@ -839,7 +856,7 @@ double	f_wt(int k)
 	/* Always return immediately when zero weight encountered.  */
 	
 	for (j = 0; j < 3; j++) {
-		if (!(f_info.do_this[j])) continue;
+		if (!(f_info.do_this[j])) continue;	/* Only do one of x, y, or r filtering */
 		switch (j) {
 			case 0:
 				freq = modk(k);
@@ -851,10 +868,9 @@ double	f_wt(int k)
 				freq = ky(k);
 				break;
 		}
-		if (freq <= f_info.lc[j] || freq >= f_info.hc[j])
-			/* In fully cut range.  Weight is zero.  */
-			return(0.0);
-		else if (freq > f_info.lc[j] && freq < f_info.lp[j])
+		if (freq <= f_info.lc[j] || freq >= f_info.hc[j]) return(0.0);	/* In fully cut range.  Weight is zero.  */
+			
+		if (freq > f_info.lc[j] && freq < f_info.lp[j])
 			return_value *= 0.5 * (1.0 + cos (M_PI * (freq - f_info.lp[j]) * f_info.ltaper[j]));
 		else if (freq > f_info.hp[j] && freq < f_info.hc[j])
 			return_value *= 0.5 * (1.0 + cos (M_PI * (freq - f_info.hp[j]) * f_info.htaper[j]));
@@ -863,15 +879,50 @@ double	f_wt(int k)
 
 	/* Get here when all weights have been multiplied on return_value:  */
 	
-	return(return_value);
+	return (return_value);
 }
 
-int	parse_f_string(char *c)
+double f_wt_exp (int k)
+{
+	double	freq, return_value = 1.0, lo, hi;
+	int	j;
+		
+	for (j = 0; j < 3; j++) {
+		if (!(f_info.do_this[j])) continue;	/* Only do one of x, y, or r filtering */
+		switch (j) {
+			case 0:
+				freq = modk(k);
+				break;
+			case 1:
+				freq = kx(k);
+				break;
+			default:
+				freq = ky(k);
+				break;
+		}
+		lo = (f_info.llambda[j] == -1.0) ? 0.0 : exp (-M_LN2 * pow (freq * f_info.llambda[j], 2.0));
+		hi = (f_info.hlambda[j] == -1.0) ? 1.0 : exp (-M_LN2 * pow (freq * f_info.hlambda[j], 2.0));
+		return_value = hi - lo;
+	}
+
+	return (return_value);
+}
+
+int count_slashes (char *txt)
+{
+	int i, n;
+	for (i = n = 0; txt[i]; i++) if (txt[i] == '/') n++;
+	return (n);
+}
+
+int parse_f_string (char *c)
 {
 	int	i, j, n_tokens, pos, descending;
 	double	fourvals[4];
 	char	line[GMT_LONG_TEXT], p[GMT_LONG_TEXT];
 	
+	/* Syntax is either -F[x|y]lc/hc/lp/hp (Cosine taper) or -F[x|y]lo/hi (Gaussian) */
+	
 	strcpy(line, c);
 	i = j = 0;	/* j is Filter type:  r=0, x=1, y=2  */
 	
@@ -885,6 +936,7 @@ int	parse_f_string(char *c)
 	}
 	
 	f_info.do_this[j] = TRUE;
+	fourvals[0] = fourvals[1] = fourvals[2] = fourvals[3] = -1.0;
 	
 	n_tokens = pos = 0;
 	while ((GMT_strtok (&line[i], "/", &pos, p))) {
@@ -904,13 +956,12 @@ int	parse_f_string(char *c)
 		n_tokens++;
 	}
 	
-	if (n_tokens != 4) {
-		fprintf(stderr,"%s: -F Cannot find 4 tokens separated by slashes.\n", GMT_program);
+	if (!(n_tokens == 2 || n_tokens == 4)) {
+		fprintf(stderr,"%s: -F Cannot find 2 or 4 tokens separated by slashes.\n", GMT_program);
 		return(TRUE);
 	}
-
 	descending = TRUE;
-	for (i = 1; i < 4; i++) {
+	for (i = 1; i < n_tokens; i++) {
 		if (fourvals[i] == -1.0 || fourvals[i-1] == -1.0) continue;
 		if (fourvals[i] > fourvals[i-1]) descending = FALSE;
 	}
@@ -918,29 +969,35 @@ int	parse_f_string(char *c)
 		fprintf(stderr,"%s: -F Wavelengths are not in descending order.\n", GMT_program);
 		return(TRUE);
 	}
-	if ( (fourvals[0] * fourvals[1]) < 0.0 || (fourvals[2] * fourvals[3]) < 0.0) {
-		fprintf(stderr,"%s: -F Pass/Cut specification error.\n", GMT_program);
-		return(TRUE);
+	if (f_info.kind == 0) {	/* Cosine band-pass specification */
+		if ( (fourvals[0] * fourvals[1]) < 0.0 || (fourvals[2] * fourvals[3]) < 0.0) {
+			fprintf(stderr,"%s: -F Pass/Cut specification error.\n", GMT_program);
+			return(TRUE);
+		}
+	
+		/* Now everything is OK  */
+	
+		if (fourvals[0] >= 0.0 || fourvals[1] >= 0.0) {	/* Lower end values are set  */
+			f_info.lc[j] = (2.0 * M_PI)/fourvals[0];
+			f_info.lp[j] = (2.0 * M_PI)/fourvals[1];
+			if (fourvals[0] != fourvals[1]) f_info.ltaper[j] = 1.0/(f_info.lc[j] - f_info.lp[j]);
+		}
+	
+		if (fourvals[2] >= 0.0 || fourvals[3] >= 0.0) {	/* Higher end values are set  */
+			f_info.hp[j] = (2.0 * M_PI)/fourvals[2];
+			f_info.hc[j] = (2.0 * M_PI)/fourvals[3];
+			if (fourvals[2] != fourvals[3]) f_info.htaper[j] = 1.0/(f_info.hc[j] - f_info.hp[j]);
+		}
 	}
-	
-	/* Now everything is OK  */
-	
-	if (fourvals[0] >= 0.0 || fourvals[1] >= 0.0) {	/* Lower end values are set  */
-		f_info.lc[j] = (2.0 * M_PI)/fourvals[0];
-		f_info.lp[j] = (2.0 * M_PI)/fourvals[1];
-		if (fourvals[0] != fourvals[1]) f_info.ltaper[j] = 1.0/(f_info.lc[j] - f_info.lp[j]);
-	}
-	
-	if (fourvals[2] >= 0.0 || fourvals[3] >= 0.0) {	/* Higher end values are set  */
-		f_info.hp[j] = (2.0 * M_PI)/fourvals[2];
-		f_info.hc[j] = (2.0 * M_PI)/fourvals[3];
-		if (fourvals[2] != fourvals[3]) f_info.htaper[j] = 1.0/(f_info.hc[j] - f_info.hp[j]);
+	else {	/* Gaussian half-amp specifications */
+		f_info.llambda[j] = fourvals[0] / TWO_PI;	/* TWO_PI is used to counteract the 2*pi in the wavenumber */
+		f_info.hlambda[j] = fourvals[1] / TWO_PI;
 	}
 	
 	return(FALSE);
 }
 
-void	do_spectrum(double *par, int give_wavelength)
+void do_spectrum (double *par, int give_wavelength)
 {
 	/* This is modeled on the 1-D case, using the following ideas:
 	 *	In 1-D, we ensemble average over samples of length L = 
@@ -1018,7 +1075,7 @@ void	do_spectrum(double *par, int give_wavelength)
 	}
 }
 
-void	fourt_stats(int nx, int ny, int *f, double *r, int *s, double *t)
+void fourt_stats (int nx, int ny, int *f, double *r, int *s, double *t)
 {
 	/* Find the proportional run time, t, and rms relative error, r,
 	 * of a Fourier transform of size nx,ny.  Also gives s, the size
@@ -1098,7 +1155,7 @@ void	fourt_stats(int nx, int ny, int *f, double *r, int *s, double *t)
 	return;
 } 
 
-int	get_non_symmetric_f(int *f, int n)
+int get_non_symmetric_f (int *f, int n)
 {
 	/* Return the product of the non-symmetric factors in f[]  */
 	int	i = 0, j = 1, retval = 1;
@@ -1115,7 +1172,7 @@ int	get_non_symmetric_f(int *f, int n)
 	return(retval);
 }
 
-void	suggest_fft(int nx, int ny, struct FFT_SUGGESTION *fft_sug, int do_print)
+void suggest_fft (int nx, int ny, struct FFT_SUGGESTION *fft_sug, int do_print)
 {
 	int	f[64], xstop, ystop;
 	int	nx_best_t, ny_best_t;
@@ -1222,7 +1279,7 @@ void	suggest_fft(int nx, int ny, struct FFT_SUGGESTION *fft_sug, int do_print)
 	return;
 }
 
-int	get_prime_factors(int n, int *f)
+int get_prime_factors (int n, int *f)
 {
 	/* Fills the integer array f with the prime factors of n.
 	 * Returns the number of locations filled in f, which is
