@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfilter.c,v 1.46 2006/10/06 17:19:36 pwessel Exp $
+ *	$Id: grdfilter.c,v 1.51 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -275,18 +275,13 @@ int main (int argc, char **argv)
 	
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	/* Assing filter_type number */
 	
 	for (filter_type = 0; filter_type < GRDFILTER_N_FILTERS && filter_code[filter_type] != Ctrl->F.filter; filter_type++);
 	
 	if (project_info.region_supplied) new_range = TRUE;
 
-	if (GMT_read_grd_info (fin, &h)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, fin);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (fin, &h), fin);
 	GMT_grd_init (&h, argc, argv, TRUE);	/* Update command history only */
 
 	if (Ctrl->T.active) {	/* Make output grid of the opposite registration */
@@ -299,10 +294,7 @@ int main (int argc, char **argv)
 
 	input = (float *) GMT_memory (VNULL, (size_t)(h.nx * h.ny), sizeof(float), GMT_program);
 
-	if (GMT_read_grd (fin, &h, input, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, fin);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd (fin, &h, input, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), fin);
 
 	last_median = 0.5 * (h.z_min + h.z_max);
 
@@ -336,7 +328,7 @@ int main (int argc, char **argv)
 	test_h.x_min = west_new;	test_h.x_max = east_new;	test_h.x_inc = Ctrl->I.xinc;
 	test_h.y_min = south_new;	test_h.y_max = north_new;	test_h.y_inc = Ctrl->I.yinc;
 	GMT_RI_prepare (&test_h);	/* Ensure -R -I consistency and set nx, ny */
-	GMT_grd_RI_verify (&test_h, 1);
+	GMT_err_fail (GMT_grd_RI_verify (&test_h, 1), Ctrl->G.file);
 
 	/* We can save time by computing a weight matrix once [or once pr scanline] only
 	   if new grid spacing is a multiple of old spacing */
@@ -634,10 +626,7 @@ int main (int argc, char **argv)
 	h.y_inc = Ctrl->I.yinc;
 	h.node_offset = !one_or_zero;
 
-	if (GMT_write_grd (Ctrl->G.file, &h, output, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &h, output, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *) input);
 	GMT_free ((void *) output);
