@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdgradient.c,v 1.27 2006/04/13 18:58:27 remko Exp $
+ *	$Id: grdgradient.c,v 1.32 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -278,7 +278,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   y for periodic boundary conditions on y\n");
 		fprintf (stderr, "\t   [Default:  Natural conditions]\n");
 		fprintf (stderr, "\t-M to use map units.  In this case, dx,dy of grdfile\n");
-		fprintf (stderr, "\t   will be converted from degrees lon,lat into meters.\n");
+		fprintf (stderr, "\t   will be converted from degrees lon,lat into meters (Flat-earth approximation).\n");
 		fprintf (stderr, "\t   Default computes gradient in units of data/grid_distance.\n");
 		fprintf (stderr, "\t-N will normalize gradients so that max |grad| = <amp> [1.0]\n");
 		fprintf (stderr, "\t  -Nt will make atan transform, then scale to <amp> [1.0]\n");
@@ -327,12 +327,7 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
-	if (GMT_read_grd_info (infile, &header)) {
-		fprintf (stderr, "%s: Error opening file %s (not found?)\n", infile, GMT_program);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (infile, &header), infile);
 
 	if (Ctrl->N.active && Ctrl->N.sigma != 0.0) sigma_set = TRUE;
 	if (Ctrl->N.active && Ctrl->N.offset != 0.0) offset_set = TRUE;
@@ -371,7 +366,7 @@ int main (int argc, char **argv)
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;
 	if (Ctrl->S.active) slp = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 
-	GMT_read_grd (infile, &header, data, header.x_min, header.x_max, header.y_min, header.y_max, GMT_pad, FALSE);
+	GMT_err_fail (GMT_read_grd (infile, &header, data, header.x_min, header.x_max, header.y_min, header.y_max, GMT_pad, FALSE), infile);
 
 	/* set boundary conditions:  */
 
@@ -574,13 +569,13 @@ int main (int argc, char **argv)
 
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;	/* Because of the shift */
 
-	GMT_write_grd (Ctrl->G.file, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *) data);
 
 	if (Ctrl->S.active) {
 		strcpy (header.title, "Magnitude of maximum slopes");
-		GMT_write_grd (Ctrl->S.file, &header, slp, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+		GMT_err_fail (GMT_write_grd (Ctrl->S.file, &header, slp, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->S.file);
 		GMT_free ((void *)slp);
 	}
 
