@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdhisteq.c,v 1.4.4.6 2004/01/02 22:23:11 pwessel Exp $
+ *	$Id: grdhisteq.c,v 1.20 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,70 +38,90 @@
  * Updated to v2.0 15-May-1991 Paul Wessel
  * Updated to v3.1 14-Jun-1998 Paul Wessel
  * Updated to v3.3.5 14-Jun-2000 Paul Wessel
- * Version:	3.4.3
+ * Version:	4
  */
  
 #include "gmt.h"
 
+struct GRDHISTEQ_CTRL {
+	struct C {	/* -C<n_cells>*/
+		BOOLEAN active;
+		int value;
+	} C;
+	struct D {	/* -D */
+		BOOLEAN active;
+	} D;
+	struct G {	/* -G<file> */
+		BOOLEAN active;
+		char *file;
+	} G;
+	struct N {	/* -N[<norm>] */
+		BOOLEAN active;
+		double norm;
+	} N;
+	struct Q {	/* -Q */
+		BOOLEAN active;
+	} Q;
+};
+
 struct	INDEXED_DATA {
 	float	x;
 	int	i;
-}	*indexed_data;
+};
 
 struct	CELL {
 	float	low;
 	float	high;
-}	*cell;
+};
 
-float	*data, data_min, data_max;
-float	get_cell(float x);
-double	qsnorm(double p), norm = 0.0;
-
-int	last_cell, n_cells = 0, n_cells_m1 = 0;
-int	i, j, nxy;
-int	compare_indexed_floats(const void *point_1, const void *point_2);
-int	compare_indices(const void *point_1, const void *point_2);
-
-void do_usual (char *infile, char *outfile, int n_cells, int quadratic, int dump_intervals, int argc, char **argv);
-void do_gaussian (char *infile, char *outfile, int argc, char **argv);
-
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
+	BOOLEAN	error = FALSE;
+	
+	char *infile = CNULL;
+
+	int i;
+		
+	struct GRDHISTEQ_CTRL *Ctrl;
+
+	void do_usual (char *infile, char *outfile, int n_cells, BOOLEAN quadratic, BOOLEAN dump_intervals, int argc, char **argv);
+	void do_gaussian (char *infile, char *outfile, double norm, int argc, char **argv);
+	void *New_Grdhisteq_Ctrl (), Free_Grdhisteq_Ctrl (struct GRDHISTEQ_CTRL *C);
 
-	int	i;
-	int	dump = FALSE, error = FALSE, quadratic = FALSE, gaussian = FALSE;
-	char *infile = CNULL, *outfile = CNULL;
-	
 	argc = GMT_begin (argc, argv);
-	
+
+	Ctrl = (struct GRDHISTEQ_CTRL *)New_Grdhisteq_Ctrl ();	/* Allocate and initialize a new control structure */
+
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
-			
+
 				/* Common parameters */
-				
+
 				case 'V':
 				case '\0':
-					error += GMT_get_common_args (argv[i], 0, 0, 0, 0);
+					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
-					
+
 				/* Supplemental parameters */
-			
+
 				case 'C':
-					n_cells = atoi(&argv[i][2]);
+					Ctrl->C.active = TRUE;
+					Ctrl->C.value = atoi(&argv[i][2]);
 					break;
 				case 'D':
-					dump = TRUE;
+					Ctrl->D.active = TRUE;
 					break;
 				case 'G':
-					outfile = &argv[i][2];
+					Ctrl->G.active = TRUE;
+					Ctrl->G.file = strdup (&argv[i][2]);
 					break;
 				case 'N':
-					gaussian = TRUE;
-					if (argv[i][2]) norm = atof (&argv[i][2]);
+					Ctrl->N.active = TRUE;
+					if (argv[i][2]) Ctrl->N.norm = atof (&argv[i][2]);
 					break;
 				case 'Q':
-					quadratic = TRUE;
+					Ctrl->Q.active = TRUE;
 					break;
 				default:
 					error = TRUE;
@@ -113,10 +133,10 @@ main (int argc, char **argv)
 			infile = argv[i];
 	}
 
-	if (argc == 1 || GMT_quick) {
+	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"grdhisteq %s - Histogram equalization for grdfiles\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdhisteq <infile> -G<outfile> [-C<n_cells> -D -N[<norm>] -Q -V]\n");
-		if (GMT_quick) exit (EXIT_FAILURE);
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 		fprintf (stderr, "\t-C<n_cells> sets how many cells (divisions) of data range to make.\n");
 		fprintf (stderr, "\t-D dump level information to stdout\n");
 		fprintf (stderr, "\t-G<outfile> will create an equalized output grdfile.\n");
@@ -131,56 +151,58 @@ main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify input file\n", GMT_program);
 		error++;
 	}
-	if (gaussian && !outfile) {
+	if (Ctrl->N.active && !Ctrl->G.file) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -N option:  Must also specify output file with -G\n", GMT_program);
 		error++;
 	}
-	if (!gaussian && n_cells <= 0) {
+	if (!Ctrl->N.active && Ctrl->C.value <= 0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -C option:  n_cells must be positive\n", GMT_program);
 		error++;
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands */
-
 	if (!strcmp (infile, "=")) {
 		fprintf (stderr, "%s: Piping of input grdfile not supported!\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-	
-	if (gaussian)
-		do_gaussian (infile, outfile, argc, argv);
+
+	if (Ctrl->N.active)
+		do_gaussian (infile, Ctrl->G.file, Ctrl->N.norm, argc, argv);
 	else
-		do_usual (infile, outfile, n_cells, quadratic, dump, argc, argv);
+		do_usual (infile, Ctrl->G.file, Ctrl->C.value, Ctrl->Q.active, Ctrl->D.active, argc, argv);
+
+	Free_Grdhisteq_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
 }
 
-void do_usual (char *infile, char *outfile, int n_cells, int quadratic, int dump_intervals, int argc, char **argv)
+void do_usual (char *infile, char *outfile, int n_cells, BOOLEAN quadratic, BOOLEAN dump_intervals, int argc, char **argv)
 {
-
+	char format[BUFSIZ];
+	int	i, j, last_cell, n_cells_m1 = 0, nxy, nxy_0, current_cell;
+	float	*data, data_min, data_max;
 	double	delta_cell, target;
 	struct GRD_HEADER header;
-	int	nxy, nxy_0, current_cell;
-	char format[BUFSIZ];
+	struct	CELL *cell;
 	
+	float get_cell (float x, struct CELL *cell, int n_cells_m1, int last_cell);
+
 	sprintf (format, "%s\t%s\t%%d\n", gmtdefs.d_format, gmtdefs.d_format);
-	
-	if (GMT_read_grd_info (infile, &header)) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR:  File %s not found\n", GMT_program, infile);
-		exit (EXIT_FAILURE);
-	}
+
+	GMT_err_fail (GMT_read_grd_info (infile, &header), infile);
 
 	GMT_grd_init (&header, argc, argv, TRUE);
 
 	nxy_0 = header.nx * header.ny;
 	data = (float *) GMT_memory (VNULL, (size_t)nxy_0, sizeof (float), GMT_program);
-	GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+	GMT_err_fail (GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), infile);
 
 	cell = (struct CELL *) GMT_memory (VNULL, (size_t)n_cells, sizeof(struct CELL), GMT_program);
 
 	/* Sort the data and find the division points:  */
-	
+
 	qsort ((void *)data, (size_t)nxy_0, sizeof(float), GMT_comp_float_asc);
 	nxy = nxy_0;
 	while (nxy > 0 && GMT_is_fnan (data[nxy-1])) nxy--;	/* Only deal with real numbers */
@@ -190,8 +212,7 @@ void do_usual (char *infile, char *outfile, int n_cells, int quadratic, int dump
 	last_cell = n_cells/2;
 	n_cells_m1 = n_cells - 1;
 
-	current_cell = 0;
-	i = 0;
+	current_cell = i = 0;
 	delta_cell = ((double)nxy) / ((double)n_cells);
 
 	while (current_cell < n_cells) {
@@ -200,7 +221,7 @@ void do_usual (char *infile, char *outfile, int n_cells, int quadratic, int dump
 			j = nxy - 1;
 		}
 		else if (quadratic) {	/* Use y = 2x - x**2 scaling  */
-			
+
 			target = ( (double) (current_cell + 1) ) / ( (double) n_cells);
 			j = (int)floor(nxy * (1.0 - sqrt(1.0 - target)));
 		}
@@ -211,7 +232,7 @@ void do_usual (char *infile, char *outfile, int n_cells, int quadratic, int dump
 
 		cell[current_cell].low = data[i];
 		cell[current_cell].high = data[j];
-		
+
 		if (dump_intervals) fprintf (GMT_stdout, format, data[i], data[j], current_cell);
 
 		i = j;
@@ -219,20 +240,20 @@ void do_usual (char *infile, char *outfile, int n_cells, int quadratic, int dump
 	}
 
 	if (outfile) {
-		GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+		GMT_err_fail (GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), infile);
 
-		for (i = 0; i < nxy_0; i++) data[i] = (GMT_is_fnan (data[i])) ? GMT_f_NaN : get_cell (data[i]);
-		
-		GMT_write_grd (outfile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+		for (i = 0; i < nxy_0; i++) data[i] = (GMT_is_fnan (data[i])) ? GMT_f_NaN : get_cell (data[i], cell, n_cells_m1, last_cell);
+
+		GMT_err_fail (GMT_write_grd (outfile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), outfile);
 	}
-	
+
 	GMT_free ((void *) data);
 	GMT_free ((void *) cell);
 }
 
-float	get_cell(float x)
+float get_cell (float x, struct CELL *cell, int n_cells_m1, int last_cell)
 {
-	int		low, high, i;
+	int	low, high, i;
 
 	low = 0;
 	high = n_cells_m1;
@@ -260,23 +281,24 @@ float	get_cell(float x)
 	} while (TRUE);
 }
 
-void do_gaussian (char *infile, char *outfile, int argc, char **argv)
+void do_gaussian (char *infile, char *outfile, double norm, int argc, char **argv)
 {
-	int	i, j, nxy_0;
+	int	i, j, nxy, nxy_0;
+	float	*data;
 	double	dnxy;
-	struct GRD_HEADER header;
-	
-	if (GMT_read_grd_info (infile, &header)) {
-                fprintf (stderr, "%s: GMT SYNTAX ERROR:  File %s not found\n", GMT_program, infile);
-		exit (EXIT_FAILURE);
-	}
+	struct	GRD_HEADER header;
+	struct	INDEXED_DATA *indexed_data;
+	int	compare_indexed_floats(const void *point_1, const void *point_2);
+	int	compare_indices(const void *point_1, const void *point_2);
+
+	GMT_err_fail (GMT_read_grd_info (infile, &header), infile);
 
 	GMT_grd_init (&header, argc, argv, TRUE);
 
 	nxy_0 = header.nx * header.ny;
 	data = (float *) GMT_memory (VNULL, (size_t)nxy_0, sizeof (float), GMT_program);
-	GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
-	
+	GMT_err_fail (GMT_read_grd (infile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), infile);
+
 	indexed_data = (struct INDEXED_DATA *) GMT_memory (VNULL, (size_t)nxy_0, sizeof (struct INDEXED_DATA), GMT_program);
 
 	for (i = j = 0, nxy = nxy_0; i < nxy_0; i++) {
@@ -291,17 +313,17 @@ void do_gaussian (char *infile, char *outfile, int argc, char **argv)
 			j++;
 		}
 	}
-	
+
 	/* Sort on data value  */
 
 	qsort ((void *)indexed_data, (size_t)nxy, sizeof(struct INDEXED_DATA), compare_indexed_floats);
 
 	dnxy = 1.0 / (nxy + 1);
 
-	if (norm != 0.0) norm /= fabs (qsnorm ((double)dnxy));	/* Normalize by abs(max score) */
+	if (norm != 0.0) norm /= fabs (GMT_zcrit ((double)dnxy));	/* Normalize by abs(max score) */
 
 	for (i = 0; i < nxy; i++) {
-		indexed_data[i].x = (float)qsnorm ((double)((i + 1) * dnxy));
+		indexed_data[i].x = (float)GMT_zcrit ((double)((i + 1) * dnxy));
 		if (norm != 0.0) indexed_data[i].x *= (float)norm;
 	}
 
@@ -311,82 +333,42 @@ void do_gaussian (char *infile, char *outfile, int argc, char **argv)
 
 	for (i = 0; i < nxy_0; i++) data[i] = indexed_data[i].x;
 
-	GMT_write_grd (outfile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+	GMT_err_fail (GMT_write_grd (outfile, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), outfile);
 
 	GMT_free ((void *) indexed_data);
 	GMT_free ((void *) data);
 }
 
-int	compare_indexed_floats(const void *point_1, const void *point_2)
+int compare_indexed_floats (const void *point_1, const void *point_2)
 {
-	if ( ((struct INDEXED_DATA *)point_1)->x < ((struct INDEXED_DATA *)point_2)->x )
+	if (((struct INDEXED_DATA *)point_1)->x < ((struct INDEXED_DATA *)point_2)->x)
 		return (-1);
-	else if ( ((struct INDEXED_DATA *)point_1)->x > ((struct INDEXED_DATA *)point_2)->x )
+	else if (((struct INDEXED_DATA *)point_1)->x > ((struct INDEXED_DATA *)point_2)->x)
 		return (1);
 	else 
 		return (0);
 }
 
-int	compare_indices(const void *point_1, const void *point_2)
+int compare_indices (const void *point_1, const void *point_2)
 {
-	if ( ((struct INDEXED_DATA *)point_1)->i < ((struct INDEXED_DATA *)point_2)->i )
+	if (((struct INDEXED_DATA *)point_1)->i < ((struct INDEXED_DATA *)point_2)->i)
 		return (-1);
-	else if ( ((struct INDEXED_DATA *)point_1)->i > ((struct INDEXED_DATA *)point_2)->i )
+	else if (((struct INDEXED_DATA *)point_1)->i > ((struct INDEXED_DATA *)point_2)->i)
 		return (1);
 	else 
 		return (0);
 }
 
-/* double qsnorm(p)
- * double	p;
- *
- * Function to invert the cumulative normal probability
- * function.  If z is a standardized normal random deviate,
- * and Q(z) = p is the cumulative Gaussian probability 
- * function, then z = qsnorm(p).
- *
- * Note that 0.0 < p < 1.0.  Data values outside this range
- * will return +/- a large number (1.0e6).
- * To compute p from a sample of data to test for Normalcy,
- * sort the N samples into non-decreasing order, label them
- * i=[1, N], and then compute p = i/(N+1).
- *
- * Author:	Walter H. F. Smith
- * Date:	19 February, 1991.
- *
- * Based on a Fortran subroutine by R. L. Parker.  I had been
- * using IMSL library routine DNORIN(DX) to do what qsnorm(p)
- * does, when I was at the Lamont-Doherty Geological Observatory
- * which had a site license for IMSL.  I now need to invert the
- * gaussian CDF without calling IMSL; hence, this routine.
- *
- */
-
-double	qsnorm(double p)
-{
-	double	t, z;
+void *New_Grdhisteq_Ctrl () {	/* Allocate and initialize a new control structure */
+	struct GRDHISTEQ_CTRL *C;
 	
-	if (p <= 0.0) {
-		fprintf(stderr,"%s: qsnorm:  Bad probability.\n", GMT_program);
-		return(-1.0e6);
-	}
-	else if (p >= 1.0) {
-		fprintf(stderr,"%s: qsnorm:  Bad probability.\n", GMT_program);
-		return(1.0e6);
-	}
-	else if (p == 0.5) {
-		return(0.0);
-	}
-	else if (p > 0.5) {
-		t = sqrt(-2.0 * log(1.0 - p) );
-		z = t - (2.515517 +t*(0.802853 +t*0.010328))/
-			(1.0 + t*(1.432788 + t*(0.189269+ t*0.001308)));
-		return(z);
-	}
-	else {
-		t = sqrt(-2.0 * log(p) );
-		z = t - (2.515517 +t*(0.802853 +t*0.010328))/
-			(1.0 + t*(1.432788 + t*(0.189269+ t*0.001308)));
-		return(-z);
-	}
+	C = (struct GRDHISTEQ_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GRDHISTEQ_CTRL), "New_Grdhisteq_Ctrl");
+	
+	/* Initialize values whose defaults are not 0/FALSE/NULL */
+	return ((void *)C);
+}
+
+void Free_Grdhisteq_Ctrl (struct GRDHISTEQ_CTRL *C) {	/* Deallocate control structure */
+	if (C->G.file) GMT_free ((void *)C->G.file);	
+	GMT_free ((void *)C);	
 }
