@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdimage.c,v 1.54 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: grdimage.c,v 1.66 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -70,7 +70,7 @@ struct GRDIMAGE_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, do_rgb = FALSE, need_to_project, normal_x, normal_y;
+	BOOLEAN error = FALSE, do_rgb = FALSE, need_to_project, normal_x, normal_y, resampled = FALSE;
 
 	unsigned char *bitimage_8 = NULL, *bitimage_24 = NULL;
 
@@ -141,7 +141,7 @@ int main (int argc, char **argv)
 						case 'F':
 						case 'f':
 							if (GMT_getrgb (&argv[i][3], Ctrl->G.f_rgb)) {
-								GMT_rgb_syntax ('G');
+								GMT_rgb_syntax ('G', " ");
 								error++;
 							}
 							else
@@ -150,7 +150,7 @@ int main (int argc, char **argv)
 						case 'B':
 						case 'b':
 							if (GMT_getrgb (&argv[i][3], Ctrl->G.b_rgb)) {
-								GMT_rgb_syntax ('G');
+								GMT_rgb_syntax ('G', " ");
 								error++;
 							}
 							else
@@ -158,7 +158,7 @@ int main (int argc, char **argv)
 							break;
 						default:	/* Same as -Gf */
 							if (GMT_getrgb (&argv[i][2], Ctrl->G.f_rgb)) {
-								GMT_rgb_syntax ('G');
+								GMT_rgb_syntax ('G', " ");
 								error++;
 							}
 							else
@@ -194,7 +194,7 @@ int main (int argc, char **argv)
 						Ctrl->T.outline = TRUE;
 						k++;
 						if (argv[i][k] && GMT_getpen (&argv[i][k], &Ctrl->T.pen)) {
-							GMT_pen_syntax ('T');
+							GMT_pen_syntax ('T', " ");
 							error++;
 						}
 					}
@@ -233,8 +233,7 @@ int main (int argc, char **argv)
 		fprintf(stderr, "\t-E sets dpi for the projected grid which must be constructed\n");
 		fprintf(stderr, "\t   if -Jx or -Jm is not selected [Default gives same size as input grid]\n");
 		fprintf(stderr, "\t   Give i to do the interpolation in PostScript at device resolution.\n");
-		fprintf (stderr,"\t-G sets transparency color for images that\n");
-		fprintf (stderr,"\t   otherwise would result in 1-bit images\n");
+		GMT_rgb_syntax ('G', "sets transparency color for images that otherwise would result in 1-bit images\n");
 		fprintf (stderr,"\t-I use illumination.  Append name of intensity grd file\n");
 		GMT_explain_option ('K');
 		fprintf (stderr, "\t-M force monochrome image\n");
@@ -243,9 +242,7 @@ int main (int argc, char **argv)
 		fprintf(stderr, "\t-Q use PS Level 3 colormasking for nodes with z = NaN.\n");
 		GMT_explain_option ('R');
 		fprintf(stderr, "\t-S sets the search radius in projected units [Default avoids aliasing]\n");
-		fprintf(stderr, "\t-T will image the data without interpolation by painting polygonal tiles\n");
-		fprintf(stderr, "\t   Append s to skip tiles for nodes with z = NaN [Default paints all tiles]\n");
-		fprintf(stderr, "\t   Append o[<pen>] to draw tile outline [Default uses no outline]\n");
+		GMT_pen_syntax ('T', "will image the data without interpolation by painting polygonal tiles\n\t   Append s to skip tiles for nodes with z = NaN [Default paints all tiles]\n\t   Append o[<pen>] to draw tile outline [Default uses no outline]");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
 		GMT_explain_option ('X');
@@ -281,8 +278,6 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	/* Get color palette file */
 
 	if (!do_rgb) GMT_read_cpt (Ctrl->C.file);
@@ -296,10 +291,7 @@ int main (int argc, char **argv)
 		GMT_grd_init (&g_head[i], argc, argv, FALSE);
 		GMT_grd_init (&r_head[i], argc, argv, FALSE);
 
-		if (GMT_read_grd_info (grdfile[i], &g_head[i])) {
-			fprintf (stderr, "%s: Error opening file %s\n", GMT_program, grdfile[i]);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd_info (grdfile[i], &g_head[i]), grdfile[i]);
 	}
 	if (do_rgb) {	/* Must ensure all three grids are coregistered */
 		if (!(g_head[0].x_min == g_head[1].x_min && g_head[0].x_min == g_head[2].x_min)) error++;
@@ -323,7 +315,7 @@ int main (int argc, char **argv)
 		north = g_head[0].y_max;
 	}
 	
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	/* Determine the wesn to be used to read the grdfile; or exit if file is outside -R */
 
@@ -344,11 +336,12 @@ int main (int argc, char **argv)
 	nm = nx * ny;
 
 	for (i = 0; i < n_grids; i++) {
-		tmp1[i] = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
-		if (GMT_read_grd (grdfile[i], &g_head[i], tmp1[i], data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grdfile[i]);
-			exit (EXIT_FAILURE);
-		}
+#ifdef _GENPER
+		tmp1[i] = (float *) GMT_memory (VNULL, (size_t)(nm + nx), sizeof (float), GMT_program);
+#else
+		tmp1[i] = (float *) GMT_memory (VNULL, (size_t)(nm), sizeof (float), GMT_program);
+#endif
+		GMT_err_fail (GMT_read_grd (grdfile[i], &g_head[i], tmp1[i], data_west, data_east, data_south, data_north, GMT_pad, FALSE), grdfile[i]);
 	}
 
 	/* If given, get intensity file or compute intensities */
@@ -360,10 +353,7 @@ int main (int argc, char **argv)
 		GMT_grd_init (&i_head, argc, argv, FALSE);
 		GMT_grd_init (&j_head, argc, argv, FALSE);
 
-		if (GMT_read_grd_info (Ctrl->I.file, &i_head)) {
-			fprintf (stderr, "%s: Error opening file %s\n", GMT_program, Ctrl->I.file);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd_info (Ctrl->I.file, &i_head), Ctrl->I.file);
 
 		if (i_head.nx != nx_f || i_head.ny != ny_f) {
 			fprintf (stderr, "%s: Intensity file has improper dimensions!\n", GMT_program);
@@ -371,10 +361,7 @@ int main (int argc, char **argv)
 		}
 		tmp2 = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 
-		if (GMT_read_grd (Ctrl->I.file, &i_head, tmp2, data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error reading file %s\n", GMT_program, Ctrl->I.file);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd (Ctrl->I.file, &i_head, tmp2, data_west, data_east, data_south, data_north, GMT_pad, FALSE), Ctrl->I.file);
 	}
 
 	for (i = 0; i < n_grids; i++) GMT_set_proj_limits (&r_head[i], &g_head[i]);
@@ -390,10 +377,10 @@ int main (int argc, char **argv)
 		}
 		for (i = 0; i < n_grids; i++) {
 			grid_type = (Ctrl->E.dpi > 0) ? 1 : g_head[i].node_offset;	/* Force pixel if dpi is set */
-			GMT_grdproject_init (&r_head[i], 0.0, 0.0, nx_proj, ny_proj, Ctrl->E.dpi, grid_type);
+			GMT_err_fail (GMT_grdproject_init (&r_head[i], 0.0, 0.0, nx_proj, ny_proj, Ctrl->E.dpi, grid_type), grdfile[i]);
 			GMT_init_search_radius (&Ctrl->S.radius, &r_head[i], &g_head[i], FALSE);
 			nm2 = r_head[i].nx * r_head[i].ny;
-			map[i] = (float *) GMT_memory (VNULL, (size_t)nm2, sizeof (float), "grdproject");
+			map[i] = (float *) GMT_memory (VNULL, (size_t)nm2, sizeof (float), "grdimage");
 			GMT_grd_forward (tmp1[i], &g_head[i], map[i], &r_head[i], Ctrl->S.radius);
 			GMT_free ((void *)tmp1[i]);
 		}
@@ -405,13 +392,13 @@ int main (int argc, char **argv)
 				nx_proj = i_head.nx;
 				ny_proj = i_head.ny;
 			}
-			GMT_grdproject_init (&j_head, 0.0, 0.0, nx_proj, ny_proj, Ctrl->E.dpi, grid_type);
-			intensity = (float *) GMT_memory (VNULL, (size_t)nm2, sizeof (float), "grdproject");
+			GMT_err_fail (GMT_grdproject_init (&j_head, 0.0, 0.0, nx_proj, ny_proj, Ctrl->E.dpi, grid_type), Ctrl->I.file);
+			intensity = (float *) GMT_memory (VNULL, (size_t)nm2, sizeof (float), "grdimage");
 			GMT_grd_forward (tmp2, &i_head, intensity, &j_head, Ctrl->S.radius);
 			GMT_free ((void *)tmp2);
 		}
 		nm = nm2;
-		/* project_info.xyz_pos[0] = project_info.xyz_pos[1] = 1; */	/* Since we have applied the projection we do no longer have 'negative' axes */
+		resampled = TRUE;
 	}
 	else {	/* Simply copy g_head[0] info to r_head[0] */
 		for (i = 0; i < n_grids; i++) {
@@ -455,7 +442,7 @@ int main (int argc, char **argv)
 			grd_y = GMT_j_to_y (j, g_head[0].y_min, g_head[0].y_max, g_head[0].y_inc, g_head[0].xy_off, g_head[0].ny);
 			y_bot = grd_y - dy2;
 			y_top = grd_y + dy2;
-			if (project_info.degree[1]) {
+			if (GMT_io.in_col_type[1] == GMT_IS_LAT) {
 				if (y_bot < -90.0) y_bot = -90.0;
 				if (y_top > +90.0) y_top = +90.0;
 			}
@@ -480,7 +467,7 @@ int main (int argc, char **argv)
 				}
 				else {
 					if (GMT_is_fnan (map[0][node]) && Ctrl->T.skip) continue;
-					index = GMT_get_rgb24 (map[0][node], rgb);
+					index = GMT_get_rgb_from_z (map[0][node], rgb);
 					if (GMT_cpt_skip) continue;	/* Skip this z-slice */
 				}
 				if (Ctrl->I.active && index != -1) GMT_illuminate (intensity[node], rgb);
@@ -566,8 +553,8 @@ int main (int argc, char **argv)
 			bitimage_24[2] = (unsigned char)GMT_bfn[GMT_NAN].rgb[2];
 		}
 	}
-	normal_x = !(project_info.projection == GMT_LINEAR && !project_info.xyz_pos[0]);
-	normal_y = !(project_info.projection == GMT_LINEAR && !project_info.xyz_pos[1]);
+	normal_x = !(project_info.projection == GMT_LINEAR && !project_info.xyz_pos[0] && !resampled);
+	normal_y = !(project_info.projection == GMT_LINEAR && !project_info.xyz_pos[1] && !resampled);
 	for (j = 0, byte = PS_colormask_off; j < r_head[0].ny; j++) {
 		kk = r_head[0].nx * (normal_y ? j : r_head[0].ny - j - 1);
 		for (i = 0; i < r_head[0].nx; i++) {	/* Compute rgb for each pixel */
@@ -586,7 +573,7 @@ int main (int argc, char **argv)
 				}
 			}
 			else
-				index = GMT_get_rgb24 (map[0][node], rgb);
+				index = GMT_get_rgb_from_z (map[0][node], rgb);
 			if (Ctrl->I.active && index != -1) GMT_illuminate (intensity[node], rgb);
 
 			if (GMT_gray)	/* Color table only has grays, pick r */
@@ -696,20 +683,31 @@ void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g)
 	 * if GMT_grdproject_init is called at a later stage */
 
 	int i, j;
-	BOOLEAN all_lats, all_lons;
+	BOOLEAN all_lats = FALSE, all_lons = FALSE;
 	double lon, lat, x, y;
 
 	r->nx = g->nx;
 	r->ny = g->ny;
+	r->node_offset = g->node_offset;
 
-	all_lats = (fabs (g->y_max - 90.0) < GMT_CONV_LIMIT && fabs (g->y_min + 90.0) < GMT_CONV_LIMIT);
-	all_lons = (fabs (g->x_max - g->x_min - 360.0) < GMT_CONV_LIMIT);
-
-	if (GMT_IS_AZIMUTHAL && all_lons && all_lats) {	/* Whole globe, get square box */
+#ifdef _GENPER
+	if( project_info.projection == GMT_GENPER && project_info.g_width ) {
 		r->x_min = project_info.xmin;	r->x_max = project_info.xmax;
 		r->y_min = project_info.ymin;	r->y_max = project_info.ymax;
 		return;
 	}
+#endif   /* END of _GENPER */
+
+	if (GMT_IS_AZIMUTHAL) {	/* Applies only to Azimuthal projections */
+		all_lats = (fabs (g->y_max - 90.0) < GMT_CONV_LIMIT && fabs (g->y_min + 90.0) < GMT_CONV_LIMIT);
+		all_lons = (fabs (g->x_max - g->x_min - 360.0) < GMT_CONV_LIMIT);
+
+		if (all_lons && all_lats) {	/* Whole globe, get square box */
+			r->x_min = project_info.xmin;	r->x_max = project_info.xmax;
+			r->y_min = project_info.ymin;	r->y_max = project_info.ymax;
+			return;
+		}
+	}
 
 	/* Must search for extent along perimeter */
 
@@ -734,11 +732,10 @@ void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g)
 		r->x_min = MIN (r->x_min, x);	r->x_max = MAX (r->x_max, x);
 		r->y_min = MIN (r->y_min, y);	r->y_max = MAX (r->y_max, y);
 	}
-
-	if (GMT_IS_AZIMUTHAL && all_lons) {	/* Full 360, use min/max for x */
+	if (all_lons) {	/* Full 360, use min/max for x */
 		r->x_min = project_info.xmin;	r->x_max = project_info.xmax;
 	}
-	if (GMT_IS_AZIMUTHAL && all_lats) {	/* Full -90/+90, use min/max for y */
+	if (all_lats) {	/* Full -90/+90, use min/max for y */
 		r->y_min = project_info.ymin;	r->y_max = project_info.ymax;
 	}
 }
