@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdmask.c,v 1.42 2006/05/14 23:31:46 pwessel Exp $
+ *	$Id: grdmask.c,v 1.52 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -80,7 +80,8 @@ int main (int argc, char **argv)
 	float *data;
 
 	double	*x, *y, xx, yy, xmin, xmax, ymin, ymax, lon_sum, lat_sum, dlon;
-	double xinc2, yinc2, distance, radius = 0.0, shrink = 1.0, idx, idy, x0, y0, *in;
+	double xinc2, yinc2, distance, shrink = 1.0, idx, idy, x0, y0, *in;
+	double xmin1, xmin2, xmax1, xmax2, lon_w;
 
 	FILE *fp;
 
@@ -224,11 +225,12 @@ int main (int argc, char **argv)
                 fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least 2 columns\n", GMT_program);
 		error++;
 	}
-
+	if (Ctrl->S.active && (Ctrl->S.radius <= 0.0 || GMT_is_dnan (Ctrl->S.radius))) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Radius is NaN or negative\n", GMT_program);
+		error++;
+	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -241,7 +243,7 @@ int main (int argc, char **argv)
 	header.x_inc = Ctrl->I.xinc;
 	header.y_inc = Ctrl->I.yinc;
 	GMT_RI_prepare (&header);	/* Ensure -R -I consistency and set nx, ny */
-	GMT_grd_RI_verify (&header, 1);
+	GMT_err_fail (GMT_grd_RI_verify (&header, 1), Ctrl->G.file);
 
 	header.xy_off = 0.5 * header.node_offset;
 	xinc2 = header.xy_off * header.x_inc;
@@ -266,12 +268,12 @@ int main (int argc, char **argv)
 
 	if (distance_flag > 0) {
 		shrink = cos (0.5 * (header.y_min + header.y_max) * D2R);
-		di = (int)ceil (radius / (project_info.KM_PR_DEG * header.x_inc * shrink));
-		dj = (int)ceil (radius / (project_info.KM_PR_DEG * header.y_inc));
+		di = (int)ceil (Ctrl->S.radius / (project_info.KM_PR_DEG * header.x_inc * shrink));
+		dj = (int)ceil (Ctrl->S.radius / (project_info.KM_PR_DEG * header.y_inc));
 	}
 	else {
-		di = (int)ceil (radius * idx);
-		dj = (int)ceil (radius * idy);
+		di = (int)ceil (Ctrl->S.radius * idx);
+		dj = (int)ceil (Ctrl->S.radius * idy);
 	}
 	periodic = (GMT_io.in_col_type[GMT_X] == GMT_IS_LON);	/* Dealing with geographic coordinates */
 	resample = (!Ctrl->A.active && periodic);
@@ -294,6 +296,7 @@ int main (int argc, char **argv)
 		break;
 	}
 
+	memset ((void *)&P, 0, sizeof (struct GMT_LINE_SEGMENT));
 	P.coord = (double **) GMT_memory (VNULL, 2, sizeof (double *), GMT_program);	/* Needed as pointers below */
 	P.min = (double *) GMT_memory (VNULL, 2, sizeof (double), GMT_program);		/* Needed to hold min lon/lat */
 	P.max = (double *) GMT_memory (VNULL, 2, sizeof (double), GMT_program);		/* Needed to hold max lon/lat */
@@ -339,6 +342,8 @@ int main (int argc, char **argv)
 			n_path = 0;
 			xmin = ymin = +DBL_MAX;
 			xmax = ymax = -DBL_MAX;
+			xmin1 = xmin2 = 360.0;
+			xmax1 = xmax2 = -360.0;
 			lon_sum = lat_sum = 0.0;
 
 			while (!(GMT_io.status & (GMT_IO_SEGMENT_HEADER | GMT_IO_EOF))) {	/* Keep going until FALSE  */
@@ -349,15 +354,29 @@ int main (int argc, char **argv)
 				x[n_path] = in[GMT_X];
 				y[n_path] = in[GMT_Y];
 
-				if (x[n_path] > xmax) xmax = x[n_path];
-				if (x[n_path] < xmin) xmin = x[n_path];
 				if (y[n_path] > ymax) ymax = y[n_path];
 				if (y[n_path] < ymin) ymin = y[n_path];
-				if (periodic && n_path > 0) {	/* Do longitude-difference check sum */
-					dlon = x[n_path] - x[n_path-1];
-					if (fabs (dlon) > 180.0) dlon = copysign (360.0 - fabs (dlon), -dlon);
-					lon_sum += dlon;
-					lat_sum += y[n_path];
+				if (periodic) {	/* Longitudes */
+					lon_w = x[n_path];
+					if (x[n_path] < 0.0) x[n_path] += 360.0;	/* Start off with everything in 0-360 range */
+					if (x[n_path] < 180.0) {
+						xmin1 = MIN (x[n_path], xmin1);
+						xmax1 = MAX (x[n_path], xmax1);
+					}
+					else {
+						xmin2 = MIN (lon_w, xmin2);
+						xmax2 = MAX (lon_w, xmax2);
+					}
+					if (n_path > 0) {	/* Do longitude-difference check sum */
+						dlon = x[n_path] - x[n_path-1];
+						if (fabs (dlon) > 180.0) dlon = copysign (360.0 - fabs (dlon), -dlon);
+						lon_sum += dlon;
+						lat_sum += y[n_path];
+					}
+				}
+				else {	/* Cartesian x */
+					if (x[n_path] > xmax) xmax = x[n_path];
+					if (x[n_path] < xmin) xmin = x[n_path];
 				}
 				n_path++;
 
@@ -369,6 +388,25 @@ int main (int argc, char **argv)
 				n_fields = GMT_input (fp, &n_expected_fields, &in);
 			}
 			n_pol++;
+			if (periodic) {	/* Longitudes */
+				if (xmin1 == 360.0) {		/* Only negative longitudes found */
+					xmin = xmin2;
+					xmax = xmax2;
+				}
+				else if (xmin2 == 360.0) {	/* Only positive longitudes found */
+					xmin = xmin1;
+					xmax = xmax1;
+				}
+				else if ((xmin1 - xmax2) < 90.0) {	/* Crossed Greenwich */
+					xmin = xmin2;
+					xmax = xmax1;
+				}
+				else {					/* Crossed Dateline */
+					xmin = xmin1;
+					xmax = xmax2;
+				}
+				if (xmin > xmax) xmin -= 360.0;
+			}
 			if (Ctrl->S.active) {	/* Assign 'inside' to nodes within given distance of data constrains */
 				for (k = 0; k < n_path; k++) {
 
@@ -387,7 +425,7 @@ int main (int argc, char **argv)
 					j0 = GMT_y_to_j (y[k], header.y_min, header.y_inc, header.xy_off, header.ny);
 					if (j0 == header.ny) j0--;	/* Was exactly on the ymin edge */
 					data[j0 * header.nx + i0] = (float)Ctrl->N.mask[GRDMASK_INSIDE];	/* This is the nearest node */
-					if (radius == 0.0) continue;
+					if (Ctrl->S.radius == 0.0) continue;
 
 					for (j = j0 - dj; j <= (j0 + dj); j++) {
 						if (j < 0 || j >= header.ny) continue;
@@ -397,7 +435,7 @@ int main (int argc, char **argv)
 							x0 = GMT_i_to_x (i, header.x_min, header.x_max, header.x_inc, header.xy_off, header.nx);
 							y0 = GMT_j_to_y (j, header.y_min, header.y_max, header.y_inc, header.xy_off, header.ny);
 							distance = (GMT_distance_func) (x[k], y[k], x0, y0);
-							if (distance > radius) continue;
+							if (distance > Ctrl->S.radius) continue;
 							data[ij] = (float)Ctrl->N.mask[GRDMASK_INSIDE];	/* The in value */
 						}
 					}
@@ -429,6 +467,8 @@ int main (int argc, char **argv)
 					if (fabs (fabs (lon_sum) - 360.0) < GMT_CONV_LIMIT) {	/* Contains a pole, convert to polar x,y */
 						P.pole = (lat_sum < 0.0) ? -1 : +1;	/* S or N pole */
 					}
+					else
+						P.pole = 0;
 				}
 
 				for (j = 0; j < header.ny; j++) {
@@ -438,8 +478,8 @@ int main (int argc, char **argv)
 					/* First check if point is outside, then there is no need to assign value */
 					
 					if (periodic) {	/* Containing annulus test */
-						if (P.pole == -1 && yy > ymax) continue;
-						if (P.pole == +1 && yy < ymin) continue;
+						if (P.pole != +1 && yy > ymax) continue;	/* No N polar cap and beyond north */
+						if (P.pole != -1 && yy < ymin) continue;	/* No S polar cap and beyond south */
 					}
 					else if (yy < ymin || yy > ymax)	/* Cartesian case */
 						continue;
@@ -447,7 +487,14 @@ int main (int argc, char **argv)
 					for (i = 0; i < header.nx; i++) {
 						xx = GMT_i_to_x (i, header.x_min, header.x_max, header.x_inc, header.xy_off, header.nx);
 						if (periodic) {
-							side = GMT_inonout_sphpol (xx, yy, &P);
+							if (P.pole)	/* 360-degree polar cap, must check fully */
+								side = GMT_inonout_sphpol (xx, yy, &P);
+							else {	/* See if we are outside range of longitudes for polygon */
+								while (xx > xmin) xx -= 360.0;	/* Wind clear of west */
+								while (xx < xmin) xx += 360.0;	/* Wind east until inside or beyond east */
+								if (xx > xmax) continue;	/* Point outside, no need to assign value */
+								side = GMT_inonout_sphpol (xx, yy, &P);
+							}
 						}
 						else {
 							if (xx < xmin || xx > xmax) continue;	/* Point outside, no need to assign value */
@@ -469,10 +516,7 @@ int main (int argc, char **argv)
 		if (fp != GMT_stdin) GMT_fclose (fp);
 	}
 
-	if (GMT_write_grd (Ctrl->G.file, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *)data);
 	GMT_free ((void *)x);
