@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdpaste.c,v 1.14 2006/04/12 21:55:46 pwessel Exp $
+ *	$Id: grdpaste.c,v 1.18 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -123,22 +123,14 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	/* Check that the options selected make sense */
 
 
 	/* Try to find a common side to join on  */
 
 	GMT_grd_init (&hc, argc, argv, FALSE);
-	if (GMT_read_grd_info (grd_a, &ha)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, grd_a);
-		exit (EXIT_FAILURE);
-	}
-	if (GMT_read_grd_info (grd_b, &hb)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, grd_b);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (grd_a, &ha), grd_a);
+	GMT_err_fail (GMT_read_grd_info (grd_b, &hb), grd_b);
 
 	if (ha.node_offset != hb.node_offset) error = TRUE;
 	if ((ha.z_scale_factor != hb.z_scale_factor) || (ha.z_add_offset != hb.z_add_offset)) {
@@ -232,59 +224,32 @@ int main (int argc, char **argv)
 	switch (way) {
 		case 1:
 			GMT_pad[3] = hb.ny - one_or_zero;
-			if (GMT_read_grd (grd_a, &ha, c, ha.x_min, ha.x_max, ha.y_min, ha.y_max, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_a);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (grd_a, &ha, c, ha.x_min, ha.x_max, ha.y_min, ha.y_max, GMT_pad, FALSE), grd_a);
 			GMT_pad[3] = 0;	GMT_pad[2] = ha.ny - one_or_zero;
-			if (GMT_read_grd (grd_b, &hb, c, hb.x_min, hb.x_max, hb.y_min, hb.y_max, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_b);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (grd_b, &hb, c, hb.x_min, hb.x_max, hb.y_min, hb.y_max, GMT_pad, FALSE), grd_b);
 			break;
 		case 2:
 			GMT_pad[2] = hb.ny - one_or_zero;
-			if (GMT_read_grd (grd_a, &ha, c, ha.x_min, ha.x_max, ha.y_min, ha.y_max, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_a);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (grd_a, &ha, c, ha.x_min, ha.x_max, ha.y_min, ha.y_max, GMT_pad, FALSE), grd_a);
 			GMT_pad[2] = 0;	GMT_pad[3] = ha.ny - one_or_zero;
-			if (GMT_read_grd (grd_b, &hb, c, hb.x_min, hb.x_max, hb.y_min, hb.y_max, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_b);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (grd_b, &hb, c, hb.x_min, hb.x_max, hb.y_min, hb.y_max, GMT_pad, FALSE), grd_b);
 			break;
 		case 3:
 			GMT_pad[0] = hb.nx - one_or_zero;
-			if (GMT_read_grd (grd_a, &ha, c, ha.x_min, ha.x_max, ha.y_min, ha.y_max, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_a);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (grd_a, &ha, c, ha.x_min, ha.x_max, ha.y_min, ha.y_max, GMT_pad, FALSE), grd_a);
 			GMT_pad[0] = 0;	GMT_pad[1] = ha.nx - one_or_zero;
-			if (GMT_read_grd (grd_b, &hb, c, hb.x_min, hb.x_max, hb.y_min, hb.y_max, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_b);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (grd_b, &hb, c, hb.x_min, hb.x_max, hb.y_min, hb.y_max, GMT_pad, FALSE), grd_b);
 			break;
 		case 4:
 			GMT_pad[1] = hb.nx - one_or_zero;
-			if (GMT_read_grd (grd_a, &ha, c, ha.x_min, ha.x_max, ha.y_min, ha.y_max, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_a);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (grd_a, &ha, c, ha.x_min, ha.x_max, ha.y_min, ha.y_max, GMT_pad, FALSE), grd_a);
 			GMT_pad[1] = 0;	GMT_pad[0] = ha.nx - one_or_zero;
-			if (GMT_read_grd (grd_b, &hb, c, hb.x_min, hb.x_max, hb.y_min, hb.y_max, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grd_b);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (grd_b, &hb, c, hb.x_min, hb.x_max, hb.y_min, hb.y_max, GMT_pad, FALSE), grd_b);
 			break;
 	}
 
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;
-	if (GMT_write_grd (Ctrl->G.file, &hc, c, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &hc, c, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *) c);
 
