@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdproject.c,v 1.28 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: grdproject.c,v 1.34 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -76,7 +76,7 @@ int main (int argc, char **argv)
 {
 	BOOLEAN error = FALSE, set_n = FALSE, shift_xy = FALSE, offset;
 
-	char *infile, format[BUFSIZ], unit_name[80], scale_unit_name[80];
+	char *infile, format[BUFSIZ], unit_name[GRD_UNIT_LEN], scale_unit_name[GRD_UNIT_LEN];
 
 	int i, unit = 0;
 	
@@ -251,22 +251,20 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
-	if (Ctrl->M.active) GMT_set_measure_unit ('M', Ctrl->M.unit);
+	if (Ctrl->M.active) GMT_err_fail (GMT_set_measure_unit (Ctrl->M.unit), "-M");
 	shift_xy = !(Ctrl->C.easting == 0.0 && Ctrl->C.northing == 0.0);
 	
 	unit = GMT_check_scalingopt ('A', Ctrl->A.unit, scale_unit_name);
 	GMT_init_scales (unit, &fwd_scale, &inv_scale, &inch_to_unit, &unit_to_inch, unit_name);
 
-	GMT_map_setup (w, e, s, n);
+	GMT_err_fail (GMT_map_setup (w, e, s, n), "");
 
 	xmin = (Ctrl->C.active) ? project_info.xmin - project_info.x0 : project_info.xmin;
 	xmax = (Ctrl->C.active) ? project_info.xmax - project_info.x0 : project_info.xmax;
 	ymin = (Ctrl->C.active) ? project_info.ymin - project_info.y0 : project_info.ymin;
 	ymax = (Ctrl->C.active) ? project_info.ymax - project_info.y0 : project_info.ymax;
 	if (Ctrl->A.active) {	/* Convert to chosen units */
-		strncpy (unit_name, scale_unit_name, 80);
+		strncpy (unit_name, scale_unit_name, GRD_UNIT_LEN);
 		xmin /= project_info.x_scale;
 		xmax /= project_info.x_scale;
 		ymin /= project_info.y_scale;
@@ -302,10 +300,7 @@ int main (int argc, char **argv)
 
 		g_head.x_min = w;	g_head.x_max = e;	g_head.y_min = s;	g_head.y_max = n;
 
-		if (GMT_read_grd_info (infile, &r_head)) {
-			fprintf (stderr, "%s: Error opening file %s\n", GMT_program, infile);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd_info (infile, &r_head), infile);
 
 		if (Ctrl->S.careful) {
 			GMT_boundcond_init (&edgeinfo);
@@ -316,17 +311,14 @@ int main (int argc, char **argv)
 			nm = ((size_t)r_head.nx) * ((size_t)r_head.ny);
 
 		rect = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
-		if (GMT_read_grd (infile, &r_head, rect, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error reading file %s\n", infile, GMT_program);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd (infile, &r_head, rect, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), infile);
 		offset = r_head.node_offset;		/* Same as input */
 		if (Ctrl->F.active) offset = !offset;	/* Toggle */
 		if (set_n) {
 			Ctrl->N.nx = r_head.nx;
 			Ctrl->N.ny = r_head.ny;
 		}
-		GMT_grdproject_init (&g_head, Ctrl->D.xinc, Ctrl->D.yinc, Ctrl->N.nx, Ctrl->N.ny, Ctrl->E.dpi, offset);
+		GMT_err_fail (GMT_grdproject_init (&g_head, Ctrl->D.xinc, Ctrl->D.yinc, Ctrl->N.nx, Ctrl->N.ny, Ctrl->E.dpi, offset), Ctrl->G.file);
 		geo = (float *) GMT_memory (VNULL, (size_t)(g_head.nx * g_head.ny), sizeof (float), GMT_program);
 		if (gmtdefs.verbose) {
 			fprintf (stderr, "%s:  Transform ", GMT_program);
@@ -385,18 +377,11 @@ int main (int argc, char **argv)
 
 		if (Ctrl->S.careful) GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;
 
-		if (GMT_write_grd (Ctrl->G.file, &g_head, geo, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-			exit (EXIT_FAILURE);
-		}
-
+		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &g_head, geo, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 	}
 	else {	/* Forward projection from geographical to rectangular grid */
 
-		if (GMT_read_grd_info (infile, &g_head)) {
-			fprintf (stderr, "%s: Error opening file %s\n", GMT_program, infile);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd_info (infile, &g_head), infile);
 
 		if (Ctrl->S.careful) {
 			GMT_boundcond_init (&edgeinfo);
@@ -407,10 +392,7 @@ int main (int argc, char **argv)
 			nm = ((size_t)g_head.nx) * ((size_t)g_head.ny);
 
 		geo = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
-		if (GMT_read_grd (infile, &g_head, geo, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error reading file %s\n", GMT_program, infile);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd (infile, &g_head, geo, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), infile);
 
 		r_head.x_min = project_info.xmin;	r_head.x_max = project_info.xmax;
 		r_head.y_min = project_info.ymin;	r_head.y_max = project_info.ymax;
@@ -445,7 +427,7 @@ int main (int argc, char **argv)
 		offset = g_head.node_offset;		/* Same as input */
 		if (Ctrl->F.active) offset = !offset;	/* Toggle */
 
-		GMT_grdproject_init (&r_head, Ctrl->D.xinc, Ctrl->D.yinc, Ctrl->N.nx, Ctrl->N.ny, Ctrl->E.dpi, offset);
+		GMT_err_fail (GMT_grdproject_init (&r_head, Ctrl->D.xinc, Ctrl->D.yinc, Ctrl->N.nx, Ctrl->N.ny, Ctrl->E.dpi, offset), Ctrl->G.file);
 		rect = (float *) GMT_memory (VNULL, (size_t)(r_head.nx * r_head.ny), sizeof (float), GMT_program);
 		GMT_init_search_radius (&Ctrl->S.radius, &r_head, &g_head, FALSE);
 		if (Ctrl->S.careful)
@@ -493,11 +475,7 @@ int main (int argc, char **argv)
 
 		if (Ctrl->S.careful) GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;
 
-		if (GMT_write_grd (Ctrl->G.file, &r_head, rect, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-			exit (EXIT_FAILURE);
-		}
-
+		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &r_head, rect, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 	}
 
 	GMT_free ((void *)geo);
