@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdsample.c,v 1.41 2006/10/17 22:10:42 remko Exp $
+ *	$Id: grdsample.c,v 1.46 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -197,10 +197,7 @@ int main (int argc, char **argv)
 	if (Ctrl->L.active && GMT_boundcond_parse (&edgeinfo, Ctrl->L.mode)) error++;
 	if (error) exit (EXIT_FAILURE);
 	
-	if (GMT_read_grd_info (infile, &grd_a)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, infile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (infile, &grd_a), infile);
 
 	if (!project_info.region_supplied) {
 		grd_b.x_min = grd_a.x_min;
@@ -229,8 +226,6 @@ int main (int argc, char **argv)
 
 	GMT_RI_prepare (&grd_b);	/* Ensure -R -I consistency and set nx, ny */
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	GMT_boundcond_param_prep (&grd_a, &edgeinfo);
 
 	a = (float *) GMT_memory (VNULL, (size_t)((grd_a.nx + 4) * (grd_a.ny + 4)), sizeof(float), GMT_program);
@@ -251,7 +246,7 @@ int main (int argc, char **argv)
 		grd_b.y_inc = GMT_get_inc (grd_b.y_min, grd_b.y_max, grd_b.ny, grd_b.node_offset);
 	}
 
-	GMT_grd_RI_verify (&grd_b, 1);
+	GMT_err_fail (GMT_grd_RI_verify (&grd_b, 1), Ctrl->G.file);
 
 	nm = ((size_t)grd_b.nx) * ((size_t)grd_b.ny);
 	b = (float *) GMT_memory (VNULL, nm, sizeof(float), GMT_program);
@@ -261,10 +256,7 @@ int main (int argc, char **argv)
 
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;	/* Leave room for 2 empty boundary rows/cols */
 
-	if (GMT_read_grd (infile, &grd_a, a, grd_a.x_min, grd_a.x_max, grd_a.y_min, grd_a.y_max, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, infile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd (infile, &grd_a, a, grd_a.x_min, grd_a.x_max, grd_a.y_min, grd_a.y_max, GMT_pad, FALSE), infile);
 
 	/* Initialize bcr structure:  */
 
@@ -314,10 +306,7 @@ int main (int argc, char **argv)
 	}
 
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;	/* No boundary rows/cols on output */
-	if (GMT_write_grd (Ctrl->G.file, &grd_b, b, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &grd_b, b, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *)a);
 	GMT_free ((void *)b);
