@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrack.c,v 1.43 2006/05/08 03:24:05 pwessel Exp $
+ *	$Id: grdtrack.c,v 1.50 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -248,8 +248,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (edgeinfo.gn) {
 		GMT_io.in_col_type[0] = GMT_io.out_col_type[0] = GMT_IS_LON;
 		GMT_io.in_col_type[1] = GMT_io.out_col_type[1] = GMT_IS_LAT;
@@ -272,10 +270,7 @@ int main (int argc, char **argv)
 
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;
 	if (Ctrl->G.type == 0) {	/* Regular GMT grids */
-		if (GMT_read_grd_info (Ctrl->G.file, &grd)) {
-			fprintf (stderr, "%s: Error opening file %s\n", GMT_program, Ctrl->G.file);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd_info (Ctrl->G.file, &grd), Ctrl->G.file);
 
 		if (west == east) {	/* No subset asked for */
 			west = grd.x_min;
@@ -290,10 +285,7 @@ int main (int argc, char **argv)
 
 		f = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
 
-		if (GMT_read_grd (Ctrl->G.file, &grd, f, west, east, south, north, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error reading file %s\n", GMT_program, Ctrl->G.file);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd (Ctrl->G.file, &grd, f, west, east, south, north, GMT_pad, FALSE), Ctrl->G.file);
 
 		project_info.w = west;	project_info.e = east;
 		project_info.s = south;	project_info.n = north;
@@ -388,7 +380,10 @@ int main (int argc, char **argv)
 
 		if (!out) out = (double *) GMT_memory (VNULL, (size_t)n_output, sizeof (double), GMT_program);
 
-		if (pure_ascii && n_expected_fields > 2) {
+		if (Ctrl->Z.active) {	/* Simply print out value */
+			GMT_output (GMT_stdout, 1, &value);
+		}
+		else if (pure_ascii && n_expected_fields > 2) {
 			/* Special case: Ascii i/o and at least 3 columns:
 			   Columns beyond first two could be text strings */
 
@@ -400,9 +395,6 @@ int main (int argc, char **argv)
 			fprintf (GMT_stdout, "%s\t", line);
 			GMT_ascii_output_one (GMT_stdout, value, 2);	fprintf (GMT_stdout, "\n");
 		}
-		else if (Ctrl->Z.active) {	/* Simply print out value */
-			GMT_output (GMT_stdout, 1, &value);
-		}
 		else {	/* Simply copy other columns, append value, and output */
 			for (i = 0; i < n_expected_fields; i++) out[i] = in[i];
 			out[i] = value;
