@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrend.c,v 1.19 2006/04/13 01:44:31 pwessel Exp $
+ *	$Id: grdtrend.c,v 1.23 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -236,23 +236,18 @@ int main(int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 /* End of argument parsing.  */
 
 	trivial = ( (Ctrl->N.value < 5) && (!(Ctrl->N.robust)) && (!Ctrl->W.file) );
 
 /* Read the input file:  */
 
-	if (GMT_read_grd_info (i_filename, &head_d)) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR:  File %s not found\n", GMT_program, i_filename);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (i_filename, &head_d), i_filename);
 
 	GMT_grd_init (&head_d, argc, argv, TRUE);
 	nxy = head_d.nx * head_d.ny;
 	data = (float *) GMT_memory (VNULL, (size_t)nxy, sizeof (float), GMT_program);
-	GMT_read_grd (i_filename, &head_d, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+	GMT_err_fail (GMT_read_grd (i_filename, &head_d, data, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), i_filename);
 
 	/* Check for NaNs:  */
 	i = 0;
@@ -282,16 +277,13 @@ int main(int argc, char **argv)
 		weight = (float *) GMT_memory (VNULL, (size_t)nxy, sizeof (float), GMT_program);
 		if (!GMT_access (Ctrl->W.file, R_OK)) {	/* We have weights on input  */
 			GMT_grd_init (&head_w, argc, argv, FALSE);
-			if (GMT_read_grd_info (Ctrl->W.file, &head_w)) {
-				fprintf (stderr, "%s: GMT SYNTAX ERROR:  File %s not found\n", GMT_program, Ctrl->W.file);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd_info (Ctrl->W.file, &head_w), Ctrl->W.file);
 			if (head_w.nx != head_d.nx || head_w.ny != head_d.ny) {
 				fprintf (stderr,"%s:  Input weight file does not match input data file.  Ignoring.\n", GMT_program);
 				for (i = 0; i < nxy; i++) weight[i] = 1.0;
 			}
 			else
-				GMT_read_grd (Ctrl->W.file, &head_w, weight, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+				GMT_err_fail (GMT_read_grd (Ctrl->W.file, &head_w, weight, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->W.file);
 		}
 		else {
 			for (i = 0; i < nxy; i++) weight[i] = 1.0;
@@ -363,15 +355,15 @@ int main(int argc, char **argv)
 	if (gmtdefs.verbose) write_model_parameters(gtd, Ctrl->N.value);
 	if (Ctrl->T.file) {
 		strcpy (head_d.title, "trend surface");
-		GMT_write_grd (Ctrl->T.file, &head_d, trend, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+		GMT_err_fail (GMT_write_grd (Ctrl->T.file, &head_d, trend, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->T.file);
 	}
 	if (Ctrl->D.file) {
 		strcpy (head_d.title, "trend residuals");
-		GMT_write_grd (Ctrl->D.file, &head_d, resid, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+		GMT_err_fail (GMT_write_grd (Ctrl->D.file, &head_d, resid, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->D.file);
 	}
 	if (Ctrl->W.file && Ctrl->N.robust) {
 		strcpy (head_d.title, "trend weights");
-		GMT_write_grd (Ctrl->W.file, &head_d, weight, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE);
+		GMT_err_fail (GMT_write_grd (Ctrl->W.file, &head_d, weight, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->W.file);
 	}
 
 /* That's all, folks!  */
