@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvector.c,v 1.32 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: grdvector.c,v 1.41 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -121,6 +121,7 @@ int main (int argc, char **argv)
 				case 'Y':
 				case 'y':
 				case 'c':
+				case 'f':
 				case '\0':
 					error += GMT_parse_common_options (argv[i], &west, &east, &south, &north);
 					break;
@@ -128,7 +129,7 @@ int main (int argc, char **argv)
 				/* Supplemental parameters */
 
 				case 'A':
-					Ctrl->A.active = FALSE;
+					Ctrl->A.active = TRUE;
 					break;
 				case 'C':	/* Vary symbol color with z */
 					Ctrl->C.active = TRUE;
@@ -140,7 +141,7 @@ int main (int argc, char **argv)
 				case 'G':		/* Set Gray shade for polygon */
 					Ctrl->G.active = TRUE;
 					if (GMT_getfill (&argv[i][2], &Ctrl->G.fill)) {
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					break;
@@ -198,7 +199,7 @@ int main (int argc, char **argv)
 				case 'W':		/* Set line attributes */
 					Ctrl->W.active = TRUE;
 					if (argv[i][2] && GMT_getpen (&argv[i][2], &Ctrl->W.pen)) {
-						GMT_pen_syntax ('W');
+						GMT_pen_syntax ('W', " ");
 						error++;
 					}
 					break;
@@ -232,8 +233,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('b');
 		fprintf (stderr, "\t-C Use cpt-file to assign colors based on vector length\n");
 		fprintf (stderr, "\t-E cEnter vectors on grid nodes [Default draws from grid node]\n");
-		fprintf (stderr, "\t-G Specify color. fill can be either <r/g/b> (each 0-255) for color or (0-255) for gray [0].\n");
-		fprintf (stderr, "\t   Default is no fill (vector outlines only)\n");
+		GMT_fill_syntax ('G', "Select vector fill [Default is outlines only].");
 		fprintf (stderr, "\t-I plots only those nodes that are <dx/dy> apart [Default is all nodes]\n");
 		GMT_explain_option ('K');
 		fprintf (stderr, "\t-N Do Not clip vectors that exceed the map boundaries [Default will clip]\n");
@@ -251,11 +251,13 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-T means azimuth should be converted to angles based on map projection\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
-		fprintf (stderr, "\t-W sets pen attributes [width = %gp, color = (%d/%d/%d), texture = solid line].\n", 
+		GMT_pen_syntax ('W', "sets pen attributes.");
+		fprintf (stderr, "\t   Default pen attributes [width = %gp, color = (%d/%d/%d), solid line].\n", 
 			Ctrl->W.pen.width, Ctrl->W.pen.rgb[0], Ctrl->W.pen.rgb[1], Ctrl->W.pen.rgb[2]);
 		GMT_explain_option ('X');
 		fprintf (stderr, "\t-Z means the angles provided are azimuths rather than direction\n");
 		GMT_explain_option ('c');
+		GMT_explain_option ('f');
 		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
@@ -280,7 +282,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -Sl, -Q options:  Cannot use -Q..n<size> with -Sl\n", GMT_program);
 		error++;
 	}
-	if (Ctrl->Z.active && Ctrl->A.active) {
+	if (Ctrl->Z.active && !Ctrl->A.active) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -Z option:  Azimuths not valid input for Cartesian data\n", GMT_program);
 		error++;
 	}
@@ -299,8 +301,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (Ctrl->C.active) GMT_read_cpt (Ctrl->C.file);
 
 	if (!(strcmp (file[0], "=") || strcmp (file[1], "="))) {
@@ -308,15 +308,8 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (GMT_read_grd_info (file[0], &h[0])) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, file[0]);
-		exit (EXIT_FAILURE);
-	}
-
-	if (GMT_read_grd_info (file[1], &h[1])) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, file[1]);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (file[0], &h[0]), file[0]);
+	GMT_err_fail (GMT_read_grd_info (file[1], &h[1]), file[1]);
 
 	if (!(h[0].nx == h[1].nx && h[0].ny == h[1].ny && h[0].x_min == h[1].x_min && h[0].y_min == h[1].y_min 
 		&& h[0].x_inc == h[1].x_inc && h[0].y_inc == h[1].y_inc)) {
@@ -333,7 +326,7 @@ int main (int argc, char **argv)
 		north = h[0].y_max;
 	}
 
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	/* Determine the wesn to be used to read the grdfile */
 
@@ -351,14 +344,9 @@ int main (int argc, char **argv)
 	nm = nx * ny;
 	r = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 	theta = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
-	if (GMT_read_grd (file[0], &h[0], r, data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, file[0]);
-		exit (EXIT_FAILURE);
-	}
-	if (GMT_read_grd (file[1], &h[1], theta, data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, file[1]);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd (file[0], &h[0], r, data_west, data_east, data_south, data_north, GMT_pad, FALSE), file[0]);
+	GMT_err_fail (GMT_read_grd (file[1], &h[1], theta, data_west, data_east, data_south, data_north, GMT_pad, FALSE), file[1]);
+
 	if (!Ctrl->S.constant) Ctrl->S.factor = 1.0 / Ctrl->S.factor;
 
 	switch (Ctrl->S.unit) {	/* Adjust for possible unit selection */
@@ -416,7 +404,7 @@ int main (int argc, char **argv)
 
 			value = r[ij];
 
-			if (Ctrl->A.active) {
+			if (!Ctrl->A.active) {
 				value = hypot (theta[ij], r[ij]);
 				if (value == 0.0) continue;
 				theta[ij] = (float)(R2D * atan2 (theta[ij], r[ij]));
@@ -428,7 +416,7 @@ int main (int argc, char **argv)
 			}
 			else if (r[ij] == 0.0) continue;
 
-			if (Ctrl->C.active) GMT_get_rgb24 (value, Ctrl->G.fill.rgb);
+			if (Ctrl->C.active) GMT_get_rgb_from_z (value, Ctrl->G.fill.rgb);
 
 			x = GMT_i_to_x (i, h[0].x_min, h[0].x_max, h[0].x_inc, h[0].xy_off, h[0].nx);
 			GMT_geo_to_xy (x, y, &plot_x, &plot_y);
