@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdview.c,v 1.59 2006/10/30 18:34:42 pwessel Exp $
+ *	$Id: grdview.c,v 1.68 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -42,9 +42,9 @@
 
 /* Declarations needed for binning of smooth contours */
 
-#define GRDVIEW_MESH		0
-#define GRDVIEW_SURF		1
-#define GRDVIEW_IMAGE		2
+#define GRDVIEW_MESH		1
+#define GRDVIEW_SURF		2
+#define GRDVIEW_IMAGE		3
 
 struct GRDVIEW_CTRL {
 	struct C {	/* -C<cpt> */
@@ -466,8 +466,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (Ctrl->C.file) {
 		GMT_read_cpt (Ctrl->C.file);
 		if (GMT_b_and_w) Ctrl->Q.monochrome = TRUE;
@@ -485,23 +483,11 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (GMT_read_grd_info (topofile, &t_head)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, topofile);
-		exit (EXIT_FAILURE);
-	}
-
-	if (Ctrl->I.active && GMT_read_grd_info (Ctrl->I.file, &i_head)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, Ctrl->I.file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (topofile, &t_head), topofile);
+	if (Ctrl->I.active) GMT_err_fail (GMT_read_grd_info (Ctrl->I.file, &i_head), Ctrl->I.file);
 
 	if (Ctrl->G.active) {
-		for (i = 0; i < n_drape; i++) {
-			if (GMT_read_grd_info (Ctrl->G.file[i], &d_head[i])) {
-				fprintf (stderr, "%s: Error opening file %s\n", GMT_program, Ctrl->G.file[i]);
-				exit (EXIT_FAILURE);
-			}
-		}
+		for (i = 0; i < n_drape; i++) GMT_err_fail (GMT_read_grd_info (Ctrl->G.file[i], &d_head[i]), Ctrl->G.file[i]);
 		two = 2; 
 	}
 
@@ -525,7 +511,7 @@ int main (int argc, char **argv)
 		if (Ctrl->N.active && Ctrl->N.level > project_info.z_top) project_info.z_top = Ctrl->N.level;
 	}
 
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	/* Determine the wesn to be used to read the grdfile */
 
@@ -572,10 +558,7 @@ int main (int argc, char **argv)
 	nm2 = mx * my;
 	topo = (float *) GMT_memory (VNULL, (size_t)nm2, sizeof (float), GMT_program);
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = two;
-	if (GMT_read_grd (topofile, &t_head, topo, data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, topofile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd (topofile, &t_head, topo, data_west, data_east, data_south, data_north, GMT_pad, FALSE), topofile);
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;
 
 	nx_f = t_head.nx;
@@ -597,10 +580,7 @@ int main (int argc, char **argv)
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Processing drape file %s\n", GMT_program, Ctrl->G.file[i]);
 
 			grd[i] = (float *) GMT_memory (VNULL, (size_t)(d_head[i].nx*d_head[i].ny), sizeof (float), GMT_program);
-			if (GMT_read_grd (Ctrl->G.file[i], &d_head[i], grd[i], data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, Ctrl->G.file[i]);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (Ctrl->G.file[i], &d_head[i], grd[i], data_west, data_east, data_south, data_north, GMT_pad, FALSE), Ctrl->G.file[i]);
 			if (d_head[i].nx != nx_f || d_head[i].ny != ny_f) {
 				drape_resample = TRUE;
 				/* fprintf (stderr, "%s: Drape file %s has improper dimensions!\n", GMT_program, Ctrl->G.file[i]);
@@ -662,8 +642,8 @@ int main (int argc, char **argv)
 
 			side = 0;
 			begin = TRUE;
-			while (side < 5) {
-				while ((n = GMT_contours (zgrd, &header, Ctrl->S.value, gmtdefs.interpolant, &side, edge, begin, &x, &y)) > 0) {
+			while (side <= GMT_LAST_CONTOUR_SIDE) {
+				while ((n = GMT_contours (zgrd, &header, Ctrl->S.value, gmtdefs.interpolant, 0, &side, edge, begin, &x, &y)) > 0) {
 
 					begin = FALSE;
 
@@ -697,26 +677,14 @@ int main (int argc, char **argv)
 		/* Go back to beginning and reread since grd has been destroyed */
 
 		if (Ctrl->G.active) {
-			if (GMT_read_grd_info (Ctrl->G.file[0], &d_head[0])) {
-				fprintf (stderr, "%s: Error opening file %s\n", GMT_program, Ctrl->G.file[0]);
-				exit (EXIT_FAILURE);
-			}
-			if (GMT_read_grd (Ctrl->G.file[0], &d_head[0], grd[0], data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, Ctrl->G.file[0]);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd_info (Ctrl->G.file[0], &d_head[0]), Ctrl->G.file[0]);
+			GMT_err_fail (GMT_read_grd (Ctrl->G.file[0], &d_head[0], grd[0], data_west, data_east, data_south, data_north, GMT_pad, FALSE), Ctrl->G.file[0]);
 			header = d_head[0];
 		}
 		else {
-			if (GMT_read_grd_info (topofile, &t_head)) {
-				fprintf (stderr, "%s: Error opening file %s\n", GMT_program, topofile);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd_info (topofile, &t_head), topofile);
 			GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = two;
-			if (GMT_read_grd (topofile, &t_head, topo, data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, topofile);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (topofile, &t_head, topo, data_west, data_east, data_south, data_north, GMT_pad, FALSE), topofile);
 			GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 0;
 			header = t_head;
 		}
@@ -731,10 +699,7 @@ int main (int argc, char **argv)
 		intensity = (float *) GMT_memory (VNULL, (size_t)nm_use, sizeof (float), GMT_program);
 		k = (drape_resample) ? two : 0;
 		GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = k;
-		if (GMT_read_grd (Ctrl->I.file, &i_head, intensity, data_west, data_east, data_south, data_north, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error reading file %s\n", GMT_program, Ctrl->I.file);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd (Ctrl->I.file, &i_head, intensity, data_west, data_east, data_south, data_north, GMT_pad, FALSE), Ctrl->I.file);
 		if (i_head.nx != nx_f || i_head.ny != ny_f) {
 			fprintf (stderr, "%s: Intensity file has improper dimensions!\n", GMT_program);
 			exit (EXIT_FAILURE);
@@ -874,7 +839,7 @@ int main (int argc, char **argv)
 		for (j = k = 0; j < header.ny; j++) {
 			for (i = 0; i < header.nx; i++, k++) {	/* Compute rgb for each pixel */
 				if (GMT_is_fnan (topo[k]) && Ctrl->T.skip) continue;
-				GMT_get_rgb24 (topo[k], rgb);
+				GMT_get_rgb_from_z (topo[k], rgb);
 				if (Ctrl->I.active) GMT_illuminate (intensity[k], rgb);
 
 				n = GMT_graticule_path (&xx, &yy, 1, xval[i] - dx2, xval[i] + dx2, yval[j] - dy2, yval[j] + dy2);
@@ -1038,7 +1003,7 @@ int main (int argc, char **argv)
 								if (GMT_rgb_is_nan_rgb (rgb)) bad++;	/* watch out for NaN colors */
 							}
 							else {		/* Use lookup to get color */
-								GMT_get_rgb24 (zgrd[node], rgb);
+								GMT_get_rgb_from_z (zgrd[node], rgb);
 								if (GMT_is_fnan (zgrd[node])) bad++;	/* watch out for NaNs */
 							}
 							if (bad) continue;	/* We don't want to blend in the (typically) gray NaN colors with the others. */
@@ -1739,7 +1704,7 @@ void paint_it (double x[], double y[], int n, double z, BOOLEAN intens, BOOLEAN
 
 	if (n < 3) return;	/* Need at least 3 points to make a polygon */
 
-	index = GMT_get_rgb24 (z, rgb);
+	index = GMT_get_rgb_from_z (z, rgb);
 	if (GMT_cpt_skip) return;	/* Skip this z-slice */
 
 	/* Now we must paint, with colors or patterns */
