@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvolume.c,v 1.28 2006/05/08 08:56:52 pwessel Exp $
+ *	$Id: grdvolume.c,v 1.33 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -68,7 +68,7 @@ int main (int argc, char **argv)
 	
 	float *f;
 
-	double take_out, west, east, south, north, dv, da, cval = 0.0, x_size, y_size, m_pr_deg, x_fact;
+	double take_out, west, east, south, north, dv, da, cval = 0.0, cellsize, fact, m_pr_deg;
 	double *area, *vol, *height, this_base, small;
 
 	struct GRDVOLUME_CTRL *Ctrl;
@@ -189,12 +189,7 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
-	if (GMT_read_grd_info (grdfile, &grd)) {
-		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, grdfile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd_info (grdfile, &grd), grdfile);
 
 	if (!project_info.region_supplied) {	/* No subset asked for */
 		west = grd.x_min;
@@ -211,23 +206,15 @@ int main (int argc, char **argv)
 
 	f = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
 
-	if (GMT_read_grd (grdfile, &grd, f, west, east, south, north, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grdfile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_read_grd (grdfile, &grd, f, west, east, south, north, GMT_pad, FALSE), grdfile);
 
 	ij_inc[0] = 0;	ij_inc[1] = 1;	ij_inc[2] = 1 - nx;	ij_inc[3] = -(long)nx;
-	x_fact = grd.x_inc;
 	mode = (Ctrl->T.active) ? 1 : 0;
+	cellsize = grd.x_inc * grd.y_inc;
 	if (Ctrl->S.active) {
 		m_pr_deg = TWO_PI * gmtdefs.ref_ellipsoid[gmtdefs.ellipsoid].eq_radius / 360.0;
 		if (Ctrl->S.unit == 'k') m_pr_deg *= 0.001;	/* Use km instead */
-		x_size = m_pr_deg * grd.x_inc;
-		y_size = m_pr_deg * grd.y_inc;
-	}
-	else {
-		x_size = grd.x_inc;
-		y_size = grd.y_inc;
+		cellsize *= m_pr_deg * m_pr_deg;
 	}
 
 	n_contours = (Ctrl->C.active) ? irint ((Ctrl->C.high - Ctrl->C.low) / Ctrl->C.inc) + 1 : 1;
@@ -323,52 +310,55 @@ int main (int argc, char **argv)
 			}
 			ij++;
 
-			if (Ctrl->L.active) dv -= this_base;	/* Adjust for lower starting base */
-
+			fact = cellsize;
 			/* Allow for shrinking of longitudes with latitude */
-			if (Ctrl->S.active) x_fact = x_size * cosd (grd.y_max - (j+0.5) * grd.y_inc);
+			if (Ctrl->S.active) fact *= cosd (grd.y_max - (j+0.5) * grd.y_inc);
 
-			dv *= x_fact;
-			da *= x_fact;
-			vol[c]  += dv;
-			area[c] += da;
+			vol[c]  += dv * fact;
+			area[c] += da * fact;
 		}
+
+		/* Adjust for lower starting base */
+		if (Ctrl->L.active) vol[c] -= area[c] * this_base;
 	}
 	if (!Ctrl->C.active) {	/* Columns with bilinear tops */
 		if (Ctrl->L.active && Ctrl->L.value >= grd.z_min) {
 			fprintf (stderr, "%s: Base is > than minimum z - exiting\n", GMT_program);
 			exit (EXIT_FAILURE);
 		}
-		for (j = 1, ij = grd.nx; j < grd.ny; j++) {
+		for (j = 0, ij = 0; j < grd.ny; j++) {
 			dv = da = 0.0;
-			for (i = 0; i < grd.nx-1; i++, ij++) {
-				for (k = 0, bad = FALSE; !bad && k < 4; k++) if (GMT_is_fnan (f[ij+ij_inc[k]])) bad = TRUE;
-                                if (bad) continue;
+			for (i = 0; i < grd.nx; i++, ij++) {
+				if (GMT_is_fnan (f[ij])) continue;
 
-				dv += 0.25 * (f[ij] + f[ij+1] + f[ij-nx] + f[ij-nx+1]);
-				da += 1.0;
-				if (Ctrl->L.active) dv -= this_base;	/* Adjust for lower starting base */
+				/* Half the leftmost and rightmost cell */
+				if (!grd.node_offset && (i == 0 || i == grd.nx-1)) {
+					dv += 0.5 * f[ij];
+					da += 0.5;
+				}
+				else {
+					dv += f[ij];
+					da += 1.0;
+				}
 			}
-			ij++;
 
+			fact = cellsize;
 			/* Allow for shrinking of longitudes with latitude */
-			if (Ctrl->S.active) x_fact = x_size * cosd (grd.y_max - (j+0.5) * grd.y_inc);
+			if (Ctrl->S.active) fact *= cosd (grd.y_max - j * grd.y_inc);
+			/* Half the top and bottom row */
+			if (!grd.node_offset && (j == 0 || j == grd.ny-1)) fact *= 0.5;
 
-			dv *= x_fact;
-			da *= x_fact;
-			vol[0]  += dv;
-			area[0] += da;
+			vol[0]  += dv * fact;
+			area[0] += da * fact;
 		}
+
+		/* Adjust for lower starting base */
+		if (Ctrl->L.active) vol[0] -= area[0] * this_base;
 	}
 
-	/* Adjust values for actual y dimension */
-
-	for (c = 0; c < n_contours; c++) {
-		vol[c]  *= y_size;
-		area[c] *= y_size;
-		height[c] = (area[c] > 0.0) ? vol[c] / area[c] : GMT_d_NaN;
-	}
+	/* Compute average heights */
 
+	for (c = 0; c < n_contours; c++) height[c] = (area[c] > 0.0) ? vol[c] / area[c] : GMT_d_NaN;
 
 	/* Find the best contour that gives largest height */
 
