@@ -1,4 +1,7 @@
-/*	$Id: gshhs.c,v 1.9 2006/05/04 00:06:11 pwessel Exp $
+/*	$Id: gshhs.c,v 1.14 2007/03/07 13:07:04 remko Exp $
+ *
+ *	Copyright (c) 1996-2007 by P. Wessel and W. H. F. Smith
+ *	See COPYING file for copying and redistribution conditions.
  *
  * PROGRAM:	gshhs.c
  * AUTHOR:	Paul Wessel (pwessel@hawaii.edu)
@@ -13,9 +16,7 @@
  *		1.4 05-SEPT-2000: Made a GMT supplement; FLIP no longer needed
  *		1.5 14-SEPT-2004: Updated to deal with latest GSHHS database (1.3)
  *		1.6 02-MAY-2006: Updated to deal with latest GSHHS database (1.4)
- *
- *	Copyright (c) 1996-2006 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *		1.7 11-NOV-2006: Fixed bug in computing level (&& vs &)
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -40,7 +41,7 @@ int main (int argc, char **argv)
 	struct GSHHS h;
         
 	if (argc < 2 || argc > 3) {
-		fprintf (stderr, "gshhs v. 1.6 ASCII export tool\n");
+		fprintf (stderr, "gshhs v. %s ASCII export tool\n", GSHHS_PROG_VERSION);
 		fprintf (stderr, "usage:  gshhs gshhs_[f|h|i|l|c].b [-L] > ascii.dat\n");
 		fprintf (stderr, "-L will only list headers (no data output)\n");
 		exit (EXIT_FAILURE);
@@ -67,7 +68,7 @@ int main (int argc, char **argv)
 			h.area  = swabi4 ((unsigned int)h.area);
 			h.flag  = swabi4 ((unsigned int)h.flag);
 		}
-		level = h.flag && 255;
+		level = h.flag & 255;
 		version = (h.flag >> 8) & 255;
 		greenwich = (h.flag >> 16) & 255;
 		src = (h.flag >> 24) & 255;
