@@ -1,4 +1,8 @@
-/*	$Id: gshhstograss.c,v 1.4 2004/09/12 01:25:20 pwessel Exp $
+/*	$Id: gshhstograss.c,v 1.14 2007/03/31 17:43:21 pwessel Exp $
+ *
+ *	This program is free software; you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation; version 2 of the License.
  *
  * PROGRAM:     gshhstograss.c
  * AUTHOR:      Simon Cox (simon@ned.dem.csiro.au) &
@@ -10,14 +14,20 @@
  * VERSION:	1.2 18-MAY-1999: Explicit binary open for DOS
  * VERSION:	1.4 05-SEP-2000: Swab done automatically
  *		1.5 11-SEP-2004: Updated to work with GSHHS database v1.3
+ *		1.6 02-MAY-2006: Updated to work with GSHHS database v1.4
  */
 
 #include "gshhs.h"
 #include <unistd.h>
+#ifndef __INTERIX
+#include <getopt.h>
+#endif
 #include <string.h>
+#include <sys/types.h>
+#include <pwd.h>
 #include <time.h>
 
-main (argc, argv)
+int main (argc, argv)
 int     argc;
 char **argv;
 
@@ -26,14 +36,15 @@ char **argv;
 {
 	double w, e, s, n, area, lon, lat;
 	double minx = -360., maxx = 360., miny = -90., maxy = 90.;
-	char buf[64], source, *progname, *dataname, dig_name[24], att_name[24], cats_name[24];
+	char source, *progname, *dataname = NULL, dig_name[24], att_name[24], cats_name[24];
 	static char *slevel[] = { "null" , "land" , "lake" , "island_in_lake" , "pond_in_island_in_lake" };
 	FILE    *fp,*dig_ascii,*dig_att,*dig_cats;
-	int     k, max = 270000000, flip, n_read;
+	int     k, max = 270000000, flip, n_read, level, version, greenwich, src;
 	struct  POINT p;
 	struct GSHHS h;
 	int c, max_id=0;
 	time_t tloc;
+	struct passwd *pw;
 
 	optarg = NULL;
 	progname = argv[0];
@@ -103,7 +114,10 @@ char **argv;
 	fprintf(dig_ascii,"ORGANIZATION: \n");
 	time(&tloc);
 	fprintf(dig_ascii,"DIGIT DATE:   %s",ctime(&tloc));
-	fprintf(dig_ascii,"DIGIT NAME:   %s\n",cuserid(buf));
+	if ((pw = getpwuid (getuid ())) != NULL)
+		fprintf(dig_ascii,"DIGIT NAME:   %s\n",pw->pw_name);
+	else
+		fprintf(dig_ascii,"DIGIT NAME:   unknown\n");
 	fprintf(dig_ascii,"MAP NAME:     Global Shorelines\n");
 	fprintf(dig_ascii,"MAP DATE:     2004\n");
 	fprintf(dig_ascii,"MAP SCALE:    1\n");
@@ -124,34 +138,36 @@ char **argv;
 	fprintf(dig_cats,"0:unknown\n");
 
 	n_read = fread((void *)&h, (size_t)sizeof (struct GSHHS), (size_t)1, fp);
-	flip = (! (h.level > 0 && h.level < 5));
+	version = (h.flag >> 8) & 255;
+	flip = (version != GSHHS_DATA_VERSION);	/* Take as sign that byte-swabbing is needed */
 
 	while (n_read == 1) {
 
 		if (flip) {
 			h.id = swabi4 ((unsigned int)h.id);
 			h.n  = swabi4 ((unsigned int)h.n);
-			h.level = swabi4 ((unsigned int)h.level);
 			h.west  = swabi4 ((unsigned int)h.west);
 			h.east  = swabi4 ((unsigned int)h.east);
 			h.south = swabi4 ((unsigned int)h.south);
 			h.north = swabi4 ((unsigned int)h.north);
 			h.area  = swabi4 ((unsigned int)h.area);
-			h.version   = swabi4 ((unsigned int)h.version);
-			h.greenwich = swabi2 ((unsigned int)h.greenwich);
-			h.source    = swabi2 ((unsigned int)h.source);
+			h.flag   = swabi4 ((unsigned int)h.flag);
 		}
+		level = h.flag && 255;
+		version = (h.flag >> 8) & 255;
+		greenwich = (h.flag >> 16) & 255;
+		src = (h.flag >> 24) & 255;
 		w = h.west  * 1.0e-6;
 		e = h.east  * 1.0e-6;
 		s = h.south * 1.0e-6;
 		n = h.north * 1.0e-6;
-		source = (h.source == 1) ? 'W' : 'C';
+		source = (src == 1) ? 'W' : 'C';
 		area = 0.1 * h.area;
 
 		if( ( w < maxx && e > minx ) && ( s < maxy && n > miny ) ){
 			fprintf(dig_ascii,"L %d\n",h.n);
 			if( h.id > max_id )     max_id= h.id;
-			fprintf(dig_cats,"%d:%s\n",h.id,slevel[h.level]);
+			fprintf(dig_cats,"%d:%s\n",h.id,slevel[level]);
 		}
 
 		for (k = 0; k < h.n; k++) {
@@ -164,7 +180,7 @@ char **argv;
 				p.x = swabi4 ((unsigned int)p.x);
 				p.y = swabi4 ((unsigned int)p.y);
 			}
-			lon = (h.greenwich && p.x > max) ? p.x * 1.0e-6 -360.0 : p.x * 1.0e-6;
+			lon = (greenwich && p.x > max) ? p.x * 1.0e-6 -360.0 : p.x * 1.0e-6;
 			lat = p.y * 1.0e-6;
 			if( ( w < maxx && e > minx ) && ( s < maxy && n > miny ) ){
 				if(k==1)	fprintf(dig_att,"L  %15f %15f  %9d	  \n",lon,lat,h.id);
@@ -184,5 +200,5 @@ char **argv;
 	fprintf(dig_cats,"# %6d categories\n", max_id);
 	fclose(dig_cats);
 
-	exit (EXIT_SUCCSESS);
+	exit (EXIT_SUCCESS);
 }
