@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: makecpt.c,v 1.28 2006/10/25 21:56:22 pwessel Exp $
+ *	$Id: makecpt.c,v 1.36 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -81,7 +81,7 @@ int main(int argc, char **argv)
 
 	Ctrl = (struct MAKECPT_CTRL *)New_Makecpt_Ctrl ();	/* Allocate and initialize a new control structure */
 	
-	/* Get list of available color tables in $GMTHOME/share */
+	/* Get list of available color tables in $GMT_SHAREDIR */
 
 	GMT_getsharepath (CNULL, "GMT_CPT", ".lis", CPT_lis);
 	if ((fpc = fopen (CPT_lis, "r")) == NULL) {
@@ -184,8 +184,6 @@ int main(int argc, char **argv)
 
 	/* OK, we can now do the resampling */
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (Ctrl->N.active) GMT_cpt_flags += 1;	/* bit 0 controls if BFN will be written out */
 	if (Ctrl->D.active) GMT_cpt_flags += 2;	/* bit 1 controls if BF will be set to equal bottom/top rgb value */
 	if (Ctrl->M.active) GMT_cpt_flags += 4;	/* bit 2 controls if BFN is determined by parameters */
@@ -198,7 +196,7 @@ int main(int argc, char **argv)
 		int n_alloc = GMT_SMALL_CHUNK;
 		z = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(double), GMT_program);
 		nz = 0;
-		while (fgets (buffer, BUFSIZ, fpl)) {
+		while (GMT_fgets (buffer, BUFSIZ, fpl)) {
 			if (buffer[0] == '#') continue;
 			z[nz] = atof (buffer);
 			nz++;
