@@ -1,7 +1,8 @@
 /*--------------------------------------------------------------------
- *    $Id: pscoupe.c,v 1.23 2006/04/10 05:47:30 pwessel Exp $
+ *    $Id: pscoupe.c,v 1.32 2007/03/24 01:42:07 pwessel Exp $
  *
- *    Copyright (c) 1996-2001 by G. Patau
+ *    Copyright (c) 1996-2007 by G. Patau
+ *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -186,14 +187,14 @@ int main (int argc, char **argv)
                     break;
                 case 'E':    /* Set color for extensive parts  */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &efill))) {
-                        GMT_fill_syntax ('G');
+                        GMT_fill_syntax ('G', " ");
                         error++;
                     }
                     polygon = TRUE;
                     break;
                 case 'G':    /* Set color for compressive parts */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &fill))) {
-                        GMT_fill_syntax ('G');
+                        GMT_fill_syntax ('G', " ");
                         error++;
                     }
                     polygon = TRUE;
@@ -201,7 +202,7 @@ int main (int argc, char **argv)
                 case 'L':    /* Draw outline [set outline attributes] */
                     outline = TRUE;
                     if (argv[i][2] && GMT_getpen (&argv[i][2], &lpen)) {
-                        GMT_pen_syntax ('L');
+                        GMT_pen_syntax ('L', " ");
                         error++;
                     }
                     break;
@@ -328,14 +329,14 @@ int main (int argc, char **argv)
                     sscanf (&argv[i][2], "%d",&n_plane);
                     if(strlen(argv[i]) > 3) { /* Set transparent attributes */
                         if (argv[i][2] && GMT_getpen (&argv[i][2], &tr_pen)) {
-                            GMT_pen_syntax ('T');
+                            GMT_pen_syntax ('T', " ");
                             error++;
                         }
                     }
                     break;
                 case 'W':    /* Set line attributes */
                     if (argv[i][2] && GMT_getpen (&argv[i][2], &pen)) {
-                        GMT_pen_syntax ('W');
+                        GMT_pen_syntax ('W', " ");
                         error++;
                     }
                     break;
@@ -431,14 +432,14 @@ int main (int argc, char **argv)
                     break;
                 case 'e':    /* Set color for T axis symbol */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &tfill))) {
-                        GMT_fill_syntax ('e');
+                        GMT_fill_syntax ('e', " ");
                         error++;
                     }
                     polygon = TRUE;
                     break;
                 case 'g':    /* Set color for P axis symbol */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &pfill))) {
-                        GMT_fill_syntax ('g');
+                        GMT_fill_syntax ('g', " ");
                         error++;
                     }
                     GMT_getfill (&argv[i][2], &pfill);
@@ -448,7 +449,7 @@ int main (int argc, char **argv)
                     p_outline = TRUE;
                     if(strlen(argv[i]) > 2) {
                         if (argv[i][2] && GMT_getpen (&argv[i][2], &ppen)) {
-                            GMT_pen_syntax ('p');
+                            GMT_pen_syntax ('p', " ");
                             error++;
                         }
                     }
@@ -457,7 +458,7 @@ int main (int argc, char **argv)
                     t_outline = TRUE;
                     if(strlen(argv[i]) > 2){
                         if (argv[i][2] && GMT_getpen (&argv[i][2], &tpen)) {
-                            GMT_pen_syntax ('t');
+                            GMT_pen_syntax ('t', " ");
                             error++;
                         }
                     }
@@ -595,8 +596,6 @@ int main (int argc, char **argv)
         n_files = 1;
     n_args = (argc > 1) ? argc : 2;
     
-    GMT_put_history (argc, argv);   /* Update .gmtcommands4 */
-
     if(frame_coupe) {
         west = 0.;
         east = p_length;
@@ -607,7 +606,7 @@ int main (int argc, char **argv)
 
     greenwich = (project_info.w < 0.0 || project_info.e <= 0.0);
     
-    GMT_map_setup (west, east, south, north);
+    GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
     GMT_plotinit (argc, argv);
     
@@ -629,7 +628,7 @@ int main (int argc, char **argv)
             fp = stdin;
             done = TRUE;
         }
-        else if ((fp = fopen (argv[fno], "r")) == NULL) {
+        else if ((fp = GMT_fopen (argv[fno], "r")) == NULL) {
             fprintf (stderr, "pscoupe: Cannot open file %s\n", argv[fno]);
             continue;
         }
@@ -702,7 +701,7 @@ int main (int argc, char **argv)
             }
 
             if (get_rgb) {
-                GMT_get_rgb24 (depth, fill.rgb);
+                GMT_get_rgb_from_z (depth, fill.rgb);
             }
 
             GMT_geo_to_xy (xy[0], xy[1], &plot_x, &plot_y);
