@@ -1,7 +1,8 @@
 /*--------------------------------------------------------------------
- *    $Id: psmeca.c,v 1.28 2006/10/11 02:52:17 remko Exp $
+ *    $Id: psmeca.c,v 1.36 2007/03/24 01:42:07 pwessel Exp $
  *
- *    Copyright (c) 1996-2001 by G. Patau
+ *    Copyright (c) 1996-2007 by G. Patau
+ *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -551,9 +552,7 @@ int main (int argc, char **argv)
         n_files = 1;
     n_args = (argc > 1) ? argc : 2;
     
-    GMT_put_history (argc, argv);   /* Update .gmtcommands4 */
-    
-    GMT_map_setup (west, east, south, north);
+    GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
     GMT_plotinit (argc, argv);
     
@@ -573,7 +572,7 @@ int main (int argc, char **argv)
             fp = GMT_stdin;
             done = TRUE;
         }
-        else if ((fp = fopen (argv[fno], "r")) == NULL) {
+        else if ((fp = GMT_fopen (argv[fno], "r")) == NULL) {
             fprintf (stderr, "psmeca: Cannot open file %s\n", argv[fno]);
             continue;
         }
@@ -626,7 +625,7 @@ int main (int argc, char **argv)
                 depth = atof (col[2]);
                 if((depth - depmin) * (depth - depmax) > 0.) continue;
                 if (get_rgb) {
-                    GMT_get_rgb24 (depth, fill.rgb);
+                    GMT_get_rgb_from_z (depth, fill.rgb);
                 }
                 sscanf (string, "%s %[^\n]\n", txt_a, event_title);
             }
