@@ -1,7 +1,8 @@
 /*--------------------------------------------------------------------
- *    $Id: psvelo.c,v 1.20 2006/04/10 05:47:30 pwessel Exp $
+ *    $Id: psvelo.c,v 1.27 2007/03/24 01:42:07 pwessel Exp $
  *
- *    Copyright (c) 1996-2001 by G. Patau
+ *    Copyright (c) 1996-2007 by G. Patau
+ *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -271,11 +272,9 @@ int main (int argc, char **argv)
 		n_files = 1;
 	n_args = (argc > 1) ? argc : 2;
 
-        GMT_put_history (argc, argv);   /* Update .gmtcommands4 */
-
 	greenwich = (project_info.w < 0.0 || project_info.e <= 0.0);
 
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	GMT_plotinit (argc, argv);
 
@@ -298,7 +297,7 @@ int main (int argc, char **argv)
 			fp = stdin;
 			done = TRUE;
 		}
-		else if ((fp = fopen (argv[fno], "r")) == NULL) {
+		else if ((fp = GMT_fopen (argv[fno], "r")) == NULL) {
 			fprintf (stderr, "psvelo: Cannot open file %s\n", argv[fno]);
 			continue;
 		}
