@@ -1,7 +1,7 @@
 /*-------------------------------------------------------------------------
- *	$Id: mgd77.h,v 1.73 2006/04/11 04:21:27 pwessel Exp $
+ *	$Id: mgd77.h,v 1.77 2007/04/02 15:25:57 remko Exp $
  * 
- *    Copyright (c) 2005-2006 by P. Wessel
+ *    Copyright (c) 2005-2007 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *
  *  File:	mgd77.h
@@ -21,15 +21,6 @@
 
 #include "gmt.h"
 
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#if defined(WIN32) || defined(__EMX__)  /* Some definitions and includes are different under Windows or OS/2 */
-#define STAT _stat
-#else                                   /* Here for Unix, Linux, Cygwin, Interix, etc */
-#define STAT stat
-#endif
-
 #define MGD77_VERSION		"1.3"		/* Current version of MGD77 supplement */
 #define MGD77_CDF_VERSION	"2006.04.15"	/* Current version of MGD77+ files created */
 #define MGD77_RECORD_LENGTH	120		/* Length of MGD77 ASCII data records */
@@ -306,7 +297,7 @@ struct MGD77_META {	/* Information about a cruise as derived from navigation dat
 	int w, e, s, n;		/* Whole degree left/right/bottom/top coordinates */
 	int Departure[3];	/* yyyy, mm, dd of departure */
 	int Arrival[3];		/* yyyy, mm, dd of arrival */
-	char ten_box[20][38];	/* Set to 1 for each box visited */
+	signed char ten_box[20][38];	/* Set to 1 for each box visited */
 };
 
 struct MGD77_HEADER {	
@@ -386,7 +377,7 @@ struct MGD77_CONTROL {
 	 */
 	
 	/* File path information */
-	char *MGD77_HOME;				/* Directory where paths are stored [$GMTHOME/share/mgd77] */
+	char *MGD77_HOME;				/* Directory where paths are stored [$GMT_SHAREDIR/mgd77] */
 	char **MGD77_datadir;				/* Directories where MGD77 data may live */
 	int n_MGD77_paths;				/* Number of such directories */
 	char user[MGD77_COL_ABBREV_LEN];		/* Current user id */
