@@ -1,3 +1,10 @@
+/*-------------------------------------------------------------------------
+ *	$Id: mgd77_IGF_coeffs.h,v 1.4 2007/01/30 20:37:09 pwessel Exp $
+ * 
+ *    Copyright (c) 2005-2007 by P. Wessel
+ *    See README file for copying and redistribution conditions.
+ */
+ 
 #define MGD77_IGF24_G0	978052.0
 #define MGD77_IGF30_G0	978049.0
 #define MGD77_IGF67_G0	978031.846
