@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77list.c,v 1.64 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: mgd77list.c,v 1.76 2007/03/12 21:45:19 pwessel Exp $
  *
- *    Copyright (c) 2004-2006 by P. Wessel
+ *    Copyright (c) 2004-2007 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -26,13 +26,14 @@
  * Date:	19-JUN-2004
  * Version:	1.0 Based somewhat on the old gmtlist.c
  *		31-MAR-2006: Changed -X to -L to avoid GMT collision
+ *		23-MAY-2006: Added -Q for limits on speed/azimuths
  *
  *
  */
  
 #include "mgd77.h"
 
-#define MGD77_ALL "leg,time,lat,lon,ptc,twt,depth,bcc,btc,mtf1,mtf2,mag,msens,diur,msd,gobs,eot,faa,nqc,sln,sspn"
+#define MGD77_ALL "id,time,lat,lon,ptc,twt,depth,bcc,btc,mtf1,mtf2,mag,msens,diur,msd,gobs,eot,faa,nqc,sln,sspn"
 #define MGD77_GEO "time,lat,lon,twt,depth,mtf1,mtf2,mag,gobs,faa"
 #define MGD77_AUX "dist,azim,vel,weight"
 
@@ -85,14 +86,15 @@ int main (int argc, char **argv)
 	BOOLEAN negative_depth = FALSE,  negative_msd = FALSE, need_distances, need_time, limit_on_time = FALSE;
 	BOOLEAN limit_on_dist = FALSE, limit_on_wesn = FALSE, need_lonlat = FALSE, first_cruise = TRUE, need_twt = FALSE;
 	BOOLEAN need_date, need_sound = FALSE, apply_corrections = FALSE, apply_bits[MGD77_N_SETS], might_need_bits;
-	BOOLEAN lonlat_not_NaN;
+	BOOLEAN limit_on_azimuth = FALSE, limit_on_velocity = FALSE, lonlat_not_NaN, first_warning = TRUE;
 	
 	char *start_date = CNULL, *stop_date = CNULL, f_setting[BUFSIZ], fx_setting[BUFSIZ], **list;
 	char *tvalue[MGD77_MAX_COLS], institution[3], s_unit[2], d_unit[2], *aux_tvalue[N_AUX], *correction_table = CNULL;
 	
-	double west, east, south, north, start_time, stop_time, start_dist, IGRF[7],correction;
+	double west, east, south, north, start_time, stop_time, start_dist, IGRF[7], correction, min_vel = 0.0, max_vel = DBL_MAX;
 	double stop_dist, dist_scale, vel_scale, ds, dt, cumulative_dist, aux_dvalue[N_AUX], *out = VNULL;
 	double sound_speed = 0.0, i_sound_speed = 0.0, n_days, date = 0.0, g, m, z, v, twt, *dvalue[MGD77_MAX_COLS];
+	double min_az = 0.0, max_az = 360.0;
 	
 	struct MGD77_CONTROL M;
 	struct MGD77_DATASET *D;
@@ -191,7 +193,7 @@ int main (int argc, char **argv)
 						}
 						if (argv[i][4] == ',') {
 							GF_version = atoi (&argv[i][5]);
-							if (GF_version < MGD77_IGF_HEISKANEN || sound_speed > MGD77_IGF_1980) {
+							if (GF_version < MGD77_IGF_HEISKANEN || GF_version > MGD77_IGF_1980) {
 								fprintf (stderr, "%s: ERROR -Af<code>,<field>.  Select <field> is 1-4 range.\n", GMT_program);
 							error++;
 							}
@@ -303,6 +305,32 @@ int main (int argc, char **argv)
 				institution[0] = argv[i][2];
 				institution[1] = argv[i][3];
 				break;
+			case 'Q':		/* Assign min/max values for speeds or azimuth */
+				switch (argv[i][2]) {
+					case 'a':	/* Azimuth min/max */
+						if (sscanf (&argv[i][3], "%lf/%lf", &min_az, &max_az) != 2) {
+							fprintf(stderr, "%s: ERROR -Qa: append min/max azimuth limits [0/360]\n", GMT_program);
+							error++;
+						}
+						limit_on_azimuth = TRUE;
+						break;
+					case 'v':	/* Velocity min/max */
+						code = sscanf (&argv[i][3], "%lf/%lf", &min_vel, &max_vel);
+						if (code == 1)
+							max_vel = DBL_MAX;
+						else if (code <= 0) {
+							fprintf(stderr, "%s: ERROR -Qv: append min[/max] velocity limits [0]\n", GMT_program);
+							error++;
+						}
+						limit_on_velocity = TRUE;
+						break;
+					default:
+						fprintf(stderr, "%s: ERROR -Q: Syntax is -Qa|v<min>/<max>\n", GMT_program);
+						error++;
+						break;
+				}
+				break;
+				
 			case 'S':		/* Assign start/stop position for sub-section (converted to meters) */
 				limit_on_dist = TRUE;
 				if (argv[i][2] == 'a') {		/* Start position */
@@ -344,6 +372,7 @@ int main (int argc, char **argv)
 				break;
 	
 			default:		/* Options not recognized */
+				fprintf(stderr, "%s: ERROR -%s: option not recognized\n", GMT_program, &argv[i][1]);
 				error = TRUE;
 				break;
 		}
@@ -368,26 +397,34 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 	if (start_date && GMT_verify_expectations (GMT_IS_ABSTIME, GMT_scanf (start_date, GMT_IS_ABSTIME, &start_time), start_date)) {
-		fprintf (stderr, "%s: ERROR: Start time (%s) in wrong format\n", GMT_program, start_date);
+		fprintf (stderr, "%s: ERROR -Da: Start time (%s) in wrong format\n", GMT_program, start_date);
 		exit (EXIT_FAILURE);
 	}
 	if (stop_date && GMT_verify_expectations (GMT_IS_ABSTIME, GMT_scanf (stop_date, GMT_IS_ABSTIME, &stop_time), stop_date)) {
-		fprintf (stderr, "%s: ERROR: Stop time (%s) in wrong format\n", GMT_program, stop_date);
+		fprintf (stderr, "%s: ERROR -Db : Stop time (%s) in wrong format\n", GMT_program, stop_date);
 		exit (EXIT_FAILURE);
 	}
 	if (start_time > stop_time) {
-		fprintf(stderr, "%s: ERROR: Start time exceeds stop time!\n", GMT_program);
+		fprintf(stderr, "%s: ERROR -D: Start time exceeds stop time!\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
 	if (start_dist > stop_dist) {
-		fprintf (stderr, "%s: ERROR: Start distance exceeds stop distance!\n", GMT_program);
+		fprintf (stderr, "%s: ERROR -S: Start distance exceeds stop distance!\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
+	if (limit_on_azimuth && min_az >= max_az) {
+		fprintf(stderr, "%s: ERROR -Qa: Minimum azimuth equals or exceeds maximum azimuth\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
+	if (limit_on_velocity && (min_vel >= max_vel || min_vel < 0.0)) {
+		fprintf(stderr, "%s: ERROR -Qv: Minimum velocity equals or exceeds maximum velocity or is negative\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
 
 	if (GMT_give_synopsis_and_exit || argc == 1) {	/* Display usage */
 		fprintf(stderr,"mgd77list %s - Extract data from MGD77 files\n\n", MGD77_VERSION);
 		fprintf (stderr,"usage: mgd77list <cruise(s)> -F<dataflags>[,<tests>] [-Ac|d|f|g[code]] [-Cf|g|e] [-Da<startdate>] [-Db<stopdate>] [-E]\n");
-		fprintf (stderr, "\t[-H] [-I<code>] [-L[<corrtable.d>]] [%s] [-N[s|p][e|k|n|m]]] [%s]\n", GMT_Mo_OPT, GMT_Rgeo_OPT);
+		fprintf (stderr, "\t[-H] [-I<code>] [-L[<corrtable.d>]] [%s] [-N[s|p][e|k|n|m]]] [-Qa|v<min>/<max>] [%s]\n", GMT_Mo_OPT, GMT_Rgeo_OPT);
 		fprintf (stderr, "\t[-Sa<startdist>[unit]] [-Sb<stopdist>[unit]] [-T[m|e]] [-V] [-W<Weight>] [-Z[+|-] [%s]\n\n", GMT_bo_OPT);
          
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -505,6 +542,10 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   m British/US units (miles, miles/hr)\n");
 		fprintf (stderr, "\t   n Nautical units (nautical miles, knots)\n");
 		fprintf (stderr, "\t   [Default is -Ndk -Nse]\n");
+		fprintf (stderr, "\t-Q Only return data whose azimuth (-Qa) or velocity (-Qv) fall inside specified range:\n");
+		fprintf (stderr, "\t   -Qa<min_az>/<max_az>, where <min_az> < <max_az> [all azimuths, i.e. 0/360]");
+		fprintf (stderr, "\t   -Qv<min_vel>[/<max_vel>], where <max_vel> is optional [all velocities, i.e., 0/infinity]");
+		fprintf (stderr, "\t      Velocities are given in m/s unless changed by -Ns");
 		fprintf (stderr, "\t-R Only return data inside the specified region [0/360/-90/90]\n");
 		fprintf (stderr, "\t-Sa<dist> lists from dist  (in m; append k, m, or n) [Start of the cruise]\n");
 		fprintf (stderr, "\t-Sb<dist> lists up to dist (in m; append k, m, or n) [End of the cruise]\n");
@@ -515,7 +556,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-W Sets weight for these data [1]\n");
 		fprintf (stderr, "\t-Z Append - to report bathymetry & msd as negative depths [Default is positive -Z+]\n");
 		GMT_explain_option ('o');
-		exit(EXIT_FAILURE);
+		exit (EXIT_FAILURE);
 	}
 
 	n_paths = MGD77_Path_Expand (&M, argv, argc, &list);	/* Get list of requested IDs */
@@ -542,8 +583,8 @@ int main (int argc, char **argv)
 	 */
 	 
 	need_distances = (limit_on_dist || auxlist[AUX_SP].requested || auxlist[AUX_DS].requested || auxlist[AUX_AZ].requested);	/* Distance is requested */
-	need_lonlat = (auxlist[AUX_MG].requested || auxlist[AUX_GR].requested || auxlist[AUX_CT].requested);	/* Need lon, lat to calculate reference fields or Carter correction */
-	need_time = (auxlist[AUX_YR].requested || auxlist[AUX_MO].requested || auxlist[AUX_DY].requested || auxlist[AUX_HR].requested || auxlist[AUX_MI].requested || auxlist[AUX_MG].requested);
+	need_lonlat = (auxlist[AUX_MG].requested || auxlist[AUX_GR].requested || auxlist[AUX_CT].requested || adj_code[ADJ_MG] & 2 || adj_code[ADJ_MG] & 4 || adj_code[ADJ_DP] & 4 || adj_code[ADJ_CT] >= 2 || adj_code[ADJ_GR] & 2);	/* Need lon, lat to calculate reference fields or Carter correction */
+	need_time = (auxlist[AUX_YR].requested || auxlist[AUX_MO].requested || auxlist[AUX_DY].requested || auxlist[AUX_HR].requested || auxlist[AUX_MI].requested || auxlist[AUX_MG].requested || (adj_code[ADJ_MG] & 2) || (adj_code[ADJ_MG] & 4));
 	n_sub = 0;	/* This value will hold the number of columns that we will NOT printout (they are only needed to calculate auxillary values) */
 	if (need_distances || need_lonlat) {	/* Must make sure we get lon,lat if they are not already requested */
 		 if (MGD77_Get_Column ("lat", &M) == MGD77_NOT_SET) strcat (fx_setting, ",lat"), n_sub++;	/* Append lat to requested list */
@@ -687,6 +728,10 @@ int main (int argc, char **argv)
 		if (time_column != MGD77_NOT_SET && D->H.no_time) {	/* Cannot know if ASCII MGD77 dont have time until after reading */
 			fprintf (stderr, "%s: Warning: Time column not present in cruise %s - set to NaN\n", GMT_program, list[argno]);
 		}
+		if (time_column != MGD77_NOT_SET && GMT_io.binary[GMT_OUT] && gmtdefs.verbose && first_warning) {	/* Warn that binary time output is in Unix secs */
+			fprintf (stderr, "%s: Warning: For binary output, time is stored as seconds since 1970 (Use TIME_SYSTEM=Unix to decode)\n", GMT_program);
+			first_warning = FALSE;
+		}
 		for (i = kx = pos = 0; pos < n_out_columns; i++, pos++) {	/* Prepare GMT output formatting machinery */
 			while (kx < n_aux && aux[kx].pos == i) {	/* Insert formatting for auxillary column (none are special) */
 				GMT_io.out_col_type[pos] = GMT_IS_FLOAT;
@@ -736,7 +781,8 @@ int main (int argc, char **argv)
 		if (need_twt) twt_col = MGD77_Get_Column ("twt",  &M);
 		if (adj_code[ADJ_GR]) f_col = MGD77_Get_Column ("faa",  &M);
 		if (adj_code[ADJ_GR] & 2) g_col = MGD77_Get_Column ("gobs",  &M);
-		if (adj_code[ADJ_MG] > 1) {
+		if (adj_code[ADJ_MG]) m_col = MGD77_Get_Column ("mag",  &M);
+		if (adj_code[ADJ_MG] > 1) {	/* Need more magnetics items */
 			m1_col = MGD77_Get_Column ("mtf1",  &M);
 			m2_col = MGD77_Get_Column ("mtf2",  &M);
 			ms_col = MGD77_Get_Column ("msens",  &M);
@@ -816,6 +862,15 @@ int main (int argc, char **argv)
 				if (dvalue[x_col][rec] > east) continue;
 			}
 			
+			if (limit_on_velocity) {	/* Check if we are outside velocity range */
+				if (aux_dvalue[AUX_SP] < min_vel || aux_dvalue[AUX_SP] > max_vel) continue;
+			}
+			
+			if (limit_on_azimuth) {	/* Check if we are outside azimuth range */
+				while (aux_dvalue[AUX_AZ] > min_az) aux_dvalue[AUX_AZ] -= 360.0;	/* Wind down to be sure az < min azimuth */
+				while (aux_dvalue[AUX_AZ] < min_az) aux_dvalue[AUX_AZ] += 360.0;	/* Now add 360 until we pass min azimuth */	
+				if (aux_dvalue[AUX_AZ] > max_az) continue;				/* Outside azimuth range */
+			}
 			/* Check if it passes any given column data constraints */
 			
 			if (!MGD77_Pass_Record (&M, D, rec)) continue;	/* Failed the test */
@@ -830,6 +885,9 @@ int main (int argc, char **argv)
 				aux_dvalue[AUX_HR] = cal.hour;
 				aux_dvalue[AUX_MI] = cal.min;
 				aux_dvalue[AUX_SC] = cal.sec;
+				n_days = (GMT_is_gleap (cal.year)) ? 366.0 : 365.0;	/* Number of days in this year */
+				/* Get date as decimal year */
+				date = cal.year + cal.day_y / n_days + (cal.hour * GMT_HR2SEC_I + cal.min * GMT_MIN2SEC_I + cal.sec) * GMT_SEC2DAY;
 				need_date = FALSE;
 			}
 			else
