@@ -1,13 +1,13 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77manage.c,v 1.60 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: mgd77manage.c,v 1.72 2007/04/02 15:25:57 remko Exp $
  *
+ *    Copyright (c) 2005-2007 by P. Wessel
  * mgd77manage is used to (1) remove data columns from mgd77+ files
  * or (2) add a new data column to mgd77+ files.  Data can be added
  * from data tables, created from reference field formulas, or by
  * sampling grids along track.  Data from tables may be numbers or
  * text strings.
  *
- *    Copyright (c) 2005-2006 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -55,7 +55,7 @@ int main (int argc, char **argv)
 	nc_type c_nc_type;
 	
 	BOOLEAN got_c = FALSE, got_a = FALSE, got_d = FALSE, got_g = FALSE, got_i = FALSE, got_n = FALSE, got_t = FALSE;
-	BOOLEAN error = FALSE, bilinear = FALSE, replace = FALSE, delete = FALSE, interpolate = FALSE, transform;
+	BOOLEAN error = FALSE, bilinear = FALSE, replace = FALSE, delete = FALSE, interpolate = FALSE, transform, verified;
 	BOOLEAN strings = FALSE, track_decode, got_grid, got_table, two_cols = FALSE, constant, ok_to_read = TRUE, got_e = FALSE;
 	
 	char line[BUFSIZ], file[BUFSIZ], *d_list = CNULL, p[BUFSIZ], history[BUFSIZ], c_size = 0, **list;
@@ -300,7 +300,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   However, sometimes the shape of new data demands the old to be deleted first (you will be told)\n");
 		fprintf (stderr, "\t-E Give character used to fill empty/missing string columns [9]\n");
 		fprintf (stderr, "\t-I In addition to the file information above, you must also specify column information:\n");
-		fprintf (stderr, "\t      abbrev:  Short, abbreviated word, like satfaa (%d char max)\n", MGD77_COL_ABBREV_LEN);
+		fprintf (stderr, "\t      abbrev:  Short, abbreviated word (lower case only), like satfaa (%d char max)\n", MGD77_COL_ABBREV_LEN);
 		fprintf (stderr, "\t      name:    Descriptive name, like \"Geosat/ERS-1 Free-air gravity\" (%d char max)\n", MGD77_COL_NAME_LEN);
 		fprintf (stderr, "\t      units:   Units for the column (e.g., mGal, gamma, km) (%d char max)\n", MGD77_COL_NAME_LEN);
 		fprintf (stderr, "\t      size:    Either t(ext), b(yte), s(hort), f(loat), i(nt), or d(ouble)\n");
@@ -320,12 +320,12 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   -Q0 means only consider the nearest node (no interpolation).\n");
 		GMT_explain_option ('V');
 		GMT_explain_option ('i');
-		exit(EXIT_FAILURE);
+		exit (EXIT_FAILURE);
 	}
 
 	got_table = (got_a || got_d || got_e || got_n || got_t);	/* Got a table to read */
 	got_grid = (got_g || got_i);					/* Got a grid to read */
-	c_nc_type = irint (parameters[COL_TYPE]);			/* NC data type */
+	c_nc_type = (nc_type) irint (parameters[COL_TYPE]);		/* NC data type */
 	strings = (c_nc_type == NC_CHAR);				/* TRUE if our new column contains strings */
 	
 	n_paths = MGD77_Path_Expand (&In, argv, argc, &list);	/* Get list of requested IDs */
@@ -400,10 +400,7 @@ int main (int argc, char **argv)
 	}
 	else if (got_g) {	/* Read regular GMT grid */
 
-		if (GMT_read_grd_info (file, &grd)) {
-			fprintf (stderr, "%s: Error opening file %s\n", GMT_program, file);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd_info (file, &grd), file);
 		if (fabs (grd.x_max - grd.x_min - 360.0) < GMT_CONV_LIMIT) GMT_boundcond_parse (&edgeinfo, "g");
 	
 		GMT_boundcond_param_prep (&grd, &edgeinfo);
@@ -416,10 +413,7 @@ int main (int argc, char **argv)
 
 		f = (float *) GMT_memory (VNULL, (size_t)(mx * my), sizeof (float), GMT_program);
 
-		if (GMT_read_grd (file, &grd, f, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error reading file %s\n", GMT_program, file);
-			exit (EXIT_FAILURE);
-		}
+		GMT_err_fail (GMT_read_grd (file, &grd, f, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), file);
 		interpolate = (threshold > 0.0);
 	}
 	else if (got_i) {	/* Read Sandwell/Smith IMG file */
@@ -450,7 +444,7 @@ int main (int argc, char **argv)
 		project_info.pars[0] = 1.0;
 		project_info.projection = GMT_MERCATOR;
 		
-		GMT_map_setup (0.0, 360.0, GMT_IMG_MINLAT, GMT_IMG_MAXLAT);
+		GMT_err_fail (GMT_map_setup (0.0, 360.0, GMT_IMG_MINLAT, GMT_IMG_MAXLAT), "");
 		
 		GMT_geo_to_xy (project_info.w, project_info.s, &grd.x_min, &grd.y_min);
 		GMT_geo_to_xy (project_info.e, project_info.n, &grd.x_max, &grd.y_max);
@@ -831,7 +825,7 @@ int main (int argc, char **argv)
 				if ((iy = skip_if_missing ("lat", list[argno], &In, D)) == MGD77_NOT_SET) continue;
 				x = (double *)D->values[ix];
 				y = (double *)D->values[iy];
-				d = GMT_distances (x, y, D->H.n_records, dist_scale, dist_flag);
+				GMT_err_fail (GMT_distances (x, y, D->H.n_records, dist_scale, dist_flag, d), "");
 				x = d;
 			}
 			else if (got_t) {	/* Time */
@@ -896,7 +890,7 @@ int main (int argc, char **argv)
 			unsigned int *flags, pattern;
 			BOOLEAN has_time;
 			struct MGD77_HEADER_PARAMS *P;
-			double rec_time, value, *tvar = VNULL;
+			double rec_time, del_t, value, *tvar = VNULL;
 			
 			sprintf (efile, "%s.e77", list[argno]);
 			if ((fp_e = GMT_fopen (efile, "r")) == NULL) {	/* Not in current directory, try MGD77_HOME/E77 */
@@ -934,12 +928,25 @@ int main (int argc, char **argv)
 				fprintf(stderr, "%s: ERROR: E77 Conflict %s: n_recs = %d versus %d = aborting\n", GMT_program, efile, n_recs, D->H.n_records);
 				e_error++;
 			}
+			verified = FALSE;
+			while (fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Header", 14)) {	/* Read until we get to Header record section */
+				if (line[0] == '#') continue;	/* Skip comments */
+				GMT_chop (line);		/* Rid the world of CR/LF */
+				if (!strncmp (line, "Y Errata table verification status", 34)) verified = TRUE;
+			}
+			if (!verified) {
+				fprintf(stderr, "%s: ERROR: E77 file %s not yet verified - aborting\n", GMT_program, efile);
+				e_error++;
+			}
+			
 			if (e_error) {
 				fprintf(stderr, "%s: ERROR: The file %s has too many errors - skipped\n", GMT_program, efile);
 				MGD77_Free (D);	/* Free memory allocated by MGD77_Read_File for this aborted effort */
 				continue;
 			}
 			
+			/* OK, we got this far so the meta data for this E77 file seems OK */
+			
 			flags = (unsigned int *)GMT_memory (VNULL, D->H.n_records, sizeof (unsigned int), GMT_program);
 			n_flags = 0;
 
@@ -948,7 +955,7 @@ int main (int argc, char **argv)
 
 			while (fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Data", 14)) {	/* Read until we get to data record section */
 				if (line[0] == '#') continue;	/* Skip comments */
-				GMT_chop (line);	/* Rid the world of CR/LF */
+				GMT_chop (line);		/* Rid the world of CR/LF */
 				sscanf (line, "%c-%[^-]-%c-%d-%d", &YorN, field, &kind, &number, &item);
 				if (YorN == 'I') {	/* Information message */
 					fprintf (stderr, "%s: %s\n", list[argno], line);
@@ -1212,8 +1219,9 @@ int main (int argc, char **argv)
 						fprintf (stderr, "%s: ERROR: E77 time stamp (%s) in wrong format? - skipped\n", GMT_program, timestamp);
 						continue;
 					}
-					if (fabs (tvar[rec] - rec_time) > 0.05) {	/* 0.06 is finest resolution in MGD77 file */
-						fprintf (stderr, "%s: ERROR: E77 time stamp and record number do not match record time - skipped\n", GMT_program);
+					del_t = fabs (tvar[rec] - rec_time);
+					if (del_t > (0.06 + GMT_CONV_LIMIT)) {	/* 0.06 is finest time step in MGD77 file so we allow that much slop */
+						fprintf (stderr, "%s: ERROR: E77 time stamp and record number do not match record time (del_t = %g s) - skipped\n", GMT_program, del_t);
 						continue;
 					}
 				}
@@ -1485,15 +1493,16 @@ int decode_I_options (char *line, char *abbrev, char *name, char *units, char *s
 		switch (i) {
 			case 0:
 				strcpy (abbrev, p);
-				/* Check abbrev for COARDS compliance */
+				/* Check abbrev for COARDS compliance as well as being lower case */
 				for (k = error = 0; abbrev[k]; k++) {
+					if (isupper ((int)abbrev[k])) error++;
 					if (isalpha ((int)abbrev[k])) continue;
 					if (isdigit ((int)abbrev[k]) && k > 0) continue;
 					if (abbrev[k] == '_' && k > 0) continue;
 					error++;
 				}
 				if (error) {
-					fprintf (stderr, "%s: Abbreviation name should only contain letters, digits, and underscores\n", GMT_program);
+					fprintf (stderr, "%s: Abbreviation name should only contain lower case letters, digits, and underscores\n", GMT_program);
 					return (TRUE);
 				}
 				break;
