@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77track.c,v 1.42 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: mgd77track.c,v 1.49 2007/03/26 01:54:58 pwessel Exp $
  *
- *    Copyright (c) 2004-2006 by P. Wessel
+ *    Copyright (c) 2004-2007 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -64,7 +64,7 @@ int main (int argc, char **argv)
 
 	double west, east, south, north, start_time, stop_time, start_dist;
 	double stop_dist, dist_scale, x, y, annot_dist = 0, tick_dist = 0, annot_time = 0, tick_time = 0;
-	double *track_dist, angle, plot_x, plot_y, *lon, *lat, *track_time;
+	double *track_dist = NULL, angle, plot_x, plot_y, *lon, *lat, *track_time;
 	double annotsize = MGD77TRACK_ANSIZE, factor = 0.001, scale = 1.0, c_angle;
 	
 	struct MGD77_CONTROL M;
@@ -302,7 +302,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('X');
 		GMT_explain_option ('c');
 		GMT_explain_option ('.');
-		exit(EXIT_FAILURE);
+		exit (EXIT_FAILURE);
 	}
 
 	n_paths = MGD77_Path_Expand (&M, argv, argc, &list);	/* Get list of requested IDs */
@@ -312,13 +312,11 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	dist_scale = 1000.0 * project_info.M_PR_DEG;	/* Work internally in meters */
 
 	if (east < west) west -= 360.0;
 		
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 	
 	GMT_plotinit (argc, argv);
 	
@@ -366,7 +364,7 @@ int main (int argc, char **argv)
 		track_time = (double*)D.values[0];
 		lon = (double*)D.values[1];
 		lat = (double*)D.values[2];
-		track_dist = GMT_distances (lon, lat, D.H.n_records, 1.0, dist_flag);	/* Work internally in meters */
+		GMT_err_fail (GMT_distances (lon, lat, D.H.n_records, 1.0, dist_flag, track_dist), "");	/* Work internally in meters */
 		for (rec = 0; rec < D.H.n_records && track_time[rec] < start_time && track_dist[rec] < start_dist; rec++);	/* Find first record of interest */
 		first_rec = rec;
 		for (rec = D.H.n_records - 1; rec && track_time[rec] > stop_time && track_dist[rec] > stop_dist; rec--);	/* Find last record of interest */
