@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: binlegs.c,v 1.2 2004/06/10 02:57:44 pwessel Exp $
+ *	$Id: binlegs.c,v 1.12 2007/03/12 19:52:27 remko Exp $
  *
- *    Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -22,7 +22,7 @@
  * 		13-FEB-1991	Allow for legnames up to 16 chars
  * Version:	2.0 21-Jun-1991
  *		3.1 15-OCT-1998 POSIX compliant
- *		3.2 10-MAR-1999 New share/mgg directory place for data
+ *		3.2 10-MAR-1999 New GMT_SHAREDIR/mgg directory place for data
  * 
  */
  
@@ -41,7 +41,7 @@ struct GRID {
 	int bix;
 	int n_legs;
 	struct LEG *first_leg, *last_leg;
-} grid[64800];
+};
 	
 struct LEG {
 	int leg_id;		/* Low 4 bytes carries gmt-flag, rest has id_no << 4 */
@@ -55,26 +55,24 @@ struct INFO {
 	struct INFO *next_info;
 };
 
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
 
 	struct INFO *info_head, *this_info, *new_info, *make_info(char *name, int id_no, int flag);
 	struct LEG *this_leg, *make_leg(int id, int flag);
 	
-	char file[BUFSIZ], leg[16], lname[16], line[BUFSIZ], *LIBDIR;
+	char file[BUFSIZ], leg[16], lname[16], line[BUFSIZ];
 	char leg_file[BUFSIZ], index_file[BUFSIZ], old_leg_file[BUFSIZ], old_index_file[BUFSIZ], path[BUFSIZ];
 	char error = FALSE, replace = FALSE, delete = FALSE, found_it, verbose = FALSE;
 	
 	FILE *fp = NULL, *fbin, *fleg, *find;
 	
 	int no_of_legs, index, id, bin, free_id, max, flag;
-	int remove_leg(int leg_id);
+	int remove_leg(int leg_id, struct GRID *grid);
 	int i, j, year, last_id;
-	
-	if ((LIBDIR = getenv ("GMTHOME")) == (char *)NULL) {
-		fprintf (stderr, "binlegs: Environment variable GMTHOME not set!\n");
-		exit (EXIT_FAILURE);
-	}
+	struct GRID grid[64800];
+
+	argc = GMT_begin (argc, argv);
 
 	if (argc == 1) error = TRUE;
 	for (i = 1; i < argc; i++) {
@@ -102,13 +100,13 @@ main (int argc, char **argv)
 			}
 		}
 		else
-			fp = fopen(argv[i],"r");
+			fp = GMT_fopen(argv[i],"r");
 	}
 	
 	if (error || fp == NULL) {
 		fprintf(stderr, "Usage: binlegs leglistfile [-D] [-P<Path>] [-R] [-V]\n");
 		fprintf(stderr,"	-D will remove info for the listed legs\n");
-		fprintf(stderr,"	-P gives directory for the index files [Default is %s%cshare%cmgg]\n", LIBDIR, DIR_DELIM, DIR_DELIM);
+		fprintf(stderr,"	-P gives directory for the index files [Default is %s%cmgg]\n", GMT_SHAREDIR, DIR_DELIM);
 		fprintf(stderr,"	-R will replace old info. [Default is append].\n");
 		fprintf(stderr,"	-V (verbose) will print update-messages. [Default is silent]\n");
 		exit (EXIT_FAILURE);
@@ -119,12 +117,12 @@ main (int argc, char **argv)
 	for (bin = 0; bin < 64800; bin++) grid[bin].n_legs = 0;
 	
 	if (path[0]) {
-		sprintf (leg_file, "%s%cgmt_legs.d\0", path, DIR_DELIM);
-		sprintf (index_file, "%s%cgmt_index.b\0", path, DIR_DELIM);
+		sprintf (leg_file, "%s%cgmt_legs.d", path, DIR_DELIM);
+		sprintf (index_file, "%s%cgmt_index.b", path, DIR_DELIM);
 	}
 	else {
-		sprintf (leg_file, "%s%cshare%cmgg%cgmt_legs.d\0", LIBDIR, DIR_DELIM, DIR_DELIM, DIR_DELIM);
-		sprintf (index_file, "%s%cshare%cmgg%cgmt_index.b\0", LIBDIR, DIR_DELIM, DIR_DELIM, DIR_DELIM);
+		sprintf (leg_file, "%s%cmgg%cgmt_legs.d", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
+		sprintf (index_file, "%s%cmgg%cgmt_index.b", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
 	}
 	
 	
@@ -180,7 +178,7 @@ main (int argc, char **argv)
 		if (found_it && !strcmp (this_info->next_info->legname, leg)) {
 			if (replace) {
 				if (verbose) fprintf (stderr, "binlegs: Removing old info for leg: %s\n", leg);
-				free_id = remove_leg (this_info->next_info->leg_id);
+				free_id = remove_leg (this_info->next_info->leg_id, grid);
 				if (delete) this_info->next_info = this_info->next_info->next_info;
 			}
 			else {
@@ -198,8 +196,8 @@ main (int argc, char **argv)
 			
 		/* Open the bix file */
 		
-		sprintf (file, "%s.bix\0", leg);
-		if ((find = fopen (file,"r")) == NULL) {
+		sprintf (file, "%s.bix", leg);
+		if ((find = GMT_fopen (file,"r")) == NULL) {
 			fprintf (stderr, "Could not find file: %s\n",file);
 			continue;
 		}
@@ -239,8 +237,8 @@ main (int argc, char **argv)
 	
 	/* Done, now we must rewrite the gmt_index.b and gmt_legs.d files */
 	
-	sprintf (old_leg_file, "%s_old\0", leg_file);
-	sprintf (old_index_file, "%s_old\0", index_file);
+	sprintf (old_leg_file, "%s_old", leg_file);
+	sprintf (old_index_file, "%s_old", index_file);
 	
 	if (rename (leg_file, old_leg_file)) {
 		fprintf (stderr, "binlegs: Rename failed for %s. Aborts!\n", leg_file);
@@ -277,6 +275,10 @@ main (int argc, char **argv)
 	fclose (fbin);
 	chmod (index_file, S_RDONLY);
 	if (verbose) fprintf (stderr, "binlegs completed successfully\n");
+
+	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
 }
 
 struct INFO *make_info (char *name, int id_no, int flag)
@@ -299,7 +301,7 @@ struct LEG *make_leg (int id, int flag)
 	return (new);
 }
 
-int remove_leg (int leg_id)
+int remove_leg (int leg_id, struct GRID *grid)
 {
 	/* Remove all traces of the leg with id leg_id from structures */
 	struct LEG *leg, *skip_leg;
