@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt2bin.c,v 1.6 2006/03/25 03:56:52 pwessel Exp $
+ *	$Id: gmt2bin.c,v 1.12 2007/03/12 19:52:27 remko Exp $
  *
- *    Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -47,6 +47,8 @@ int main (int argc, char **argv)
 	char line[BUFSIZ], path[80];
 	FILE *fpl = NULL, *fpo, *fp;
 	struct GMTMGG_REC *record;
+
+	argc = GMT_begin (argc, argv);
 	
 	path[0] = 0;
 	for (i = 1; i < argc; i++) {
@@ -64,7 +66,7 @@ int main (int argc, char **argv)
 					break;
 			}
 		}
-		else if ((fpl = fopen (argv[i], "r")) == NULL) {
+		else if ((fpl = GMT_fopen (argv[i], "r")) == NULL) {
 			fprintf (stderr, "gmt2bin: Couldn't open file %s\n", argv[i]);
 			exit (EXIT_FAILURE);
 		}
@@ -86,7 +88,7 @@ int main (int argc, char **argv)
 			sprintf (gmtfile, "%s%c%s.gmt", path, DIR_DELIM, legid);
 		else
 			sprintf (gmtfile, "%s.gmt", legid);
-		if ((fp = fopen (gmtfile, "rb")) == NULL) {
+		if ((fp = GMT_fopen (gmtfile, "rb")) == NULL) {
 			fprintf (stderr, "gmt2bin: Cannot open file %s\n", gmtfile);
 			continue;
 		}
@@ -210,6 +212,8 @@ int main (int argc, char **argv)
 	fclose (fpl);
 	
 	GMT_free ((void *)record);
+
+	GMT_end (argc, argv);
 	
 	exit (EXIT_SUCCESS);
 }
