@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt2dat.c,v 1.5 2006/03/25 03:56:52 pwessel Exp $
+ *	$Id: gmt2dat.c,v 1.12 2007/03/12 19:52:27 remko Exp $
  *
- *    Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -28,7 +28,9 @@ int main (int argc, char **argv)
 	struct GMTMGG_TIME *gmt;
 	struct GMTMGG_REC *record;
 
-	if (argc != 2 || (fp = fopen(argv[1], "rb")) == NULL) {
+	argc = GMT_begin (argc, argv);
+
+	if (argc != 2 || (fp = GMT_fopen(argv[1], "rb")) == NULL) {
 		fprintf(stderr, "usage: gmt2dat file.gmt > asciifile\n");
 		exit (EXIT_FAILURE);
 	}
@@ -37,15 +39,15 @@ int main (int argc, char **argv)
 	
 	if (fread((void *)(&leg_year), (size_t)4, (size_t)1, fp) != 1) {
 		fprintf(stderr,"gmt2dat: Error while reading first year\n");
-		exit(EXIT_FAILURE);
+		exit (EXIT_FAILURE);
 	}
 	if (fread((void *)(&n_records), (size_t)4, (size_t)1, fp) != 1) {
 		fprintf(stderr,"gmt2dat: Error while reading no of records\n");
-		exit(EXIT_FAILURE);
+		exit (EXIT_FAILURE);
 	}
 	if (fread((void *)agency, (size_t)10, (size_t)1, fp) != 1) {
 		fprintf(stderr,"gmt2dat: Error while reading info-header\n");
-		exit(EXIT_FAILURE);
+		exit (EXIT_FAILURE);
 	}
 	
 	record = (struct GMTMGG_REC *) GMT_memory (VNULL, (size_t)n_records, sizeof (struct GMTMGG_REC), "gmt2dat");
@@ -57,7 +59,7 @@ int main (int argc, char **argv)
 	for (rec = 0; rec < n_records; rec++) {
 		if (fread ((void *)(&record[rec]), (size_t)18, (size_t)1, fp) != 1) {
 			fprintf (stderr,"gmt2dat: Error reading data record no %d\n",rec);
-			exit(EXIT_FAILURE);
+			exit (EXIT_FAILURE);
 		}
 	}
 	fclose(fp);
@@ -74,6 +76,8 @@ int main (int argc, char **argv)
 	
 	GMT_free ((void *)gmt);
 	GMT_free ((void *)record);
+
+	GMT_end (argc, argv);
 	
 	exit (EXIT_SUCCESS);
 }
