@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_mgg.c,v 1.10 2005/12/27 04:28:12 pwessel Exp $
+ *	$Id: gmt_mgg.c,v 1.14 2007/03/14 23:11:11 pwessel Exp $
  *
- *    Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -40,6 +40,7 @@
 
 char *gmtmgg_path[10];	/* Max 10 directories for now */
 int n_gmtmgg_paths = 0;	/* Number of these directories */
+char *MGG_SHAREDIR;	/* Copy of GMT_SHAREDIR (for DLL purposes) */
 
 BOOLEAN MGD77_first_1900 = FALSE, MGD77_first_2000 = FALSE;
 
@@ -58,13 +59,13 @@ int gmtmgg_date (int time, int *year, int *month, int *day, int *hour, int *minu
 
 	if ((*month) < 0 || (*month) >= GMTMGG_TIME_MAXMONTH) {
 		fprintf (stderr, "GMT ERROR: in gmtmgg_date: Month outside valid range [0-%d>: %d\n", GMTMGG_TIME_MAXMONTH, *month);
-		exit (EXIT_FAILURE);
+		GMT_exit (EXIT_FAILURE);
 	}
 	while (gmt_struct->daymon[*month +1] <= day_time) {
 		(*month)++;
 		if ((*month) < 0 || (*month) > GMTMGG_TIME_MAXMONTH) {
 			fprintf (stderr, "GMT ERROR: in gmtmgg_date: Month outside valid range [0-%d>: %d\n", GMTMGG_TIME_MAXMONTH, *month);
-			exit (EXIT_FAILURE);
+			GMT_exit (EXIT_FAILURE);
 		}
 	}
 	*year = (*month  - 1) / 12 + gmt_struct->first_year;
@@ -158,21 +159,18 @@ int gmtmgg_time (int *time, int year, int month, int day, int hour, int minute,
 	return (*time);
 }
 	
-/* gmtmggpath_init reads the SHAREDIR/share/mgg/gmtfile_paths file and gets all
+/* gmtmggpath_init reads the SHAREDIR/mgg/gmtfile_paths file and gets all
  * the gmtfile directories.
  */
  
-void gmtmggpath_init (void) {
+void gmtmggpath_init (char *dir) {
 	int i;
-	char file[BUFSIZ], line[BUFSIZ], *SHAREDIR;
+	char file[BUFSIZ], line[BUFSIZ];
 	FILE *fp;
-	
-	if ((SHAREDIR = getenv ("GMTHOME")) == (char *)NULL) {
-		fprintf (stderr, "gmtmggpath_init: Environment variable GMTHOME not set!\n");
-		exit (EXIT_FAILURE);
-	}
 
-	sprintf (file, "%s%cshare%cmgg%cgmtfile_paths", SHAREDIR, DIR_DELIM, DIR_DELIM, DIR_DELIM);
+	sprintf (file, "%s%cmgg%cgmtfile_paths", dir, DIR_DELIM, DIR_DELIM);
+	MGG_SHAREDIR = GMT_memory (VNULL, (size_t)1, (size_t)(strlen (dir)+1), "gmtmggpath_init");
+	strcpy (MGG_SHAREDIR, dir);
 	
 	n_gmtmgg_paths = 0;
 
@@ -364,7 +362,6 @@ int gmtmgg_decode_MGD77 (char *string, int tflag, struct GMTMGG_REC *record, str
 }
 
 /* CARTER TABLE ROUTINES */
-
 int carter_setup (void)
 {
 	/* This routine must be called once before using carter table stuff.
@@ -373,19 +370,14 @@ int carter_setup (void)
 	and returns 0.  If failure occurs, it returns -1.  */
 
 	FILE *fp = NULL;
-	char buffer [BUFSIZ], *SHAREDIR;
+	char buffer [BUFSIZ];
 	int  i;
 
 	carter_not_initialized = TRUE;
 
 	/* Read the correction table:  */
 
-	if ((SHAREDIR = getenv ("GMTHOME")) == (char *)NULL) {
-		fprintf (stderr, "carter_setup: Environment variable GMTHOME not set!\n");
-                return (-1);
-	}
-
-	sprintf (buffer, "%s%cshare%cmgg%ccarter.d", SHAREDIR, DIR_DELIM, DIR_DELIM, DIR_DELIM);
+	sprintf (buffer, "%s%cmgg%ccarter.d", MGG_SHAREDIR, DIR_DELIM, DIR_DELIM);
 	if ( (fp = fopen (buffer, "r")) == NULL) {
                 fprintf (stderr,"carter_setup:  Cannot open r %s\n", buffer);
                 return (-1);
@@ -609,4 +601,3 @@ int carter_twt_from_depth (int zone, short int depth_in_corr_m, short int *twt_i
 	*twt_in_msec = (short int)irint (133.333 * (guess - min + fraction) );
 	return (0);
 }
-
