@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtlegs.c,v 1.1.1.1 2000/12/28 01:23:45 gmt Exp $
+ *	$Id: gmtlegs.c,v 1.9 2007/03/12 19:52:27 remko Exp $
  *
- *    Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -29,22 +29,17 @@ struct INFO {
 	struct INFO *next_info;
 };
 
-static char *data[8] = 
-	{ "-", "G", "M", "GM", "T", "GT", "MT", "GMT" };
-
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
 	int i, ninfo, n_found = 0, bin, leg, no, flagin, nlegs, gmt, gmtflag = 0;
-	char lname[16], line[BUFSIZ], file[BUFSIZ], *LIBDIR;
+	char lname[16], line[BUFSIZ], file[BUFSIZ];
 	double west, east, south, north;
 	FILE *fleg, *fbin;
 	BOOLEAN error = FALSE, full = FALSE, verbose = FALSE, inside(double w, double e, double s, double n, int binnr);
 	struct INFO *leginfo[MSIZE], *ptr[MSIZE], *make_info(char *name, int id_no, int flag);
-	
-	if ((LIBDIR = getenv ("GMTHOME")) == (char *)NULL) {
-		fprintf (stderr, "gmtlegs: Environment variable GMTHOME not set!\n");
-		exit (EXIT_FAILURE);
-	}
+	static char *data[8] = { "-", "G", "M", "GM", "T", "GT", "MT", "GMT" };
+
+	argc = GMT_begin (argc, argv);
 
 	west = east = south = north = 0.0;
   	gmtflag = 0;
@@ -91,12 +86,12 @@ main (int argc, char **argv)
   		exit (EXIT_FAILURE);
   	}
   	
-  	sprintf (file, "%s%cshare%cmgg%cgmt_legs.d\0", LIBDIR, DIR_DELIM, DIR_DELIM, DIR_DELIM);
+  	sprintf (file, "%s%cmgg%cgmt_legs.d", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
   	if ((fleg = fopen (file, "r")) == NULL) {
 		fprintf (stderr,"gmtlegs: Could not open %s\n", file);
 		exit (EXIT_FAILURE);
 	}
-  	sprintf (file, "%s%cshare%cmgg%cgmt_index.b\0", LIBDIR, DIR_DELIM, DIR_DELIM, DIR_DELIM);
+  	sprintf (file, "%s%cmgg%cgmt_index.b", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
 	if ((fbin = fopen (file, "rb")) == NULL) {
 		fprintf(stderr,"gmtlegs: Could not open %s\n", file);
 		exit (EXIT_FAILURE);
