@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtlist.c,v 1.14 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: gmtlist.c,v 1.22 2007/03/14 23:11:11 pwessel Exp $
  *
- *    Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -53,7 +53,7 @@ int main (int argc, char **argv)
 	int correct = FALSE, tsec = FALSE, calender = FALSE, do_heading = FALSE;
 	int no_g, no_m, no_t, greenwich = FALSE, do_speed = FALSE, binary = FALSE;
 	
-	char gmtfile[BUFSIZ], corrfile[BUFSIZ], agency[10], ndata, g, m, t, *LIBDIR;
+	char gmtfile[BUFSIZ], corrfile[BUFSIZ], agency[10], ndata, g, m, t;
 	
 	double lat, lon, grv, mag, top, dist, val, start_dist = 0., stop_dist = 1.0E100;
 	double ds, dx, dy, west = 0.0, east = 360.0, south = -90.0, north = 90.0;
@@ -71,11 +71,6 @@ int main (int argc, char **argv)
 	FILE *fp, *fpc;
 	
 	struct GMTMGG_REC record;
-	
-	if ((LIBDIR = getenv ("GMTHOME")) == (char *)NULL) {
-		fprintf (stderr, "binlegs: Environment variable GMTHOME not set!\n");
-		exit (EXIT_FAILURE);
-	}
 
 	g = m = t = no_g = no_m = no_t = FALSE;
 	
@@ -100,7 +95,7 @@ int main (int argc, char **argv)
 					
 				case 'C':
 					if (argv[i][2] == 0)	/* Use default corrfile */
-						sprintf (corrfile, "%s%cshare%cmgg%cxx_corrections.b", LIBDIR, DIR_DELIM, DIR_DELIM, DIR_DELIM);
+						sprintf (corrfile, "%s%cmgg%cxx_corrections.b", GMT_SHAREDIR, DIR_DELIM, DIR_DELIM);
 					else
 						strcpy (corrfile, &argv[i][2]);
 					correct = TRUE;
@@ -247,18 +242,18 @@ int main (int argc, char **argv)
 		fprintf(stderr,"	-V verbose, report progress\n");
 		fprintf(stderr,"	-W sets weight for these data\n");
 		fprintf(stderr,"	-b means binary (double) output [ascii]\n");
-		exit(EXIT_FAILURE);
+		exit (EXIT_FAILURE);
 	}
 
-	gmtmggpath_init();
+	gmtmggpath_init(GMT_SHAREDIR);
 
 	if ((west < 0.0 && east > 0.0) || (west < 360.0 && east > 360.0)) greenwich = TRUE;
 	if (!geodetic) greenwich = TRUE;
 	
 	if (correct) {	/* Read correction table */
-		if ((fpc = fopen(corrfile, "rb")) == NULL) {
+		if ((fpc = GMT_fopen(corrfile, "rb")) == NULL) {
 			fprintf(stderr, "Could not read correction file %s\n", corrfile);
-			exit(EXIT_FAILURE);
+			exit (EXIT_FAILURE);
 		}
 		bin = (struct CORR **) GMT_memory (VNULL, (size_t)MAXLEGS, sizeof (struct CORR *), "gmtlist");
 		i = 0;
@@ -333,7 +328,7 @@ int main (int argc, char **argv)
    			fprintf (stderr, "gmtlist : Cannot find leg %s\n", argv[argno]);
      			continue;
   		}
-		if ((fp = fopen (gmtfile, "rb")) == NULL) {
+		if ((fp = GMT_fopen (gmtfile, "rb")) == NULL) {
 			fprintf (stderr,"gmtlist: Could not open %s\n", gmtfile);
 			continue;
 		}
@@ -550,6 +545,8 @@ int main (int argc, char **argv)
 		fclose (fp);
 		GMT_free ((void *)gmt);
 	}
+
+	GMT_end (argc, argv);
 	
 	exit (EXIT_SUCCESS);
 }
