@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmttrack.c,v 1.17 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: gmttrack.c,v 1.26 2007/03/24 01:42:07 pwessel Exp $
  *
- *    Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -62,17 +62,16 @@ int main (int argc, char **argv)
 	struct LEG_ANOT *cruise_id = VNULL;
 	struct GMT_PEN pen;
 	struct ANOT info;
-struct GMTMGG_REC *record;
-int *distance;
+	struct GMTMGG_REC *record;
+	int *distance;
 	FILE *fp;
 	
 	struct GMTMGG_TIME *gmt;
 	
-double heading (int rec, int n_records, struct GMTMGG_REC *record);
-int get_annotinfo (char *args, struct ANOT *info);
-int gmttrack_outside (int lon, int lat, int w, int e, int s, int n);
-void annot_legname (double x, double y, int rec, int nrecs, char *text, double size, int w, int e, int s, int n, struct GMTMGG_REC *record, struct GMT_PEN *pen);
-
+	double heading (int rec, int n_records, struct GMTMGG_REC *record);
+	int get_annotinfo (char *args, struct ANOT *info);
+	int gmttrack_outside (int lon, int lat, int w, int e, int s, int n);
+	void annot_legname (double x, double y, int rec, int nrecs, char *text, double size, int w, int e, int s, int n, struct GMTMGG_REC *record, struct GMT_PEN *pen);
 
 	GMT_init_pen (&pen, GMT_PENWIDTH);
 	for (i = 0; i < 3; i++) black[i] = 0, white[i] = 255;
@@ -174,13 +173,11 @@ void annot_legname (double x, double y, int rec, int nrecs, char *text, double s
 		exit (EXIT_FAILURE);
 	}
 	
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
-	gmtmggpath_init();
+	gmtmggpath_init(GMT_SHAREDIR);
 
 	if (east < west) west -= 360.0;
 		
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 	
 	GMT_plotinit (argc, argv);
 	
@@ -206,7 +203,7 @@ void annot_legname (double x, double y, int rec, int nrecs, char *text, double s
    			fprintf(stderr,"gmttrack : Cannot find leg %s\n", argv[i]);
      			continue;
   		}
-		if ((fp = fopen(gmtfile, "rb")) == NULL) {
+		if ((fp = GMT_fopen(gmtfile, "rb")) == NULL) {
 			fprintf(stderr, "gmttrack: Could not open file %s\n", gmtfile);
 			continue;
 		}
@@ -215,15 +212,15 @@ void annot_legname (double x, double y, int rec, int nrecs, char *text, double s
 		
 		if (fread((void *)(&leg_year), (size_t)4, (size_t)1, fp) != 1) {
 			fprintf(stderr,"gmttrack: Error while reading first year\n");
-			exit(EXIT_FAILURE);
+			exit (EXIT_FAILURE);
 		}
 		if (fread((void *)(&n_records), (size_t)4, (size_t)1, fp) != 1) {
 			fprintf(stderr,"gmttrack: Error while reading no of records\n");
-			exit(EXIT_FAILURE);
+			exit (EXIT_FAILURE);
 		}
 		if (fread((void *)agency, (size_t)10, (size_t)1, fp) != 1) {
 			fprintf(stderr,"gmttrack: Error while reading info-header\n");
-			exit(EXIT_FAILURE);
+			exit (EXIT_FAILURE);
 		}
 		
 		distance = (int *) GMT_memory ((void *)distance, (size_t)n_records, sizeof (int), "gmttrack");
@@ -241,7 +238,7 @@ void annot_legname (double x, double y, int rec, int nrecs, char *text, double s
 		for (rec = k = 0; rec < n_records; rec++) {
 			if (fread((void *)(&record[k]), (size_t)18, (size_t)1, fp) != 1) {
 				fprintf(stderr,"gmttrack: Error reading data record no %d\n",rec);
-				exit(EXIT_FAILURE);
+				exit (EXIT_FAILURE);
 			}
 			lon = record[k].lon * MDEG2DEG;
 			lat = record[k].lat * MDEG2DEG;
