@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: minmax.c,v 1.36 2006/04/13 08:34:41 pwessel Exp $
+ *    $Id: minmax.c,v 1.44 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -145,7 +145,7 @@ int main (int argc, char **argv)
 
 	if (error || GMT_give_synopsis_and_exit) {	/* Because it's ok to give no arguments */
 		fprintf (stderr, "minmax %s - Find extreme values in ASCII tables\n\n", GMT_VERSION);
-		fprintf (stderr, "usage: minmax [files] [-C] [-E<L|l|H|h><col>] [%s] [-Idx[/dy[/<dz>..]] [%s]\n", GMT_H_OPT, GMT_M_OPT);
+		fprintf (stderr, "usage: minmax [files] [-C] [-E<L|l|H|h><col>] [%s] [-I[p]<dx>[/<dy>[/<dz>..]] [%s]\n", GMT_H_OPT, GMT_M_OPT);
 		fprintf (stderr, "\t[-T<dz>] [%s] [%s] [%s]\n", GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
              
               	if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -158,6 +158,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-I returns textstring -Rw/e/s/n to nearest multiple of dx/dy (assumes 2+ col data)\n");
 		fprintf (stderr, "\t   If -C is set then no -R string is issued.  Instead, the number of increments\n");
 		fprintf (stderr, "\t   given determines how many columns are rounded off to the nearest multiple.\n");
+		fprintf (stderr, "\t   If only one increment is given we also use it for the second column (for backwards compatibility).\n");
+		fprintf (stderr, "\t   To override this behaviour, use -Ip<dx>.\n");
 		GMT_explain_option ('M');
 		fprintf (stderr, "\t-T returns textstring -Tzmin/zmax/dz to nearest multiple of the given dz\n");
 		fprintf (stderr, "\t   Calculations are based on the first column only\n");
@@ -212,8 +214,6 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -239,12 +239,12 @@ int main (int argc, char **argv)
 				strcpy (gmtdefs.output_degree_format, "-D");
 			else
 				strcpy (gmtdefs.output_degree_format, "+D");
-			GMT_geo_C_format (gmtdefs.output_degree_format, &GMT_io.geo);
+			GMT_err_fail (GMT_geo_C_format (gmtdefs.output_degree_format, &GMT_io.geo), "");
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Warning: OUTPUT_DEGREE_FORMAT reset from D to %s to ensure east > west\n", GMT_program, gmtdefs.output_degree_format);
 		}
 		else if (!strcmp (gmtdefs.output_degree_format, "ddd:mm:ss")) {
 			strcpy (gmtdefs.output_degree_format, "ddd:mm:ssF");
-			GMT_geo_C_format (gmtdefs.output_degree_format, &GMT_io.geo);
+			GMT_err_fail (GMT_geo_C_format (gmtdefs.output_degree_format, &GMT_io.geo), "");
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Warning: OUTPUT_DEGREE_FORMAT reset from ddd:mm:ss to %s to ensure east > west\n", GMT_program, gmtdefs.output_degree_format);
 		}
 	}
