@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: gmtdigitize.c,v 1.7 2006/04/10 05:47:30 pwessel Exp $
+ *    $Id: gmtdigitize.c,v 1.15 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -36,7 +36,7 @@
 #endif
 
 /* Default port and line density in lines per inch (only tested on RedHat Linux 9)*/
-#define DIG_PORT	"/dev/ttyS0"
+#define DIG_PORT	"/dev/ttyS1"
 #define DIG_LPI		2540
 
 /*===========================================================================*/
@@ -204,8 +204,6 @@ int main (int argc, char **argv)
 #endif
 	tcflush (digunit, TCIFLUSH);	/* Clean the muzzle */
 	
-	GMT_put_history (argc, argv);	/* Update .gmtcommands */
-
 #ifdef SET_IO_MODE
 	GMT_setmode (1);
 #endif
@@ -214,7 +212,7 @@ int main (int argc, char **argv)
 
 	u_scale = inv_scale;
 
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	fprintf (stderr, "\n==>   %s version %s  Paul Wessel, SOEST, Apr 22, 2004   <==\n\n", GMT_program, GMT_VERSION);
 	fprintf (stderr, "================  HOW TO DIGITIZE ================\n\n");
