@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: makepattern.c,v 1.12 2006/10/11 02:52:18 remko Exp $
+ *	$Id: makepattern.c,v 1.19 2007/03/12 19:52:27 remko Exp $
  *
- *      Copyright (c) 1999-2006 by P. Wessel
+ *      Copyright (c) 1999-2007 by P. Wessel
  *      See COPYING file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -109,7 +109,7 @@ int main (int argc, char **argv)
 		}
 		else {
 			fname = argv[i];
-			if ((fp = fopen (fname, "rb")) == NULL) {
+			if ((fp = GMT_fopen (fname, "rb")) == NULL) {
 				fprintf(stderr,"%s: Cannot open file %s\n", GMT_program, fname);
 				exit (EXIT_FAILURE);
 			}
@@ -145,7 +145,7 @@ int main (int argc, char **argv)
 #ifdef _WIN32
 		fprintf(stderr,"\t-G  Name of output Sun rasterfile\n");
 #endif
-		exit(EXIT_FAILURE);
+		exit (EXIT_FAILURE);
 	}
 
 	if (!fp) {
@@ -153,8 +153,6 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	GMT_put_history (argc, argv);
-
 	if (fp) {	/* Got a 1-bit Sun rasterfile */
 
 		if (ps_read_rasheader (fp, &h, 0, 7)) {
@@ -278,7 +276,7 @@ unsigned short int *get_icon (char *file, int *nx, int *ny, int invert)
 	char t[8][7], line[80], width[12], height[12];
 	FILE *fp;
 
-	if ((fp = fopen (file, "r")) == NULL) {
+	if ((fp = GMT_fopen (file, "r")) == NULL) {
 		fprintf (stderr, "%s: Cannot open file %s\n", GMT_program, file);
 		return ((unsigned short int *)NULL);
 	}
