@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psmegaplot.c,v 1.6 2006/03/30 04:40:04 pwessel Exp $
+ *	$Id: psmegaplot.c,v 1.11 2007/03/12 19:52:27 remko Exp $
  *
- *      Copyright (c) 1999-2006 by P. Wessel
+ *      Copyright (c) 1999-2007 by P. Wessel
  *      See COPYING file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -79,7 +79,7 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	if ((fp = fopen(ifile, "r")) == NULL) {
+	if ((fp = GMT_fopen(ifile, "r")) == NULL) {
 		fprintf(stderr, "psmegaplot: Could not open file %s\n", ifile);
 		exit (EXIT_FAILURE);
 	}
