@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: nearneighbor.c,v 1.40 2006/09/26 16:58:54 remko Exp $
+ *	$Id: nearneighbor.c,v 1.47 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -234,8 +234,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -N option:  Must specify a positive number of sectors\n", GMT_program);
 		error++;
 	}
-	if (Ctrl->S.radius <= 0.0) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Must specify a positive search radius\n", GMT_program);
+	if (Ctrl->S.active && (Ctrl->S.radius <= 0.0 || GMT_is_dnan (Ctrl->S.radius))) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Radius is NaN or negative\n", GMT_program);
 		error++;
 	}
 	if (Ctrl->I.xinc <= 0.0 || Ctrl->I.yinc <= 0.0) {
@@ -256,8 +256,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -269,7 +267,7 @@ int main (int argc, char **argv)
 	header.y_inc = Ctrl->I.yinc;
 	header.node_offset = Ctrl->F.active;
 	GMT_RI_prepare (&header);	/* Ensure -R -I consistency and set nx, ny */
-	GMT_grd_RI_verify (&header, 1);
+	GMT_err_fail (GMT_grd_RI_verify (&header, 1), Ctrl->G.file);
 
 	n_expected_fields = (GMT_io.binary[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3 + Ctrl->W.active;
 
@@ -497,10 +495,7 @@ int main (int argc, char **argv)
 	}
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Gridded row %6d\n", GMT_program, j);
 
-	if (GMT_write_grd (Ctrl->G.file, &header, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	if (gmtdefs.verbose) {
 		sprintf (line, "%s)\n", gmtdefs.d_format);
