@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: project.c,v 1.41 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: project.c,v 1.48 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,7 @@
 		03-NOV-1998	PW: Can read any number of data columns; z in -Fz refers to
 				all these columns in the output.
    Version:	3.4		PW: Fixed problem with small circle distances
-   Version:	4
+   Version:	4.1.x
 */
 
 #include "gmt.h"
@@ -421,8 +421,6 @@ int main (int argc, char **argv)
 	
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
