@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psbasemap.c,v 1.33 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: psbasemap.c,v 1.39 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -105,7 +105,7 @@ int main (int argc, char **argv)
 			case 'G':
 				Ctrl->G.active = TRUE;
 				if (GMT_getfill (&argv[i][2], &Ctrl->G.fill)) {
-					GMT_fill_syntax ('G');
+					GMT_fill_syntax ('G', " ");
 					error++;
 				}
 				break;
@@ -155,7 +155,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
-		fprintf (stderr, "\t-G fill inside of basemap with the specified fill\n");
+		GMT_fill_syntax ('G', "Select fill inside of basemap.");
 		GMT_explain_option ('K');
 		fprintf (stderr, "\t-L draws a simple map scaLe centered on <lon0>/<lat0>.  Use -Lx to specify Cartesian\n");
 		fprintf (stderr, "\t   coordinates instead.  Scale is calculated at latitude <slat>; optionally give longitude\n");
@@ -200,14 +200,12 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
 
 	if (gmtdefs.verbose) fprintf (stderr, "psbasemap: Constructing basemap\n");
 
-	GMT_map_setup (w, e, s, n);
+	GMT_err_fail (GMT_map_setup (w, e, s, n), "");
 
 	GMT_plotinit (argc, argv);
 
