@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscoast.c,v 1.57 2006/05/08 07:49:08 pwessel Exp $
+ *	$Id: pscoast.c,v 1.70 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -122,7 +122,7 @@ struct PSCOAST_CTRL {
 
 int main (int argc, char **argv)
 {
-	int i, n, np, ind, bin, base, anti_bin = -1, level, flag, np_new, k, last_k;
+	int i, n, np, ind, bin, base, anti_bin = -1, level, flag, np_new, k, last_k, err;
 	int level_to_be_painted = 0, direction, start_direction, stop_direction;
 	int n_blevels = 0, n_rlevels = 0, bin_trouble, lowest_level = 1, n_pieces = 0;
 
@@ -191,7 +191,7 @@ int main (int argc, char **argv)
 				case 'C':	/* Lake color */
 					Ctrl->C.active = TRUE;
 					if (argv[i][2] && GMT_getfill (&argv[i][2], &Ctrl->C.fill)) {
-						GMT_fill_syntax ('C');
+						GMT_fill_syntax ('C', " ");
 						error++;
 					}
 					break;
@@ -205,10 +205,10 @@ int main (int argc, char **argv)
 					break;
 				case 'G':		/* Set Gray shade, pattern, or clipping */
 					Ctrl->G.active = TRUE;
-					if (argv[i][2] == 'c')
+					if (argv[i][2] == 'c' && argv[i][3] == '\0')
 						Ctrl->G.clip = TRUE;
 					else if (argv[i][2] && GMT_getfill (&argv[i][2], &Ctrl->G.fill)) {
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					break;
@@ -226,9 +226,11 @@ int main (int argc, char **argv)
 						error++;
 						continue;
 					}
-					if ((string = strchr (argv[i], '/')) && GMT_getpen (++string, &pen)) {	/* Get specified pen */
-						GMT_pen_syntax ('N');
-						error++;
+					if ((string = strchr (argv[i], '/'))) {		/* Get specified pen */
+						if (GMT_getpen (++string, &pen)) {	/* Error decoding pen */
+							GMT_pen_syntax ('N', " ");
+							error++;
+						}
 					}
 					else	/* No pen specified, use default */
 						GMT_init_pen (&pen, GMT_PENWIDTH);
@@ -259,9 +261,11 @@ int main (int argc, char **argv)
 						error++;
 						continue;
 					}
-					if ((string = strchr (argv[i], '/')) && GMT_getpen (++string, &pen)) {	/* Get specified pen */
-						GMT_pen_syntax ('I');
-						error++;
+					if ((string = strchr (argv[i], '/'))) {	/* Get specified pen */
+						if (GMT_getpen (++string, &pen)) {	/* Error decoding pen */
+							GMT_pen_syntax ('I', " ");
+							error++;
+						}
 					}
 					else	/* No pen specified, use default */
 						GMT_init_pen (&pen, GMT_PENWIDTH);
@@ -299,10 +303,10 @@ int main (int argc, char **argv)
 
 				case 'S':		/* Set ocean color if needed */
 					Ctrl->S.active = TRUE;
-					if (argv[i][2] == 'c')
+					if (argv[i][2] == 'c' && argv[i][3] == '\0')
 						Ctrl->S.clip = TRUE;
 					else if (argv[i][2] && GMT_getfill (&argv[i][2], &Ctrl->S.fill)) {
-						GMT_fill_syntax ('S');
+						GMT_fill_syntax ('S', " ");
 						error++;
 					}
 					break;
@@ -313,7 +317,7 @@ int main (int argc, char **argv)
 				case 'W':
 					Ctrl->W.active = TRUE;
 					if (argv[i][2] && GMT_getpen (&argv[i][2], &Ctrl->W.pen)) {
-						GMT_pen_syntax ('W');
+						GMT_pen_syntax ('W', " ");
 						error++;
 					}
 					break;
@@ -352,7 +356,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t[%s]\n", GMT_SCALE);
 		fprintf (stderr, "\t[%s] [-N<feature>[/<pen>]] [-O] [-P] [-Q] [-S<fill>]\n", GMT_Mo_OPT);
 		fprintf (stderr, "\t[%s] [%s]\n", GMT_TROSE, GMT_U_OPT);
-		fprintf (stderr, "\t[-V] [-W[<pen>]] [%s] [%s] [%s] [%s]\n", GMT_X_OPT, GMT_Y_OPT, GMT_bo_OPT, GMT_c_OPT);
+		fprintf (stderr, "\t[-V] [-W[<pen>]] [%s] [%s] [-Z<zlevel>] [%s] [%s]\n", GMT_X_OPT, GMT_Y_OPT, GMT_bo_OPT, GMT_c_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -363,9 +367,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-A features smaller than <min_area> (in km^2) or of levels (0-4) outside the min-max levels\n");
 		fprintf (stderr, "\t   will be skipped [0/4 (4 means lake inside island inside lake)]\n");
 		GMT_explain_option ('b');
-		fprintf (stderr, "\t-C sets separate color for lakes. [Default is same as ocean (white)]. Set\n");
-		fprintf (stderr, "\t   1) <r/g/b> (each 0-255) for color or <gray> (0-255) for gray-shade [0].\n");
-		fprintf (stderr, "\t   2) p[or P]<dpi>/<pattern> for predefined patterns (1-90).\n");
+		GMT_fill_syntax ('C', "Sets separate color for lakes [Default is same as ocean].");
 		fprintf (stderr, "\t-D Choose one of the following resolutions:\n");
 		fprintf (stderr, "\t   f - full resolution (may be very slow for large regions)\n");
 		fprintf (stderr, "\t   h - high resolution (may be slow for large regions)\n");
@@ -373,11 +375,9 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   l - low resolution [Default]\n");
 		fprintf (stderr, "\t   c - crude resolution, for busy plots that need crude continent outlines only\n");
 		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
-		fprintf (stderr, "\t-G Paint or clip \"dry\" areas.  Append desired effect as:\n");
-		fprintf (stderr, "\t   1) <r/g/b> (each 0-255) for color or <gray> (0-255) for gray-shade [0].\n");
-		fprintf (stderr, "\t   2) p[or P]<dpi>/<pattern> for predefined patterns (1-90).\n");
-		fprintf (stderr, "\t   3) c to issue clip paths for land areas.\n");
-		fprintf (stderr, "\t-I draws rIvers.  Specify feature and optionally append pen [Default is solid line of unit thickness].\n");
+		GMT_fill_syntax ('G', "Paint or clip \"dry\" areas.");
+		fprintf (stderr, "\t   6) c to issue clip paths for land areas.\n");
+		GMT_pen_syntax ('I', "draws rivers.  Specify feature and optionally append pen [Default is solid line of unit thickness].");
 		fprintf (stderr, "\t   Choose from the features below.  Repeat the -I option as many times as needed\n");
 		fprintf (stderr, "\t      1 = Permanent major rivers\n");
 		fprintf (stderr, "\t      2 = Additional major rivers\n");
@@ -404,7 +404,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-M Dump a multisegment ascii (or binary, see -bo) file to standard output.  No plotting occurs\n");
 		fprintf (stderr, "\t   Specify any combination of -W, -I, -N.  Optionally, append 1-char\n");
 		fprintf (stderr, "\t   segment header <flag> [%c]\n", GMT_io.EOF_flag[GMT_OUT]);
-		fprintf (stderr, "\t-N draws boundaries.  Specify feature and optionally append pen [Default is solid line of unit thickness]\n");
+		GMT_pen_syntax ('N', "draws boundaries.  Specify feature and optionally append pen [Default is solid line of unit thickness].");
 		fprintf (stderr, "\t   Choose from the features below.  Repeat the -N option as many times as needed\n");
 		fprintf (stderr, "\t     1 = National boundaries\n");
 		fprintf (stderr, "\t     2 = State boundaries within the Americas\n");
@@ -413,10 +413,8 @@ int main (int argc, char **argv)
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
 		fprintf (stderr,"\t-Q means terminate previously set clip-paths\n");
-		fprintf (stderr, "\t-S Paint or clip \"wet\" areas.  Append desired effect as:\n");
-		fprintf (stderr, "\t   1) <r/g/b> (each 0-255) for color or <gray> (0-255) for gray-shade [0].\n");
-		fprintf (stderr, "\t   2) p[or P]<dpi>/<pattern> for predefined patterns (1-90).\n");
-		fprintf (stderr, "\t   3) c to issue clip paths for water areas.\n");
+		GMT_fill_syntax ('S', "Paint of clip \"wet\" areas.");
+		fprintf (stderr, "\t   6) c to issue clip paths for water areas.\n");
 		fprintf (stderr, "\t-T draws a north-poinTing rose centered on <lon0>/<lat0>.  Use -Tx to specify Cartesian\n");
 		fprintf (stderr, "\t   coordinates instead.  -Tf draws a \"fancy\" rose [Default is plain].  Give rose diameter\n");
 		fprintf (stderr, "\t   <size> and optionally the west, east, south, north labels desired [W,E,S,N].\n");
@@ -429,8 +427,9 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Append +<gints>/<mints> to override default annotation/tick interval(s) [10/5/1/30/5/1].\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
-		fprintf (stderr,"\t-W draw shorelines.  Append pen [Default is solid line of unit thickness].\n");
+		GMT_pen_syntax ('W', "draw shorelines.  Append pen [Default is solid line of unit thickness].");
 		GMT_explain_option ('X');
+		fprintf (stderr, "\t-Z For 3-D plots: Set the z-level of map [0]\n");
 		GMT_explain_option ('o');
 		GMT_explain_option ('n');
 		GMT_explain_option ('c');
@@ -452,6 +451,10 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
 		error++;
 	}
+	if (!GMT_IS_MAPPING) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Geographic coastline data require the use of a map projection (use -Jx<scale>d if linear scaling is desired).\n", GMT_program);
+		error++;
+	}
 	if (Ctrl->W.pen.width < 0.0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -W option:  Pen thickness cannot be negative\n", GMT_program);
 		error++;
@@ -517,8 +520,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	base = GMT_set_resolution (&Ctrl->D.set, 'D');
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
@@ -543,7 +544,7 @@ int main (int argc, char **argv)
 		GMT_parse_J_option ("x1d");
 	}
 
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	world_map_save = GMT_world_map;
 
@@ -568,6 +569,9 @@ int main (int argc, char **argv)
 	}
 
 	if (dumping) {
+#ifdef SET_IO_MODE
+		GMT_setmode (GMT_OUT);
+#endif
 		if (!GMT_io.binary[1]) fprintf (GMT_stdout, "# Data from the %s resolution GMT shoreline, borders, and rivers database\n", shore_resolution[base]);
 	}
 	else {
@@ -663,6 +667,9 @@ int main (int argc, char **argv)
 	if ((360.0 - fabs (project_info.e - project_info.w) ) < c.bsize) {
 		GMT_world_map = TRUE;
 		if (project_info.projection == GMT_GNOMONIC) GMT_world_map = FALSE;
+#ifdef _GENPER
+		if (project_info.projection == GMT_GENPER) GMT_world_map = FALSE;
+#endif /* _GENPER */
 	}
 	if (GMT_world_map && greenwich)
 		edge = project_info.central_meridian;
@@ -692,7 +699,10 @@ int main (int argc, char **argv)
 #ifdef DEBUG
 		if (Ctrl->debug.bin >= 0 && bin != Ctrl->debug.bin) continue;
 #endif
-		GMT_get_shore_bin (ind, &c, Ctrl->A.area, Ctrl->A.low, Ctrl->A.high);
+		if ((err = GMT_get_shore_bin (ind, &c, Ctrl->A.area, Ctrl->A.low, Ctrl->A.high))) {
+			fprintf (stderr, "%s: %s [%s resolution shoreline]\n", GMT_program, GMT_strerror(err), shore_resolution[base]);
+			exit (EXIT_FAILURE);
+		}
 
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Working on block # %5d\r", GMT_program, bin);
 		if (!dumping) {
