@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscontour.c,v 1.49 2004/06/19 03:06:15 pwessel Exp $
+ *	$Id: pscontour.c,v 1.81 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,77 +26,116 @@
  */
 
 #include "gmt.h"
+#include "pslib.h"
+
+struct PSCONTOUR_CTRL {
+	struct GMT_CONTOUR contour;
+	struct A {	/* -A[-|aint][+a<angle>][+c<dx>[/<dy>]][+f<font>][+g<fill>][+j<just>][+l<label>][+o|O|t][+s<size>][+p<pen>][+u<unit>] */
+		BOOLEAN active;
+		BOOLEAN off;
+		double interval;
+	} A;
+	struct C {	/* -C<cpt> */
+		BOOLEAN active;
+		char *file;
+	} C;
+	struct D {	/* -D<dumpfile> */
+		BOOLEAN active;
+		char *file;
+	} D;
+	struct E {	/* -Eazim/elev */
+		BOOLEAN active;
+		double azimuth, elevation;
+	} E;
+	struct G {	/* -G[d|f|n|l|L|x|X]<params> */
+		BOOLEAN active;
+	} G;
+	struct I {	/* -I */
+		BOOLEAN active;
+	} I;
+	struct L {	/* -L<pen> */
+		BOOLEAN active;
+		struct GMT_PEN pen;
+	} L;
+	struct N {	/* -N */
+		BOOLEAN active;
+	} N;
+	struct S {	/* -S */
+		BOOLEAN active;
+	} S;
+	struct T {	/* -T<indexfile> */
+		BOOLEAN active;
+		char *file;
+	} T;
+	struct W {	/* -W[+]<type><pen> */
+		BOOLEAN active;
+		BOOLEAN color;
+		struct GMT_PEN pen;
+	} W;
+};
 
-/* Macros used below */
-int delta, sum;
-/* Returns plus/minus 1 if node2 is after/before node1 */
-#define get_direction(node_1, node_2) (((delta = (node_2) - (node_1)) == 1 || delta == -2) ? 1 : -1)
 /* Returns the id of the node common to the two edges */
-#define get_node_index(edge_1, edge_2) (((sum = (edge_1) + (edge_2)) == 1) ? 1 : ((sum == 2) ? 0 : 2))
-#define get_other_node(node1, node2) (((sum = (node1 + node2)) == 3) ? 0 : ((sum == 2) ? 1 : 2))	/* The other node needed */
+#define get_node_index(edge_1, edge_2) (((PSCONTOUR_SUM = (edge_1) + (edge_2)) == 1) ? 1 : ((PSCONTOUR_SUM == 2) ? 0 : 2))
+#define get_other_node(node1, node2) (((PSCONTOUR_SUM = (node1 + node2)) == 3) ? 0 : ((PSCONTOUR_SUM == 2) ? 1 : 2))	/* The other node needed */
+
+struct PSCONTOUR_LINE {	/* Beginning and end of straight contour segment */
+	double x0, y0;
+	double x1, y1;
+};
 
 struct PSCONTOUR {
 	int n_alloc, nl;
 	double val;
 	double angle;
 	char type;
-	struct PSLINE *L;
-} *cont;
-
-struct PSLINE {	/* Beginning and end of straight contour segment */
-	double x0, y0;
-	double x1, y1;
+	struct PSCONTOUR_LINE *L;
 };
 
-struct CHAIN {
-	struct PT *begin;
-	struct PT *end;
-	struct CHAIN *next;
-};
-
-struct PT {
+struct PSCONTOUR_PT {
 	double x, y;
-	struct PT *next;
+	struct PSCONTOUR_PT *next;
 };
-	
-int get_triangle_crossings (double *x, double *y, double *z, int *ind, double **xc, double **yc, double **zc, int **v, int **cindex);
-void paint_it (double x[], double y[], int n, double z);
 
-main(int argc, char **argv)
+struct PSCONTOUR_CHAIN {
+	struct PSCONTOUR_PT *begin;
+	struct PSCONTOUR_PT *end;
+	struct PSCONTOUR_CHAIN *next;
+};
+
+int main(int argc, char **argv)
 {
-	int n, np, nx, i, ij, k, k2, k3, node1, node2, c, rgb[3];
-	int n_alloc, box = 1, section = 0, *ind, *vert, *cind, n_fields, n_contours;
+	int n, np, nx, i, ij, k, k2, k3, node1, node2, c, rgb[3], PSCONTOUR_SUM;
+	int n_alloc, section = 0, *ind, *vert, *cind, n_fields, n_contours;
 	int add, close, bad, n_expected_fields, low, high, last_entry, last_exit;
-	
-	BOOLEAN error = FALSE, image_them = FALSE, draw_contours = FALSE, dump = FALSE, clip = TRUE, skip_if_outside = FALSE;
-	BOOLEAN more, t_set = FALSE, draw_mesh = FALSE, use_cpt_colors = FALSE, use_cpt_annot = TRUE, skip = FALSE;
-	
+
+	BOOLEAN error = FALSE, more, skip = FALSE;
+
 	double xx[3], yy[3], zz[3], xout[5], yout[5], *in, west, east, south, north;
-	double *xc, *yc, *zc, *x, *y, *z, *xp, *yp, label_angle = 0.0, current_contour = -DBL_MAX, xyz[2][3];
-	
-	char line[BUFSIZ], *cpt_file = CNULL, *t_file = CNULL, dfile[BUFSIZ];
-	char cont_label[128], format[128];
-	
+	double *xc, *yc, *zc, *x, *y, *z, *xp, *yp, current_contour = -DBL_MAX, xyz[2][3];
+
+	char line[BUFSIZ], cont_label[GMT_LONG_TEXT], format[GMT_LONG_TEXT];
+
 	FILE *fp = NULL, *fp_d = NULL;
-	
-	struct GMT_PEN pen, lpen;
-	struct GMT_CONTOUR G;
+
+	struct PSCONTOUR *cont;
+	struct PSCONTOUR_CTRL *Ctrl;
+
+	int get_triangle_crossings (double *x, double *y, double *z, int *ind, double **xc, double **yc, double **zc, int **v, int **cindex);
+	void paint_it (double x[], double y[], int n, double z);
+	void *New_Pscontour_Ctrl (), Free_Pscontour_Ctrl (struct PSCONTOUR_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
-	
-	GMT_init_pen (&pen, GMT_PENWIDTH);
-	GMT_init_pen (&lpen, GMT_PENWIDTH);
-	dfile[0] = 0;
-	GMT_contlabel_init (&G);
-	
+
+	Ctrl = (struct PSCONTOUR_CTRL *)New_Pscontour_Ctrl ();	/* Allocate and initialize a new control structure */
+
 	/* Check and interpret the command line arguments */
-	
+
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch(argv[i][1]) {
-		
+
 				/* Common parameters */
-			
+
 				case 'B':
 				case 'H':
 				case 'J':
@@ -114,78 +153,80 @@ main(int argc, char **argv)
 				case 'c':
 				case ':':
 				case '\0':
-					error += GMT_get_common_args (argv[i], &west, &east, &south, &north);
+					error += GMT_parse_common_options (argv[i], &west, &east, &south, &north);
 					break;
-				
+
 				/* Supplemental parameters */
-			
+
 				case 'A':
 					/* Format can be one of two:
 					 * 3.4.x: -A[-][f<fontsize>][a<angle>][/<r/g/b>][t|o]
 					 * 4.x:   -A[-][+a<angle>][+c<dx>[/<dy>]][+f<size>][+g[<fill>]][+j<just>][+o][+p[<pen>]][+v]
 					 */
-					if (argv[i][2] == '-') use_cpt_annot = FALSE;
-					bad = GMT_contlabel_specs (&argv[i][2], &G);
-					G.annot = use_cpt_annot;
+					Ctrl->A.active = TRUE;
+					if (argv[i][2] == '-') Ctrl->A.off = TRUE;
+					bad = GMT_contlabel_specs (&argv[i][2], &Ctrl->contour);
+					Ctrl->contour.annot = !Ctrl->A.off;
 					if (bad) {
 						fprintf (stderr, "%s: GMT SYNTAX ERROR -A option.  Correct syntax:\n", GMT_program);
 						fprintf (stderr, "\t-A[-][+a<angle>][+c<dx>[/<dy>]][+f<font>][+g[<fill>]][+j<just>][+o][+p[<pen>]][+s<size>][+u<unit>][+v]\n");
 						error += bad;
 					}
 					break;
-				break;
 
 				case 'C':
-					cpt_file = &argv[i][2];
+					Ctrl->C.active = TRUE;
+					Ctrl->C.file = strdup (&argv[i][2]);
 					break;
 				case 'D':
-					dump = TRUE;
-					strcpy (dfile, &argv[i][2]);
+					Ctrl->D.active = TRUE;
+					GMT_free ((void *)Ctrl->D.file);
+					Ctrl->D.file = strdup (&argv[i][2]);
 					break;
 				case 'E':
-					sscanf (&argv[i][2], "%lf/%lf", &z_project.view_azimuth, &z_project.view_elevation);
+					Ctrl->E.active = TRUE;
+					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
 					break;
 				case 'G':
-					error += GMT_contlabel_info ('G', &argv[i][2], &G);
+					Ctrl->G.active = TRUE;
+					error += GMT_contlabel_info ('G', &argv[i][2], &Ctrl->contour);
 					break;
 				case 'I':
-					image_them = TRUE;
+					Ctrl->I.active = TRUE;
 					break;
 				case 'L':
-					if (GMT_getpen (&argv[i][2], &lpen)) {
-						GMT_pen_syntax ('L');
+					Ctrl->L.active = TRUE;
+					if (GMT_getpen (&argv[i][2], &Ctrl->L.pen)) {
+						GMT_pen_syntax ('L', " ");
 						error++;
 					}
-					else
-						draw_mesh = TRUE;
 					break;
 				case 'M':	/* with -D, create one multiple line segments */
 					GMT_multisegment (&argv[i][2]);
-					GMT_io.multi_segments = 2;
+					GMT_io.multi_segments[GMT_OUT] = 2;
 					break;
 				case 'N':
-					clip = FALSE;
+					Ctrl->N.active = TRUE;
 					break;
 				case 'S':		/* Skip points outside border */
-					skip_if_outside = TRUE;
+					Ctrl->S.active = TRUE;
 					break;
 				case 'T':
-					t_file = &argv[i][2];
-					t_set = TRUE;
+					Ctrl->T.file = strdup (&argv[i][2]);
+					Ctrl->T.active = TRUE;
 					break;
 				case 'W':
+					Ctrl->W.active = TRUE;
 					k = 2;
-					if (argv[i][k] == '+') use_cpt_colors = TRUE, k++;
-					if (argv[i][k] && GMT_getpen (&argv[i][k], &pen)) {
-						GMT_pen_syntax ('W');
+					if (argv[i][k] == '+') Ctrl->W.color = TRUE, k++;
+					if (argv[i][k] && GMT_getpen (&argv[i][k], &Ctrl->W.pen)) {
+						GMT_pen_syntax ('W', " ");
 						error++;
 					}
-					else
-						draw_contours = TRUE;
 					break;
-					
+
 				/* Options not recognized */
-						
+
 				default:
 					error = TRUE;
 					GMT_default_error (argv[i][1]);
@@ -195,19 +236,20 @@ main(int argc, char **argv)
 		else
 			fp = GMT_fopen (argv[i], GMT_io.r_mode);
 	}
-	
-	if (GMT_quick || argc == 1) {	/* Display usage */
+
+	if (GMT_give_synopsis_and_exit || argc == 1) {	/* Display usage */
 		fprintf (stderr,"pscontour %s - Contour xyz-data by triangulation\n\n", GMT_VERSION);
-		fprintf (stderr,"usage: pscontour <xyzfile> -C<cpt_file> -J<params> -R<west>/<east>/<south>/<north>\n");
-		fprintf (stderr, "\t[-A[-|<annot_int>][<labelinfo>] [-B<tickinfo>] [-D<dumpfile>] [-E<az>/<el>]\n");
-		fprintf (stderr, "\t[-G[d|f|l|n|x]<info>] [-H[<nrec>]] [-I] [-K] [-L<pen>] [-M[<flag>]] [-N] [-O]\n");
- 		fprintf (stderr, "\t[-P] [S-] [-T<indexfile>] [-U] [-V] [-W[+]<pen>] [-X<x_shift>] [-Y<y_shift>]\n");
-		fprintf (stderr, "\t[-c<ncopies>] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
-		
-		if (GMT_quick) exit (EXIT_FAILURE);
-		
+		fprintf (stderr,"usage: pscontour <xyzfile> -C<cpt_file> %s %s\n", GMT_J_OPT, GMT_Rgeoz_OPT);
+		fprintf (stderr, "\t[-A[-|<annot_int>][<labelinfo>] [%s] [-D<dumpfile>] [-E<az>/<el>]\n", GMT_B_OPT);
+		fprintf (stderr, "\t[%s] [%s] [-I] [%s] [-K] [-L<pen>] [%s] [-N] [-O]\n", GMT_CONTG, GMT_H_OPT, GMT_Jz_OPT, GMT_Mo_OPT);
+ 		fprintf (stderr, "\t[-P] [S-] [-T<indexfile>] [-U] [-V] [-W[+]<pen>] [%s] [%s]\n", GMT_X_OPT, GMT_Y_OPT);
+		fprintf (stderr, "\t[%s] [%s] [%s]\n\n", GMT_c_OPT, GMT_t_OPT, GMT_b_OPT);
+
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
+
 		fprintf (stderr,"\t-C Color palette table\n");
 		GMT_explain_option ('j');
+		GMT_explain_option ('Z');
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t-A Annotation label information.\n");
@@ -222,7 +264,7 @@ main(int argc, char **argv)
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-I Color triangles using the cpt file\n");
 		GMT_explain_option ('K');
-		fprintf (stderr, "\t-L draws the triangular mesh with the specified pen\n");
+		GMT_pen_syntax ('L', "draws the triangular mesh with the specified pen.");
 		fprintf (stderr, "\t-M Used with -D.   Create a single multiple segment file where contours are separated by a record\n");
 		fprintf (stderr, "\t   whose first character is <flag> ['>'].  This header also has the contour level value\n");
 		fprintf (stderr,"\t-N do NOT clip contours/image at the border [Default clips]\n");
@@ -233,7 +275,7 @@ main(int argc, char **argv)
 		fprintf (stderr,"\t   [Default performs the Delaunay triangulation on xyz-data]\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
-		fprintf (stderr, "\t-W selects contouring and sets contour pen attributes\n");
+		GMT_pen_syntax ('W', "selects contouring and sets contour pen attributes.");
 		fprintf (stderr, "\t   Use + to draw colored contours based on the cpt file\n");
 		GMT_explain_option ('X');
 		GMT_explain_option ('c');
@@ -248,28 +290,28 @@ main(int argc, char **argv)
 	}
 
 	/* Check that the options selected are mutually consistent */
-	
+
 	if (!project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify -R option\n", GMT_program);
 		error++;
 	}
-	if (!(draw_contours || image_them)) {
+	if (!(Ctrl->W.active || Ctrl->I.active)) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify one of -W or -I\n", GMT_program);
 		error++;
 	}
-	if (!cpt_file) {
+	if (!Ctrl->C.file) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -C option:  Must specify a color palette table\n", GMT_program);
 		error++;
 	}
-	if (t_set && !t_file) {
+	if (Ctrl->T.active && !Ctrl->T.file) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -T option:  Must specify an index file\n", GMT_program);
 		error++;
 	}
-	if (z_project.view_azimuth > 360.0 || z_project.view_elevation <= 0.0 || z_project.view_elevation > 90.0) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -E option:  Enter azimuth in 0-360 range, elevation in 0-90 range\n", GMT_program);
+	if (Ctrl->E.elevation <= 0.0 || Ctrl->E.elevation > 90.0) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -E option:  Elevation must be in 0-90 range\n", GMT_program);
 		error++;
 	}
-	if (GMT_io.binary[GMT_IN] && gmtdefs.io_header[GMT_IN]) {
+	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
@@ -278,49 +320,45 @@ main(int argc, char **argv)
                 fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least 3 columns\n", GMT_program);
 		error++;
 	}
-	
-	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
+	if (error) exit (EXIT_FAILURE);
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
-	if (GMT_io.binary[GMT_OUT] && GMT_io.multi_segments) {
+	if (GMT_io.binary[GMT_OUT] && GMT_io.multi_segments[GMT_OUT]) {
 		fprintf (stderr, "%s: GMT Warning.  -M for output ignored with -D, -bo\n", GMT_program);
 		error++;
 	}
-	if (t_set) {
-		if ((fp_d = fopen (t_file, GMT_io.r_mode)) == NULL) {
-		fprintf (stderr, "%s: Could not open index file %s\n", GMT_program, t_file);
+	z_project.view_azimuth = Ctrl->E.azimuth;
+	z_project.view_elevation = Ctrl->E.elevation;
+	if (Ctrl->T.active) {
+		if ((fp_d = GMT_fopen (Ctrl->T.file, GMT_io.r_mode)) == NULL) {
+		fprintf (stderr, "%s: Could not open index file %s\n", GMT_program, Ctrl->T.file);
 			exit (EXIT_FAILURE);
 		}
 	}
-	
-	if (dump && dfile[0] == 0) {
+
+	if (Ctrl->D.active && Ctrl->D.file[0] == 0) {
 		fprintf (stderr, "%s: contours will be written to file contour\n", GMT_program);
-		strcpy (dfile,"contour");
+		strcpy (Ctrl->D.file,"contour");
 	}
 
-	GMT_read_cpt (cpt_file);
-	if (image_them && GMT_continuous) {
+	GMT_read_cpt (Ctrl->C.file);
+	if (Ctrl->I.active && GMT_continuous) {
 		fprintf (stderr, "%s: -I option requires constant color between contours!\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-	
-	GMT_map_setup (west, east, south, north);
-	
-	ps_plotinit (CNULL, gmtdefs.overlay, gmtdefs.page_orientation, gmtdefs.x_origin, gmtdefs.y_origin,
-		gmtdefs.global_x_scale, gmtdefs.global_y_scale, gmtdefs.n_copies, gmtdefs.dpi,
-		GMT_INCH, gmtdefs.paper_width, gmtdefs.page_rgb, gmtdefs.encoding.name, GMT_epsinfo (argv[0]));
-		
-	GMT_echo_command (argc, argv);
-	if (gmtdefs.unix_time) GMT_timestamp (argc, argv);
+
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
+
+	GMT_plotinit (argc, argv);
+
 	if (project_info.three_D) ps_transrotate (-z_project.xmin, -z_project.ymin, 0.0);
-	
-        if (clip) GMT_map_clip_on (GMT_no_rgb, 3);
+
+        if (!Ctrl->N.active) GMT_map_clip_on (GMT_no_rgb, 3);
 
 	if (fp == NULL) {
 		fp = GMT_stdin;
@@ -333,14 +371,14 @@ main(int argc, char **argv)
 	x = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 	y = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 	z = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
-	
-	if (gmtdefs.io_header[GMT_IN]) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
-	
+
+	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
+
 	xyz[0][2] = DBL_MAX;	xyz[1][2] = -DBL_MAX;
 	n = 0;
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3;
 	n_fields = GMT_input (fp, &n_expected_fields, &in);
-		
+
 	while (! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
 		if (GMT_io.status & GMT_IO_MISMATCH) {
@@ -348,13 +386,13 @@ main(int argc, char **argv)
 			exit (EXIT_FAILURE);
 		}
 
-		if (skip_if_outside) {	/* Must check if points are inside plot region */
+		if (Ctrl->S.active) {	/* Must check if points are inside plot region */
 			GMT_map_outside (in[0], in[1]);
 			skip = ( abs (GMT_x_status_new) > 1 || abs (GMT_y_status_new) > 1);
 		}
-		
+
 		if (!(skip || GMT_is_dnan (in[2]))) {	/* Unless outside or z = NaN */
-		
+
 			x[n] = in[0];
 			y[n] = in[1];
 			z[n] = in[2];
@@ -369,7 +407,7 @@ main(int argc, char **argv)
 				xyz[1][2] = z[n];
 			}
 			n++;
-		
+
 			if (n == n_alloc) {
 				n_alloc += GMT_CHUNK;
 				x = (double *) GMT_memory ((void *)x, (size_t)n_alloc, sizeof (double), GMT_program);
@@ -377,32 +415,32 @@ main(int argc, char **argv)
 				z = (double *) GMT_memory ((void *)z, (size_t)n_alloc, sizeof (double), GMT_program);
 			}
 		}
-	
+
 		n_fields = GMT_input (fp, &n_expected_fields, &in);
 	}
 	if (fp != GMT_stdin) GMT_fclose (fp);
-	
+
 	x = (double *) GMT_memory ((void *)x, (size_t)n, sizeof (double), GMT_program);
 	y = (double *) GMT_memory ((void *)y, (size_t)n, sizeof (double), GMT_program);
 	z = (double *) GMT_memory ((void *)z, (size_t)n, sizeof (double), GMT_program);
-	
-	if (GMT_contlabel_prep (&G, xyz, 1)) exit (EXIT_FAILURE);	/* Prep for crossing lines, if any */
+
+	if (GMT_contlabel_prep (&Ctrl->contour, xyz)) exit (EXIT_FAILURE);	/* Prep for crossing lines, if any */
 
 	/* Map transform */
-	
+
 	for (i = 0; i < n; i++) GMT_geo_to_xy (x[i], y[i], &x[i], &y[i]);
-	
+
 	if (fp_d) {
 		n_alloc = 3 * GMT_CHUNK;
 		ind = (int *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (int), GMT_program);
 
 		ij = np = 0;
-		
+
 		if (GMT_io.binary[GMT_IN])	/* Binary input */
-			more = (fread ((void *)ind, sizeof (int), (size_t)3, fp_d) == 3);
+			more = (GMT_fread ((void *)ind, sizeof (int), (size_t)3, fp_d) == 3);
 		else		/* ascii input */
-			more = (fgets (line, BUFSIZ, fp_d) != CNULL);
-			
+			more = (GMT_fgets (line, BUFSIZ, fp_d) != CNULL);
+
 		while (more) {
 			if (!GMT_io.binary[GMT_IN] && sscanf (line, "%d %d %d", &ind[ij], &ind[ij+1], &ind[ij+2]) != 3) continue;
 			ij += 3;
@@ -412,62 +450,63 @@ main(int argc, char **argv)
 				ind = (int *) GMT_memory ((void *)ind, (size_t)n_alloc, sizeof (int), GMT_program);
 			}
 			if (GMT_io.binary[GMT_IN])	/* Binary input */
-				more = (fread ((void *)&ind[ij], sizeof (int), (size_t)3, fp_d) == 3);
+				more = (GMT_fread ((void *)&ind[ij], sizeof (int), (size_t)3, fp_d) == 3);
 			else		/* ascii input */
-				more = (fgets (line, BUFSIZ, fp_d) != CNULL);
+				more = (GMT_fgets (line, BUFSIZ, fp_d) != CNULL);
 		}
 		ind = (int *) GMT_memory ((void *)ind, (size_t)ij, sizeof (int), GMT_program);
-		fclose (fp_d);
+		GMT_fclose (fp_d);
 	}
 	else	/* Do Delaunay triangulation */
-			
-		np = GMT_delaunay (x, y, n, &ind);
-	
-	if (draw_mesh) {	/* Draw triangular mesh */
 
-		GMT_setpen (&lpen);
+		np = GMT_delaunay (x, y, n, &ind);
+
+	if (Ctrl->L.active) {	/* Draw triangular mesh */
+
+		GMT_setpen (&Ctrl->L.pen);
 
 		for (i = k = 0; i < np; i++) {	/* For all triangles */
-	
+
 			xx[0] = x[ind[k]];	yy[0] = y[ind[k++]];
 			xx[1] = x[ind[k]];	yy[1] = y[ind[k++]];
 			xx[2] = x[ind[k]];	yy[2] = y[ind[k++]];
 
+			if (project_info.three_D) for (c = 0; c < 3; c++) GMT_xy_do_z_to_xy (xx[c], yy[c], project_info.z_level, &xx[c], &yy[c]);
 			ps_line (xx, yy, 3, 3, 1, FALSE);
 		}
 	}
-		
+
 	/* Get PSCONTOUR structs */
-	
+
 	n_contours = GMT_n_colors + 1;
 	cont = (struct PSCONTOUR *) GMT_memory (VNULL, (size_t)n_contours, sizeof (struct PSCONTOUR), GMT_program);
-	
+
 	for (i = 0; i < GMT_n_colors; i++) {
 		cont[i].val = GMT_lut[i].z_low;
-		cont[i].type = (GMT_lut[i].annot && use_cpt_annot) ? 'A' : 'C';
-		cont[i].angle = (G.angle_type == 2) ? label_angle : GMT_d_NaN;
+		cont[i].type = (GMT_lut[i].annot && !Ctrl->A.off) ? 'A' : 'C';
+		cont[i].angle = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT_d_NaN;
 	}
 	cont[GMT_n_colors].val = GMT_lut[GMT_n_colors-1].z_high;
-	cont[GMT_n_colors].type = ((GMT_lut[GMT_n_colors-1].annot & 2) && use_cpt_annot) ? 'A' : 'C';
-	cont[GMT_n_colors].angle = (G.angle_type == 2) ? label_angle : GMT_d_NaN;
+	cont[GMT_n_colors].type = ((GMT_lut[GMT_n_colors-1].annot & 2) && !Ctrl->A.off) ? 'A' : 'C';
+	cont[GMT_n_colors].angle = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT_d_NaN;
 	for (i = 0; i < n_contours; i++) {
 		cont[i].n_alloc = GMT_SMALL_CHUNK;
-		cont[i].L = (struct PSLINE *) GMT_memory (VNULL, (size_t)GMT_SMALL_CHUNK, sizeof (struct PSLINE), GMT_program);
+		cont[i].L = (struct PSCONTOUR_LINE *) GMT_memory (VNULL, (size_t)GMT_SMALL_CHUNK, sizeof (struct PSCONTOUR_LINE), GMT_program);
 	}
-	
-	G.line_pen = pen;
+
+	Ctrl->contour.line_pen = Ctrl->W.pen;
 
 	for (i = ij = 0; i < np; i++, ij += 3) {	/* For all triangles */
-			
+
 		k = ij;
 		xx[0] = x[ind[k]];	yy[0] = y[ind[k]];	zz[0] = z[ind[k++]];
 		xx[1] = x[ind[k]];	yy[1] = y[ind[k]];	zz[1] = z[ind[k++]];
 		xx[2] = x[ind[k]];	yy[2] = y[ind[k]];	zz[2] = z[ind[k]];
-		
+
 		nx = get_triangle_crossings (x, y, z, &ind[ij], &xc, &yc, &zc, &vert, &cind);
-		
-		if (image_them) {	/* Must color the triangle slices according to cpt file */
-		
+
+		if (Ctrl->I.active) {	/* Must color the triangle slices according to cpt file */
+
 			if (nx == 0) {	/* No contours go through - easy, but must check for NaNs */
 				int kzz;
 				double zzz;
@@ -479,16 +518,16 @@ main(int argc, char **argv)
 				if (kzz) paint_it (xx, yy, 3, zzz / kzz);
 			}
 			else {	/* Must paint all those slices separately */
-			
+
 				/* Find vertices with the lowest and highest values */
-				
+
 				for (k = 1, low = high = 0; k < 3; k++) {
 					if (zz[k] < zz[low])   low = k;
 					if (zz[k] > zz[high]) high = k;
 				}
-				
+
 				/* Paint the piece delimited by the low node and the first contour */
-				
+
 				xout[0] = xx[low];	yout[0] = yy[low];
 				node1 = get_node_index (vert[0], vert[1]);	/* Find single vertex opposing this contour segment */
 				if (node1 == low) {	/* Contour and low node make up a triangle */
@@ -512,7 +551,7 @@ main(int argc, char **argv)
 				paint_it (xout, yout, n, 0.5 * (zz[low] + zc[1]));	/* z is contour value */
 
 				/* Then loop over contours and paint the part between contours */
-			
+
 				for (k = 1, k2 = 2, k3 = 3; k < nx; k++, k2 += 2, k3 += 2) {
 					xout[0] = xc[k2-2];	yout[0] = yc[k2-2];
 					xout[1] = xc[k3-2];	yout[1] = yc[k3-2];
@@ -549,9 +588,9 @@ main(int argc, char **argv)
 					}
 					paint_it (xout, yout, n, 0.5 * (zc[k2]+zc[k2-2]));
 				}
-			
+
 				/* Add the last piece between last contour and high node */
-				
+
 				k2 -= 2;	k3 -= 2;
 				xout[0] = xx[high];	yout[0] = yy[high];
 				node1 = get_node_index (vert[k2], vert[k3]);	/* Find corner id */
@@ -576,12 +615,8 @@ main(int argc, char **argv)
 				paint_it (xout, yout, n, 0.5 * (zz[high] + zc[k2]));	/* z is contour value */
 			}
 		}
-		
-		if (draw_contours && nx > 0) {	/* Save contour lines for later */
-		
-			if (project_info.three_D)
-				for (k = 0; k < 2*nx; k++) GMT_xy_do_z_to_xy (xc[k], yc[k], project_info.z_level, &xc[k], &yc[k]);
-				
+
+		if (Ctrl->W.active && nx > 0) {	/* Save contour lines for later */
 			for (k = k2 = 0; k < nx; k++) {
 				c = cind[k];
 				n = cont[c].nl;
@@ -592,14 +627,12 @@ main(int argc, char **argv)
 				n++;
 				if (n >= cont[c].n_alloc) {
 					cont[c].n_alloc += GMT_SMALL_CHUNK;
-					cont[c].L = (struct PSLINE *) GMT_memory ((void *)cont[c].L, (size_t)cont[c].n_alloc, sizeof (struct PSLINE), GMT_program);
+					cont[c].L = (struct PSCONTOUR_LINE *) GMT_memory ((void *)cont[c].L, (size_t)cont[c].n_alloc, sizeof (struct PSCONTOUR_LINE), GMT_program);
 				}
 				cont[c].nl = n;
 			}
-				
-			/* for (k = 0; k < nx; k++) ps_line (&xc[2*k], &yc[2*k], 2, 3, FALSE, FALSE); */
 		}
-		
+
 		if (nx > 0) {
 			GMT_free ((void *)xc);
 			GMT_free ((void *)yc);
@@ -608,28 +641,28 @@ main(int argc, char **argv)
 			GMT_free ((void *)cind);
 		}
 	}
-	
+
 	/* Draw contours */
-	
-	if (draw_contours) {
-		
-		struct CHAIN *head_c, *last_c, *this_c;
-		struct PT *p, *q;
-		
+
+	if (Ctrl->W.active) {
+
+		struct PSCONTOUR_CHAIN *head_c, *last_c, *this_c;
+		struct PSCONTOUR_PT *p = VNULL, *q;
+
 		for (c = 0; c < n_contours; c++) {
-		
+
 			if (cont[c].nl == 0) {
 				GMT_free ((void *)cont[c].L);
 				continue;
 			}
-			
-			head_c = last_c = (struct CHAIN *) GMT_memory (VNULL, (size_t)1, sizeof (struct CHAIN), GMT_program);
+
+			head_c = last_c = (struct PSCONTOUR_CHAIN *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_CHAIN), GMT_program);
 
 			while (cont[c].nl) {
-				this_c = last_c->next = (struct CHAIN *) GMT_memory (VNULL, (size_t)1, sizeof (struct CHAIN), GMT_program);
+				this_c = last_c->next = (struct PSCONTOUR_CHAIN *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_CHAIN), GMT_program);
 				k = 0;
-				this_c->begin = (struct PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PT), GMT_program);
-				this_c->end = (struct PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PT), GMT_program);
+				this_c->begin = (struct PSCONTOUR_PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_PT), GMT_program);
+				this_c->end = (struct PSCONTOUR_PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_PT), GMT_program);
 				this_c->begin->x = cont[c].L[k].x0;
 				this_c->begin->y = cont[c].L[k].y0;
 				this_c->end->x = cont[c].L[k].x1;
@@ -639,29 +672,29 @@ main(int argc, char **argv)
 				cont[c].L[k] = cont[c].L[cont[c].nl];
 				while (k < cont[c].nl) {
 					add = 0;
-					if (fabs(cont[c].L[k].x0 - this_c->begin->x) < SMALL && fabs(cont[c].L[k].y0 - this_c->begin->y) < SMALL) {
-						p = (struct PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PT), GMT_program);
+					if (fabs(cont[c].L[k].x0 - this_c->begin->x) < GMT_SMALL && fabs(cont[c].L[k].y0 - this_c->begin->y) < GMT_SMALL) {
+						p = (struct PSCONTOUR_PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_PT), GMT_program);
 						p->x = cont[c].L[k].x1;
 						p->y = cont[c].L[k].y1;
 						p->next = this_c->begin;
 						add = -1;
 					}
-					else if (fabs(cont[c].L[k].x1 - this_c->begin->x) < SMALL && fabs(cont[c].L[k].y1 - this_c->begin->y) < SMALL) {
-						p = (struct PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PT), GMT_program);
+					else if (fabs(cont[c].L[k].x1 - this_c->begin->x) < GMT_SMALL && fabs(cont[c].L[k].y1 - this_c->begin->y) < GMT_SMALL) {
+						p = (struct PSCONTOUR_PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_PT), GMT_program);
 						p->x = cont[c].L[k].x0;
 						p->y = cont[c].L[k].y0;
 						p->next = this_c->begin;
 						add = -1;
 					}
-					else if (fabs(cont[c].L[k].x0 - this_c->end->x) < SMALL && fabs(cont[c].L[k].y0 - this_c->end->y) < SMALL) {
-						p = (struct PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PT), GMT_program);
+					else if (fabs(cont[c].L[k].x0 - this_c->end->x) < GMT_SMALL && fabs(cont[c].L[k].y0 - this_c->end->y) < GMT_SMALL) {
+						p = (struct PSCONTOUR_PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_PT), GMT_program);
 						p->x = cont[c].L[k].x1;
 						p->y = cont[c].L[k].y1;
 						this_c->end->next = p;
 						add = 1;
 					}
-					else if (fabs(cont[c].L[k].x1 - this_c->end->x) < SMALL && fabs(cont[c].L[k].y1 - this_c->end->y) < SMALL) {
-						p = (struct PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PT), GMT_program);
+					else if (fabs(cont[c].L[k].x1 - this_c->end->x) < GMT_SMALL && fabs(cont[c].L[k].y1 - this_c->end->y) < GMT_SMALL) {
+						p = (struct PSCONTOUR_PT *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSCONTOUR_PT), GMT_program);
 						p->x = cont[c].L[k].x0;
 						p->y = cont[c].L[k].y0;
 						this_c->end->next = p;
@@ -682,7 +715,7 @@ main(int argc, char **argv)
 				last_c = this_c;
 			}
 			GMT_free ((void *)cont[c].L);
-			
+
 			this_c = head_c->next;
 			while (this_c) {
 				xp = (double *) GMT_memory (VNULL, (size_t)GMT_SMALL_CHUNK, sizeof (double), GMT_program);
@@ -705,48 +738,63 @@ main(int argc, char **argv)
 				last_c = this_c;
 				this_c = this_c->next;
 				GMT_free ((void *)last_c);
-				
-				close = (xp[0] == xp[n-1] && yp[0] == yp[n-1]);
 
-				if (use_cpt_colors) {
+				close = !GMT_polygon_is_open (xp, yp, n);
+
+				if (Ctrl->W.color) {
 					if (current_contour != cont[c].val) {
-						GMT_get_rgb24 (cont[c].val, rgb);
+						GMT_get_rgb_from_z (cont[c].val, rgb);
 						ps_setpaint (rgb);
-						memcpy ((void *)&G.line_pen.rgb, (void *)rgb, (size_t)(3 * sizeof (int)));
-						if (!G.got_font_rgb && G.curved_text) memcpy ((void *)&G.font_rgb, (void *)rgb, (size_t)(3 * sizeof (int)));
+						memcpy ((void *)&Ctrl->contour.line_pen.rgb, (void *)rgb, (size_t)(3 * sizeof (int)));
+						if (!Ctrl->contour.got_font_rgb && Ctrl->contour.curved_text) memcpy ((void *)&Ctrl->contour.font_rgb, (void *)rgb, (size_t)(3 * sizeof (int)));
 						current_contour = cont[c].val;
 					}
 				}
 
 				if (cont[c].type == 'A' || cont[c].type == 'a') {	/* Annotated contours */
-					GMT_get_format (cont[c].val, G.unit, CNULL, format);
+					GMT_get_format (cont[c].val, Ctrl->contour.unit, CNULL, format);
 					sprintf (cont_label, format, cont[c].val);
 				}
-				if (dump) GMT_dump_contour (xp, yp, n, cont[c].val, section++, close, dfile);
-				GMT_hold_contour (&xp, &yp, n, cont_label, cont[c].type, cont[c].angle, close, &G);
+				if (Ctrl->D.active) {
+					int count;
+					double *xtmp, *ytmp;
+					/* Must first apply inverse map transform */
+					xtmp = (double *) GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
+					ytmp = (double *) GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
+					for (count = 0; count < n; count++) GMT_xy_to_geo (&xtmp[count], &ytmp[count], xp[count], yp[count]);
+					GMT_dump_contour (xtmp, ytmp, n, cont[c].val, section++, close, Ctrl->D.file);
+					GMT_free ((void *)xtmp);
+					GMT_free ((void *)ytmp);
+				}
+
+				GMT_hold_contour (&xp, &yp, n, cont[c].val, cont_label, cont[c].type, cont[c].angle, close, &Ctrl->contour);
 
 				GMT_free ((void *)xp);
 				GMT_free ((void *)yp);
 			}
-					
+
 		}
-		GMT_contlabel_plot (&G);
+		GMT_contlabel_plot (&Ctrl->contour);
 	}
-							
-        if (clip) GMT_map_clip_off ();
+
+        if (!Ctrl->N.active) GMT_map_clip_off ();
 
 	GMT_map_basemap ();
-	
+
 	if (project_info.three_D) ps_rotatetrans (z_project.xmin, z_project.ymin, 0.0);
 
-	ps_plotend (gmtdefs.last_page);
-	
+	GMT_plotend ();
+
 	GMT_free ((void *)x);
 	GMT_free ((void *)y);
 	GMT_free ((void *)z);
 	GMT_free ((void *)ind);
-	
+
+	Free_Pscontour_Ctrl (Ctrl);	/* Deallocate control structure */
+
 	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
 }
 
 
@@ -758,7 +806,7 @@ int get_triangle_crossings (double *x, double *y, double *z, int *ind, double **
 	 
 	int i, j, k, k2, i1, nx, n_alloc, *vout, *cind;
 	double xx[3], yy[3], zz[3], zmin, zmax, dz, frac, *xout, *yout, *zout;
-	
+
 	xx[0] = x[ind[0]];	yy[0] = y[ind[0]];	zz[0] = z[ind[0]];
 	xx[1] = x[ind[1]];	yy[1] = y[ind[1]];	zz[1] = z[ind[1]];
 	xx[2] = x[ind[2]];	yy[2] = y[ind[2]];	zz[2] = z[ind[2]];
@@ -767,15 +815,15 @@ int get_triangle_crossings (double *x, double *y, double *z, int *ind, double **
 
 	zmin = MIN (zz[0], MIN (zz[1], zz[2]));	/* Min z vertex */
 	zmax = MAX (zz[0], MAX (zz[1], zz[2]));	/* Max z vertex */
-	
+
 	i = 0;	j = GMT_n_colors - 1;
 	while (GMT_lut[i].z_low <= zmin && i < GMT_n_colors) i++;
 	while (GMT_lut[j].z_high >= zmax && j > 0) j--;
-	
+
 	nx = j - i + 2;	/* Total number of contours */
-	
+
 	if (nx <= 0) return (0);
-	
+
 	n_alloc = 2 * nx;
 	xout = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 	yout = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
@@ -784,7 +832,7 @@ int get_triangle_crossings (double *x, double *y, double *z, int *ind, double **
 	cind = (int *) GMT_memory (VNULL, (size_t)nx, sizeof (int), GMT_program);
 
 	/* Fill out array zout which holds the nx contour levels */
-	
+
 	k = k2 = 0;
 	while (i <= j) {
 		zout[k2] = zout[k2+1] = GMT_lut[i].z_low;
@@ -796,7 +844,7 @@ int get_triangle_crossings (double *x, double *y, double *z, int *ind, double **
 	cind[k] = j + 1;
 
 	/* Loop over the contour levels and determine the line segments */
-	
+
 	for (k = k2 = j = 0; k < nx; k++, k2 += 2) {
 		for (i = 0; i < 3; i++) {	/* Try each side in turn 0-1, 1-2, 2-0 */
 			i1 = (i == 2) ? 0 : i + 1;
@@ -815,27 +863,27 @@ int get_triangle_crossings (double *x, double *y, double *z, int *ind, double **
 		}
 		if (j%2) j--;	/* Contour went through a single vertex only, skip this */
 	}
-	
+
 	*xc = xout;
 	*yc = yout;
 	*zc = zout;
 	*v = vout;
 	*cindex = cind;
-	
+
 	return (j/2);
 }
 
 void paint_it (double x[], double y[], int n, double z) {
 	int index, k, rgb[3];
 	struct GMT_FILL *f;
-	
+
 	if (n < 3) return;	/* Need at least 3 points to make a polygon */
-	
-	index = GMT_get_rgb24 (z, rgb);
+
+	index = GMT_get_rgb_from_z (z, rgb);
 	if (GMT_cpt_skip) return;	/* Skip this z-slice */
-	
+
 	/* Now we must paint, with colors or patterns */
-	
+
 	if (project_info.three_D)
 		for (k = 0; k < n; k++) GMT_xy_do_z_to_xy (x[k], y[k], project_info.z_level, &x[k], &y[k]);
 	if ((index >= 0 && (f = GMT_lut[index].fill)) || (index < 0 && (f = GMT_bfn[index+3].fill))) {
@@ -844,3 +892,23 @@ void paint_it (double x[], double y[], int n, double z) {
 	else
 		ps_patch (x, y, n, rgb, FALSE);	/* Contours drawn separately later if desired */
 }
+
+void *New_Pscontour_Ctrl () {	/* Allocate and initialize a new control structure */
+	struct PSCONTOUR_CTRL *C;
+	
+	C = (struct PSCONTOUR_CTRL *) GMT_memory (VNULL, 1, sizeof (struct PSCONTOUR_CTRL), "New_Pscontour_Ctrl");
+	
+	/* Initialize values whose defaults are not 0/FALSE/NULL */
+	GMT_contlabel_init (&C->contour, 1);
+	C->D.file = strdup ("contour");
+	C->E.azimuth = 180.0;
+	C->E.elevation = 90.0;
+	GMT_init_pen (&C->L.pen, GMT_PENWIDTH);
+	GMT_init_pen (&C->W.pen, GMT_PENWIDTH);
+		
+	return ((void *)C);
+}
+
+void Free_Pscontour_Ctrl (struct PSCONTOUR_CTRL *C) {	/* Deallocate control structure */
+	GMT_free ((void *)C);	
+}
