@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pshistogram.c,v 1.45 2006/10/11 02:25:13 remko Exp $
+ *	$Id: pshistogram.c,v 1.52 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -321,8 +321,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -487,10 +485,10 @@ int main (int argc, char **argv)
 		strcpy (buffer, frame_info.axis[0].label);
 		strcpy(frame_info.axis[0].label, frame_info.axis[1].label);
 		strcpy (frame_info.axis[1].label, buffer);
-		GMT_map_setup (F.south, F.north, F.west, F.east);
+		GMT_err_fail (GMT_map_setup (F.south, F.north, F.west, F.east), "");
 	}
 	else
-		GMT_map_setup (F.west, F.east, F.south, F.north);
+		GMT_err_fail (GMT_map_setup (F.west, F.east, F.south, F.north), "");
 
 	GMT_plotinit (argc, argv);
 
