@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pslib_inc.h,v 1.25 2004/09/03 20:26:45 pwessel Exp $
+ *	$Id: pslib_inc.h,v 1.36 2007/01/30 20:37:09 pwessel Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -78,12 +78,9 @@
  *--------------------------------------------------------------------*/
 
 #define PSL_Version "4.1"
-#ifndef R2D
-#define R2D (180.0/M_PI)
-#endif
-#define SMALL 1.0e-10
-#define MAX_L1_PATH 1000 /* Max path length in Level 1 implementations */
-#define I_255 (1.0 / 255.0)
+#define PSL_SMALL 1.0e-10
+#define PSL_MAX_L1_PATH 1000 /* Max path length in Level 1 implementations */
+#define PSL_INV_255 (1.0 / 255.0)
 #ifndef TRUE
 #define TRUE 1
 #endif
@@ -93,11 +90,17 @@
 #ifndef M_PI
 #define M_PI            3.14159265358979323846
 #endif
+#ifndef R2D
+#define R2D (180.0/M_PI)
+#endif
+#ifndef D2R
+#define D2R (M_PI/180.0)
+#endif
 #ifndef M_SQRT2
 #define M_SQRT2         1.41421356237309504880
 #endif
 #define VNULL		((void *)NULL)
-#define PAGE_HEIGHT_IN_PTS 842
+#define PSL_PAGE_HEIGHT_IN_PTS 842
 #ifndef CNULL
 #define CNULL (char *)NULL
 #endif
@@ -114,11 +117,13 @@
 #ifndef irint
 #define irint(x) ((int)rint(x))
 #endif
-#define YIQ(rgb) irint (0.299 * (rgb[0]) + 0.587 * (rgb[1]) + 0.114 * (rgb[2]))	/* How B/W TV's convert RGB to Gray */
-#define iscolor(rgb) (rgb[0] != rgb[1] || rgb[1] != rgb[2])
+#define PSL_YIQ(rgb) irint (0.299 * (rgb[0]) + 0.587 * (rgb[1]) + 0.114 * (rgb[2]))	/* How B/W TV's convert RGB to Gray */
+#define PSL_iscolor(rgb) (rgb[0] != rgb[1] || rgb[1] != rgb[2])
+#define PSL_RGB		0
+#define PSL_CMYK	1
+#define PSL_HSV		2
 
-int N_PS_FONTS;		/* Total no of fonts;  To add more, modify the file CUSTOM_font_info.d */
-int N_GMT_FONTS;	/* Total no of standard GMT fonts. */
+int PSL_N_FONTS;	/* Total no of fonts;  To add more, modify the file CUSTOM_font_info.d */
 
 typedef int BOOLEAN;		/* BOOLEAN used for logical variables */
 
@@ -126,13 +131,13 @@ typedef int BOOLEAN;		/* BOOLEAN used for logical variables */
  *			PSL PARAMETERS DEFINITIONS
  *--------------------------------------------------------------------*/
 
-struct PS_FONT {
+struct PSL_FONT {
 	char *name;		/* Name of this font */
-	double height;		/* Height of A for unit fontsize */ 
+	double height;		/* Height of A for unit fontsize */
 	BOOLEAN encoded;	/* TRUE if we never should reencode this font (e.g. symbols) */
 				/* This is also changed to TRUE after we do reencode a font */
 };
-	
+
 /* Global structure used internally by pslib */
 
 struct {
@@ -141,12 +146,15 @@ struct {
 	int font_no;		/* Current font number				*/
 	int linewidth;		/* Current pen thickness			*/
 	int rgb[3];		/* Current paint				*/
-	BOOLEAN landscape;	/* TRUE = Landscape, FALSE = Portrait			*/
+	int offset;		/* Current setdash offset			*/
+	char pattern[512];	/* Current setdash pattern			*/
+	BOOLEAN landscape;	/* TRUE = Landscape, FALSE = Portrait		*/
 	int ix, iy;		/* Absolute coordinates of last point		*/
 	int npath;		/* Length of current unstroked path		*/
 	int split;		/* 1 if last ps_line had to split path		*/
 	char bw_format[8];	/* Format used for grayshade value		*/
 	char rgb_format[64];	/* Same, for RGB color triplets			*/
+	char hsv_format[64];	/* Same, for HSV color triplets	(HSB in PS)	*/
 	char cmyk_format[64];	/* Same, for CMYK color quadruples		*/
 	double xscl, yscl;	/* Global scale values [1.0]			*/
 	double xoff, yoff;	/* Origin offset [1/1]				*/
@@ -157,17 +165,24 @@ struct {
 	int v1_path_length_limit;	/* Implementation limit on path lengths	in Level 1 PostScript	*/
 	int max_path_length;	/* Maximum path length encountered during execution	*/
 	int clip_path_length;	/* Current length of clip path			*/
-	int hex_image;		/* TRUE writes images in hex, FALSE uses binary	*/
-	int cmyk_mode;		/* TRUE writes all color calls in cmyk, FALSE uses rgb	*/
+	int hex_image;		/* TRUE writes images in ascii, FALSE uses binary	*/
+	int compress;		/* Compresses images with (1) RLE or (2) LZW or (0) None */
+	int color_mode;		/* 0 = rgb, 1 = cmyk, 2 = hsv (only 1-2 for images)	*/
 	int absolute;		/* TRUE will reset origin, FALSE means relative position	*/
 	int eps_format;		/* TRUE makes EPS file, FALSE means PS file	*/
-	char *encoding;		/* The encoding name. e.g. ISO-8859-1 */
-	struct PS_FONT *font;	/* Pointer to array of font structures 		*/
+	int line_cap;		/* 0, 1, or 2 for butt, round, or square [butt] */
+	int line_join;		/* 0, 1, or 2 for miter, arc, or bevel [miter] */
+	int miter_limit;	/* Acute angle threshold 0-180; 0 means PS default [0] */
+	BOOLEAN verbose;	/* TRUE for verbose output, FALSE remains quiet	*/
+	BOOLEAN comments;	/* TRUE for writing comments to the PS output, FALSE strips all comments */
+	char *encoding;		/* The encoding name. e.g. ISO-8859-1		*/
+	struct PSL_FONT *font;	/* Pointer to array of font structures 		*/
 } ps;
 
-char *PSHOME = (char *)NULL;	/* Pointer to path of directory with lib subdirectory */
+char *PSL_SHAREDIR = CNULL;	/* Pointer to path of directory with pslib subdirectory */
+char *PSL_USERDIR = CNULL;	/* Pointer to path of directory with user definitions (~/.gmt) */
 
-char *ps_scandcodes[13][4] = {	/* Short-hand converrsion for Norwegian characters in both Standard [0], Standard+ [1], ISOLatin1 [2], and ISOLatin1+ [2] encoding */
+char *psl_scandcodes[13][4] = {	/* Short-hand converrsion for Norwegian characters in both Standard [0], Standard+ [1], ISOLatin1 [2], and ISOLatin1+ [2] encoding */
 	{ "AA", "\\375", "\\305", "\\305"},	/* Aring */
 	{ "AE", "\\341", "\\306", "\\306"},	/* AE */
 	{ "OE", "\\351", "\\330", "\\330"},	/* Oslash */
@@ -184,22 +199,19 @@ char *ps_scandcodes[13][4] = {	/* Short-hand converrsion for Norwegian character
 };
 
 	/* Pattern information */
-	
-#define N_PATTERNS 91	/* Current number of predefined patterns + 1, # 91 is user-supplied */
 
-char ps_pattern_status[N_PATTERNS][2];
-int ps_pattern_nx[N_PATTERNS][2];
-int ps_pattern_ny[N_PATTERNS][2];
+#define PSL_N_PATTERNS 91	/* Current number of predefined patterns + 1, # 91 is user-supplied */
 
-int ps_n_userimages;
-struct USERIMAGE {
-	char *name;
-	int nx, ny;
-} ps_user_image[N_PATTERNS];
+struct PSL_PATTERN {
+	int status, nx, ny, depth, dpi, f_rgb[3], b_rgb[3];
+} psl_pattern[PSL_N_PATTERNS*2];
 
-int no_rgb[3] = {-1, -1, -1};
+int psl_n_userimages;
+char *psl_user_image[PSL_N_PATTERNS];
 
-int ps_outline_offset[4] = {0, 2, 5, 3};
-char ps_paint_code[4] = {'A', 'C', 'K', ' '};
+int psl_no_rgb[3] = {-1, -1, -1};
+
+int psl_outline_offset[5] = {0, 2, 5, 3, 7};
+char psl_paint_code[5] = {'A', 'C', 'K', ' ', 'H'};
 
 #endif	/* _PSLIB_INC_H */
