@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psmask.c,v 1.43 2006/04/13 06:20:35 pwessel Exp $
+ *	$Id: psmask.c,v 1.53 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -165,7 +165,7 @@ int main (int argc, char **argv)
 				case 'G':
 					Ctrl->G.active = TRUE;
 					if (GMT_getfill (&argv[i][2], &Ctrl->G.fill)) {
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					break;
@@ -202,7 +202,7 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr,"psmask %s - Clipping of 2-D data sets\n\n", GMT_VERSION);
+		fprintf (stderr,"psmask %s - Masking or clipping of 2-D data sets\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: psmask <xyz-file> %s %s %s\n", GMT_I_OPT, GMT_J_OPT, GMT_Rgeo_OPT);
 		fprintf (stderr, "\t[%s] [-C] -D[-]<file> [-Eaz/el] [-F] [-G<fill>] [%s] [-K] [%s]\n", GMT_B_OPT, GMT_H_OPT, GMT_Mo_OPT);
 		fprintf (stderr, "\t[-N] [-O] [-P] [-S<radius>[k]] [-T] [%s] [-V] [%s]\n", GMT_U_OPT, GMT_X_OPT);
@@ -222,7 +222,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   use the rest of the name for a single multi-segment file.\n");
 		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
 		fprintf (stderr, "\t-F Force pixel registration [Default is gridline registration]\n");
-		fprintf (stderr, "\t-G sets fill color or pattern [Default is no fill]\n");
+		GMT_fill_syntax ('G', "Select fill color/pattern [Default is no fill].");
 		GMT_explain_option ('H');
 		GMT_explain_option ('K');
 		GMT_explain_option ('M');
@@ -273,8 +273,8 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: GMT SYNTAX ERROR -I option:  Must specify positive increments\n", GMT_program);
 			error++;
 		}
-		if (Ctrl->S.active && Ctrl->S.radius <= 0.0) {
-			fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Radius must be positive\n", GMT_program);
+		if (Ctrl->S.active && (Ctrl->S.radius <= 0.0 || GMT_is_dnan (Ctrl->S.radius))) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR.  Radius is NaN or negative\n", GMT_program);
 			error++;
 		}
 		if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = 2;
@@ -298,8 +298,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -308,7 +306,7 @@ int main (int argc, char **argv)
 	if (Ctrl->S.unit == 'K') distance_flag = 2;
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
-	if (!Ctrl->C.active) GMT_map_setup (h.x_min, h.x_max, h.y_min, h.y_max);
+	if (!Ctrl->C.active) GMT_err_fail (GMT_map_setup (h.x_min, h.x_max, h.y_min, h.y_max), "");
 
 	if (!project_info.x_off_supplied && GMT_ps.overlay) GMT_ps.x_origin = 0.0;
 	if (!project_info.y_off_supplied && GMT_ps.overlay) GMT_ps.y_origin = 0.0;
@@ -598,7 +596,7 @@ int clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *h, do
 	 * trace_clip_contours will try to allocate more memory in blocks of GMT_CHUNK points
 	 */
 	 
-	static int i0, j0;
+	static int i0, j0, side;
 	int i, j, ij, n = 0, n_edges, edge_word, edge_bit;
 	BOOLEAN go_on = TRUE;
 	int trace_clip_contours (struct PSMASK_INFO *info, char *grd, int *edge, struct GRD_HEADER *h, double xinc2, double yinc2, double **xx, double **yy, int i, int j, int kk, int *max);
@@ -611,6 +609,7 @@ int clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *h, do
 		info->offset = n_edges / 2;
 	 	i0 = 0;	/* Begin with upper left bin which is i = 0 and j = 1 */
 	 	j0 = 1;
+		side = 4;	/* Vertical interior gridlines */
 		info->p[0] = info->p[4] = 0;	info->p[1] = 1;	info->p[2] = 1 - h->nx;	info->p[3] = -h->nx;
 		info->i_off[0] = info->i_off[2] = info->i_off[3] = info->i_off[4] = 0;	info->i_off[1] =  1;
 		info->j_off[0] = info->j_off[1] = info->j_off[3] = info->j_off[4] = 0;	info->j_off[2] = -1;
@@ -620,23 +619,49 @@ int clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *h, do
 
 	/* Loop over interior boxes */
 
-	for (j = j0; go_on && j < h->ny; j++) {
-		ij = i0 + j * h->nx;
-		for (i = i0; go_on && i < h->nx-1; i++, ij++) {	/* nx-1 since the last bin starts at nx-2 and ends at nx-1 */
-			edge_word = ij / 32 + info->offset;
-			edge_bit = ij % 32;
-			if (!(edge[edge_word] & info->bit[edge_bit]) && ((grd[ij]+grd[ij-h->nx]) == 1)) { /* Start tracing contour */
-				*x[0] = GMT_i_to_x (i, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);
-				*y[0] = GMT_j_to_y (j, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);
-				edge[edge_word] |= info->bit[edge_bit];
-				n = trace_clip_contours (info, grd, edge, h, xinc2, yinc2, x, y, i, j, 3, max);
-				go_on = FALSE;
-				i0 = i + 1;
-				j0 = j;	/* Return to finish this row later */
+	if (side == 4) {
+		for (j = j0; go_on && j < h->ny; j++) {
+			ij = i0 + j * h->nx;
+			for (i = i0; go_on && i < h->nx-1; i++, ij++) {	/* nx-1 since the last bin starts at nx-2 and ends at nx-1 */
+				edge_word = ij / 32 + info->offset;
+				edge_bit = ij % 32;
+				if (!(edge[edge_word] & info->bit[edge_bit]) && ((grd[ij]+grd[ij-h->nx]) == 1)) { /* Start tracing contour */
+					*x[0] = GMT_i_to_x (i, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);
+					*y[0] = GMT_j_to_y (j, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);
+					edge[edge_word] |= info->bit[edge_bit];
+					n = trace_clip_contours (info, grd, edge, h, xinc2, yinc2, x, y, i, j, 3, max);
+					go_on = FALSE;
+					i0 = i + 1;
+					j0 = j;	/* Return to finish this row later */
+				}
+			}
+			if (go_on) i0 = 0;	/* Go to start of next row unless we found something */
+		}
+		if (n == 0) {
+			side = 5;
+			i0 = 0;
+			j0 = 1;
+		}
+	}
+	if (n == 0 && side == 5) {
+		for (j = j0; go_on && j < h->ny; j++) {
+			ij = i0 + j * h->nx;
+			for (i = i0; go_on && i < h->nx-1; i++, ij++) {
+				edge_word = ij / 32 + info->offset;
+				edge_bit = ij % 32;
+				if (!(edge[edge_word] & info->bit[edge_bit]) && ((grd[ij]+grd[ij+1]) == 1)) { /* Start tracing contour */
+					*x[0] = GMT_i_to_x (i, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);
+					*y[0] = GMT_j_to_y (j, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);
+					edge[edge_word] |= info->bit[edge_bit];
+					n = trace_clip_contours (info, grd, edge, h, xinc2, yinc2, x, y, i, j, 2, max);
+					go_on = FALSE;
+					i0 = i + 1;
+					j0 = j;	/* Return to finish this row later */
+				}
+				if (go_on) i0 = 1;
 			}
 		}
-		if (go_on) i0 = 0;	/* Go to start of next row unless we found something */
-	}
+	}	
 
 	return (n);
 }
