@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psrose.c,v 1.44 2006/10/11 02:25:13 remko Exp $
+ *	$Id: psrose.c,v 1.54 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -45,6 +45,9 @@ struct PSROSE_CTRL {	/* All control options for this program (except common args
 		BOOLEAN active;
 		char *file;
 	} C;
+	struct D {	/* -D */
+		BOOLEAN active;
+	} D;
 	struct E {	/* -Eazimuth/elevation */
 		BOOLEAN active;
 		double azimuth, elevation;
@@ -93,10 +96,10 @@ int main (int argc, char **argv)
 	int i, n_bins, bin, n_annot, n = 0, n_alloc = GMT_CHUNK;
 	int status, n_alpha, n_modes, n_fields, n_expected_fields;
 
-	double max = 0.0, radius, az, x_origin, y_origin, tmp, one_or_two = 1.0, s, c;
+	double max = 0.0, radius, az, x_origin, y_origin, tmp, one_or_two = 1.0, s, c, half_bin_width;
 	double angle1, angle2, angle, x, y, mean_theta, mean_radius, xr = 0.0, yr = 0.0;
 	double x1, x2, y1, y2, total = 0.0, total_arc, off, max_radius, az_offset, *in;
-	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, asize, lsize;
+	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, asize, lsize, this_az;
 	double *xx, *yy, *sum, *azimuth, *length, *mode_direction, *mode_length;
 
 	FILE *fp = NULL, *fpm = NULL;
@@ -157,6 +160,9 @@ int main (int argc, char **argv)
 					Ctrl->C.active = TRUE;
 					if (argv[i][2]) Ctrl->C.file = strdup (&argv[i][2]);
 					break;
+				case 'D':		/* Center the bins */
+					Ctrl->D.active = TRUE;
+					break;
 				case 'E':
 					Ctrl->E.active = TRUE;
 					sscanf (&argv[i][2], "%lf/%lf", &Ctrl->E.azimuth, &Ctrl->E.elevation);
@@ -226,7 +232,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"psrose %s - Polar histogram (rose diagram) plotter\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: psrose <infile> [-A<sector_angle>[r]] [%s]\n", GMT_B_OPT);
-		fprintf (stderr, "\t[-C[<modes>]] [-E<azim>/<elev>] [-G<fill>] [%s] [-I] [-K] [-M<parameters>]\n", GMT_H_OPT);
+		fprintf (stderr, "\t[-C[<modes>]] [-D] [-E<azim>/<elev>] [-G<fill>] [%s] [-I] [-K] [-M<parameters>]\n", GMT_H_OPT);
 		fprintf (stderr, "\t[-N] [-O] [-P] [-R<r0/r1/theta0/theta1>] [-S<scale>[n]] [-T] [%s] [-V] [%s]\n", GMT_U_OPT, GMT_t_OPT);
 		fprintf (stderr, "\t[-W<pen>] [%s] [%s] [-Z<scale>] [%s] [%s]\n\n", GMT_X_OPT, GMT_Y_OPT, GMT_c_OPT, GMT_bi_OPT);
 
@@ -239,6 +245,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('B');
 		fprintf (stderr, "\t   (Remember: radial is x-direction, azimuthal is y-direction)\n");
 		fprintf (stderr, "\t-C plot vectors listed in the <modes> file.  If no file, use mean direction\n");
+		fprintf (stderr, "\t-D will center the sectors\n");
 		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
 		GMT_fill_syntax ('G', "Specifies color for diagram [Default is no fill]");
 		GMT_explain_option ('H');
@@ -251,7 +258,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('P');
 		fprintf (stderr, "\t-R specifies the region.  (r0 = 0, r1 = max_radius.  For azimuth:\n");
 		fprintf (stderr, "\t   Specify theta0/theta1 = -90/90 (half-circle) or 0/360 only)\n");
-		fprintf (stderr, "\t   If r0 = r1 = 0, psrose will compute reasonable a r1 value.\n");
+		fprintf (stderr, "\t   If r0 = r1 = 0, psrose will compute a reasonable r1 value.\n");
 		fprintf (stderr, "\t-S specifies the radius of the unit circle in %s [%g]. Normalize r if n is appended\n", GMT_unit_names[gmtdefs.measure_unit], Ctrl->S.scale);
 		fprintf (stderr, "\t-T indicates that the vectors are oriented (two-headed), not directed [Default]\n");
 		GMT_explain_option ('U');
@@ -302,8 +309,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -311,7 +316,15 @@ int main (int argc, char **argv)
 
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
-	if (Ctrl->C.file && (fpm = fopen (Ctrl->C.file, "r")) == NULL) find_mean = TRUE;
+	if (Ctrl->C.active) {	/* Either calculate or read mean vector to plot */
+		if (!Ctrl->C.file)	/* Not given, calculate mean direction */
+			find_mean = TRUE;
+		else if ((fpm = GMT_fopen (Ctrl->C.file, "r")) == NULL) {	/* oops */
+			fprintf (stderr, "%s: GMT SYNTAX ERROR -C.  Cannot open file %s\n", GMT_program, Ctrl->C.file);
+			exit (EXIT_FAILURE);
+		}
+	}
+		
 	if (file && (fp = GMT_fopen (file, GMT_io.r_mode)) == NULL) {
 		fprintf (stderr, "%s:  Cannot open file %s\n", GMT_program, file);
 		exit (EXIT_FAILURE);
@@ -332,7 +345,7 @@ int main (int argc, char **argv)
 	if (!Ctrl->S.normalize) Ctrl->N.active = FALSE;	/* Only do this is data is normalized for length also */
 	if (!Ctrl->I.active && !project_info.region_supplied) automatic = TRUE;
 	if (Ctrl->T.active) one_or_two = 2.0;
-
+	half_bin_width = Ctrl->D.active * Ctrl->A.inc * 0.5;
 	if (half_only) {
 		total_arc = 180.0;
 		az_offset = 90.0;
@@ -382,7 +395,7 @@ int main (int argc, char **argv)
 
 		/* Double angle to find mean azimuth */
 
-		sincos (one_or_two * azimuth[n] * D2R, &s, &c);
+		sincosd (one_or_two * azimuth[n], &s, &c);
 		xr += length[n] * c;
 		yr += length[n] * s;
 
@@ -400,7 +413,14 @@ int main (int argc, char **argv)
 
 	if (Ctrl->A.inc > 0.0) {	/* Sum up sector diagram info */
 		for (i = 0; i < n; i++) {
-			bin = (int) ((azimuth[i] + az_offset) / Ctrl->A.inc);
+			if (Ctrl->D.active) {	/* Center bin by removing half bin width here */
+				this_az = azimuth[i] - half_bin_width;
+				if (!half_only && this_az < 0.0)   this_az += 360.0;
+				if (half_only  && this_az < -90.0) this_az += 180.0;
+			}
+			else
+				this_az = azimuth[i];
+			bin = (int) ((this_az + az_offset) / Ctrl->A.inc);
 			sum[bin] += length[i];
 		}
 	}
@@ -459,7 +479,7 @@ int main (int argc, char **argv)
 	project_info.projection = GMT_LINEAR;
 	project_info.region = TRUE;
 	project_info.pars[0] = project_info.pars[1] = (Ctrl->S.normalize) ? 1.0 : Ctrl->S.scale / max_radius;
-	GMT_map_setup (-Ctrl->S.scale, Ctrl->S.scale, -Ctrl->S.scale, Ctrl->S.scale);
+	GMT_err_fail (GMT_map_setup (-Ctrl->S.scale, Ctrl->S.scale, -Ctrl->S.scale, Ctrl->S.scale), "");
 
 	GMT_plotinit (argc, argv);
 
@@ -471,19 +491,19 @@ int main (int argc, char **argv)
 	GMT_setpen (&Ctrl->W.pen);
 	if (windrose) {
 		for (i = 0; i < n; i++) {
-			angle = (90.0 - azimuth[i]) * D2R;
+			sincosd (90.0 - azimuth[i], &s, &c);
 			radius = length[i] * Ctrl->S.scale;
-			x = radius * cos (angle);
-			y = radius * sin (angle);
+			x = radius * c;
+			y = radius * s;
 			plot3d (0.0, 0.0, 3);
 			plot3d (x, y, -2);
 		}
 	}
 
-	if (sector_plot && !Ctrl->A.rose) {	/* Draw pie slices for sector plot */
+	if (sector_plot && !Ctrl->A.rose && Ctrl->G.fill.rgb[0] >= 0) {	/* Draw pie slices for sector plot if fill is requested */
 
 		for (bin = 0; bin < n_bins; bin++) {
-			az = bin * Ctrl->A.inc - az_offset;
+			az = bin * Ctrl->A.inc - az_offset + half_bin_width;
 			angle1 = (90.0 - az - Ctrl->A.inc);
 			angle2 = angle1 + Ctrl->A.inc;
 			pie3d (0.0, 0.0, sum[bin] * Ctrl->S.scale, angle1, angle2, Ctrl->G.fill.rgb, FALSE);
@@ -492,10 +512,10 @@ int main (int argc, char **argv)
 	else if (Ctrl->A.rose) {	/* Draw rose diagram */
 
 		for (bin = i = 0; bin < n_bins; bin++, i++) {
-			az = bin * Ctrl->A.inc - az_offset + 0.5 * Ctrl->A.inc;
-			angle = 90.0 - az;
-			xx[i] = Ctrl->S.scale * sum[bin] * cos (D2R * angle);
-			yy[i] = Ctrl->S.scale * sum[bin] * sin (D2R * angle);
+			az = (bin + 0.5) * Ctrl->A.inc - az_offset - half_bin_width;
+			sincosd (90.0 - az, &s, &c);
+			xx[i] = Ctrl->S.scale * sum[bin] * c;
+			yy[i] = Ctrl->S.scale * sum[bin] * s;
 		}
 		if (half_only) {
 			xx[i] = Ctrl->S.scale * 0.5 * (sum[0] + sum[n_bins-1]);
@@ -510,25 +530,22 @@ int main (int argc, char **argv)
 	}
 
 	if (sector_plot && Ctrl->W.active && !Ctrl->A.rose) {	/* Draw a line outlining the pie slices */
-		angle1 = (half_only) ? 180.0 : 90.0;
-		angle2 = (half_only) ? 0.0 : 90.0;
-		angle1 *= D2R;
-		angle2 *= D2R;
-		sincos (angle1, &s, &c);
+		angle1 = ((half_only) ? 180.0 : 90.0) - half_bin_width;
+		angle2 = ((half_only) ?   0.0 : 90.0) - half_bin_width;
+		sincosd (angle1, &s, &c);
 		x1 = (sum[0] * Ctrl->S.scale) * c;
 		y1 = (sum[0] * Ctrl->S.scale) * s;
-		sincos (angle2, &s, &c);
+		sincosd (angle2, &s, &c);
 		x2 = (sum[n_bins-1] * Ctrl->S.scale) * c;
 		y2 = (sum[n_bins-1] * Ctrl->S.scale) * s;
 		plot3d (x1, y1, 3);
 		plot3d (x2, y2, 2);
 		for (bin = n_bins-1; bin >= 0; bin--) {
 			status = (bin == 0) ? 2 : 0;
-			az = bin * Ctrl->A.inc - az_offset;
+			az = bin * Ctrl->A.inc - az_offset + half_bin_width;
 			angle1 = 90.0 - az - Ctrl->A.inc;
 			angle2 = angle1 + Ctrl->A.inc;
 			arc3d (0.0, 0.0, sum[bin] * Ctrl->S.scale, angle1, angle2, status);
-			angle1 *= D2R;
 		}
 	}
 
@@ -542,7 +559,7 @@ int main (int argc, char **argv)
 		else {	/* Get mode parameters from separate file */
 			n_modes = 0;
 			n_alloc = 1;
-			while (fgets (text, BUFSIZ, fpm)) {
+			while (GMT_fgets (text, BUFSIZ, fpm)) {
 				sscanf (text, "%lf %lf", &mode_direction[n_modes], &mode_length[n_modes]);
 				n_modes++;
 				if (n_modes == n_alloc) {
@@ -551,15 +568,15 @@ int main (int argc, char **argv)
 					mode_length = (double *) GMT_memory ((void *)mode_length, (size_t)n_alloc, sizeof (double), "psrose");
 				}
 			}
-			fclose (fpm);
+			GMT_fclose (fpm);
 			mode_direction = (double *) GMT_memory ((void *)mode_direction, (size_t)n_modes, sizeof (double), "psrose");
 			mode_length = (double *) GMT_memory ((void *)mode_length, (size_t)n_modes, sizeof (double), "psrose");
 		}
 		for (i = 0; i < n_modes; i++) {
 			if (Ctrl->N.active) mode_length[i] = sqrt (mode_length[i]);
 			if (half_only && mode_direction[i] > 90.0 && mode_direction[i] <= 270.0) mode_direction[i] -= 180.0;
-			angle = D2R * (90.0 - mode_direction[i]);
-			sincos (angle, &s, &c);
+			angle = 90.0 - mode_direction[i];
+			sincosd (angle, &s, &c);
 			xr = Ctrl->S.scale * mode_length[i] * c;
 			yr = Ctrl->S.scale * mode_length[i] * s;
 			GMT_vector3D (0.0, 0.0, xr, yr, project_info.z_level, Ctrl->M.thickness, Ctrl->M.length, Ctrl->M.width, gmtdefs.vector_shape, Ctrl->M.rgb, TRUE);
@@ -572,8 +589,8 @@ int main (int argc, char **argv)
 		off = max_radius * Ctrl->S.scale;
 		n_alpha = (frame_info.axis[1].item[GMT_GRID_UPPER].interval > 0.0) ? irint (total_arc / frame_info.axis[1].item[GMT_GRID_UPPER].interval) : -1;
 		for (i = 0; i <= n_alpha; i++) {
-			angle = D2R * i * frame_info.axis[1].item[GMT_GRID_UPPER].interval;
-			sincos (angle, &s, &c);
+			angle = i * frame_info.axis[1].item[GMT_GRID_UPPER].interval;
+			sincosd (angle, &s, &c);
 			x = max_radius * Ctrl->S.scale * c;
 			y = max_radius * Ctrl->S.scale * s;
 			plot3d (0.0, 0.0, 3);
