@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psscale.c,v 1.67 2006/11/01 19:11:23 remko Exp $
+ *	$Id: psscale.c,v 1.76 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -288,8 +288,6 @@ int main(int argc, char **argv)
 
 	if (Ctrl->L.active && B_set) B_set = FALSE;	/* -L overrides intervals set with -B */
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (gmtdefs.verbose) {
 		if (Ctrl->C.file)
 			fprintf (stderr, "%s: Reading CPT file %s.", GMT_program, Ctrl->C.file);
@@ -319,13 +317,13 @@ int main(int argc, char **argv)
 
 	z_width = (double *) GMT_memory (VNULL, (size_t)GMT_n_colors, sizeof (double), GMT_program);
 
-	if (Ctrl->Z.file && (fp = fopen (Ctrl->Z.file, "r")) == NULL) {
+	if (Ctrl->Z.file && (fp = GMT_fopen (Ctrl->Z.file, "r")) == NULL) {
 		fprintf (stderr, "%s: Unable to open file %s\n", GMT_program, Ctrl->Z.file);
 		exit (EXIT_FAILURE);
 	}
 	else if (Ctrl->Z.file) {	/* Opened successfully, now read */
 		i = 0;
-		while (fgets (line, BUFSIZ, fp)) {
+		while (GMT_fgets (line, BUFSIZ, fp)) {
 			if (i == GMT_n_colors) {
 				fprintf (stderr, "%s: -Z file %s has more slices than -C file %s!\n", GMT_program, Ctrl->Z.file, Ctrl->C.file);
 				exit (EXIT_FAILURE);
@@ -337,7 +335,7 @@ int main(int argc, char **argv)
 				exit (EXIT_FAILURE);
 			}
 		}
-		fclose (fp);
+		GMT_fclose (fp);
 		if (i < GMT_n_colors) {
 			fprintf (stderr, "%s: -Z file %s has fewer slices than -C file %s!\n", GMT_program, Ctrl->Z.file, Ctrl->C.file);
 			exit (EXIT_FAILURE);
@@ -358,7 +356,7 @@ int main(int argc, char **argv)
 
 	sprintf (text, "X%gi/%gi", Ctrl->D.length, Ctrl->D.width);
 	GMT_parse_J_option (text);	/* Fake linear projection */
-	GMT_map_setup (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, Ctrl->D.width);
+	GMT_err_fail (GMT_map_setup (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, Ctrl->D.width), "");
 
 	/* We must do any origin translation manually in psscale */
 
@@ -506,7 +504,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 
 		for (i = 0; i < nx; i++) {
 			z = (GMT_continuous) ? get_z ((i+0.5) * inc_i, z_width, GMT_n_colors) : GMT_lut[i].z_low;
-			GMT_get_rgb24 (z, rrggbb);
+			GMT_get_rgb_from_z (z, rrggbb);
 			ii = (reverse) ? nx - i - 1 : i;
 			for (j = 0; j < ny; j++) {
 				for (k = 0; k < 3; k++) rgb[k] = rrggbb[k];
@@ -920,13 +918,13 @@ double get_z (double x, double *width, int n)
 void fix_format (char *unit, char *format)
 {
 	int i, j;
-	char text[80], new_format[BUFSIZ];
+	char text[GMT_TEXT_LEN], new_format[BUFSIZ];
 
 	/* Check if annotation units should be added */
 
 	if (unit && unit[0]) {	/* Must append the unit string */
 		if (!strchr (unit, '%'))	/* No percent signs */
-			strncpy (text, unit, 80);
+			strncpy (text, unit, GMT_TEXT_LEN);
 		else {
 			for (i = j = 0; i < (int)strlen (unit); i++) {
 				text[j++] = unit[i];
