@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pstext.c,v 1.53 2006/04/12 21:55:46 pwessel Exp $
+ *	$Id: pstext.c,v 1.65 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  * Version:	3.1 based on old 3.0
  * Version:	3.3: PW: Introducing paragraph mode -M
  * Version:	3.3.4: PW: Input x,y can be in dd:mm[:ss] format
- * Version:	4
+ * Version:	4.1.x
  *
  */
 
@@ -196,7 +196,7 @@ int main(int argc, char **argv)
 				case 'G':
 					Ctrl->G.active = TRUE;
 					if (GMT_getfill (&argv[i][2], &Ctrl->G.fill)) {
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					break;
@@ -212,28 +212,64 @@ int main(int argc, char **argv)
 				case 'S':
 					Ctrl->S.active = TRUE;
 					if (GMT_getpen (&argv[i][2], &Ctrl->S.pen)) {
-						GMT_pen_syntax ('S');
+						GMT_pen_syntax ('S', " ");
 						error++;
 					}
 					break;
 				case 'W':
 					Ctrl->W.active = TRUE;
-					for (j = 0; argv[i][j] && !(strchr ("cCoO", argv[i][j])); j++);
-					if (argv[i][j])  {
-						Ctrl->W.outline = TRUE;	/* Want box outline */
+					/* Do we have -W<fill>,o|O|c|C<pen> ? */
+					for (j = 3; argv[i][j] && (argv[i][j-1] != ',' || !(strchr("cCoO", argv[i][j]))); j++);
+					if (argv[i][j]) {	/* Gave comma separated fill and outline pens */
+						Ctrl->W.outline = TRUE;
 						Ctrl->W.mode = argv[i][j];
 						if (argv[i][j+1] && GMT_getpen (&argv[i][j+1], &Ctrl->W.pen)) {
-							fprintf (stderr, "%s: GMT SYNTAX ERROR -W option: Give pen after o\n", GMT_program);
+							fprintf (stderr, "%s: GMT SYNTAX ERROR -W option: Bad pen given after %c\n", GMT_program, Ctrl->W.mode);
 							error++;
 						}
-						argv[i][j] = 0;
+						if (j > 3) {	/* Gave fill */
+							char txt_a[GMT_LONG_TEXT];
+							strncpy (txt_a, &argv[i][2], j-3);
+							txt_a[j-3] = '\0';
+							if (GMT_getfill (txt_a, &Ctrl->W.fill)) {
+								GMT_fill_syntax ('W', " ");
+								error++;
+							}
+							Ctrl->W.paint = TRUE;
+						}
 					}
-					if (argv[i][2]) {	/* Also gave fill */
-						if (GMT_getfill (&argv[i][2], &Ctrl->W.fill)) {
-							GMT_fill_syntax ('W');
-							error++;
+					else {	/* Backwards compatible way of doing things - will fail if things like -Wcyanored is given */
+						for (j = 2; argv[i][j] && !(strchr ("cCoO", argv[i][j])); j++);
+						if (argv[i][j])  {	/* Found c|C|o|O, but this could be a mistake since -Wcyan or -Worange will trigger this - must check further */
+							char txt_a[GMT_LONG_TEXT];
+							int n;
+							n = 2;
+							while (!(argv[i][n] == '/' || argv[i][n] == '\0')) n++;
+							strncpy (txt_a, &argv[i][2], n-2);	txt_a[n-2] = '\0';
+							if (GMT_colorname2index (txt_a) >= 0) {	/* Found a colorname; thus this was actually a fill statement instead */
+								if (GMT_getfill (txt_a, &Ctrl->W.fill)) {
+									GMT_fill_syntax ('W', " ");
+									error++;
+								}
+								Ctrl->W.paint = TRUE;
+							}
+							else {	/* Presumably we did get a pen outline request */
+								Ctrl->W.outline = TRUE;	/* Want box outline */
+								Ctrl->W.mode = argv[i][j];
+								if (argv[i][j+1] && GMT_getpen (&argv[i][j+1], &Ctrl->W.pen)) {
+									fprintf (stderr, "%s: GMT SYNTAX ERROR -W option: Bad pen given after %c\n", GMT_program, Ctrl->W.mode);
+									error++;
+								}
+								argv[i][j] = 0;
+							}
+						}
+						if (argv[i][2]) {	/* Also gave fill */
+							if (GMT_getfill (&argv[i][2], &Ctrl->W.fill)) {
+								GMT_fill_syntax ('W', " ");
+								error++;
+							}
+							Ctrl->W.paint = TRUE;
 						}
-						Ctrl->W.paint = TRUE;
 					}
 					break;
 				case 'Z':
@@ -260,7 +296,7 @@ int main(int argc, char **argv)
 		fprintf (stderr, "usage: pstext <txtfile> %s %s\n", GMT_J_OPT, GMT_Rgeoz_OPT);
 		fprintf (stderr, "\t[-A] [%s] [-C<dx>/<dy>] [-D[j]<dx>/<dy>[v[<pen>]] [-Eaz/el] [-G<color>]\n", GMT_B_OPT);
 		fprintf (stderr, "\t[%s] [-K] [-L] [%s] [-N] [-O] [-P] [-S<pen>] [%s]\n", GMT_Ho_OPT, GMT_Mo_OPT, GMT_U_OPT);
-		fprintf (stderr, "\t[-V] [-W[<fill>][o|O|c[<pen>]]] [%s] [%s]\n", GMT_X_OPT, GMT_X_OPT);
+		fprintf (stderr, "\t[-V] [-W[<fill>,][o|O|c|C[<pen>]]] [%s] [%s]\n", GMT_X_OPT, GMT_X_OPT);
 		fprintf (stderr, "\t[-Z<zlevel>] [%s] [%s]\n\n", GMT_t_OPT, GMT_c_OPT);
 		fprintf (stderr, "\tReads (x,y,size,angle,fontno,justify,text) from <txtfile> [or stdin]\n");
 		fprintf (stderr, "\tOR (with -M) one or more text paragraphs with formatting info in the segment header.\n");
@@ -300,7 +336,7 @@ int main(int argc, char **argv)
 		fprintf (stderr, "\t   Use -Dj to move text origin away from point (direction determined by text's justification)\n");
 		fprintf (stderr, "\t   Append v[<pen>] to draw line from text to original point\n");
 		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
-		fprintf (stderr, "\t-G set the color (red/green/blue (0-255)) for solid text [0/0/0]\n");
+		fprintf (stderr, "\t-G set the color (red/green/blue (0-255)) for solid text [%d/%d/%d]\n", gmtdefs.basemap_frame_rgb[0], gmtdefs.basemap_frame_rgb[1], gmtdefs.basemap_frame_rgb[2]);
 		GMT_explain_option ('H');
 		GMT_explain_option ('K');
 		GMT_explain_option ('M');
@@ -315,6 +351,7 @@ int main(int argc, char **argv)
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W paints and outlines a rectangle underneath the text.  [Default is no rectangle]\n");
 		fprintf (stderr, "\t   Append fill color [none].  To draw outline, append o, O, or c, and optionally a pen [No outline]\n");
+		fprintf (stderr, "\t   Separate the fill color and the outline information by a comma if both are present.\n");
 		fprintf (stderr, "\t   Lower case o will draw rectangular outline\n");
 		fprintf (stderr, "\t   Upper case O will draw rectangle with rounded corners (-M only)\n");
 		fprintf (stderr, "\t   Lower case c will draw concave rectangle (-M only)\n");
@@ -361,8 +398,6 @@ int main(int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	load_parameters (&T, Ctrl);	/* Pass info from Ctrl to T */
 	
 	z_project.view_azimuth = Ctrl->E.azimuth;
@@ -376,7 +411,7 @@ int main(int argc, char **argv)
 		n_files = 1;
 	n_args = (argc > 1) ? argc : 2;
 
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	GMT_plotinit (argc, argv);
 
@@ -420,7 +455,7 @@ int main(int argc, char **argv)
 			fp = GMT_stdin;
 			done = TRUE;
 		}
-		else if ((fp = fopen (argv[fno], "r")) == NULL) {
+		else if ((fp = GMT_fopen (argv[fno], "r")) == NULL) {
 			fprintf (stderr, "%s: Cannot open file %s\n", GMT_program, argv[fno]);
 			continue;
 		}
@@ -428,7 +463,7 @@ int main(int argc, char **argv)
 		if (!nofile && gmtdefs.verbose) fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
 		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) fgets (line, BUFSIZ, fp);
 
-		while (fgets (line, BUFSIZ, fp)) {
+		while (GMT_fgets (line, BUFSIZ, fp)) {
 
 			if (line[0] == '\0' || (line[0] == '#' && GMT_io.EOF_flag[GMT_IN] != '#')) continue;	/* Skip blank lines or # comments */
 
@@ -607,7 +642,7 @@ int main(int argc, char **argv)
 			n_processed = n_words = 0;
 			n_paragraphs++;
 		}
-		if (fp != GMT_stdin) fclose (fp);
+		if (fp != GMT_stdin) GMT_fclose (fp);
 	}
 
  	if (do_paragraphs) GMT_free ((void *)word);
@@ -715,7 +750,7 @@ void *New_Pstext_Ctrl () {	/* Allocate and initialize a new control structure */
 	C->E.azimuth = 180.0;
 	C->E.elevation = 90.0;
 	C->G.active = TRUE;
-	GMT_init_fill (&C->G.fill, 0, 0, 0);
+	GMT_init_fill (&C->G.fill, gmtdefs.basemap_frame_rgb[0], gmtdefs.basemap_frame_rgb[1], gmtdefs.basemap_frame_rgb[2]);
 	GMT_init_fill (&C->W.fill, -1, -1, -1);	/* No fill */
 	GMT_init_pen (&C->S.pen, GMT_PENWIDTH);
 	GMT_init_pen (&C->W.pen, GMT_PENWIDTH);
