@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pswiggle.c,v 1.42 2006/10/11 02:25:13 remko Exp $
+ *	$Id: pswiggle.c,v 1.49 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -296,8 +296,6 @@ int main (int argc, char **argv)
 	      
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -306,7 +304,7 @@ int main (int argc, char **argv)
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
 
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	if (GMT_IS_MAPPING) Ctrl->D.value *= 1000.0;    /* Distance in meters */
 
