@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psxy.c,v 1.99 2006/04/12 21:55:46 pwessel Exp $
+ *	$Id: psxy.c,v 1.120 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -72,26 +72,26 @@ struct PSXY_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, nofile = TRUE, polygon = FALSE, read_symbol = FALSE, penset_OK = TRUE;
+	BOOLEAN	error = FALSE, nofile = TRUE, polygon = FALSE, read_symbol = FALSE, penset_OK = TRUE, outline_active;
 	BOOLEAN	default_outline = FALSE, done, get_rgb = FALSE, greenwich, default_polygon = FALSE, resample;
-	BOOLEAN old_GMT_world_map, error_x = FALSE, error_y = FALSE, def_err_xy = FALSE, clip_set = FALSE;
+	BOOLEAN old_GMT_world_map, error_x = FALSE, error_y = FALSE, def_err_xy = FALSE, clip_set = FALSE, fill_active;
 
-	char line[BUFSIZ], *p, txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT];
+	char line[BUFSIZ], txt_a[GMT_LONG_TEXT], txt_b[GMT_LONG_TEXT];
 
 	int i, j, n, j0, n_files = 0, fno, xy_errors[2], two, three, four, error_type[2] = {0,0};
-	int n_alloc = GMT_CHUNK, plot_n, n_args, n_fields, n_cols_start = 2, this_outline;
+	int n_alloc = GMT_CHUNK, plot_n, n_args, n_fields, n_cols_start = 2, this_outline, change;
 	int n_required, n_total_read = 0, n_expected = 0, reset_cap = 0, error_cols[2] = {1,4};
 
 	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, s, c;
-	double plot_x, plot_y, x_1, x_2, y_1, y_2, y0, *xx, *yy, *xp, *yp;
-	double direction = 0.0, length = 0.0, major = 0.0, minor = 0.0, x2, y2, z;
+	double plot_x, plot_y, x_1, x_2, y_1, y_2, x0, y0, *xx, *yy, *xp, *yp;
+	double direction = 0.0, length = 0.0, major = 0.0, minor = 0.0, x2, y2;
 	double dir1 = 0.0, dir2 = 0.0, x_len = 0.0, y_len = 0.0, dx, dy, size;
 	double v_w, h_l, h_w, tmp, *in, font_size;
 
 	FILE *fp = NULL;
 
-	struct GMT_PEN default_pen;
-	struct GMT_FILL default_fill, test_fill;
+	struct GMT_PEN current_pen, default_pen;
+	struct GMT_FILL current_fill, default_fill;
 	struct GMT_SYMBOL S;
 	struct PSXY_CTRL *Ctrl;
 
@@ -201,7 +201,7 @@ int main (int argc, char **argv)
 				case 'G':		/* Set fill for symbols or polygon */
 					Ctrl->G.active = TRUE;
 					if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &Ctrl->G.fill))) {
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					break;
@@ -221,7 +221,7 @@ int main (int argc, char **argv)
 				case 'W':		/* Set line attributes */
 					Ctrl->W.active = TRUE;
 					if (argv[i][2] && GMT_getpen (&argv[i][2], &Ctrl->W.pen)) {
-						GMT_pen_syntax ('W');
+						GMT_pen_syntax ('W', " ");
 						error++;
 					}
 					break;
@@ -255,18 +255,14 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-A Suppress drawing line segments as great circle arcs\n");
 		fprintf (stderr, "\t-C Use cpt-file to assign symbol colors based on z-value in 3rd column (requires -S)\n");
 		fprintf (stderr, "\t   Without -S, psxy excepts -M lines/polygons and looks for -Z<val> options in each multiheader\n");
+		fprintf (stderr, "\t   Then, color is applied to polygon fill (-L) or polygon pen\n");
 		fprintf (stderr, "\t-D Offset symbol positions by <dx>/<dy> [no offset].. Requires -S.\n");
 		fprintf (stderr, "\t-E means draw error bars for x, y, or both.  Add cap-width [%g]. Append pen attributes.\n", Ctrl->E.size);
 		fprintf (stderr, "\t   If X or Y is used instead a box-and-whisker diagram is drawn instead, using data from 4\n");
 		fprintf (stderr, "\t   extra columns to get the 0 %%, 25 %%, 75 %% ,and 100%% quartiles (point value is assumed to be 50%%)\n");
 		fprintf (stderr, "\t   Then, use -W, -G to control the appearance of the 25-75%% box.\n");
-		fprintf (stderr, "\t-G Specify color (for symbols/polygons) or pattern (for polygons). Fill can be either\n");
-		fprintf (stderr, "\t   1) <gray> (0-255) for gray-shade [0].\n");
-		fprintf (stderr, "\t   2) <r/g/b> (each 0-255), <h/s/v> (0-360,0-1,0-1), or <c/m/y/k> (each 0-100) for color.\n");
-		fprintf (stderr, "\t   3) black, white or [light|dark]{red, orange, yellow, green, cyan, blue, magenta, brown, gray}.\n");
-		fprintf (stderr, "\t   4) p[or P]<dpi>/<pattern> for predefined patterns (1-90).\n");
-		fprintf (stderr, "\t   5) not given; -G option is present in all subheader (requires -M and no -S)\n");
-		fprintf (stderr, "\t   Default is no fill (transparent symbols or polygons)\n");
+		GMT_fill_syntax ('G', "Specify color (for symbols/polygons) or pattern (for polygons) [Default is no fill]");
+		fprintf (stderr, "\t   -G option can be present in all subheaders (requires -M and no -S)\n");
 		GMT_explain_option ('H');
 		GMT_explain_option ('K');
 		fprintf (stderr, "\t-L Force closed polygons.\n");
@@ -275,18 +271,24 @@ int main (int argc, char **argv)
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
 		fprintf (stderr, "\t-S to select symbol type and symbol size (in %s).  Choose between\n", GMT_unit_names[gmtdefs.measure_unit]);
-		fprintf (stderr, "\t   -(xdash), st(a)r, (b)ar, (c)ircle, (d)iamond, (e)llipse, (f)ront, octa(g)on, (h)exagon, (i)nvtriangle,\n");
-		fprintf (stderr, "\t   (k)ustom, (l)etter, pe(n)tagon, (p)oint, (q)uoted line, (r)ect, (s)quare, (t)riangle, (v)ector, (w)edge, (x)cross, (y)dash\n");
+		fprintf (stderr, "\t   -(xdash), st(a)r, (b|B)ar, (c)ircle, (d)iamond, (e)llipse, (f)ront, octa(g)on, (h)exagon, (i)nvtriangle,\n");
+		fprintf (stderr, "\t   (j)rotated rectangle, (k)ustom, (l)etter, pe(n)tagon, (p)oint, (q)uoted line, (r)ect, (s)quare,\n");
+		fprintf (stderr, "\t   (t)riangle, (v)ector, (w)edge, (x)cross, (y)dash\n");
 		fprintf (stderr, "\t   If no size is specified, psxy expects the 3rd column to have sizes.\n");
 		fprintf (stderr, "\t   If no symbol is specified, psxy expects the last column to have symbol code.\n");
 		fprintf (stderr, "\t   [Note: if -C is selected then 3rd means 4th column, etc.]\n");
 		fprintf (stderr, "\t   Symbols A, C, D, G, H, I, N, S, T are adjusted to have same area as a circle of given size\n");
 		fprintf (stderr, "\t   Bars: Append b<base> to give the y-value of the base [Default = 0]\n");
 		fprintf (stderr, "\t      Append u if width is in x-input units [Default is %s]\n", GMT_unit_names[gmtdefs.measure_unit]);
+		fprintf (stderr, "\t      Use upper case -SB for horizontal bars (base then refers to x and width may be in y-units [Default is vertical]\n");
 		fprintf (stderr, "\t   Ellipses: the direction, major, and minor axis must be in input columns 3, 4 and 5.\n");
 		fprintf (stderr, "\t     If -SE rather than -Se is selected, psxy will expect azimuth, and axes in km\n");
 		fprintf (stderr, "\t     and convert azimuths based on the chosen map projection.  If projection is linear then\n");
 		fprintf (stderr, "\t     we scale the minor/major axes by the map scale.\n");
+		fprintf (stderr, "\t   Rotatable Rectangle: Direction, x-dimension, and y-dimension are expected in columns 3, 4, and 5.\n");
+		fprintf (stderr, "\t     If -SJ rather than -Sj is selected, psxy will expect azimuth, and dimensions in km\n");
+		fprintf (stderr, "\t     and convert azimuths based on the chosen map projection.  If projection is linear then\n");
+		fprintf (stderr, "\t     we scale the rectangle dimension by the map scale.\n");
 		fprintf (stderr, "\t   Fronts: Give tickgap/ticklen[dir][type][:offset], where\n");
 		fprintf (stderr, "\t     dir    = Plot symbol to the l(eft) or r(ight) of front [Default is centered]\n");
 		fprintf (stderr, "\t     type   =  b(ox), c(ircle), f(ault), s(lip), t(riangle) [Default is f]\n");
@@ -297,7 +299,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t       triangle : diagonal square when centered, directed triangle otherwise.\n"); 
 		fprintf (stderr, "\t     offset = start plotting symbols when along-track distance equals offset [0].\n"); 
 		fprintf (stderr, "\t   Kustom: append <symbolname> immediately after 'k'; this will look for <symbolname>.def in\n");
-		fprintf (stderr, "\t     the current directory or in $GMTHOME/share/custom.\n");
+		fprintf (stderr, "\t     the current directory or in %s or in %s/custom.\n", GMT_USERDIR, GMT_SHAREDIR);
 		GMT_list_custom_symbols ();
 		fprintf (stderr, "\t   Letter: append /<string> after symbol size, and optionally %%<font>\n");
 		fprintf (stderr, "\t   Quoted line: Give [d|f|n|l|x]<info>[:<labelinfo>]\n");
@@ -317,12 +319,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t     If -SW rather than -Sw is selected, psxy will expect two azimuths instead.\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
-		fprintf (stderr, "\t-W sets pen attributes [width = %gp, color = black, texture = solid line].\n", Ctrl->W.pen.width);
-		fprintf (stderr, "\t   Implicitly draws symbol outline with this pen.\n");
-		fprintf (stderr, "\t   OR -W:<width>:<color>:<texture>: (leave empty to obtain the default values [:thinnest:black::]\n");
-		fprintf (stderr, "\t   <width> = faint or {thin, thick, fat}[er|est].\n");
-		fprintf (stderr, "\t   <color> = black, white or [light|dark]{red, orange, yellow, green, cyan, blue, magenta, brown, gray}.\n");
-		fprintf (stderr, "\t   <texture> = pattern of dashes (-) and dots (.) which will be scaled by pen width.\n");
+		GMT_pen_syntax ('W', "sets pen attributes");
 		GMT_explain_option ('X');
 		GMT_explain_option ('c');
 		GMT_explain_option (':');
@@ -336,13 +333,13 @@ int main (int argc, char **argv)
 
 	/* Check that the options selected are mutually consistent */
 
-	if (Ctrl->S.active && GMT_decode_symbol_option (Ctrl->S.arg, &S, 0, TRUE)) {
+	if (Ctrl->S.active && GMT_parse_symbol_option (Ctrl->S.arg, &S, 0, TRUE)) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option\n", GMT_program);
 		error++;
 	}
 	if (S.symbol > 0 && Ctrl->C.active) get_rgb = TRUE;	/* Need to read z-vales from input data file */
-	if (Ctrl->E.active && (S.read_vector || S.symbol == GMT_SYMBOL_ELLIPSE || S.symbol == GMT_SYMBOL_FRONT || S.symbol == GMT_SYMBOL_QUOTED_LINE)) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -E option: Incompatible with -Se, -Sf, -Sq, -Sv\n", GMT_program);
+	if (Ctrl->E.active && (S.read_vector || S.symbol == GMT_SYMBOL_ELLIPSE || S.symbol == GMT_SYMBOL_FRONT || S.symbol == GMT_SYMBOL_QUOTED_LINE || S.symbol == GMT_SYMBOL_ROTATERECT)) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -E option: Incompatible with -Se, -Sf, -Sj, -Sq, -Sv\n", GMT_program);
 		error++;
 	}
 	if (Ctrl->G.fill.use_pattern && !(S.symbol == GMT_SYMBOL_LINE || S.symbol == GMT_SYMBOL_CUSTOM)) {	/* fill-pattern only for polygons */
@@ -403,10 +400,8 @@ int main (int argc, char **argv)
 	if (S.symbol == 0 && (Ctrl->G.active || Ctrl->L.active)) polygon = TRUE;
 	if (S.symbol == GMT_SYMBOL_FRONT || S.symbol == GMT_SYMBOL_QUOTED_LINE) polygon = FALSE;
 
-	if (S.symbol && !(Ctrl->G.active || Ctrl->C.active)) Ctrl->W.active = TRUE;	/* User wants symbol but no fill - implicitly set outline */
-
-	default_pen = Ctrl->W.pen;
-	default_fill = Ctrl->G.fill;
+	current_pen = default_pen = Ctrl->W.pen;
+	current_fill = default_fill = Ctrl->G.fill;
 	default_outline = Ctrl->W.active;
 	default_polygon = polygon;
 
@@ -449,18 +444,16 @@ int main (int argc, char **argv)
 		error++;
 	}
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
-	GMT_map_setup (west, east, south, north);
+	GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
 	if (S.symbol == GMT_SYMBOL_QUOTED_LINE) {
 		if (GMT_contlabel_prep (&S.G, NULL)) exit (EXIT_FAILURE);
-		penset_OK = FALSE;	/* Since it is set in PSL */
+		penset_OK = FALSE;	/* The pen for quoted lines are set within the PSL code itself so we dont do it here in psxy */
 	}
 
 	resample = (!Ctrl->A.active && GMT_IS_MAPPING);
@@ -468,16 +461,16 @@ int main (int argc, char **argv)
 
 	GMT_plotinit (argc, argv);
 
-	if (penset_OK) GMT_setpen (&Ctrl->W.pen);
-	if (S.symbol == GMT_SYMBOL_TEXT && Ctrl->G.active && !Ctrl->W.active) ps_setpaint (Ctrl->G.fill.rgb);
-
-	if (S.symbol == GMT_SYMBOL_TEXT) {
-		ps_setfont (S.font_no);			/* Set the required font */
-	}
 	if (S.symbol == GMT_SYMBOL_FRONT || S.symbol == GMT_SYMBOL_QUOTED_LINE || (S.symbol > 0 && !Ctrl->N.active)) {
 		GMT_map_clip_on (GMT_no_rgb, 3);
 		clip_set = TRUE;
 	}
+	if (penset_OK) GMT_setpen (&current_pen);
+	if (S.symbol == GMT_SYMBOL_TEXT && Ctrl->G.active && !Ctrl->W.active) ps_setpaint (current_fill.rgb);
+
+	if (S.symbol == GMT_SYMBOL_TEXT) {
+		ps_setfont (S.font_no);			/* Set the required font */
+	}
 	if (S.symbol == GMT_SYMBOL_ELLIPSE) Ctrl->N.active = TRUE;	/* So we can see ellipses that have centers outside -R */
 	if (S.symbol == GMT_SYMBOL_POINT && !Ctrl->E.active) {	/* Temporarily change linecap to round (1)*/
 		ps_setlinecap (1);
@@ -488,6 +481,12 @@ int main (int argc, char **argv)
 	}
 	old_GMT_world_map = GMT_world_map;
 	if (S.convert_angles && GMT_IS_MAPPING) S.convert_angles = 2;
+	if (S.symbol == GMT_SYMBOL_BARX && !S.base_set && project_info.xyz_projection[GMT_X] == GMT_LOG10) S.base = west;	/* Default to west level for horizontal log10 bars */
+	if (S.symbol == GMT_SYMBOL_BARY && !S.base_set && project_info.xyz_projection[GMT_Y] == GMT_LOG10) S.base = south;	/* Default to south level for vertical log10 bars */
+
+	fill_active = Ctrl->G.active;	/* Make copies because we will change the values */
+	outline_active =  Ctrl->W.active;
+	if (S.symbol > 0 && !outline_active && !fill_active && !get_rgb) outline_active = TRUE;		/* If no fill nor outline for symbols then turn outline on */
 
 	if (S.symbol <= 0) {
 		xx = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
@@ -527,34 +526,12 @@ int main (int argc, char **argv)
 			if (read_symbol) n_expected = BUFSIZ;
 			while ((n_fields = GMT_input (fp, &n_expected, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
-				while ((GMT_io.status & GMT_IO_SEGMENT_HEADER) && !(GMT_io.status & GMT_IO_EOF)) {	/* Skip segment headers */
+				while ((GMT_io.status & GMT_IO_SEGMENT_HEADER) && !(GMT_io.status & GMT_IO_EOF)) {	/* Process segment headers */
 					if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
-					if ((p = strstr (GMT_io.segment_header, " -G")) || (p = strstr (GMT_io.segment_header, "	-G"))) {
-						strcpy (line, &p[3]);
-						for (i = 0; line[i]; i++) if (line[i] == ' ') line[i] = '\0';
-						if (!GMT_getfill (line, &test_fill)) Ctrl->G.fill = test_fill;	/* Failure is OK since -G may appear in text strings */
-					}
-					else if (Ctrl->C.active && ((p = strstr (GMT_io.segment_header, " -Z")) || (p = strstr (GMT_io.segment_header, "	-Z")))) {	/* Set symbol r/g/b via cpt-lookup */
-						if(!strncmp (&p[3], "NaN", 3))	/* Got -ZNaN */
-							GMT_get_rgb24 (GMT_d_NaN, Ctrl->G.fill.rgb);
-						else {
-							if (sscanf (&p[3], "%lg", &z) == 1) GMT_get_rgb24 (z, Ctrl->G.fill.rgb);
-						}
-					}
-					else
-						Ctrl->G.fill = default_fill;
-					if ((p = strstr (GMT_io.segment_header, " -W")) || (p = strstr (GMT_io.segment_header, "	-W"))) {
-						strcpy (line, &p[3]);
-						for (i = 0; line[i]; i++) if (line[i] == ' ') line[i] = '\0';
-						if (!GMT_getpen (line, &Ctrl->W.pen)) {	/* Failure is OK since -W may appear in text strings */
-							GMT_setpen (&Ctrl->W.pen);
-							Ctrl->W.active = TRUE;
-						}
-					}
-					else {
-						GMT_setpen (&default_pen);
-						Ctrl->W.active = default_outline;
-					}
+					
+					change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
+					if (change & 4) GMT_setpen (&current_pen);
+
 					if (read_symbol) n_expected = BUFSIZ;
 					n_fields = GMT_input (fp, &n_expected, &in);
 				}
@@ -573,14 +550,16 @@ int main (int argc, char **argv)
 					i = strlen (GMT_io.current_record) - 1;
 					GMT_io.current_record[i--] = 0;	/* Chop off the \n */
 					while (GMT_io.current_record[i] && !strchr (" ,\t", (int)GMT_io.current_record[i])) i--;
-					(void ) GMT_decode_symbol_option (&GMT_io.current_record[i+1], &S, 0, FALSE);
+					(void ) GMT_parse_symbol_option (&GMT_io.current_record[i+1], &S, 0, FALSE);
 					n_required = n_cols_start + S.n_required;
 				}
 
-				if (S.symbol == GMT_SYMBOL_BAR) GMT_geo_to_xy (west, S.base, &plot_x, &y0);	/* Zero level for bars */
+				if (S.symbol == GMT_SYMBOL_BARY) GMT_geo_to_xy (west, S.base, &plot_x, &y0);	/* Zero y level for vertical bars */
+				if (S.symbol == GMT_SYMBOL_BARX) GMT_geo_to_xy (S.base, south, &x0, &plot_y);	/* Zero x level for horizontal bars */
+
 				if (get_rgb) {
-					GMT_get_rgb24 (in[2], Ctrl->G.fill.rgb);
-					if (S.symbol == GMT_SYMBOL_CROSS || S.symbol == GMT_SYMBOL_POINT || S.symbol == GMT_SYMBOL_TEXT) ps_setpaint (Ctrl->G.fill.rgb);
+					GMT_get_rgb_from_z (in[2], current_fill.rgb);
+					if (S.symbol == GMT_SYMBOL_CROSS || S.symbol == GMT_SYMBOL_POINT || S.symbol == GMT_SYMBOL_TEXT) ps_setpaint (current_fill.rgb);
 				}
 				if (GMT_cpt_skip) continue;	/* Chosen cpt file indicates skip for this z */
 		
@@ -603,6 +582,21 @@ int main (int argc, char **argv)
 					major = in[three] * GMT_u2u[S.u][GMT_INCH];
 					minor = in[four] * GMT_u2u[S.u][GMT_INCH];
 				}
+				else if (S.symbol == GMT_SYMBOL_ROTATERECT && S.convert_angles == 2) {	/* Leave axes in km */
+					direction = in[two];
+					x_len = in[three+S.read_size];
+					y_len = in[four+S.read_size];
+				}
+				else if (S.symbol == GMT_SYMBOL_ROTATERECT && S.convert_angles) {	/* Scale lengths by given scale */
+					direction = 90.0 - in[two];	/* Cartesian azimuth */
+					x_len = in[three+S.read_size] * project_info.x_scale;
+					y_len = in[four+S.read_size] * project_info.x_scale;
+				}
+				else if (S.symbol == GMT_SYMBOL_ROTATERECT) {
+					direction = in[two];
+					x_len = in[three+S.read_size];
+					y_len = in[four+S.read_size];
+				}
 				else if (S.symbol == GMT_SYMBOL_PIE && S.convert_angles) {
 					dir1 = 90.0 - in[two+S.read_size];
 					dir2 = 90.0 - in[three+S.read_size];
@@ -618,7 +612,7 @@ int main (int argc, char **argv)
 		
 				/* Skip zero-size symbols */
 		
-				if (!(S.symbol == GMT_SYMBOL_BAR) && S.symbol < GMT_SYMBOL_ELLIPSE && S.size_x <= 0.0) {
+				if (!(S.symbol == GMT_SYMBOL_BARX || S.symbol == GMT_SYMBOL_BARY) && S.symbol < GMT_SYMBOL_ELLIPSE && S.size_x <= 0.0) {
 					if (gmtdefs.verbose) fprintf (stderr, "%s: Warning: Symbol size <= 0.0 near line %d (skipped)\n", GMT_program, n_total_read);
 					continue;
 				}
@@ -656,33 +650,41 @@ int main (int argc, char **argv)
 						if (error_type[0] == 0)
 							plot_x_errorbar (in[0], in[1], in[xy_errors[0]], Ctrl->E.size, n_total_read);
 						else
-							plot_x_whiskerbar (plot_x, in[1], &in[xy_errors[0]], Ctrl->E.size, Ctrl->G.fill.rgb, n_total_read);
+							plot_x_whiskerbar (plot_x, in[1], &in[xy_errors[0]], Ctrl->E.size, current_fill.rgb, n_total_read);
 					}
 					if (error_y) {
 						if (error_type[1] == 0)
 							plot_y_errorbar (in[0], in[1], in[xy_errors[1]], Ctrl->E.size, n_total_read);
 						else
-							plot_y_whiskerbar (in[0], plot_y, &in[xy_errors[1]], Ctrl->E.size, Ctrl->G.fill.rgb, n_total_read);
+							plot_y_whiskerbar (in[0], plot_y, &in[xy_errors[1]], Ctrl->E.size, current_fill.rgb, n_total_read);
 					}
-					GMT_setpen (&Ctrl->W.pen);
+					GMT_setpen (&current_pen);
 				}
-
+				
 				switch (S.symbol) {
 					case GMT_SYMBOL_NONE:
 						break;
 					case GMT_SYMBOL_STAR:
 						size = (S.equal_area) ? 1.67289326141 * S.size_x : S.size_x;
-						ps_star (plot_x, plot_y, size, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_star (plot_x, plot_y, size, current_fill.rgb, outline_active);
 						break;
-					case GMT_SYMBOL_BAR:
+					case GMT_SYMBOL_BARX:
+						if (S.user_unit) {	/* Width measured in y units */
+							GMT_geo_to_xy (S.base, in[1]-S.size_x, &x_1, &y_1);
+							GMT_geo_to_xy (in[0], in[1]+S.size_x, &x_2, &y_2);
+							ps_rect (x_1, y_1, x_2, y_2, current_fill.rgb, outline_active);
+						}
+						else
+							ps_rect (x0, plot_y-S.size_x, plot_x, plot_y+S.size_x, current_fill.rgb, outline_active);
+						break;
+					case GMT_SYMBOL_BARY:
 						if (S.user_unit) {	/* Width measured in x units */
 							GMT_geo_to_xy (in[0]-S.size_x, S.base, &x_1, &y_1);
 							GMT_geo_to_xy (in[0]+S.size_x, in[1], &x_2, &y_2);
-			
-							ps_rect (x_1, y_1, x_2, y_2, Ctrl->G.fill.rgb, Ctrl->W.active);
+							ps_rect (x_1, y_1, x_2, y_2, current_fill.rgb, outline_active);
 						}
 						else
-							ps_rect (plot_x-S.size_x, y0, plot_x+S.size_x, plot_y, Ctrl->G.fill.rgb, Ctrl->W.active);
+							ps_rect (plot_x-S.size_x, y0, plot_x+S.size_x, plot_y, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_CROSS:
 						ps_cross (plot_x, plot_y, S.size_x);
@@ -693,42 +695,42 @@ int main (int argc, char **argv)
 						if (reset_cap == 2) ps_setlinecap (gmtdefs.ps_line_cap);
 						break;
 					case GMT_SYMBOL_CIRCLE:
-						ps_circle (plot_x, plot_y, S.size_x, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_circle (plot_x, plot_y, S.size_x, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_SQUARE:
 						size = (S.equal_area) ? 1.25331413732 * S.size_x : S.size_x;
-						ps_square (plot_x, plot_y, size, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_square (plot_x, plot_y, size, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_HEXAGON:
 						size = (S.equal_area) ? 1.09963611079 * S.size_x : S.size_x;
-						ps_hexagon (plot_x, plot_y, size, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_hexagon (plot_x, plot_y, size, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_PENTAGON:
 						size = (S.equal_area) ? 1.14948092619 * S.size_x : S.size_x;
-						ps_pentagon (plot_x, plot_y, size, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_pentagon (plot_x, plot_y, size, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_OCTAGON:
 						size = (S.equal_area) ? 1.05390736526 * S.size_x : S.size_x;
-						ps_octagon (plot_x, plot_y, size, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_octagon (plot_x, plot_y, size, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_TRIANGLE:
 						size = (S.equal_area) ? 1.55512030156 * S.size_x : S.size_x;
-						ps_triangle (plot_x, plot_y, size, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_triangle (plot_x, plot_y, size, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_ITRIANGLE:
 						size = (S.equal_area) ? 1.55512030156 * S.size_x : S.size_x;
-						ps_itriangle (plot_x, plot_y, size, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_itriangle (plot_x, plot_y, size, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_DIAMOND:
 						size = (S.equal_area) ? 1.25331413732 * S.size_x : S.size_x;
-						ps_diamond (plot_x, plot_y, size, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_diamond (plot_x, plot_y, size, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_TEXT:
 						font_size = S.size_x * 72.0;
-						if (Ctrl->W.active && Ctrl->G.active) {
-							ps_setpaint (Ctrl->G.fill.rgb);
+						if (outline_active && Ctrl->G.active) {
+							ps_setpaint (current_fill.rgb);
 							ps_text (plot_x, plot_y, font_size, S.string, 0.0, 6, FALSE);
-							ps_setpaint (Ctrl->W.pen.rgb);
+							ps_setpaint (current_pen.rgb);
 							ps_text (plot_x, plot_y, font_size, S.string, 0.0, 6, TRUE);
 						}
 						else if (Ctrl->G.active)
@@ -738,9 +740,15 @@ int main (int argc, char **argv)
 						break;
 					case GMT_SYMBOL_ELLIPSE:
 						if (S.convert_angles == 2)
-							GMT_plot_ellipse (in[0], in[1], 0.0, major, minor, direction, Ctrl->G.fill, Ctrl->W.active);
+							GMT_plot_ellipse (in[0], in[1], 0.0, major, minor, direction, current_fill, outline_active);
 						else
-							ps_ellipse (plot_x, plot_y, direction, major, minor, Ctrl->G.fill.rgb, Ctrl->W.active);
+							ps_ellipse (plot_x, plot_y, direction, major, minor, current_fill.rgb, outline_active);
+						break;
+					case GMT_SYMBOL_ROTATERECT:
+						if (S.convert_angles == 2)
+							GMT_plot_rectangle (in[0], in[1], 0.0, x_len, y_len, direction, current_fill, outline_active);
+						else
+							ps_rotaterect (plot_x, plot_y, direction, x_len, y_len, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_VECTOR:
 						if (S.convert_angles == 2) {
@@ -757,7 +765,7 @@ int main (int argc, char **argv)
 							}
 						}
 						else {
-							sincos (direction * D2R, &s, &c);
+							sincosd (direction, &s, &c);
 							x2 = plot_x + length * c;
 							y2 = plot_y + length * s;
 							if (S.v_just) {
@@ -766,8 +774,8 @@ int main (int argc, char **argv)
 								x2 -= dx;		y2 -= dy;
 							}
 						}
-						this_outline = (S.v_double_heads) ? Ctrl->W.active + 8 : Ctrl->W.active;
-						ps_vector (plot_x, plot_y, x2, y2, S.v_width, S.h_length, S.h_width, gmtdefs.vector_shape, Ctrl->G.fill.rgb, this_outline);
+						this_outline = (S.v_double_heads) ? outline_active + 8 : outline_active;
+						ps_vector (plot_x, plot_y, x2, y2, S.v_width, S.h_length, S.h_width, gmtdefs.vector_shape, current_fill.rgb, this_outline);
 						break;
 					case GMT_SYMBOL_VECTOR2:
 						if (S.convert_angles == 2) {
@@ -784,7 +792,7 @@ int main (int argc, char **argv)
 							}
 						}
 						else {
-							sincos (direction * D2R, &s, &c);
+							sincosd (direction, &s, &c);
 							x2 = plot_x + length * c;
 							y2 = plot_y + length * s;
 							if (S.v_just) {
@@ -793,15 +801,15 @@ int main (int argc, char **argv)
 								x2 -= dx;		y2 -= dy;
 							}
 						}
-						this_outline = (S.v_double_heads) ? Ctrl->W.active + 8 : Ctrl->W.active;
+						this_outline = (S.v_double_heads) ? outline_active + 8 : outline_active;
 						if (length < S.v_norm) {	/* Scale arrow attributes down with length */
 							v_w = S.v_width * length * S.v_shrink;
 							h_l = S.h_length * length * S.v_shrink;
 							h_w = S.h_width * length * S.v_shrink;
-							ps_vector (plot_x, plot_y, x2, y2, v_w, h_l, h_w, gmtdefs.vector_shape, Ctrl->G.fill.rgb, this_outline);
+							ps_vector (plot_x, plot_y, x2, y2, v_w, h_l, h_w, gmtdefs.vector_shape, current_fill.rgb, this_outline);
 						}
 						else	/* Leave as specified */
-							ps_vector (plot_x, plot_y, x2, y2, S.v_width, S.h_length, S.h_width, gmtdefs.vector_shape, Ctrl->G.fill.rgb, this_outline);
+							ps_vector (plot_x, plot_y, x2, y2, S.v_width, S.h_length, S.h_width, gmtdefs.vector_shape, current_fill.rgb, this_outline);
 						break;
 					case GMT_SYMBOL_PIE:
 						if (S.convert_angles == 2) {
@@ -810,7 +818,7 @@ int main (int argc, char **argv)
 							GMT_azim_to_angle (in[0], in[1], 1.0, dir2, &tmp);
 							dir2 = tmp;
 						}
-						ps_pie (plot_x, plot_y, S.size_x, dir1, dir2, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_pie (plot_x, plot_y, S.size_x, dir1, dir2, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_XDASH:
 						ps_segment (plot_x - S.size_x, plot_y, plot_x + S.size_x, plot_y);
@@ -819,10 +827,10 @@ int main (int argc, char **argv)
 						ps_segment (plot_x, plot_y - S.size_x, plot_x, plot_y + S.size_x);
 						break;
 					case GMT_SYMBOL_RECT:
-						ps_rect (plot_x - x_len, plot_y - y_len, plot_x + x_len, plot_y + y_len, Ctrl->G.fill.rgb, Ctrl->W.active);
+						ps_rect (plot_x - x_len, plot_y - y_len, plot_x + x_len, plot_y + y_len, current_fill.rgb, outline_active);
 						break;
 					case GMT_SYMBOL_CUSTOM:
-						GMT_draw_custom_symbol (plot_x, plot_y, 0.0, S.size_x, S.custom, &Ctrl->W.pen, &Ctrl->G.fill, Ctrl->W.active);
+						GMT_draw_custom_symbol (plot_x, plot_y, 0.0, S.size_x, S.custom, &current_pen, &current_fill, outline_active);
 						break;
 				}
 				if (read_symbol) n_expected = BUFSIZ;
@@ -834,50 +842,15 @@ int main (int argc, char **argv)
 			n_fields = GMT_input (fp, &n_expected, &in);
 			while (! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
-				while (GMT_io.status & GMT_IO_SEGMENT_HEADER) {
+				while (GMT_io.status & GMT_IO_SEGMENT_HEADER) {	/* Process multisegment header flags */
 					if (gmtdefs.verbose) ps_comment (GMT_io.segment_header);
-					if ((p = strstr (GMT_io.segment_header, " -W")) || (p = strstr (GMT_io.segment_header, "	-W"))) {
-						strcpy (line, &p[3]);
-						for (i = 0; line[i]; i++) if (line[i] == ' ') line[i] = '\0';
-						if (!GMT_getpen (line, &Ctrl->W.pen)) {	/* Failure is OK since -W may appear in text strings */
-							if (penset_OK) GMT_setpen (&Ctrl->W.pen);
-							Ctrl->W.active = TRUE;
-						}
-					}
-					else {
-						if (penset_OK) GMT_setpen (&default_pen);
-						Ctrl->W.active = default_outline;
-						Ctrl->W.pen = default_pen;
-					}
-					if ((p = strstr (GMT_io.segment_header, " -G")) || (p = strstr (GMT_io.segment_header, "	-G"))) {	/* Set polygon fill */
-						strcpy (line, &p[3]);
-						for (i = 0; line[i]; i++) if (line[i] == ' ') line[i] = '\0';
-						if (!GMT_getfill (line, &test_fill)) {	/* Failure is OK since -G may appear in text strings */
-							Ctrl->G.fill = test_fill;
-							polygon = TRUE;
-						}
-					}
-					else if (Ctrl->C.active && ((p = strstr (GMT_io.segment_header, " -Z")) || (p = strstr (GMT_io.segment_header, "	-Z")))) {	/* Set polygon or pen r/g/b via cpt-lookup */
-						if(!strncmp (&p[3], "NaN", 3)) {	/* Got -ZNaN */
-							GMT_get_rgb24 (GMT_d_NaN, Ctrl->G.fill.rgb);
-							Ctrl->G.fill.use_pattern = FALSE;
-							polygon = TRUE;
-						}
-						else {
-							if (sscanf (&p[3], "%lg", &z) == 1) {
-								GMT_get_rgb24 (z, Ctrl->G.fill.rgb);
-								Ctrl->G.fill.use_pattern = FALSE;
-								polygon = TRUE;
-							}
-						}
-						if (!Ctrl->L.active) {	/* Use -Zz -Ccpt to set pen color instead */
-							polygon = FALSE;
-							ps_setpaint (Ctrl->G.fill.rgb);
-						}
-					}
-					else {
-						polygon = default_polygon;
-						Ctrl->G.fill = default_fill;
+					
+					change = GMT_parse_multisegment_header (GMT_io.segment_header, Ctrl->C.active, &fill_active, &current_fill, &default_fill, &outline_active, &current_pen, &default_pen, default_outline);
+					if ((change & 4) && penset_OK) GMT_setpen (&current_pen);
+					if ((change & 1)) polygon = TRUE;
+					if ((change & 2) && !Ctrl->L.active) {
+						polygon = FALSE;
+						ps_setpaint (current_fill.rgb);
 					}
 					if (S.G.label_type == 2) {	/* Update segment header */
 						GMT_extract_label (&GMT_io.segment_header[1], S.G.label);
@@ -924,13 +897,13 @@ int main (int argc, char **argv)
 				if (resample) n = GMT_fix_up_path (&xx, &yy, n, greenwich, Ctrl->A.step);	/* Resample if spacing is too coarse */
 
 				if (polygon) {	/* Want a filled polygon */
-					GMT_fill_polygon (xx, yy, 0.0, n, &Ctrl->G.fill, Ctrl->W.active);
+					GMT_fill_polygon (xx, yy, 0.0, n, &current_fill, outline_active);
 				}
 				else {		/* Want a line of some sort */
 					if ((plot_n = GMT_geo_to_xy_line (xx, yy, n)) == 0) continue;		/* Nothing there there */
 					if (S.symbol == GMT_SYMBOL_QUOTED_LINE) {	/* Labelled lines are dealt with by the contour machinery */
 						int start = 0, stop;
-						S.G.line_pen = Ctrl->W.pen;
+						S.G.line_pen = current_pen;
 						/* Since the line might exit and enter the region we must isolate the segments before calling GMT_hold_contour */
 						while (start < plot_n) {	/* More segments to register */
 							while (GMT_pen[start+1] == 3 && start < (plot_n-1)) start++;	/* Skip multiple start points */
@@ -949,7 +922,7 @@ int main (int argc, char **argv)
 					}
 					else {
 						GMT_plot_line (GMT_x_plot, GMT_y_plot, GMT_pen, plot_n);
-						if (S.symbol == GMT_SYMBOL_FRONT) GMT_draw_fence (GMT_x_plot, GMT_y_plot, 0.0, plot_n, &S.f, &Ctrl->G.fill, Ctrl->W.active); 	/* Must draw front crossbars */
+						if (S.symbol == GMT_SYMBOL_FRONT) GMT_draw_fence (GMT_x_plot, GMT_y_plot, 0.0, plot_n, &S.f, &current_fill, outline_active); 	/* Must draw front crossbars */
 					}
 				}
 			}
