@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: sample1d.c,v 1.26 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: sample1d.c,v 1.33 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -130,7 +130,7 @@ int main (int argc, char **argv)
 					break;
 				case 'S':
 					Ctrl->S.active = TRUE;
-					Ctrl->S.start = atof (&argv[i][2]);
+					GMT_scanf_arg (&argv[i][2], GMT_IS_UNKNOWN, &Ctrl->S.start);
 					break;
 
 				/* For backward compatibility for now */
@@ -224,8 +224,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -243,8 +241,8 @@ int main (int argc, char **argv)
 		m_alloc = GMT_CHUNK;
 		t_supplied_out = (double *) GMT_memory (VNULL, (size_t)m_alloc, sizeof (double), GMT_program);
 		m = 0;
-		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) fgets (line, BUFSIZ, fpt);
-		while (fgets (line, BUFSIZ, fpt)) {
+		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fpt);
+		while (GMT_fgets (line, BUFSIZ, fpt)) {
 			if (line[0] == '#' || line[0] == GMT_io.EOF_flag[GMT_IN]) continue;
 			sscanf (line, "%lf", &t_supplied_out[m]);
 			m++;
