@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegy.c,v 1.13 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: pssegy.c,v 1.21 2007/03/24 01:42:07 pwessel Exp $
  *
- *    Copyright (c) 1999-2006 by T. Henstock
+ *    Copyright (c) 1999-2007 by T. Henstock
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* pssegy program to plot segy files in postscript with variable trace spacing option
@@ -99,7 +99,7 @@ int main (int argc, char **argv)
 					do_fill = TRUE;
 					if (GMT_getrgb (&argv[i][2], shade)) {
 					  error++;
-					  GMT_rgb_syntax ('F'); 
+					  GMT_rgb_syntax ('F', " "); 
 					}
 					break;
 				case 'I':
@@ -164,7 +164,7 @@ int main (int argc, char **argv)
 				case 'T':
 					strcpy (input, &argv[i][2]);
 					if ((trace_file = strlen(input))){
-						if ((fpt = fopen (input, "r")) == NULL){
+						if ((fpt = GMT_fopen (input, "r")) == NULL){
 							fprintf(stderr, "%s: Cannot find trace list file %s\n", GMT_program, input);
 							error++;
 						}
@@ -185,7 +185,7 @@ int main (int argc, char **argv)
 					break;
 			}
 		}
-		else if ((fpi = fopen (argv[i], "rb")) == NULL) {
+		else if ((fpi = GMT_fopen (argv[i], "rb")) == NULL) {
 			fprintf (stderr, "%s: Cannot find segy file %s\n", GMT_program,argv[i]);
 			exit (EXIT_FAILURE);
 		}
@@ -284,10 +284,8 @@ int main (int argc, char **argv)
 		if(gmtdefs.verbose) fprintf(stderr, "%s: read in %d trace locations\n", GMT_program, n_tracelist);
 	}
 
-       GMT_put_history (argc, argv);   /* Update .gmtcommands4 */
-
 /* set up map projection and PS plotting */
-	GMT_map_setup (w, e, s, n);
+	GMT_err_fail (GMT_map_setup (w, e, s, n), "");
 	GMT_plotinit (argc, argv);
 
 /* define area for plotting and size of array for bitmap */
