@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegyz.c,v 1.19 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: pssegyz.c,v 1.27 2007/03/24 01:42:07 pwessel Exp $
  *
- *    Copyright (c) 1999-2006 by T. Henstock
+ *    Copyright (c) 1999-2007 by T. Henstock
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* pssegyz program to plot segy files in 3d in postscript with variable trace spacing option
@@ -116,7 +116,7 @@ int main (int argc, char **argv)
 					do_fill = TRUE;
 					if (GMT_getrgb (&argv[i][2], shade)) {
 						++error;
-						GMT_rgb_syntax ('F');
+						GMT_rgb_syntax ('F', " ");
 					}
 					break;
 				case 'I':
@@ -233,7 +233,7 @@ int main (int argc, char **argv)
 					break;
 			}
 			}
-		else if ((fpi = fopen (argv[i], "rb")) == NULL) {
+		else if ((fpi = GMT_fopen (argv[i], "rb")) == NULL) {
 			fprintf (stderr, "%s: Cannot find segy file %s\n",  GMT_program, argv[i]);
 			exit (EXIT_FAILURE);
 		}
@@ -324,10 +324,8 @@ int main (int argc, char **argv)
 
 	if (fpi == NULL) fpi = stdin;
 
-	GMT_put_history (argc, argv);   /* Update .gmtcommands4 */
-
 /* set up map projection and PS plotting */
-	GMT_map_setup (w, e, s, n);
+	GMT_err_fail (GMT_map_setup (w, e, s, n), "");
 	GMT_plotinit (argc, argv);
 
         /*if (project_info.three_D) ps_transrotate (-z_project.xmin, -z_project.ymin, 0.0);*/
