@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: segy2grd.c,v 1.16 2006/04/18 13:26:27 remko Exp $
+ *	$Id: segy2grd.c,v 1.23 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by T. Henstock
+ *	Copyright (c) 1991-2007 by T. Henstock
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -147,7 +147,7 @@ int main (int argc, char **argv)
 					break;
 			}
 		}
-		else if ((fpi = fopen (argv[i], "rb")) == NULL) {
+		else if ((fpi = GMT_fopen (argv[i], "rb")) == NULL) {
 			fprintf (stderr, "%s: Cannot find segy file %s\n", GMT_program,argv[i]);
 			exit (EXIT_FAILURE);
 		}
@@ -205,9 +205,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands */
-
-
 	GMT_grd_init (&grd, argc, argv, FALSE);
 
 	/* if (!project_info.region) d_swap (s, e); */  /* Got w/s/e/n, make into w/e/s/n */
@@ -226,7 +223,7 @@ int main (int argc, char **argv)
 	grd.y_min = s;	grd.y_max = n;
 	grd.x_inc = dx;	grd.y_inc = dy;
 
-	GMT_grd_RI_verify (&grd, 1);
+	GMT_err_fail (GMT_grd_RI_verify (&grd, 1), grdfile);
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: nx = %d  ny = %d\n", GMT_program, grd.nx, grd.ny);
 
@@ -434,10 +431,7 @@ overlaps a defined header in a strange way */
 		}
 	}
 
-	if (GMT_write_grd (grdfile, &grd, a, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, grdfile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (grdfile, &grd, a, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), grdfile);
 
 	GMT_free ((void *)a);
 	GMT_free ((void *)flag);
