@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: spectrum1d.c,v 1.27 2006/04/12 21:55:46 pwessel Exp $
+ *	$Id: spectrum1d.c,v 1.34 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -83,7 +83,7 @@ struct SPECTRUM1D_CTRL {
 	} D;
 	struct N {	/* -N<namestem> */
 		BOOLEAN active;
-		char *template;
+		char *name;
 	} N;
 	struct S {	/* -S<segment_size> */
 		BOOLEAN active;
@@ -176,8 +176,8 @@ int main (int argc, char **argv)
 				case 'N':
 					Ctrl->N.active = TRUE;
 					if (argv[i][2]) {
-						GMT_free ((void *)Ctrl->N.template);
-						Ctrl->N.template = strdup (&argv[i][2]);
+						GMT_free ((void *)Ctrl->N.name);
+						Ctrl->N.name = strdup (&argv[i][2]);
 					}
 					else {
 						fprintf (stderr, "%s: GMT SYNTAX ERROR -N option: Append a name stem\n", GMT_program);
@@ -264,8 +264,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -335,7 +333,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)x);
 	if (C.y_given) GMT_free ((void *)y);
 
-	write_output (&C, Ctrl->C.col, n_outputs, Ctrl->W.active, Ctrl->N.template);
+	write_output (&C, Ctrl->C.col, n_outputs, Ctrl->W.active, Ctrl->N.name);
 
 	free_space (&C);
 
@@ -486,136 +484,136 @@ void write_output (struct SPECTRUM1D_INFO *C, char *col, int n_outputs, BOOLEAN
 
 	/* loop through output choices */
 	for (j = 0; j < n_outputs; j++) {
-	  switch (col[j]) {
-	  case 'x':		/* write x power [ B&P 2nd Ed. eqn. 9.32 ] */
-	    sprintf(fname, "%s.xpower", namestem);
-	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
-	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
-	      exit (EXIT_FAILURE);
-	    }
-	    if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
-	    for (i = 0; i < C->n_spec; i++) {
-	      out[0] = f_or_w[i];
-	      out[1] = C->spec[i].xpow;
-	      out[2] = eps_pow * C->spec[i].xpow;
-	      GMT_output (fpout, 3, out);
-	    }
-	    GMT_fclose(fpout);
-	    break;
+		switch (col[j]) {
+		case 'x':		/* write x power [ B&P 2nd Ed. eqn. 9.32 ] */
+			sprintf(fname, "%s.xpower", namestem);
+			if ( (fpout = GMT_fopen (fname, GMT_io.w_mode)) == NULL) {
+				fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
+				exit (EXIT_FAILURE);
+			}
+			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
+			for (i = 0; i < C->n_spec; i++) {
+				out[0] = f_or_w[i];
+				out[1] = C->spec[i].xpow;
+				out[2] = eps_pow * C->spec[i].xpow;
+				GMT_output (fpout, 3, out);
+			}
+			GMT_fclose(fpout);
+			break;
 
-	  case 'y':		/* Write y power [ B&P 2nd Ed. eqn. 9.32 ] */
-	    sprintf(fname, "%s.ypower", namestem);
-	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
-	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
-	      exit (EXIT_FAILURE);
-	    }
-	    if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
-	    for (i = 0; i < C->n_spec; i++) {
-	      out[0] = f_or_w[i];
-	      out[1] = C->spec[i].ypow;
-	      out[2] = eps_pow * C->spec[i].ypow;
-	      GMT_output (fpout, 3, out);
-	    }
-	    GMT_fclose(fpout);
-	    break;
-	  case 'c':		/* Write Coherent Output power [ B&P 2nd Ed. eqn. 9.71 ] */
-	    sprintf(fname, "%s.cpower", namestem);
-	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
-	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
-	      exit (EXIT_FAILURE);
-	    }
-	    if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
-	    for (i = 0; i < C->n_spec; i++) {
-	      out[0] = f_or_w[i];
-	      out[1] = C->spec[i].ypow * C->spec[i].coh;
-	      out[2] = out[1] * eps_pow * sqrt( (2.0 - C->spec[i].coh) / C->spec[i].coh);
-	      GMT_output (fpout, 3, out);
-	    }
-	    GMT_fclose(fpout);
-	    break;
-	  case 'n':		/* Write Noise Output power [ B&P 2nd Ed. eqn. 9.73 & Table 9.6 ] */
-	    sprintf(fname, "%s.npower", namestem);
-	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
-	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
-	      exit (EXIT_FAILURE);
-	    }
-	    if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
-	    for (i = 0; i < C->n_spec; i++) {
-	      out[0] = f_or_w[i];
-	      out[1] = C->spec[i].ypow * (1.0 - C->spec[i].coh);
-	      out[2] = out[1] * eps_pow;
-	      GMT_output (fpout, 3, out);
-	    }
-	    GMT_fclose(fpout);
-	    break;
-	  case 'g':		/* Write Gain spectrum [ B&P 2nd Ed. eqn. 9.90 & Table 9.6 ] */
-	    sprintf(fname, "%s.gain", namestem);
-	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
-	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
-	      exit (EXIT_FAILURE);
-	    }
-	    if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
-	    for (i = 0; i < C->n_spec; i++) {
-	      out[0] = f_or_w[i];
-	      out[1] = C->spec[i].gain;
-	      out[2] = out[1] * eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
-	      GMT_output (fpout, 3, out);
-	    }
-	    GMT_fclose(fpout);
-	    break;
-	  case 'a':		/* Write Real Admittance spectrum  */
-	    /*   We don't know the correct error estimate and it is not
-		in Bendat and Piersol, or Priestly, or any standard text.
-		Smith needs to derive this, and should make a note to
-		check the expression given by Marcia Maia et al in Geophys. 
-		J. Int, 100, 337-348, 1990, equation 10, page 341.
-		Meanwhile we will default to use the expression related to
-		that for the gain spectrum:
-	    */
-	    sprintf(fname, "%s.admit", namestem);
-	    if ( (fpout = GMT_fopen(fname, "w")) == NULL) {
-	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
-	      exit (EXIT_FAILURE);
-	    }
-	    if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
-	    for (i = 0; i < C->n_spec; i++) {
-	      out[0] = f_or_w[i];
-	      out[1] = C->spec[i].radmit;
-	      out[2] = fabs (eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) ) * out[1]);
-	      GMT_output (fpout, 3, out);
-	    }
-	    GMT_fclose(fpout);
-	    break;
-	  case 'p':		/* Write Phase spectrum [ B&P 2nd Ed. eqn. 9.91 & Table 9.6 ] */
-	    sprintf(fname, "%s.phase", namestem);
-	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
-	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
-	      exit (EXIT_FAILURE);
-	    }
-	    if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
-	    for (i = 0; i < C->n_spec; i++) {
-	      out[0] = f_or_w[i];
-	      out[1] = C->spec[i].phase;
-	      out[2] = eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
-	      GMT_output (fpout, 3, out);
-	    }
-	    GMT_fclose(fpout);
-	  case 'o':		/* Write Coherency spectrum [ B&P 2nd Ed. eqn. 9.82 ] */
-	    sprintf(fname, "%s.coh", namestem);
-	    if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
-	      fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
-	      exit (EXIT_FAILURE);
-	    }
-	    if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
-	    for (i = 0; i < C->n_spec; i++) {
-	      out[0] = f_or_w[i];
-	      out[1] = C->spec[i].coh;
-	      out[2] = out[1] * eps_pow * (1.0 - C->spec[i].coh) * sqrt(2.0 / C->spec[i].coh);
-	      GMT_output (fpout, 3, out);
-	    }
-	    GMT_fclose(fpout);
-	    break;
-	  }
+		case 'y':		/* Write y power [ B&P 2nd Ed. eqn. 9.32 ] */
+			sprintf(fname, "%s.ypower", namestem);
+			if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
+				fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
+				exit (EXIT_FAILURE);
+			}
+			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
+			for (i = 0; i < C->n_spec; i++) {
+				out[0] = f_or_w[i];
+				out[1] = C->spec[i].ypow;
+				out[2] = eps_pow * C->spec[i].ypow;
+				GMT_output (fpout, 3, out);
+			}
+			GMT_fclose(fpout);
+			break;
+		case 'c':		/* Write Coherent Output power [ B&P 2nd Ed. eqn. 9.71 ] */
+			sprintf(fname, "%s.cpower", namestem);
+			if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
+				fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
+				exit (EXIT_FAILURE);
+			}
+			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
+			for (i = 0; i < C->n_spec; i++) {
+				out[0] = f_or_w[i];
+				out[1] = C->spec[i].ypow * C->spec[i].coh;
+				out[2] = out[1] * eps_pow * sqrt( (2.0 - C->spec[i].coh) / C->spec[i].coh);
+				GMT_output (fpout, 3, out);
+			}
+			GMT_fclose(fpout);
+			break;
+		case 'n':		/* Write Noise Output power [ B&P 2nd Ed. eqn. 9.73 & Table 9.6 ] */
+			sprintf(fname, "%s.npower", namestem);
+			if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
+				fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
+				exit (EXIT_FAILURE);
+			}
+			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
+			for (i = 0; i < C->n_spec; i++) {
+				out[0] = f_or_w[i];
+				out[1] = C->spec[i].ypow * (1.0 - C->spec[i].coh);
+				out[2] = out[1] * eps_pow;
+				GMT_output (fpout, 3, out);
+			}
+			GMT_fclose(fpout);
+			break;
+		case 'g':		/* Write Gain spectrum [ B&P 2nd Ed. eqn. 9.90 & Table 9.6 ] */
+			sprintf(fname, "%s.gain", namestem);
+			if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
+				fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
+				exit (EXIT_FAILURE);
+			}
+			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
+			for (i = 0; i < C->n_spec; i++) {
+				out[0] = f_or_w[i];
+				out[1] = C->spec[i].gain;
+				out[2] = out[1] * eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
+				GMT_output (fpout, 3, out);
+			}
+			GMT_fclose(fpout);
+			break;
+		case 'a':		/* Write Real Admittance spectrum
+			We don't know the correct error estimate and it is not
+			in Bendat and Piersol, or Priestly, or any standard text.
+			Smith needs to derive this, and should make a note to
+			check the expression given by Marcia Maia et al in Geophys. 
+			J. Int, 100, 337-348, 1990, equation 10, page 341.
+			Meanwhile we will default to use the expression related to
+			that for the gain spectrum:
+		*/
+			sprintf(fname, "%s.admit", namestem);
+			if ( (fpout = GMT_fopen(fname, "w")) == NULL) {
+				fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
+				exit (EXIT_FAILURE);
+			}
+			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
+			for (i = 0; i < C->n_spec; i++) {
+				out[0] = f_or_w[i];
+				out[1] = C->spec[i].radmit;
+				out[2] = fabs (eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) ) * out[1]);
+				GMT_output (fpout, 3, out);
+			}
+			GMT_fclose(fpout);
+			break;
+		case 'p':		/* Write Phase spectrum [ B&P 2nd Ed. eqn. 9.91 & Table 9.6 ] */
+			sprintf(fname, "%s.phase", namestem);
+			if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
+				fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
+				exit (EXIT_FAILURE);
+			}
+			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
+			for (i = 0; i < C->n_spec; i++) {
+				out[0] = f_or_w[i];
+				out[1] = C->spec[i].phase;
+				out[2] = eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
+				GMT_output (fpout, 3, out);
+			}
+			GMT_fclose(fpout);
+		case 'o':		/* Write Coherency spectrum [ B&P 2nd Ed. eqn. 9.82 ] */
+			sprintf(fname, "%s.coh", namestem);
+			if ( (fpout = GMT_fopen(fname, GMT_io.w_mode)) == NULL) {
+				fprintf(stderr,"%s:  Cannot open w %s\n", GMT_program, fname);
+				exit (EXIT_FAILURE);
+			}
+			if (gmtdefs.verbose) fprintf(stderr,"%s:  Writing %s\n", GMT_program, fname);
+			for (i = 0; i < C->n_spec; i++) {
+				out[0] = f_or_w[i];
+				out[1] = C->spec[i].coh;
+				out[2] = out[1] * eps_pow * (1.0 - C->spec[i].coh) * sqrt(2.0 / C->spec[i].coh);
+				GMT_output (fpout, 3, out);
+			}
+			GMT_fclose(fpout);
+			break;
+		}
 	}
 
 	GMT_free ((void *)f_or_w);
@@ -707,11 +705,11 @@ void *New_Spectrum1d_Ctrl () {	/* Allocate and initialize a new control structur
 	C->C.col[5] = 'a';
 	C->C.col[6] = 'g';
 	C->C.col[7] = 'o';
-	C->N.template = strdup ("spectrum");
+	C->N.name = strdup ("spectrum");
 	return ((void *)C);
 }
 
 void Free_Spectrum1d_Ctrl (struct SPECTRUM1D_CTRL *C) {	/* Deallocate control structure */
-	if (C->N.template) GMT_free ((void *)C->N.template);	
+	if (C->N.name) GMT_free ((void *)C->N.name);	
 	GMT_free ((void *)C);	
 }
