@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: splitxyz.c,v 1.29 2006/04/13 18:57:42 remko Exp $
+ *	$Id: splitxyz.c,v 1.38 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -57,7 +57,7 @@ struct SPLITXYZ_CTRL {
 	} M;
 	struct N {	/* -N<namestem> */
 		BOOLEAN active;
-		char *template;
+		char *name;
 	} N;
 	struct Q {	/* -Q[<xyzdg>] */
 		BOOLEAN active;
@@ -87,7 +87,7 @@ int main(int argc, char **argv)
 	double	mean_azim, fwork[SPLITXYZ_F_RES], *in, out[SPLITXYZ_N_OUTPUT_CHOICES];
 
  	char    buffer[BUFSIZ], filename[BUFSIZ];
- 
+
 	struct  DATA *data;
 	struct SPLITXYZ_CTRL *Ctrl;
 
@@ -161,7 +161,7 @@ int main(int argc, char **argv)
 				case 'N':
 					Ctrl->N.active = TRUE;
  					if (argv[i][2])
-						Ctrl->N.template = strdup (&argv[i][2]);
+						Ctrl->N.name = strdup (&argv[i][2]);
 					else {
 						fprintf (stderr, "%s: GMT SYNTAX ERROR -N option: Append a name stem\n", GMT_program);
 						error = TRUE;
@@ -225,7 +225,7 @@ int main(int argc, char **argv)
 		fprintf(stderr,"\t  where x,y,z refer to input data locations and optional values,\n");
 		fprintf(stderr,"\t  d,h are the distance and heading along track.\n");
 		fprintf(stderr,"\t  [Default is all fields, i.e. -Qxyzdh (or -Qxydh if -Z is set)]\n");
-		fprintf(stderr,"\t-S dh is supplied.  Input is 5 col x,y,z,d,h with d non-decreasing.\n");
+		fprintf(stderr,"\t-S d,h is supplied.  Input is 5 col x,y,z,d,h with d non-decreasing.\n");
 		fprintf(stderr,"\t     [Default input is 3 col x,y,z only and computes d,h from the data].\n");
 		fprintf(stderr,"\t-Z No z-values.  Input is 2 col x,y only\n");
 		GMT_explain_option ('V');
@@ -268,7 +268,7 @@ int main(int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
-	if (GMT_io.binary[GMT_OUT] && !Ctrl->N.template) {
+	if (GMT_io.binary[GMT_OUT] && !Ctrl->N.name) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary output requires a namestem in -N\n", GMT_program);
 		error++;
 	}
@@ -289,8 +289,6 @@ int main(int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -360,7 +358,7 @@ int main(int argc, char **argv)
 			fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %d\n", GMT_program, n_fields,  n_expected_fields, i);
 			exit (EXIT_FAILURE);
 
-}
+		}
 		i++;
                 if (ndata == n_alloc) {
                         n_alloc += GMT_CHUNK;
@@ -383,7 +381,7 @@ int main(int argc, char **argv)
 				}
 				else {
 					data[ndata].val[3] = data[ndata-1].val[3] + hypot(dx,dy);
-					data[ndata].val[4] = d_atan2(dy,dx);
+					data[ndata].val[4] = d_atan2(dy,dx);	/* Angles are stored as CCW angles in radians */
 				}
 			}
 			else {
@@ -396,7 +394,7 @@ int main(int argc, char **argv)
 			data[ndata].val[1] = in[1];
 			data[ndata].val[2] = in[2];
 			data[ndata].val[3] = in[3];
-			data[ndata].val[4] = D2R * (90.0 - in[4]);
+			data[ndata].val[4] = D2R * (90.0 - in[4]);	/* Angles are stored as CCW angles in radians */
 			ndata++;
 		}
 	}
@@ -434,8 +432,7 @@ int main(int argc, char **argv)
 	end = begin;
 	while (end < ndata-1) {
 		last_d = data[begin].val[3];
-		last_c = cos(data[begin].val[4]);
-		last_s = sin(data[begin].val[4]);
+		sincos (data[begin].val[4], &last_s, &last_c);
 		csum = last_c;
 		ssum = last_s;
 		ok = TRUE;
@@ -446,8 +443,7 @@ int main(int argc, char **argv)
 				ok = FALSE;
 				continue;
 			}
-			this_c = cos(data[end].val[4]);
-			this_s = sin(data[end].val[4]);
+			sincos (data[end].val[4], &this_s, &this_c);
 			dotprod = this_c * last_c + this_s * last_s;
 			if (fabs(dotprod) > 1.0) dotprod = copysign(1.0, dotprod);
 			if (d_acos(dotprod) > Ctrl->C.value) {
@@ -487,10 +483,10 @@ int main(int argc, char **argv)
 					if (Ctrl->F.xy_filter != 0.0) filterxy(data, begin, end, Ctrl->F.xy_filter, fwork, hilow);
 					nprofiles++;
 
-					/* If (Ctrl->N.template) we write separate files, else GMT_stdout with > marks:  */
+					/* If (Ctrl->N.name) we write separate files, else GMT_stdout with > marks:  */
 
-					if (Ctrl->N.template) {
-						sprintf(filename, "%s.profile%d", Ctrl->N.template, nprofiles);
+					if (Ctrl->N.name) {
+						sprintf(filename, "%s.profile%d", Ctrl->N.name, nprofiles);
 						if ( (fpout = GMT_fopen(filename, GMT_io.w_mode)) == NULL) {
 							fprintf(stderr,"%s:  Cannot create %s\n", GMT_program, argv[i]);
 							exit (EXIT_FAILURE);
@@ -500,7 +496,9 @@ int main(int argc, char **argv)
 						fprintf (GMT_stdout, "> Start profile # %d\n", nprofiles);
 
 					for (i = begin; i < end; i++) {
-						for (j = 0; j < n_outputs; j++) out[j] = data[i].val[output_choice[j]];
+						for (j = 0; j < n_outputs; j++) {	/* Remember to convert CCW angles back to azimuths */
+							out[j] = (output_choice[j] == 4) ? 90.0 - R2D * data[i].val[4] : data[i].val[output_choice[j]];
+						}
 						GMT_output (fpout, n_outputs, out);
 					}
 
