@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: backtracker.c,v 1.17 2004/04/25 08:47:07 pwessel Exp $
+ *	$Id: backtracker.c,v 1.31 2007/03/12 19:52:27 remko Exp $
  *
- *   Copyright (c) 1999-2004 by P. Wessel
+ *   Copyright (c) 1999-2007 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@
 
 #include "spotter.h"
 
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
 	struct EULER *p;		/* Pointer to array of stage poles */
 
@@ -97,7 +97,7 @@ main (int argc, char **argv)
 
 	double d_km = 0.0;		/* Step interval along calculated tracks */
 	double t_zero = 0.0;		/* Current age in Ma */
-	double t_fix;			/* Fixed age in Ma */
+	double t_fix = 0.0;			/* Fixed age in Ma */
 	double upper_age = 0.0;		/* Extend oldest age back to this time, in Ma */
 	double *c;			/* Array of track chunks returned by libeuler routines */
 	double lon, lat;		/* Seamounts location in decimal degrees */
@@ -110,7 +110,7 @@ main (int argc, char **argv)
 	char buffer[BUFSIZ];		/* Input buffer for reading data */
 	char type[50];			/* What kind of line (flowline or hotspot track) */
 	char dir[8];			/* From or To */
-	char conf_flag;			/* t for time, a for angle, blank for nothing */
+	char conf_flag = 0;		/* t for time, a for angle, blank for nothing */
 
 	FILE *fp = NULL;		/* File pointer for input data */
 	FILE *fpo = NULL;		/* File pointer for output data */
@@ -118,7 +118,7 @@ main (int argc, char **argv)
 	PFI spot_func;			/* Pointer to the required forth/back track function */
 
 	out = (double *)NULL;
-	
+
 	argc = GMT_begin (argc, argv);
 
 #ifdef DEBUG
@@ -133,18 +133,18 @@ main (int argc, char **argv)
 			switch (argv[i][1]) {
 
 				/* Common parameters */
-			
+
 				case 'H':
 				case 'V':
 				case ':':
 				case '\0':
-					error += GMT_get_common_args (argv[i], NULL, NULL, NULL, NULL);
+					error += GMT_parse_common_options (argv[i], NULL, NULL, NULL, NULL);
 					break;
-				
+
 				/* Supplemental parameters */
-				
+
 				case 'b':
-					error += GMT_io_selection (&argv[i][2]);
+					error += GMT_parse_b_option (&argv[i][2]);
 					break;
 
 				case 'A':	/* Output only an age-limited segment of the track */
@@ -156,7 +156,7 @@ main (int argc, char **argv)
 						track_limit = 2;
 					}
 					break;
-					
+
 				case 'C':	/* Use finite rotation poles */
 					finite = TRUE;
 					break;
@@ -244,12 +244,12 @@ main (int argc, char **argv)
 		else
 			n_files++;
 	}
-	
-	if (argc == 1 || GMT_quick) {
+
+	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "%s %s - Forward and backward flowlines and hotspot tracks\n\n", GMT_program, SPOTTER_VERSION);
-		fprintf (stderr, "usage: %s [infile(s)] -E<euler.d> [-A[young/old]] [-C] [-Df|b] [-H[<nrec>]] [-Lf|b<d_km>]\n", GMT_program);
-		fprintf (stderr, "\t[-M[<flag>]] [-N<upper_age>] [-Q<t_fix>] [-S<stem>] [-T<t_zero>] [-V] [-W] [-:] [-bi[s][<n>]] [-bo[s]]\n\n");
-		if (GMT_quick) exit (EXIT_FAILURE);
+		fprintf (stderr, "usage: %s [infile(s)] -E<euler.d> [-A[young/old]] [-C] [-Df|b] [%s] [-Lf|b<d_km>]\n", GMT_program, GMT_H_OPT);
+		fprintf (stderr, "\t[%s] [-N<upper_age>] [-Q<t_fix>] [-S<stem>] [-T<t_zero>] [-V] [-W] [%s] [%s]\n\n", GMT_M_OPT, GMT_t_OPT, GMT_b_OPT);
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf (stderr, "\tinfiles (in ASCII or binary) has 3 or more columns.  If no file(s) is given, standard input is read.\n");
 		fprintf (stderr, "\tFirst 3 columns must have lon, lat (or lat, lon, see -:) and age (Ma)\n");
@@ -291,7 +291,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  -W cannot be set if -Lf or -Df are set\n", GMT_program);
 		error++;
 	}
-	if (GMT_io.binary[GMT_IN] && gmtdefs.io_header[GMT_IN]) {
+	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
@@ -303,8 +303,6 @@ main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	/* Load in the stage poles */
 
 	n_stages = spotter_init (euler_file, &p, flowline, finite, finite_out, &upper_age, gmtdefs.verbose);
@@ -316,7 +314,7 @@ main (int argc, char **argv)
 
 	spot_func = ((flowline + forward) == 1) ? spotter_forthtrack : spotter_backtrack;
 
-	if (fabs (d_km) > SMALL) {		/* User wants to interpolate tracks rather than project individual points */
+	if (fabs (d_km) > GMT_SMALL) {		/* User wants to interpolate tracks rather than project individual points */
 		make_path = TRUE;
 		(flowline) ? sprintf (type, "Flowline") : sprintf (type, "Hotspot track");
 		(forward) ? sprintf (dir, "from") : sprintf (dir, "to");
@@ -324,11 +322,11 @@ main (int argc, char **argv)
 	else if (track_limit > 0) {	/* Limits on track set but track option not selected */
                 fprintf (stderr, "%s: GMT SYNTAX ERROR.  -A requires -L\n", GMT_program);
 		exit (EXIT_FAILURE);
-	}	
+	}
 
 	fpo = GMT_stdout;
 	n_out = (seg_files) ? 4 : 3;	/* Append smt id number as 4th column when individual files are requested */
-	
+
 	/* Read the seamount data from file or stdin */
 
 	n_points = n_segments = 0;
@@ -342,10 +340,10 @@ main (int argc, char **argv)
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3 + ((track_limit == 2) ? 2 : 0);
 	if (fix_all && !GMT_io.ncol[GMT_IN]) n_expected_fields = 2;	/* Lon, lat only; use fixed t */
 	if (confidence) n_out = 5 + !(conf_flag == 0);
-	
+
 	for (fno = 1; !done && fno < n_args; fno++) {	/* Loop over input files, if any */
 		if (!nofile && argv[fno][0] == '-') continue;
-		
+
 		if (nofile) {	/* Just read standard input */
 			fp = GMT_stdin;
 			done = TRUE;
@@ -357,11 +355,11 @@ main (int argc, char **argv)
 		}
 
 		if (!nofile && gmtdefs.verbose) fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
-		
-		if (gmtdefs.io_header[GMT_IN]) {
-			for (i = 0; i < gmtdefs.n_header_recs; i++) {
+
+		if (GMT_io.io_header[GMT_IN]) {
+			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				GMT_fgets (buffer, BUFSIZ, fp);
-				if (first && !GMT_io.binary[GMT_OUT] && gmtdefs.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", buffer);
+				if (first && !GMT_io.binary[GMT_OUT] && GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", buffer);
 			}
 			first = FALSE;
 		}
@@ -395,18 +393,18 @@ main (int argc, char **argv)
 			}
 			else
 				age = in[2];
-				
+
 			if (age > upper_age) {	/* Points older than oldest stage cannot be used */
-				fprintf (stderr, "%s: Seamount at line %d has age (%lg) > oldest stage (%lg) (skipped)\n", GMT_program, n_read, in[2], upper_age);
+				fprintf (stderr, "%s: Seamount at line %d has age (%g) > oldest stage (%g) (skipped)\n", GMT_program, n_read, in[2], upper_age);
 				n_skipped++;
 				continue;
 			}
-			
+
 			if (!confidence) n_chunk = (*spot_func) (&lon, &lat, &age, 1, p, n_stages, d_km, t_zero, TRUE + stage_id, NULL, &c);
 
 			if (make_path) {	/* Asked for paths, now write out several multiple segment tracks */
 				if (seg_files) {
-					sprintf (buffer, "%s.%d\0", file_stem, n_points);
+					sprintf (buffer, "%s.%d", file_stem, n_points);
 					if ((fpo = GMT_fopen (buffer, GMT_io.w_mode)) == NULL) {
 						fprintf (stderr, "%s: Error - cannot create file %s\n", GMT_program, buffer);
 						exit (EXIT_FAILURE);
@@ -415,7 +413,7 @@ main (int argc, char **argv)
 				}
 				i = 0;
 				n_track = irint (c[i++]);
-				sprintf (GMT_io.segment_header, "> %s %s %lg %lg\n\0", type, dir, in[0], in[1]);
+				sprintf (GMT_io.segment_header, "> %s %s %g %g\n", type, dir, in[0], in[1]);
 				GMT_write_segmentheader (fpo, n_out);
 				for (j = 0; j < n_track; j++, i += 3) {
 					out[2] = c[i+2];
@@ -425,13 +423,13 @@ main (int argc, char **argv)
 					GMT_output (fpo, n_out, out);
 				}
 				if (seg_files) GMT_fclose (fpo);
-				
+
 				GMT_free ((void *)c);
 			}
 			else {	/* Just return the projected locations */
 				if (confidence) {	/* Asked for confidence ellipses on reconstructed points */
 					if (spotter_conf_ellipse (in[0], in[1], age, p, n_stages, conf_flag, out)) {
-						fprintf (stderr, "%s: Confidence ellipses only for the age of rotations.  Point with age %lg skipped\n", GMT_program, age);
+						fprintf (stderr, "%s: Confidence ellipses only for the age of rotations.  Point with age %g skipped\n", GMT_program, age);
 						continue;
 					}
 				}
@@ -461,4 +459,6 @@ main (int argc, char **argv)
 	/* Clean up and exit */
 
 	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
 }
