@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: hotspotter.c,v 1.3.4.1 2002/01/17 17:42:52 pwessel Exp $
+ *	$Id: hotspotter.c,v 1.28 2007/03/12 19:52:27 remko Exp $
  *
- *   Copyright (c) 1999-2002 by P. Wessel
+ *   Copyright (c) 1999-2007 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *   GNU General Public License for more details.
  *
- *   Contact info: www.soest.hawaii.edu/wessel
+ *   Contact info: www.soest.hawaii.edu/pwessel
  *--------------------------------------------------------------------*/
 /*
  * HOTSPOTTER will (1) read ascii file(s) with records for each seamount
@@ -107,7 +107,7 @@
  
 #include "spotter.h"
 
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
 
 	int n_smts;		/* Number of seamounts read */
@@ -135,10 +135,12 @@ main (int argc, char **argv)
 	BOOLEAN truncate_ages = FALSE;	/* Truncate all seamounts ages > upper_age */
 	BOOLEAN finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
 	BOOLEAN done;
-	
+	BOOLEAN resize = FALSE;
+
 	float *CVA;			/* The CVA surface we seek to calculate */
 
 	double sampling_int_in_km;	/* Sampling interval along flowline (in km) */
+	double sampling_factor = 0.5;	/* Sets how many points along flowline per node */
 	double upper_age = 180.0;	/* Upper age assigned to seamounts on undated seafloor */
 	double x_smt;			/* Seamount longitude (input degrees, stored as radians) */
 	double y_smt;			/* Seamount latitude (input degrees, stored as radians) */
@@ -164,45 +166,51 @@ main (int argc, char **argv)
 	char *euler_file = CNULL;	/* Input name of file with stage (Euler) rotations */
 	char line[BUFSIZ];		/* Read buffer */
 	char *processed_node;		/* Pointer to array with TRUE/FALSE values for each grid node */
-	
+
 	FILE *fp;			/* Input data file pointer */
-	
+
 	struct GRD_HEADER CVA_map;	/* Header structure for output CVA grid */
-	
+
 	struct EULER *p;		/* Array of structures with Euler stage rotations */
 
 	/* ------------------- END OF DECLARATIONS ------------------------------------------------------------*/
 
 	argc = GMT_begin (argc, argv);			/* Initialize GMT environment */
-		
+
 	GMT_grd_init (&CVA_map, argc, argv, FALSE);	/* Initialize grid structure */
-	
+
+	GMT_io.in_col_type[0] = GMT_IS_LON;
+	GMT_io.in_col_type[1] = GMT_IS_LAT;
+
 	/* Check command line arguments */
-	
+
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
-			
+
 				/* Common parameters */
-			
+
 				case 'V':
 				case 'H':
 				case 'R':
 				case ':':
 				case '\0':
-					error += GMT_get_common_args (argv[i], &CVA_map.x_min, &CVA_map.x_max, &CVA_map.y_min, &CVA_map.y_max);
+					error += GMT_parse_common_options (argv[i], &CVA_map.x_min, &CVA_map.x_max, &CVA_map.y_min, &CVA_map.y_max);
 					break;
-				
+
 				/* Supplemental parameters */
-				
+
 				case 'b':
-					error += GMT_io_selection (&argv[i][2]);
+					error += GMT_parse_b_option (&argv[i][2]);
 					break;
 
 				case 'C':	/* Use finite rotation poles */
 					finite = TRUE;
 					break;
 
+				case 'D':
+					sampling_factor = atof (&argv[i][2]);
+					break;
 				case 'E':
 					euler_file = &argv[i][2];
 					break;
@@ -218,6 +226,9 @@ main (int argc, char **argv)
 				case 'N':
 					upper_age = atof (&argv[i][2]);
 					break;
+				case 'S':
+					resize = TRUE;
+					break;
 				case 'T':
 					truncate_ages = TRUE;
 					break;
@@ -231,13 +242,13 @@ main (int argc, char **argv)
 			n_files++;
 	}
 
-	if (argc == 1 || GMT_quick) {
+	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "%s %s - Create CVA image from seamount locations\n\n", GMT_program, SPOTTER_VERSION);
-		fprintf (stderr, "usage: %s [<files>] -E<stage_file> -G<CVAgrid> -I<dx[m|c]>[/<dy>[m|c]]\n", GMT_program);
-		fprintf (stderr, "\t-R<west/east/south/north> [-C] [-F] [-H[<nrecs>]] [-N<upper_age>] [-T] [-V] [-:] [-bi[s][<n>]]\n\n");
-		
-		if (GMT_quick) exit (EXIT_FAILURE);
-		
+		fprintf (stderr, "usage: %s [<files>] -E<stage_file> -G<CVAgrid> %s\n", GMT_program, GMT_Id_OPT);
+		fprintf (stderr, "\t%s [-C] [-D<factor>] [-F] [%s] [-N<upper_age>] [-T] [-V] [%s] [%s]\n\n", GMT_Rgeo_OPT, GMT_H_OPT, GMT_t_OPT, GMT_bi_OPT);
+
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
+
 		fprintf (stderr, "\t<files> is one or more seamount (x,y,z,r,t) files\n");
 		fprintf (stderr, "\t-G Specify file name for output CVA grid.\n");
 		GMT_explain_option ('H');
@@ -245,6 +256,7 @@ main (int argc, char **argv)
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t-C The file given with -E contains finite rotation poles [Default is stage poles]\n");
+		fprintf (stderr, "\t-D Scale affecting distance between points along flowline [0.5]\n");
 		fprintf (stderr, "\t-F Force pixel-registration [Default is gridline registration]\n");
 		fprintf (stderr, "\t-N sets upper age in m.y. for seamounts whose plate age is NaN [180]\n");
 		fprintf (stderr, "\t-T truncate all ages to max age in stage pole model [Default extrapolates]\n");
@@ -268,25 +280,23 @@ main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G:  Must specify output file\n", GMT_program);
 		error = TRUE;
 	}
-	if (GMT_io.binary[0] && gmtdefs.io_header) {
+	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
-        if (GMT_io.binary[0] && GMT_io.ncol[0] == 0) GMT_io.ncol[0] = 5;
-        if (GMT_io.binary[0] && GMT_io.ncol[0] < 5) {
+        if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = 5;
+        if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < 5) {
                 fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least 5 columns\n", GMT_program);
 		error++;
 	}
-	
-	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands */
+	if (error) exit (EXIT_FAILURE);
 
 	/* ------------------- END OF PROCESSING COMMAND LINE ARGUMENTS  --------------------------------------*/
 
 	/* Load in the Euler stage poles */
 
-	n_stages = spotter_init (euler_file, &p, TRUE, finite, &upper_age);
+	n_stages = spotter_init (euler_file, &p, TRUE, finite, FALSE, &upper_age, gmtdefs.verbose);
 
 	/* Initialize the CVA grid and structure */
 
@@ -339,16 +349,16 @@ main (int argc, char **argv)
 
 	/* Set flowline sampling interval to 1/2 of the shortest distance between x-nodes */
 
-	sampling_int_in_km = 0.5 * xinc_r * EQ_RAD * ((fabs (north) > fabs (south)) ? cos (north) : cos (south));
-	if (gmtdefs.verbose) fprintf (stderr, "%s: Flowline sampling interval = %.3lf km\n", GMT_program, sampling_int_in_km);
+	sampling_int_in_km = sampling_factor * xinc_r * EQ_RAD * ((fabs (north) > fabs (south)) ? cos (north) : cos (south));
+	if (gmtdefs.verbose) fprintf (stderr, "%s: Flowline sampling interval = %.3f km\n", GMT_program, sampling_int_in_km);
 
-	if (truncate_ages && gmtdefs.verbose) fprintf (stderr, "%s: Seamount ages truncated to %lg\n", GMT_program, upper_age);
+	if (truncate_ages && gmtdefs.verbose) fprintf (stderr, "%s: Seamount ages truncated to %g\n", GMT_program, upper_age);
 
 	/* Start to read input data */
 
-	if (GMT_io.binary[0] && gmtdefs.verbose) {
+	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[0], type[GMT_io.single_precision[0]]);
+		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 	if (n_files > 0)
@@ -356,12 +366,12 @@ main (int argc, char **argv)
 	else
 		n_files = 1;
 	n_args = (argc > 1) ? argc : 2;
-	
+
 	done = FALSE;
 
 	n_smts = 0;
 
-	n_expected_fields = (GMT_io.ncol[0]) ? GMT_io.ncol[0] : 5;
+	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 5;
 
 	for (fno = 1; !done && fno < n_args; fno++) {	/* Loop over all input files */
 
@@ -376,9 +386,9 @@ main (int argc, char **argv)
 		}
 
 		if (gmtdefs.verbose) (nofile) ? fprintf (stderr, "%s: Reading stdin\n", GMT_program) : fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
-		
-		if (gmtdefs.io_header) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
-		
+
+		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
+
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 			n_read++;
 			while ((GMT_io.status & GMT_IO_SEGMENT_HEADER) && !(GMT_io.status & GMT_IO_EOF)) {
@@ -392,13 +402,17 @@ main (int argc, char **argv)
 				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %d (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
 				continue;
 			}
-	
+
 			/* STEP 1: Read information about a single seamount from input record */
 
 			x_smt = in[0] * D2R;	/* Seamount positions in RADIANS */
 			y_smt = in[1] * D2R;
 			z_smt = in[2];
 			r_smt = in[3];
+			if (resize) {
+				z_smt = 1.0;
+				/* r_smt = 2.0 * yinc_r * EQ_RAD; */
+			}
 			if (GMT_is_dnan (in[4])) {	/* Age is NaN, assign value */
 				t_smt = upper_age;
 			}
@@ -409,7 +423,7 @@ main (int argc, char **argv)
 						t_smt = upper_age;
 					}
 					else {
-						fprintf (stderr, "%s: Seamounts near line %d has age (%lg) > oldest stage (%lg) (skipped)\n", GMT_program, n_read, t_smt, upper_age);
+						fprintf (stderr, "%s: Seamounts near line %d has age (%g) > oldest stage (%g) (skipped)\n", GMT_program, n_read, t_smt, upper_age);
 						continue;
 					}
 				}
@@ -423,7 +437,7 @@ main (int argc, char **argv)
 
 			/* STEP 2: Calculate this seamount's flowline */
 
-			n_chunk = spotter_forthtrack (&x_smt, &y_smt, &t_smt, 1, p, n_stages, sampling_int_in_km, 0.0, FALSE, &c);
+			n_chunk = spotter_forthtrack (&x_smt, &y_smt, &t_smt, 1, p, n_stages, sampling_int_in_km, 0.0, FALSE, NULL, &c);
 
 			/* STEP 3: Convolve this flowline with seamount shape and add to CVA grid */
 
@@ -491,10 +505,10 @@ main (int argc, char **argv)
 
 			if (gmtdefs.verbose && !(n_smts%100)) fprintf (stderr, "%s: Processed %5d seamounts\r", GMT_program, n_smts);
 		}
-		
+
 		if (fp != stdin) GMT_fclose (fp);
 	}
-	
+
 	/* OK, Done processing, time to write out */
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Processed %5d seamounts\n", GMT_program, n_smts);
@@ -503,10 +517,7 @@ main (int argc, char **argv)
 
 	dummy[0] = dummy[1] = dummy[2] = dummy[3] = 0;	/* No grid boundary padding today */
 
-	if (GMT_write_grd (CVA_file, &CVA_map, CVA, 0.0, 0.0, 0.0, 0.0, dummy, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, CVA_file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (CVA_file, &CVA_map, CVA, 0.0, 0.0, 0.0, 0.0, dummy, FALSE), CVA_file);
 
 	/* Clean up memory */
 
@@ -516,8 +527,10 @@ main (int argc, char **argv)
 	GMT_free ((void *)ilatfactor);
 	GMT_free ((void *)xpos);
 	GMT_free ((void *)ypos);
-	
+
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done\n", GMT_program);
 
 	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
 }
