@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: libspotter.c,v 1.33 2006/04/10 04:43:31 pwessel Exp $
+ *	$Id: libspotter.c,v 1.38 2007/03/05 21:47:11 pwessel Exp $
  *
- *   Copyright (c) 1999-2006 by P. Wessel
+ *   Copyright (c) 1999-2007 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -77,9 +77,9 @@ int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in,
 
 	e = (struct EULER *) GMT_memory (VNULL, n_alloc, sizeof (struct EULER), "libspotter");
 
-	if ((fp = fopen (file, "r")) == NULL) {
+	if ((fp = GMT_fopen (file, "r")) == NULL) {
 		fprintf (stderr, "libspotter: ERROR: Cannot open stage pole file: %s\n", file);
-		exit (EXIT_FAILURE);
+		GMT_exit (EXIT_FAILURE);
 	}
 
 	if (flowline) finite_out = TRUE;	/* Override so we get finite poles for conversion to forward stage poles at the end */
@@ -115,27 +115,27 @@ int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in,
 
 		if (e[i].t_stop >= e[i].t_start) {
 			fprintf (stderr, "libspotter: ERROR: Stage rotation %d has start time younger than stop time\n", i);
-			exit (EXIT_FAILURE);
+			GMT_exit (EXIT_FAILURE);
 		}
 		e[i].duration = e[i].t_start - e[i].t_stop;
 		if (finite_in) {
 			if (e[i].t_start < last_t) {
 				fprintf (stderr, "libspotter: ERROR: Finite rotations must go from youngest to oldest\n");
-				exit (EXIT_FAILURE);
+				GMT_exit (EXIT_FAILURE);
 			}
 			last_t = e[i].t_start;
 		}
 		else {
 			if (e[i].t_stop > last_t) {
 				fprintf (stderr, "libspotter: ERROR: Stage rotations must go from oldest to youngest\n");
-				exit (EXIT_FAILURE);
+				GMT_exit (EXIT_FAILURE);
 			}
 			last_t = e[i].t_stop;
 		}
 		e[i].omega /= e[i].duration;	/* Convert to opening rate */
 
 		e[i].omega_r = e[i].omega * D2R;
-		sincos (e[i].lat * D2R, &e[i].sin_lat, &e[i].cos_lat);
+		sincosd (e[i].lat, &e[i].sin_lat, &e[i].cos_lat);
 		e[i].lon_r = e[i].lon * D2R;
 		e[i].lat_r = e[i].lat * D2R;
 		i++;
@@ -234,7 +234,7 @@ int spotter_backtrack (double xp[], double yp[], double tp[], int np, struct EUL
 			while (j < ns && t <= p[j].t_stop) j++;	/* Find first applicable stage pole */
 			if (j == ns) {
 				fprintf (stderr, "libspotter: (spotter_backtrack) Ran out of stage poles for t = %g\n", t);
-				exit (EXIT_FAILURE);
+				GMT_exit (EXIT_FAILURE);
 			}
 			dt = MIN (p[j].duration, t - MAX(p[j].t_stop, t_zero));
 			d_lon = p[j].omega_r * dt;
@@ -448,7 +448,7 @@ int spotter_forthtrack (double xp[], double yp[], double tp[], int np, struct EU
 			/* while (j < ns && (t + GMT_CONV_LIMIT) < p[j].t_stop) j++; */	/* Find first applicable stage pole */
 			if (j == ns) {
 				fprintf (stderr, "libspotter: (spotter_forthtrack) Ran out of stage poles for t = %g\n", t);
-				exit (EXIT_FAILURE);
+				GMT_exit (EXIT_FAILURE);
 			}
 			dt = MIN (tp[i], p[j].t_start) - t;	/* Time interval to rotate */
 			d_lon = p[j].omega_r * dt;		/* Rotation angle (radians) */
@@ -863,7 +863,7 @@ void make_rot_matrix_sub (double E[3], double w, double R[3][3])
 
 	double sin_w, cos_w, c, E_x, E_y, E_z, E_12c, E_13c, E_23c;
 
-	sincos (w * D2R, &sin_w, &cos_w);
+	sincosd (w, &sin_w, &cos_w);
 	c = 1 - cos_w;
 
 	E_x = E[0] * sin_w;
