@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: originator.c,v 1.28 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: originator.c,v 1.34 2007/04/02 15:25:57 remko Exp $
  *
- *   Copyright (c) 2000-2006 by P. Wessel
+ *   Copyright (c) 2000-2007 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -112,7 +112,7 @@ int main (int argc, char **argv)
 	BOOLEAN	error = FALSE, done, nofile = TRUE, truncate_ages = FALSE, first = TRUE, better;
 	BOOLEAN finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
 
-	double x_smt, y_smt, z_smt, r_smt, t_smt, *c, *in, d_km = 5.0, upper_age = 180.0, dist, plon, plat, out[3];
+	double x_smt, y_smt, z_smt, r_smt, t_smt, *c, *in, d_km = 5.0, upper_age = 180.0, dist, plon, plat, out[5];
 	double max_dist = 1.0e100, hx_dist, hx_dist_km, dist_NA, dist_NX, del_dist, dt = 0.0, A[3], H[3], N[3], X[3], dlon;
 
 	char *hsfile = CNULL, *efile = CNULL, age[GMT_TEXT_LEN];
@@ -498,7 +498,7 @@ int hotspot_init (char *file, struct HOTSPOT **p)
 	int i = 0;
 	size_t n_alloc = GMT_CHUNK;
 
-	if ((fp = fopen (file, "r")) == NULL) {
+	if ((fp = GMT_fopen (file, "r")) == NULL) {
 		fprintf (stderr, "%s: Cannot open file %s - aborts\n", GMT_program, file);
 		exit (EXIT_FAILURE);
 	}
