@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: surface.c,v 1.36 2006/05/11 05:14:12 pwessel Exp $
+ *	$Id: surface.c,v 1.43 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -376,7 +376,7 @@ int main (int argc, char **argv)
 			}
 		}
 		else {
-			if ((fp_in = GMT_fopen(argv[i], GMT_io.r_mode)) == NULL) {
+			if ((fp_in = GMT_fopen (argv[i], GMT_io.r_mode)) == NULL) {
 				fprintf (stderr, "surface: cannot open input data file %s\n", argv[i]);
 				exit (EXIT_FAILURE);
 			}
@@ -478,8 +478,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -488,7 +486,7 @@ int main (int argc, char **argv)
 	load_parameters (&C, Ctrl);	/* Pass parameters from parsing control to surface INFO structure */
 	
 	GMT_RI_prepare (&C.h);	/* Ensure -R -I consistency and set nx, ny */
-	GMT_grd_RI_verify (&C.h, 1);
+	GMT_err_fail (GMT_grd_RI_verify (&C.h, 1), Ctrl->G.file);
 
 	C.relax_old = 1.0 - C.relax_new;
 
@@ -1111,10 +1109,7 @@ void write_output (struct SURFACE_INFO *C, char *grdfile)
 		}
 	}
 	
-	if (GMT_write_grd (grdfile, &(C->h), v2, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, grdfile);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (grdfile, &(C->h), v2, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), grdfile);
 	GMT_free ((void *)v2);
 	if (C->set_low) GMT_free ((void *)C->lower);
 	if (C->set_high) GMT_free ((void *)C->upper);
@@ -1656,18 +1651,12 @@ void load_constraints (struct SURFACE_INFO *C, BOOLEAN transform)
 		if (C->set_low < 3)
 			for (i = 0; i < C->nx * C->ny; i++) C->lower[i] = (float)C->low_limit;
 		else {
-			if (GMT_read_grd_info (C->low_file, &hdr)) {
-				fprintf (stderr, "%s: Error opening file %s\n", GMT_program, C->low_file);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd_info (C->low_file, &hdr), C->low_file);
 			if (hdr.nx != C->nx || hdr.ny != C->ny) {
 				fprintf (stderr, "%s: lower limit file not of proper dimension!\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			if (GMT_read_grd (C->low_file, &hdr, C->lower, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, C->low_file);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (C->low_file, &hdr, C->lower, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), C->low_file);
 		}
 		if (transform) {
 			for (j = ij = 0; j < C->ny; j++) {
@@ -1686,18 +1675,12 @@ void load_constraints (struct SURFACE_INFO *C, BOOLEAN transform)
 		if (C->set_high < 3)
 			for (i = 0; i < C->nx * C->ny; i++) C->upper[i] = (float)C->high_limit;
 		else {
-			if (GMT_read_grd_info (C->high_file, &hdr)) {
-				fprintf (stderr, "%s: Error opening file %s\n", GMT_program, C->high_file);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd_info (C->high_file, &hdr), C->high_file);
 			if (hdr.nx != C->nx || hdr.ny != C->ny) {
 				fprintf (stderr, "%s: upper limit file not of proper dimension!\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			if (GMT_read_grd (C->high_file, &hdr, C->upper, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-				fprintf (stderr, "%s: Error reading file %s\n", GMT_program, C->high_file);
-				exit (EXIT_FAILURE);
-			}
+			GMT_err_fail (GMT_read_grd (C->high_file, &hdr, C->upper, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), C->high_file);
 		}
 		if (transform) {
 			for (j = ij = 0; j < C->ny; j++) {
