@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: trend1d.c,v 1.3.4.7 2004/01/02 22:23:11 pwessel Exp $
+ *	$Id: trend1d.c,v 1.35 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -100,132 +100,142 @@
  * Revised:	11 June, 1991-2000 for v2.0 of GMT-SYSTEM.
  *		13-JUN-1998, for GMT 3.1 (PW)
  *		13-JUL-2000, for GMT 3.3.5 (PW)
- * Version:	3.4.3
+ *		10-MAY-2001, PW: Use Numerical Recipes scheme to also output polynomial coefficients
+ * Version:	3.4 18-APR-2001
+ * Version:	4.1.x
  */
 
 #include "gmt.h"
 
-#define N_OUTPUT_CHOICES 5
+#define TREND1D_N_OUTPUT_CHOICES 5
 
-#define POLYNOMIAL 0
-#define FOURIER 1
+struct TREND1D_CTRL {
+	struct C {	/* -C<condition_#> */
+		BOOLEAN active;
+		double value;
+	} C;
+	struct F {	/* -F<xymrw> */
+		BOOLEAN active;
+		char col[TREND1D_N_OUTPUT_CHOICES];	/* Character codes for desired output in the right order */
+	} F;
+	struct I {	/* -I[<confidence>] */
+		BOOLEAN active;
+		double value;
+	} I;
+	struct N {	/* -N[f]<n_model>[r] */
+		BOOLEAN active;
+		BOOLEAN robust;
+		int mode;
+		int value;
+	} N;
+	struct W {	/* -W */
+		BOOLEAN active;
+	} W;
+};
 
-struct	DATA {
+#define TREND1D_POLYNOMIAL 0
+#define TREND1D_FOURIER 1
+
+struct	TREND1D_DATA {
 	double	x;
 	double	y;
 	double	m;
 	double	r;
 	double	w;
-}	*data;
+};
 
-
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
-	void	read_data(struct DATA **data, int *n_data, double *xmin, double *xmax, int weighted_input, double **work, FILE *fp);
-	void write_output(struct DATA *data, int n_data, char *output_choice, int n_outputs), transform_x(struct DATA *data, int n_data, int model_type, double xmin, double xmax);
-	void untransform_x(struct DATA *data, int n_data, int model_type, double xmin, double xmax);
-	void recompute_weights(struct DATA *data, int n_data, double *work, double *scale);
-	void	allocate_array_space(int np, double **gtg, double **v, double **gtd, double **lambda, double **workb, double **workz, double **c_model, double **o_model, double **w_model);
-	void free_the_memory(double *gtg, double *v, double *gtd, double *lambda, double *workb, double *workz, double *c_model, double *o_model, double *w_model, struct DATA *data, double *work);
-	void calc_m_and_r(struct DATA *data, int n_data, double *model, int n_model, int m_type, double *grow);
-	void move_model_a_to_b(double *model_a, double *model_b, int n_model, double *chisq_a, double *chisq_b);
-	void	load_gtg_and_gtd(struct DATA *data, int n_data, double *gtg, double *gtd, double *grow, int n_model, int mp, int m_type);
-	void solve_system(double *gtg, double *gtd, double *model, int n_model, int mp, double *lambda, double *v, double *b, double *z, double c_no, int *ir);
+	int i, j, k, n_data, n_outputs, n_model, np, significant, rank, n_req;
 
-	int	i, j, n_data, n_outputs, n_model, n_model_max, model_type, np, significant, rank, n_req;
+	BOOLEAN	error = FALSE, weighted_output = FALSE;
 
-	BOOLEAN	error = FALSE, weighted_input = FALSE, weighted_output = FALSE, robust = FALSE, increment = FALSE;
-
-	double	c_no = 1.0e06;	/* Condition number for matrix solution  */
-	double	confid = 0.51;	/* Confidence interval for significance test  */
 	double	*gtg, *v, *gtd, *lambda, *workb, *workz, *c_model, *o_model, *w_model, *work;	/* Arrays  */
 	double	xmin, xmax, c_chisq, o_chisq, w_chisq, scale = 1.0, prob;
-	double	get_chisq(struct DATA *data, int n_data, int n_model);
+	double	get_chisq(struct TREND1D_DATA *data, int n_data, int n_model);
 
-	char	output_choice[N_OUTPUT_CHOICES], format[BUFSIZ];
+	char	format[BUFSIZ];
 
 	FILE	*fp = NULL;
 
-	argc = GMT_begin (argc, argv);
+	struct	TREND1D_DATA *data;
+	struct TREND1D_CTRL *Ctrl;
+
+	void read_data(struct TREND1D_DATA **data, int *n_data, double *xmin, double *xmax, int weighted_input, double **work, FILE *fp);
+	void write_output(struct TREND1D_DATA *data, int n_data, char *output_choice, int n_outputs), transform_x(struct TREND1D_DATA *data, int n_data, int model_type, double xmin, double xmax);
+	void untransform_x(struct TREND1D_DATA *data, int n_data, int model_type, double xmin, double xmax);
+	void recompute_weights(struct TREND1D_DATA *data, int n_data, double *work, double *scale);
+	void allocate_array_space(int np, double **gtg, double **v, double **gtd, double **lambda, double **workb, double **workz, double **c_model, double **o_model, double **w_model);
+	void free_the_memory(double *gtg, double *v, double *gtd, double *lambda, double *workb, double *workz, double *c_model, double *o_model, double *w_model, struct TREND1D_DATA *data, double *work);
+	void calc_m_and_r(struct TREND1D_DATA *data, int n_data, double *model, int n_model, int m_type, double *grow);
+	void move_model_a_to_b(double *model_a, double *model_b, int n_model, double *chisq_a, double *chisq_b);
+	void load_gtg_and_gtd(struct TREND1D_DATA *data, int n_data, double *gtg, double *gtd, double *grow, int n_model, int mp, int m_type);
+	void solve_system(double *gtg, double *gtd, double *model, int n_model, int mp, double *lambda, double *v, double *b, double *z, double c_no, int *ir);
+	void GMT_cheb_to_pol (double c[], int n, double a, double b);
+	void *New_Trend1d_Ctrl (), Free_Trend1d_Ctrl (struct TREND1D_CTRL *C);
 	
-	model_type = POLYNOMIAL;
-	n_outputs = 0;
-	n_model_max = 0;
-	for (i = 0; i < N_OUTPUT_CHOICES; i++) output_choice[i] = 0;
+	argc = GMT_begin (argc, argv);
+
+	Ctrl = (struct TREND1D_CTRL *)New_Trend1d_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
 
 				/* Common parameters */
-			
+
 				case 'H':
 				case 'V':
 				case ':':
-				case '\0':
-					error += GMT_get_common_args (argv[i], 0, 0, 0, 0);
-					break;
-				
-				/* Supplemental parameters */
-				
 				case 'b':
-					error += GMT_io_selection (&argv[i][2]);
+				case 'f':
+				case '\0':
+					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
+					break;
+
+				/* Supplemental parameters */
+
+				case 'C':
+					Ctrl->C.active = TRUE;
+					Ctrl->C.value = atof(&argv[i][2]);
 					break;
 				case 'F':
-					j = 2;
-				       while (argv[i][j]) {
-						switch (argv[i][j]) {
-							case 'x':
-								output_choice[j-2] = 'x';
-								break;
-							case 'y':
-								output_choice[j-2] = 'y';
-								break;
-							case 'm':
-								output_choice[j-2] = 'm';
-								break;
-							case 'r':
-								output_choice[j-2] = 'r';
-								break;
-							case 'w':
-								output_choice[j-2] = 'w';
-								weighted_output = TRUE;
-								break;
-							default:
-								error = TRUE;
- 								fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Unrecognized output choice %c\n", GMT_program, argv[i][j]);
-					       }
-						n_outputs++;
-						j++;
+					Ctrl->F.active = TRUE;
+					for (j = 2, k = 0; argv[i][j]; j++, k++) {
+						if (k < TREND1D_N_OUTPUT_CHOICES)
+							Ctrl->F.col[k] = argv[i][j];
+						else {
+							error++;
+							fprintf (stderr, "%s: GMT SYNTAX ERROR -F option: Too many output columns selected\n", GMT_program);
+							fprintf (stderr, "%s: GMT SYNTAX ERROR -F option: Choose from -Fxymrw\n", GMT_program);
+						}
 					}
 					break;
-				case 'C':
-					c_no = atof(&argv[i][2]);
-					break;
 				case 'I':
-					increment = TRUE;
-					confid = (argv[i][2]) ? atof(&argv[i][2]) : 0.51;
+					Ctrl->I.active = TRUE;
+					Ctrl->I.value = (argv[i][2]) ? atof(&argv[i][2]) : 0.51;
 					break;
 				case 'N':
-					if (argv[i][strlen (argv[i]) - 1] == 'r') robust = TRUE;
-					j = 2;
+					Ctrl->N.active = TRUE;
+					if (strchr (argv[i], 'r')) Ctrl->N.robust = TRUE;
+					j = (argv[i][2] == 'r') ? 3 : 2;
 					if (argv[i][j] == 'F' || argv[i][j] == 'f') {
-						model_type = FOURIER;
+						Ctrl->N.mode = TREND1D_FOURIER;
 						j++;
 					}
 					else if (argv[i][j] == 'P' || argv[i][j] == 'p') {
-						model_type = POLYNOMIAL;
+						Ctrl->N.mode = TREND1D_POLYNOMIAL;
 						j++;
 					}
 					if (argv[i][j])
-						n_model_max = atoi(&argv[i][j]);
+						Ctrl->N.value = atoi(&argv[i][j]);
 					else {
 						error = TRUE;
  						fprintf (stderr, "%s: GMT SYNTAX ERROR -N option.  No model specified\n", GMT_program);
 					}
 					break;
 				case 'W':
-					weighted_input = TRUE;
+					Ctrl->W.active = TRUE;
 					break;
 				default:
 					error = TRUE;
@@ -241,12 +251,12 @@ main(int argc, char **argv)
 		}
 	}
 
-	if (argc == 1 || GMT_quick) {
+	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf(stderr,"trend1d %s - Fit a [weighted] [robust] polynomial [or Fourier] model for y = f(x) to ascii xy[w]\n\n", GMT_VERSION);
 		fprintf(stderr,"usage:  trend1d -F<xymrw> -N[f]<n_model>[r] [<xy[w]file>] [-C<condition_#>]\n");
-		fprintf(stderr,"\t[-H[<nrec>]] [-I[<confidence>]] [-V] [-W] [-:] [-bi[s][<n>]] [-bo[s][<n>]]\n\n");
-		
-		if (GMT_quick) exit (EXIT_FAILURE);
+		fprintf(stderr,"\t[%s] [-I[<confidence>]] [-V] [-W] [%s] [%s] [%s]\n\n", GMT_H_OPT, GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
+
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf(stderr,"\t-F Choose at least 1, up to 5, any order, of xymrw for ascii output to stdout.\n");
 		fprintf(stderr,"\t   x=x, y=y, m=model, r=residual=y-m, w=weight.  w determined iteratively if robust fit used.\n");
@@ -266,53 +276,64 @@ main(int argc, char **argv)
 		GMT_explain_option ('n');
 		fprintf(stderr,"\t   Default is 2 (or 3 if -W is set) input columns.\n");
 		GMT_explain_option ('o');
+		GMT_explain_option ('n');
+		GMT_explain_option ('f');
+		GMT_explain_option ('.');
 		exit (EXIT_FAILURE);
 	}
 
-	if (c_no <= 1.0) {
+	if (Ctrl->C.value <= 1.0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -C option.  Condition number must be larger than unity\n", GMT_program);
 		error++;
-	}	
-	if (confid < 0.0 || confid > 1.0) {
+	}
+	if (Ctrl->I.value < 0.0 || Ctrl->I.value > 1.0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -C option.  Give 0 < confidence level < 1.0\n", GMT_program);
 		error++;
-	}	
-	if (n_outputs > N_OUTPUT_CHOICES) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Too many output columns specified (%d)\n", GMT_program, n_outputs);
-		error++;
-	}	
-	if (n_model_max <= 0.0) {
+	}
+	if (Ctrl->N.value <= 0.0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -N option.  A positive number of terms must be specified\n", GMT_program);
 		error++;
-	}	
-	if (GMT_io.binary[0] && gmtdefs.io_header) {
+	}
+	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
-	n_req = (weighted_input) ? 3 : 2;
-	if (GMT_io.binary[0] && GMT_io.ncol[0] == 0) GMT_io.ncol[0] = n_req;
-	if (GMT_io.binary[0] && GMT_io.ncol[0] < n_req) {
+	n_req = (Ctrl->W.active) ? 3 : 2;
+	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = n_req;
+	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < n_req) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least %d columns\n", GMT_program, n_req);
 		error++;
 	}
+	for (k = n_outputs = 0; k < TREND1D_N_OUTPUT_CHOICES && Ctrl->F.col[k]; k++) {
+		if (!strchr ("xymrw", Ctrl->F.col[k])) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Unrecognized output choice %c\n", GMT_program, Ctrl->F.col[k]);
+			error++;
+		}
+		else if (Ctrl->F.col[k] == 'w')
+			weighted_output = TRUE;
+
+		n_outputs++;
+	}
+        if (n_outputs == 0) {
+                fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Must specify at least one output columns \n", GMT_program);
+                error++;
+        }
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands */
-
-	if (GMT_io.binary[0] && gmtdefs.verbose) {
+	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
-		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[0], type[GMT_io.single_precision[0]]);
+		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
 	}
 
 #ifdef SET_IO_MODE
-	GMT_setmode (1);
+	GMT_setmode (GMT_OUT);
 #endif
 
-	np = n_model_max;	/* Row dimension for matrices gtg and v  */
+	np = Ctrl->N.value;	/* Row dimension for matrices gtg and v  */
 	allocate_array_space(np, &gtg, &v, &gtd, &lambda, &workb, &workz, &c_model, &o_model, &w_model);
 
-	read_data(&data, &n_data, &xmin, &xmax, weighted_input, &work, fp);
+	read_data(&data, &n_data, &xmin, &xmax, Ctrl->W.active, &work, fp);
 
 	if (xmin == xmax) {
 		fprintf(stderr,"%s:  Fatal error in input data.  X min = X max.\n", GMT_program);
@@ -322,9 +343,9 @@ main(int argc, char **argv)
 		fprintf(stderr,"%s:  Fatal error.  Could not read any data.\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-	if (n_data < n_model_max) fprintf(stderr,"%s: Warning. Ill-posed problem.  n_data < n_model_max.\n", GMT_program);
+	if (n_data < Ctrl->N.value) fprintf(stderr,"%s: Warning. Ill-posed problem.  n_data < n_model_max.\n", GMT_program);
 
-	transform_x(data, n_data, model_type, xmin, xmax);	/* Set domain to [-1, 1] or [-pi, pi]  */
+	transform_x(data, n_data, Ctrl->N.mode, xmin, xmax);	/* Set domain to [-1, 1] or [-pi, pi]  */
 
 	if (gmtdefs.verbose) {
 		sprintf(format,"%%s:  Read %%d data with X values from %s to %s\n", gmtdefs.d_format, gmtdefs.d_format);
@@ -334,99 +355,99 @@ main(int argc, char **argv)
 
 	sprintf (format, "%%d\t%%d\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 
-	if (increment) {
+	if (Ctrl->I.active) {
 		n_model = 1;
 
 		/* Fit first model  */
-		load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, model_type);
-		solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
-		calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
+		load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, Ctrl->N.mode);
+		solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
+		calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
 		c_chisq = get_chisq(data, n_data, n_model);
 		if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, 1.0);
-		if (robust) {
+		if (Ctrl->N.robust) {
 			do {
 				recompute_weights(data, n_data, work, &scale);
 				move_model_a_to_b(c_model, w_model, n_model, &c_chisq, &w_chisq);
-				load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, model_type);
-				solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
-				calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
+				load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, Ctrl->N.mode);
+				solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
+				calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
 				c_chisq = get_chisq(data, n_data, n_model);
-				significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, confid, &prob);
+				significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, Ctrl->I.value, &prob);
 				if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, prob);
 			} while (significant);
 			/* Go back to previous model only if w_chisq < c_chisq  */
 			if (w_chisq < c_chisq) {
 				move_model_a_to_b(w_model, c_model, n_model, &w_chisq, &c_chisq);
-				calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
-				if (weighted_output && n_model == n_model_max) recompute_weights(data, n_data, work, &scale);
+				calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
+				if (weighted_output && n_model == Ctrl->N.value) recompute_weights(data, n_data, work, &scale);
 			}
 		}
 		/* First [robust] model has been found  */
 
 		significant = TRUE;
-		while(n_model < n_model_max && significant) {
+		while(n_model < Ctrl->N.value && significant) {
 			move_model_a_to_b(c_model, o_model, n_model, &c_chisq, &o_chisq);
 			n_model++;
 
 			/* Fit next model  */
-			load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, model_type);
-			solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
-			calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
+			load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, Ctrl->N.mode);
+			solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
+			calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
 			c_chisq = get_chisq(data, n_data, n_model);
 			if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, 1.00);
-			if (robust) {
+			if (Ctrl->N.robust) {
 				do {
 					recompute_weights(data, n_data, work, &scale);
 					move_model_a_to_b(c_model, w_model, n_model, &c_chisq, &w_chisq);
-					load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, model_type);
-					solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
-					calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
+					load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, Ctrl->N.mode);
+					solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
+					calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
 					c_chisq = get_chisq(data, n_data, n_model);
-					significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, confid, &prob);
+					significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, Ctrl->I.value, &prob);
 					if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, prob);
 				} while (significant);
 				/* Go back to previous model only if w_chisq < c_chisq  */
 				if (w_chisq < c_chisq) {
 					move_model_a_to_b(w_model, c_model, n_model, &w_chisq, &c_chisq);
-					calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
-					if (weighted_output && n_model == n_model_max) recompute_weights(data, n_data, work, &scale);
+					calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
+					if (weighted_output && n_model == Ctrl->N.value) recompute_weights(data, n_data, work, &scale);
 				}
 			}
 			/* Next [robust] model has been found  */
-			significant = GMT_sig_f(c_chisq, n_data-n_model, o_chisq, n_data-n_model-1, confid, &prob);
+			significant = GMT_sig_f(c_chisq, n_data-n_model, o_chisq, n_data-n_model-1, Ctrl->I.value, &prob);
 		}
 
 		if (!(significant) ) {	/* Go back to previous [robust] model, stored in o_model  */
 			n_model--;
 			rank--;
 			move_model_a_to_b(o_model, c_model, n_model, &o_chisq, &c_chisq);
-			calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
-			if (robust && weighted_output) recompute_weights(data, n_data, work, &scale);
+			calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
+			if (Ctrl->N.robust && weighted_output) recompute_weights(data, n_data, work, &scale);
 		}
 	}
 	else {
-		n_model = n_model_max;
-		load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, model_type);
-		solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
-		calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
+		n_model = Ctrl->N.value;
+		load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, Ctrl->N.mode);
+		solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
+		calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
 		c_chisq = get_chisq(data, n_data, n_model);
 		if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, 1.00);
-		if (robust) {
+		if (Ctrl->N.robust) {
 			do {
 				recompute_weights(data, n_data, work, &scale);
 				move_model_a_to_b(c_model, w_model, n_model, &c_chisq, &w_chisq);
-				load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, model_type);
-				solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
-				calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
+				load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np, Ctrl->N.mode);
+				solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
+				calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
 				c_chisq = get_chisq(data, n_data, n_model);
-				significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, confid, &prob);
+				significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, Ctrl->I.value, &prob);
 				if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, prob);
 			} while (significant);
 			/* Go back to previous model only if w_chisq < c_chisq  */
 			if (w_chisq < c_chisq) {
 				move_model_a_to_b(w_model, c_model, n_model, &w_chisq, &c_chisq);
-				calc_m_and_r(data, n_data, c_model, n_model, model_type, workb);
-				if (weighted_output && n_model == n_model_max) recompute_weights(data, n_data, work, &scale);
+				calc_m_and_r(data, n_data, c_model, n_model, Ctrl->N.mode, workb);
+				if (weighted_output && n_model == Ctrl->N.value) recompute_weights(data, n_data, work, &scale);
 			}
 		}
 	}
@@ -434,24 +455,31 @@ main(int argc, char **argv)
 	if (gmtdefs.verbose) {
 		sprintf (format, "%%s: Final model stats:  N model parameters %%d.  Rank %%d.  Chi-Squared:  %s\n", gmtdefs.d_format);
 		fprintf(stderr, format, GMT_program, n_model, rank, c_chisq);
-		fprintf(stderr,"Model Coefficients:");
-		sprintf (format, "%s\t", gmtdefs.d_format);
+		fprintf(stderr,"%s: Model Coefficients  (Chebyshev):", GMT_program);
+		sprintf (format, "\t%s", gmtdefs.d_format);
+		for (i = 0; i < n_model; i++) fprintf (stderr, format, c_model[i]);
+		fprintf(stderr,"\n");
+		GMT_cheb_to_pol (c_model, n_model, xmin, xmax);
+		fprintf(stderr,"%s: Model Coefficients (Polynomial):", GMT_program);
 		for (i = 0; i < n_model; i++) fprintf (stderr, format, c_model[i]);
 		fprintf(stderr,"\n");
 	}
 
-	untransform_x(data, n_data, model_type, xmin, xmax);
+	untransform_x(data, n_data, Ctrl->N.mode, xmin, xmax);
 
-	write_output(data, n_data, output_choice, n_outputs);
+	write_output(data, n_data, Ctrl->F.col, n_outputs);
 
 	free_the_memory(gtg, v, gtd, lambda, workb, workz, c_model, o_model, w_model, data, work);
 
+	Free_Trend1d_Ctrl (Ctrl);	/* Deallocate control structure */
+
 	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
 }
 
-void	read_data(struct DATA **data, int *n_data, double *xmin, double *xmax, int weighted_input, double **work, FILE *fp)
+void read_data (struct TREND1D_DATA **data, int *n_data, double *xmin, double *xmax, int weighted_input, double **work, FILE *fp)
 {
-
 	int	i, n_alloc = GMT_CHUNK, n_expected_fields, n_fields;
 	double	*in;
 	char	buffer[BUFSIZ];
@@ -459,14 +487,14 @@ void	read_data(struct DATA **data, int *n_data, double *xmin, double *xmax, int
 	if (fp == NULL) {
 		fp = GMT_stdin;
 #ifdef SET_IO_MODE
-		GMT_setmode (0);
+		GMT_setmode (GMT_IN);
 #endif
 	}
-	(*data) = (struct DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct DATA), GMT_program);
-	
-	if (gmtdefs.io_header) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp);
+	(*data) = (struct TREND1D_DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct TREND1D_DATA), GMT_program);
+
+	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp);
 	i = 0;
-	n_expected_fields = (GMT_io.binary[0]) ? GMT_io.ncol[0] : 2 + weighted_input;
+	n_expected_fields = (GMT_io.binary[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 2 + weighted_input;
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
@@ -491,18 +519,18 @@ void	read_data(struct DATA **data, int *n_data, double *xmin, double *xmax, int
 
 		if (i == n_alloc) {
 			n_alloc += GMT_CHUNK;
-			*data = (struct DATA *) GMT_memory ((void *)*data, (size_t)n_alloc, sizeof(struct DATA), GMT_program);
+			*data = (struct TREND1D_DATA *) GMT_memory ((void *)*data, (size_t)n_alloc, sizeof(struct TREND1D_DATA), GMT_program);
 		}
 	}
 	if (fp != GMT_stdin) GMT_fclose(fp);
-	
-	*data = (struct DATA *) GMT_memory ((void *)*data, (size_t)i, sizeof(struct DATA), GMT_program);
+
+	*data = (struct TREND1D_DATA *) GMT_memory ((void *)*data, (size_t)i, sizeof(struct TREND1D_DATA), GMT_program);
 	*work = (double *) GMT_memory (VNULL, (size_t)i, sizeof(double), GMT_program);
 
 	*n_data = i;
 }
 
-void	allocate_array_space(int np, double **gtg, double **v, double **gtd, double **lambda, double **workb, double **workz, double **c_model, double **o_model, double **w_model)
+void allocate_array_space (int np, double **gtg, double **v, double **gtd, double **lambda, double **workb, double **workz, double **c_model, double **o_model, double **w_model)
 {
 	*gtg = (double *) GMT_memory (VNULL, (size_t)(np*np), sizeof(double), GMT_program);
 	*v = (double *) GMT_memory (VNULL, (size_t)(np*np), sizeof(double), GMT_program);
@@ -514,8 +542,8 @@ void	allocate_array_space(int np, double **gtg, double **v, double **gtd, double
 	*o_model = (double *) GMT_memory (VNULL, (size_t)np, sizeof(double), GMT_program);
 	*w_model = (double *) GMT_memory (VNULL, (size_t)np, sizeof(double), GMT_program);
 }
-	
-void	write_output(struct DATA *data, int n_data, char *output_choice, int n_outputs)
+
+void write_output (struct TREND1D_DATA *data, int n_data, char *output_choice, int n_outputs)
 {
 	int	i, j;
 	double out[5];
@@ -544,7 +572,7 @@ void	write_output(struct DATA *data, int n_data, char *output_choice, int n_outp
 	}
 }
 
-void	free_the_memory(double *gtg, double *v, double *gtd, double *lambda, double *workb, double *workz, double *c_model, double *o_model, double *w_model, struct DATA *data, double *work)
+void free_the_memory (double *gtg, double *v, double *gtd, double *lambda, double *workb, double *workz, double *c_model, double *o_model, double *w_model, struct TREND1D_DATA *data, double *work)
 {
 	GMT_free ((void *)work);
 	GMT_free ((void *)data);
@@ -559,7 +587,7 @@ void	free_the_memory(double *gtg, double *v, double *gtd, double *lambda, double
 	GMT_free ((void *)gtg);
 }
 
-void	transform_x(struct DATA *data, int n_data, int model_type, double xmin, double xmax)
+void transform_x (struct TREND1D_DATA *data, int n_data, int model_type, double xmin, double xmax)
 {
 	int	i;
 	double	offset, scale;
@@ -567,7 +595,7 @@ void	transform_x(struct DATA *data, int n_data, int model_type, double xmin, dou
 	offset = 0.5 * (xmin + xmax);	/* Mid Range  */
 	scale = 2.0 / (xmax - xmin);	/* 1 / (1/2 Range)  */
 
-	if (model_type == FOURIER) {	/* Set Range to 1 period  */
+	if (model_type == TREND1D_FOURIER) {	/* Set Range to 1 period  */
 		scale *= M_PI;
 	}
 
@@ -576,7 +604,7 @@ void	transform_x(struct DATA *data, int n_data, int model_type, double xmin, dou
 	}
 }
 
-void	untransform_x(struct DATA *data, int n_data, int model_type, double xmin, double xmax)
+void untransform_x (struct TREND1D_DATA *data, int n_data, int model_type, double xmin, double xmax)
 {
 	int	i;
 	double	offset, scale;
@@ -584,7 +612,7 @@ void	untransform_x(struct DATA *data, int n_data, int model_type, double xmin, d
 	offset = 0.5 * (xmin + xmax);	/* Mid Range  */
 	scale = 0.5 * (xmax - xmin);	/* 1/2 Range  */
 
-	if (model_type == FOURIER) {
+	if (model_type == TREND1D_FOURIER) {
 		scale /= M_PI;
 	}
 
@@ -593,7 +621,7 @@ void	untransform_x(struct DATA *data, int n_data, int model_type, double xmin, d
 	}
 }
 
-double	get_chisq(struct DATA *data, int n_data, int n_model)
+double get_chisq (struct TREND1D_DATA *data, int n_data, int n_model)
 {
 	int	i, nu;
 	double	chi = 0.0;
@@ -612,7 +640,7 @@ double	get_chisq(struct DATA *data, int n_data, int n_model)
 	return(chi);
 }
 
-void	recompute_weights(struct DATA *data, int n_data, double *work, double *scale)
+void recompute_weights (struct TREND1D_DATA *data, int n_data, double *work, double *scale)
 {
 	int	i;
 	double	k, ksq, rr;
@@ -647,7 +675,7 @@ void	recompute_weights(struct DATA *data, int n_data, double *work, double *scal
 	}
 }
 
-void	load_g_row(double x, int n, double *gr, int m)
+void load_g_row (double x, int n, double *gr, int m)
       	  	/* Current data position, appropriately normalized.  */
    	  	/* Number of model parameters, and elements of gr[]  */
       	     	/* Elements of row of G matrix.  */
@@ -655,7 +683,7 @@ void	load_g_row(double x, int n, double *gr, int m)
 {
 	/* Routine computes the elements gr[j] in the ith row of the
 		G matrix (Menke notation), where x is the ith datum's
-		abcissa.  */
+		abscissa.  */
 
 	int	j, k;
 
@@ -665,7 +693,7 @@ void	load_g_row(double x, int n, double *gr, int m)
 
 		switch (m) {
 
-			case POLYNOMIAL:
+			case TREND1D_POLYNOMIAL:
 				/* Create Chebyshev polynomials  */
 				if (n > 1) gr[1] = x;
 				for (j = 2; j < n; j++) {
@@ -673,7 +701,7 @@ void	load_g_row(double x, int n, double *gr, int m)
 				}
 				break;
 
-			case FOURIER:
+			case TREND1D_FOURIER:
 				for (j = 1; j < n; j++) {
 					k = (j + 1)/2;
 					if (k > 1) {
@@ -698,7 +726,7 @@ void	load_g_row(double x, int n, double *gr, int m)
 	}
 }
 
-void	calc_m_and_r(struct DATA *data, int n_data, double *model, int n_model, int m_type, double *grow)
+void calc_m_and_r (struct TREND1D_DATA *data, int n_data, double *model, int n_model, int m_type, double *grow)
 {
 	/*	model[n_model] holds solved coefficients of m_type model.
 		grow[n_model] is a vector for a row of G matrix.  */
@@ -714,7 +742,7 @@ void	calc_m_and_r(struct DATA *data, int n_data, double *model, int n_model, int
 	}
 }
 
-void	move_model_a_to_b(double *model_a, double *model_b, int n_model, double *chisq_a, double *chisq_b)
+void move_model_a_to_b (double *model_a, double *model_b, int n_model, double *chisq_a, double *chisq_b)
 {
 	int	i;
 	for(i = 0; i<  n_model; i++) {
@@ -723,11 +751,9 @@ void	move_model_a_to_b(double *model_a, double *model_b, int n_model, double *ch
 	*chisq_b = *chisq_a;
 }
 
-void	load_gtg_and_gtd(struct DATA *data, int n_data, double *gtg, double *gtd, double *grow, int n_model, int mp, int m_type)
-      	    	      
-      			  
-   				    	/* mp is row dimension of gtg  */
+void load_gtg_and_gtd (struct TREND1D_DATA *data, int n_data, double *gtg, double *gtd, double *grow, int n_model, int mp, int m_type)
 {
+   	/* mp is row dimension of gtg  */
 
 	int	i, j, k;
 	double	wy;
@@ -764,7 +790,7 @@ void	load_gtg_and_gtd(struct DATA *data, int n_data, double *gtg, double *gtd, d
 	}
 }
 
-void	solve_system(double *gtg, double *gtd, double *model, int n_model, int mp, double *lambda, double *v, double *b, double *z, double c_no, int *ir)
+void solve_system (double *gtg, double *gtd, double *model, int n_model, int mp, double *lambda, double *v, double *b, double *z, double c_no, int *ir)
 {
 
 	int	i, j, k, rank = 0, n, m, nrots;
@@ -795,3 +821,67 @@ void	solve_system(double *gtg, double *gtd, double *model, int n_model, int mp,
 		*ir = rank;
 	}
 }
+
+void GMT_cheb_to_pol (double c[], int n, double a, double b)
+{
+	/* Convert from Chebyshev coefficients used on a t =  [-1,+1] interval
+	 * to polynomial coefficients on the original x = [a b] interval.
+	 * Modified from Numerical Miracles, ...eh Recipes */
+	 
+	 int j, k;
+	 double sv, cnst, fac;
+	 double *d, *dd;
+	 
+	 d  = GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
+	 dd = GMT_memory (VNULL, (size_t)n, sizeof (double), GMT_program);
+	 
+	 /* First we generate coefficients for a polynomial in t */
+	 
+	 d[0] = c[n-1];
+	 for (j = n - 2; j >= 1; j--) {
+	 	for (k = n - j; k >= 1; k--) {
+			sv = d[k];
+			d[k] = 2.0 * d[k-1] - dd[k];
+			dd[k] = sv;
+		}
+		sv = d[0];
+		d[0] = -dd[0] + c[j];
+		dd[0] = sv;
+	}
+	for (j = n - 1; j >= 1; j--) d[j] = d[j-1] - dd[j];
+	/* d[0] = -dd[0] + 0.5 * c[0]; */	/* This is what Num. Rec. says, but we do not do the approx with 0.5 * c[0] */
+	d[0] = -dd[0] + c[0];
+
+	/* Next step is to undo the scaling so we can use coefficients with x */
+
+	cnst = fac = 2.0 / (b - a);
+	for (j = 1; j < n; j++) {
+		d[j] *= fac;
+		fac *= cnst;
+	}
+	cnst = 0.5 * (a + b);
+	for (j = 0; j <= n - 2; j++) for (k = n - 2; k >= j; k--) d[k] -= cnst * d[k+1];
+
+	/* Return the new coefficients via c */
+
+	memcpy ((void *)c, (void *)d, (size_t)(n * sizeof (double)));
+
+	GMT_free ((void *) d);
+	GMT_free ((void *) dd);
+}
+
+void *New_Trend1d_Ctrl () {	/* Allocate and initialize a new control structure */
+	struct TREND1D_CTRL *C;
+	
+	C = (struct TREND1D_CTRL *) GMT_memory (VNULL, 1, sizeof (struct TREND1D_CTRL), "New_Trend1d_Ctrl");
+	
+	/* Initialize values whose defaults are not 0/FALSE/NULL */
+	C->C.value = 1.0e06;		/* Condition number for matrix solution  */	
+	C->I.value = 0.51;		/* Confidence interval for significance test  */
+	C->N.mode = TREND1D_POLYNOMIAL;
+	return ((void *)C);
+}
+
+void Free_Trend1d_Ctrl (struct TREND1D_CTRL *C) {	/* Deallocate control structure */
+	GMT_free ((void *)C);	
+}
