@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: trend2d.c,v 1.14 2004/04/25 09:10:46 pwessel Exp $
+ *	$Id: trend2d.c,v 1.35 2007/03/12 19:52:26 remko Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -67,107 +67,114 @@
 
 #include "gmt.h"
 
-#define N_OUTPUT_CHOICES 6
+#define TREND2D_N_OUTPUT_CHOICES 6
 
-struct	DATA {
+struct TREND2D_CTRL {
+	struct C {	/* -C<condition_#> */
+		BOOLEAN active;
+		double value;
+	} C;
+	struct F {	/* -F<xymrw> */
+		BOOLEAN active;
+		char col[TREND2D_N_OUTPUT_CHOICES];	/* Character codes for desired output in the right order */
+	} F;
+	struct I {	/* -I[<confidence>] */
+		BOOLEAN active;
+		double value;
+	} I;
+	struct N {	/* -N<n_model>[r] */
+		BOOLEAN active;
+		BOOLEAN robust;
+		int value;
+	} N;
+	struct W {	/* -W */
+		BOOLEAN active;
+	} W;
+};
+
+struct	TREND2D_DATA {
 	double	x;
 	double	y;
 	double	z;
 	double	m;
 	double	r;
 	double	w;
-}	*data;
+};
 
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
-	void read_data(struct DATA **data, int *n_data, double *xmin, double *xmax, double *ymin, double *ymax, int weighted_input, double **work, FILE *fp);
-	void write_output(struct DATA *data, int n_data, char *output_choice, int n_outputs);
-	void transform_x(struct DATA *data, int n_data, double xmin, double xmax, double ymin, double ymax);
-	void untransform_x(struct DATA *data, int n_data, double xmin, double xmax, double ymin, double ymax);
-	void recompute_weights(struct DATA *data, int n_data, double *work, double *scale);
-	void allocate_array_space(int np, double **gtg, double **v, double **gtd, double **lambda, double **workb, double **workz, double **c_model, double **o_model, double **w_model);
-	void free_the_memory(double *gtg, double *v, double *gtd, double *lambda, double *workb, double *workz, double *c_model, double *o_model, double *w_model, struct DATA *data, double *work);
-	void calc_m_and_r(struct DATA *data, int n_data, double *model, int n_model, double *grow);
-	void move_model_a_to_b(double *model_a, double *model_b, int n_model, double *chisq_a, double *chisq_b);
-	void load_gtg_and_gtd(struct DATA *data, int n_data, double *gtg, double *gtd, double *grow, int n_model, int mp);
-	void solve_system(double *gtg, double *gtd, double *model, int n_model, int mp, double *lambda, double *v, double *b, double *z, double c_no, int *ir);
+	int	i, j, k, n_data, n_outputs, n_model, n_model_max, np, significant, rank, n_req;
 
-	int	i, j, n_data, n_outputs, n_model, n_model_max, np, significant, rank, n_req;
+	BOOLEAN	error = FALSE, weighted_output = FALSE;
 
-	BOOLEAN	error = FALSE, weighted_input = FALSE, weighted_output = FALSE, robust = FALSE, increment = FALSE;
-
-	double	c_no = 1.0e06;	/* Condition number for matrix solution  */
-	double	confid = 0.51;	/* Confidence interval for significance test  */
 	double	*gtg, *v, *gtd, *lambda, *workb, *workz, *c_model, *o_model, *w_model, *work;	/* Arrays  */
 	double	xmin, xmax, ymin, ymax, c_chisq, o_chisq, w_chisq, scale = 1.0, prob;
-	double	get_chisq(struct DATA *data, int n_data, int n_model);
+	double	get_chisq(struct TREND2D_DATA *data, int n_data, int n_model);
 
-	char	output_choice[N_OUTPUT_CHOICES], format[BUFSIZ];
+	char format[BUFSIZ];
 
 	FILE	*fp = NULL;
 
+	struct	TREND2D_DATA *data;
+	struct TREND2D_CTRL *Ctrl;
+
+	void read_data(struct TREND2D_DATA **data, int *n_data, double *xmin, double *xmax, double *ymin, double *ymax, int weighted_input, double **work, FILE *fp);
+	void write_output(struct TREND2D_DATA *data, int n_data, char *output_choice, int n_outputs);
+	void transform_x(struct TREND2D_DATA *data, int n_data, double xmin, double xmax, double ymin, double ymax);
+	void untransform_x(struct TREND2D_DATA *data, int n_data, double xmin, double xmax, double ymin, double ymax);
+	void recompute_weights(struct TREND2D_DATA *data, int n_data, double *work, double *scale);
+	void allocate_array_space(int np, double **gtg, double **v, double **gtd, double **lambda, double **workb, double **workz, double **c_model, double **o_model, double **w_model);
+	void free_the_memory(double *gtg, double *v, double *gtd, double *lambda, double *workb, double *workz, double *c_model, double *o_model, double *w_model, struct TREND2D_DATA *data, double *work);
+	void calc_m_and_r(struct TREND2D_DATA *data, int n_data, double *model, int n_model, double *grow);
+	void move_model_a_to_b(double *model_a, double *model_b, int n_model, double *chisq_a, double *chisq_b);
+	void load_gtg_and_gtd(struct TREND2D_DATA *data, int n_data, double *gtg, double *gtd, double *grow, int n_model, int mp);
+	void solve_system(double *gtg, double *gtd, double *model, int n_model, int mp, double *lambda, double *v, double *b, double *z, double c_no, int *ir);
+	void *New_Trend2d_Ctrl (), Free_Trend2d_Ctrl (struct TREND2D_CTRL *C);
+	
 	argc = GMT_begin (argc, argv);
 
+	Ctrl = (struct TREND2D_CTRL *)New_Trend2d_Ctrl ();	/* Allocate and initialize a new control structure */
+
 	n_outputs = 0;
 	n_model_max = 0;
-	for (i = 0; i < N_OUTPUT_CHOICES; i++) output_choice[i] = 0;
 	sprintf (format, "%s\t", gmtdefs.d_format);
 
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
 				/* Common parameters */
-			
+
 				case 'H':
 				case 'V':
 				case ':':
 				case 'b':
 				case 'f':
 				case '\0':
-					error += GMT_get_common_args (argv[i], 0, 0, 0, 0);
+					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
-				
-				/* Supplemental parameters */
-				
 
+				/* Supplemental parameters */
+
+
+				case 'C':
+					Ctrl->C.active = TRUE;
+					Ctrl->C.value = atof(&argv[i][2]);
+					break;
 				case 'F':
-					j = 2;
-				       while (argv[i][j]) {
-						switch (argv[i][j]) {
-							case 'x':
-								output_choice[j-2] = 'x';
-								break;
-							case 'y':
-								output_choice[j-2] = 'y';
-								break;
-							case 'z':
-								output_choice[j-2] = 'z';
-								break;
-							case 'm':
-								output_choice[j-2] = 'm';
-								break;
-							case 'r':
-								output_choice[j-2] = 'r';
-								break;
-							case 'w':
-								output_choice[j-2] = 'w';
-								weighted_output = TRUE;
-								break;
-							default:
-								error = TRUE;
- 								fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Unrecognized output choice %c\n", GMT_program, argv[i][j]);
- 								break;
+					Ctrl->F.active = TRUE;
+					for (j = 2, k = 0; argv[i][j]; j++, k++) {
+						if (k < TREND2D_N_OUTPUT_CHOICES)
+							Ctrl->F.col[k] = argv[i][j];
+						else {
+							error++;
+							fprintf (stderr, "%s: GMT SYNTAX ERROR -F option: Too many output columns selected\n", GMT_program);
+							fprintf (stderr, "%s: GMT SYNTAX ERROR -F option: Choose from -Fxyzmrw\n", GMT_program);
 						}
-						n_outputs++;
-						j++;
 					}
 					break;
-				case 'C':
-					c_no = atof(&argv[i][2]);
-					break;
 				case 'I':
-					increment = TRUE;
-					confid = (argv[i][2]) ? atof(&argv[i][2]) : 0.51;
+					Ctrl->I.active = TRUE;
+					Ctrl->I.value = (argv[i][2]) ? atof(&argv[i][2]) : 0.51;
 					break;
 				case 'L':
 					GMT_io.in_col_type[0] = GMT_io.out_col_type[0] = GMT_IS_LON;
@@ -175,11 +182,13 @@ main(int argc, char **argv)
 					fprintf (stderr, "%s: Option -L is obsolete (but is processed correctly).  Please use -f instead\n", GMT_program);
 					break;
 				case 'N':
-					if (argv[i][strlen (argv[i]) - 1] == 'r') robust = TRUE;
-					n_model_max = (argv[i][2]) ? atoi(&argv[i][2]) : 0;
+					Ctrl->N.active = TRUE;
+					if (strchr (argv[i], 'r')) Ctrl->N.robust = TRUE;
+					j = (argv[i][2] == 'r') ? 3 : 2;
+					Ctrl->N.value = (argv[i][j]) ? atoi(&argv[i][j]) : 0;
 					break;
 				case 'W':
-					weighted_input = TRUE;
+					Ctrl->W.active = TRUE;
 					break;
 				default:
 					error = TRUE;
@@ -195,12 +204,12 @@ main(int argc, char **argv)
 		}
 	}
 
-	if (argc == 1 || GMT_quick) {
+	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf(stderr,"trend2d %s - Fit a [weighted] [robust] polynomial for z = f(x,y) to ascii xyz[w]\n\n", GMT_VERSION);
-		fprintf(stderr,"usage:  trend2d -F<xymrw> -N<n_model>[r] [<xyz[w]file>] [-C<condition_#>] [-H[<nrec>]] [-I[<confidence>]]\n\n");
-		fprintf(stderr,"	[-V] [-W] [-:] [-bi[s][<n>]] [-bo[s][<n>]] [-f[i|o]<colinfo>]\n\n");
-		
-		if (GMT_quick) exit (EXIT_FAILURE);
+		fprintf(stderr,"usage:  trend2d -F<xyzmrw> -N<n_model>[r] [<xyz[w]file>] [-C<condition_#>] [%s] [-I[<confidence>]]\n\n", GMT_H_OPT);
+		fprintf(stderr,"	[-V] [-W] [%s] [%s] [%s]\n\n", GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
+
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf(stderr,"\t-F Choose at least 1, up to 6, any order, of xyzmrw for ascii output to stdout.\n");
 		fprintf(stderr,"\t-N fit a [robust] model with <n_model> terms.  <n_model> in [1,10].  E.g., robust quadratic = -N3r.\n");
@@ -225,40 +234,48 @@ main(int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (c_no <= 1.0) {
+	if (Ctrl->C.value <= 1.0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -C option.  Condition number must be larger than unity\n", GMT_program);
 		error++;
-	}	
-	if (confid < 0.0 || confid > 1.0) {
+	}
+	if (Ctrl->I.value < 0.0 || Ctrl->I.value > 1.0) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -C option.  Give 0 < confidence level < 1.0\n", GMT_program);
 		error++;
-	}	
-	if (n_outputs == 0) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Must specify at least one output columns \n", GMT_program);
-		error++;
-	}	
-	if (n_outputs > N_OUTPUT_CHOICES) {
-		fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Too many output columns specified (%d)\n", GMT_program, n_outputs);
-		error++;
-	}	
-	if (n_model_max <= 0 || n_model_max > 10) {
+	}
+	if (Ctrl->N.value <= 0 || Ctrl->N.value > 10) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -N option.  Must request 1-10 parameters\n", GMT_program);
 		error++;
-	}	
-	if (GMT_io.binary[GMT_IN] && gmtdefs.io_header[GMT_IN]) {
+	}
+	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
-	n_req = (weighted_input) ? 4 : 3;
+	n_req = (Ctrl->W.active) ? 4 : 3;
 	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] == 0) GMT_io.ncol[GMT_IN] = n_req;
 	if (GMT_io.binary[GMT_IN] && GMT_io.ncol[GMT_IN] < n_req) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least %d columns\n", GMT_program, n_req);
 		error++;
 	}
 
-	if (error) exit (EXIT_FAILURE);
+	for (k = n_outputs = 0; k < TREND2D_N_OUTPUT_CHOICES && Ctrl->F.col[k]; k++) {
+		if (!strchr ("xyzmrw", Ctrl->F.col[k])) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Unrecognized output choice %c\n", GMT_program, Ctrl->F.col[k]);
+			error++;
+		}
+		else if (Ctrl->F.col[k] == 'w')
+			weighted_output = TRUE;
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
+		n_outputs++;
+	}
+        if (n_outputs == 0) {
+                fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Must specify at least one output column\n", GMT_program);
+                error++;
+        }
+	if (n_outputs > TREND2D_N_OUTPUT_CHOICES) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -F option.  Too many output columns specified (%d)\n", GMT_program, n_outputs);
+		error++;
+	}
+	if (error) exit (EXIT_FAILURE);
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
@@ -269,10 +286,10 @@ main(int argc, char **argv)
 	GMT_setmode (GMT_OUT);
 #endif
 	project_info.w = 0;	project_info.e = 360.0;	/* For -L not to cause trouble in GMT_input */
-	np = n_model_max;	/* Row dimension for matrices gtg and v  */
+	np = Ctrl->N.value;	/* Row dimension for matrices gtg and v  */
 	allocate_array_space(np, &gtg, &v, &gtd, &lambda, &workb, &workz, &c_model, &o_model, &w_model);
 
-	read_data(&data, &n_data, &xmin, &xmax, &ymin, &ymax, weighted_input, &work, fp);
+	read_data(&data, &n_data, &xmin, &xmax, &ymin, &ymax, Ctrl->W.active, &work, fp);
 
 	if (xmin == xmax || ymin == ymax) {
 		fprintf(stderr,"%s:  Fatal error in input data.  X min = X max.\n", GMT_program);
@@ -282,7 +299,7 @@ main(int argc, char **argv)
 		fprintf(stderr,"%s:  Fatal error.  Could not read any data.\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-	if (n_data < n_model_max) {
+	if (n_data < Ctrl->N.value) {
 		fprintf(stderr,"%s:  Warning.  Ill-posed problem.  n_data < n_model_max.\n", GMT_program);
 	}
 
@@ -295,66 +312,66 @@ main(int argc, char **argv)
 
 	sprintf (format, "%%d\t%%d\t%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 
-	if (increment) {
+	if (Ctrl->I.active) {
 		n_model = 1;
 
 		/* Fit first model  */
 		load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np);
-		solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
+		solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
 		calc_m_and_r(data, n_data, c_model, n_model, workb);
 		c_chisq = get_chisq(data, n_data, n_model);
 		if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, 1.0);
-		if (robust) {
+		if (Ctrl->N.robust) {
 			do {
 				recompute_weights(data, n_data, work, &scale);
 				move_model_a_to_b(c_model, w_model, n_model, &c_chisq, &w_chisq);
 				load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np);
-				solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
+				solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
 				calc_m_and_r(data, n_data, c_model, n_model, workb);
 				c_chisq = get_chisq(data, n_data, n_model);
-				significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, confid, &prob);
+				significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, Ctrl->I.value, &prob);
 				if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, prob);
 			} while (significant);
 			/* Go back to previous model only if w_chisq < c_chisq  */
 			if (w_chisq < c_chisq) {
 				move_model_a_to_b(w_model, c_model, n_model, &w_chisq, &c_chisq);
 				calc_m_and_r(data, n_data, c_model, n_model, workb);
-				if (weighted_output && n_model == n_model_max) recompute_weights(data, n_data, work, &scale);
+				if (weighted_output && n_model == Ctrl->N.value) recompute_weights(data, n_data, work, &scale);
 			}
 		}
 		/* First [robust] model has been found  */
 
 		significant = TRUE;
-		while(n_model < n_model_max && significant) {
+		while(n_model < Ctrl->N.value && significant) {
 			move_model_a_to_b(c_model, o_model, n_model, &c_chisq, &o_chisq);
 			n_model++;
 
 			/* Fit next model  */
 			load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np);
-			solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
+			solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
 			calc_m_and_r(data, n_data, c_model, n_model, workb);
 			c_chisq = get_chisq(data, n_data, n_model);
 			if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, 1.0);
-			if (robust) {
+			if (Ctrl->N.robust) {
 				do {
 					recompute_weights(data, n_data, work, &scale);
 					move_model_a_to_b(c_model, w_model, n_model, &c_chisq, &w_chisq);
 					load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np);
-					solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
+					solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
 					calc_m_and_r(data, n_data, c_model, n_model, workb);
 					c_chisq = get_chisq(data, n_data, n_model);
-					significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, confid, &prob);
+					significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, Ctrl->I.value, &prob);
 					if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, prob);
 				} while (significant);
 				/* Go back to previous model only if w_chisq < c_chisq  */
 				if (w_chisq < c_chisq) {
 					move_model_a_to_b(w_model, c_model, n_model, &w_chisq, &c_chisq);
 					calc_m_and_r(data, n_data, c_model, n_model, workb);
-					if (weighted_output && n_model == n_model_max) recompute_weights(data, n_data, work, &scale);
+					if (weighted_output && n_model == Ctrl->N.value) recompute_weights(data, n_data, work, &scale);
 				}
 			}
 			/* Next [robust] model has been found  */
-			significant = GMT_sig_f(c_chisq, n_data-n_model, o_chisq, n_data-n_model-1, confid, &prob);
+			significant = GMT_sig_f(c_chisq, n_data-n_model, o_chisq, n_data-n_model-1, Ctrl->I.value, &prob);
 		}
 
 		if (!(significant) ) {	/* Go back to previous [robust] model, stored in o_model  */
@@ -362,32 +379,32 @@ main(int argc, char **argv)
 			rank--;
 			move_model_a_to_b(o_model, c_model, n_model, &o_chisq, &c_chisq);
 			calc_m_and_r(data, n_data, c_model, n_model, workb);
-			if (robust && weighted_output) recompute_weights(data, n_data, work, &scale);
+			if (Ctrl->N.robust && weighted_output) recompute_weights(data, n_data, work, &scale);
 		}
 	}
 	else {
-		n_model = n_model_max;
+		n_model = Ctrl->N.value;
 		load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np);
-		solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
+		solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
 		calc_m_and_r(data, n_data, c_model, n_model, workb);
 		c_chisq = get_chisq(data, n_data, n_model);
 		if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, 1.0);
-		if (robust) {
+		if (Ctrl->N.robust) {
 			do {
 				recompute_weights(data, n_data, work, &scale);
 				move_model_a_to_b(c_model, w_model, n_model, &c_chisq, &w_chisq);
 				load_gtg_and_gtd(data, n_data, gtg, gtd, workb, n_model, np);
-				solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, c_no, &rank);
+				solve_system(gtg, gtd, c_model, n_model, np, lambda, v, workb, workz, Ctrl->C.value, &rank);
 				calc_m_and_r(data, n_data, c_model, n_model, workb);
 				c_chisq = get_chisq(data, n_data, n_model);
-				significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, confid, &prob);
+				significant = GMT_sig_f(c_chisq, n_data-n_model, w_chisq, n_data-n_model, Ctrl->I.value, &prob);
 				if (gmtdefs.verbose) fprintf(stderr, format, n_model, rank, c_chisq, prob);
 			} while (significant);
 			/* Go back to previous model only if w_chisq < c_chisq  */
 			if (w_chisq < c_chisq) {
 				move_model_a_to_b(w_model, c_model, n_model, &w_chisq, &c_chisq);
 				calc_m_and_r(data, n_data, c_model, n_model, workb);
-				if (weighted_output && n_model == n_model_max) recompute_weights(data, n_data, work, &scale);
+				if (weighted_output && n_model == Ctrl->N.value) recompute_weights(data, n_data, work, &scale);
 			}
 		}
 	}
@@ -405,14 +422,18 @@ main(int argc, char **argv)
 
 	untransform_x(data, n_data, xmin, xmax, ymin, ymax);
 
-	write_output(data, n_data, output_choice, n_outputs);
+	write_output(data, n_data, Ctrl->F.col, n_outputs);
 
 	free_the_memory(gtg, v, gtd, lambda, workb, workz, c_model, o_model, w_model, data, work);
 
+	Free_Trend2d_Ctrl (Ctrl);	/* Deallocate control structure */
+
 	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
 }
 
-void	read_data(struct DATA **data, int *n_data, double *xmin, double *xmax, double *ymin, double *ymax, int weighted_input, double **work, FILE *fp)
+void read_data (struct TREND2D_DATA **data, int *n_data, double *xmin, double *xmax, double *ymin, double *ymax, int weighted_input, double **work, FILE *fp)
 {
 
 	int	i, n_alloc = GMT_CHUNK, n_expected_fields, n_fields;
@@ -425,9 +446,9 @@ void	read_data(struct DATA **data, int *n_data, double *xmin, double *xmax, doub
 		GMT_setmode (GMT_IN);
 #endif
 	}
-	(*data) = (struct DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct DATA), GMT_program);
+	(*data) = (struct TREND2D_DATA *) GMT_memory (VNULL, (size_t)n_alloc, sizeof(struct TREND2D_DATA), GMT_program);
 
-	if (gmtdefs.io_header[GMT_IN]) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp);
+	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (buffer, BUFSIZ, fp);
 	i = 0;
 	n_expected_fields = (GMT_io.binary[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 3 + weighted_input;
 
@@ -459,16 +480,16 @@ void	read_data(struct DATA **data, int *n_data, double *xmin, double *xmax, doub
 
 		if (i == n_alloc) {
 			n_alloc += GMT_CHUNK;
-			*data = (struct DATA *) GMT_memory ((void *)*data, (size_t)n_alloc, sizeof(struct DATA), GMT_program);
+			*data = (struct TREND2D_DATA *) GMT_memory ((void *)*data, (size_t)n_alloc, sizeof(struct TREND2D_DATA), GMT_program);
 		}
 	}
 	if (fp != GMT_stdin) GMT_fclose(fp);
-	*data = (struct DATA *) GMT_memory ((void *)*data, (size_t)i, sizeof(struct DATA), GMT_program);
+	*data = (struct TREND2D_DATA *) GMT_memory ((void *)*data, (size_t)i, sizeof(struct TREND2D_DATA), GMT_program);
 	*work = (double *) GMT_memory (VNULL, (size_t)i, sizeof(double), GMT_program);
 	*n_data = i;
 }
 
-void	allocate_array_space(int np, double **gtg, double **v, double **gtd, double **lambda, double **workb, double **workz, double **c_model, double **o_model, double **w_model)
+void allocate_array_space (int np, double **gtg, double **v, double **gtd, double **lambda, double **workb, double **workz, double **c_model, double **o_model, double **w_model)
 {
 	*gtg = (double *) GMT_memory (VNULL, (size_t)(np*np), sizeof(double), GMT_program);
 	*v = (double *) GMT_memory (VNULL, (size_t)(np*np), sizeof(double), GMT_program);
@@ -480,8 +501,8 @@ void	allocate_array_space(int np, double **gtg, double **v, double **gtd, double
 	*o_model = (double *) GMT_memory (VNULL, (size_t)np, sizeof(double), GMT_program);
 	*w_model = (double *) GMT_memory (VNULL, (size_t)np, sizeof(double), GMT_program);
 }
-	
-void	write_output(struct DATA *data, int n_data, char *output_choice, int n_outputs)
+
+void write_output (struct TREND2D_DATA *data, int n_data, char *output_choice, int n_outputs)
 {
 	int	i, j;
 	double out[6];
@@ -513,7 +534,7 @@ void	write_output(struct DATA *data, int n_data, char *output_choice, int n_outp
 	}
 }
 
-void	free_the_memory(double *gtg, double *v, double *gtd, double *lambda, double *workb, double *workz, double *c_model, double *o_model, double *w_model, struct DATA *data, double *work)
+void free_the_memory (double *gtg, double *v, double *gtd, double *lambda, double *workb, double *workz, double *c_model, double *o_model, double *w_model, struct TREND2D_DATA *data, double *work)
 {
 	GMT_free ((void *)work);
 	GMT_free ((void *)data);
@@ -528,7 +549,7 @@ void	free_the_memory(double *gtg, double *v, double *gtd, double *lambda, double
 	GMT_free ((void *)gtg);
 }
 
-void	transform_x(struct DATA *data, int n_data, double xmin, double xmax, double ymin, double ymax)
+void transform_x (struct TREND2D_DATA *data, int n_data, double xmin, double xmax, double ymin, double ymax)
 {
 	int	i;
 	double	offsetx, scalex;
@@ -545,7 +566,7 @@ void	transform_x(struct DATA *data, int n_data, double xmin, double xmax, double
 	}
 }
 
-void	untransform_x(struct DATA *data, int n_data, double xmin, double xmax, double ymin, double ymax)
+void untransform_x (struct TREND2D_DATA *data, int n_data, double xmin, double xmax, double ymin, double ymax)
 {
 	int	i;
 	double	offsetx, scalex;
@@ -562,7 +583,7 @@ void	untransform_x(struct DATA *data, int n_data, double xmin, double xmax, doub
 	}
 }
 
-double	get_chisq(struct DATA *data, int n_data, int n_model)
+double get_chisq (struct TREND2D_DATA *data, int n_data, int n_model)
 {
 	int	i, nu;
 	double	chi = 0.0;
@@ -581,7 +602,7 @@ double	get_chisq(struct DATA *data, int n_data, int n_model)
 	return(chi);
 }
 
-void	recompute_weights(struct DATA *data, int n_data, double *work, double *scale)
+void recompute_weights (struct TREND2D_DATA *data, int n_data, double *work, double *scale)
 {
 	int	i;
 	double	k, ksq, rr;
@@ -616,7 +637,7 @@ void	recompute_weights(struct DATA *data, int n_data, double *work, double *scal
 	}
 }
 
-void	load_g_row(double x, double y, int n, double *gr)
+void load_g_row (double x, double y, int n, double *gr)
       	     	/* Current data position, appropriately normalized.  */
    	  	/* Number of model parameters, and elements of gr[]  */
       	     	/* Elements of row of G matrix.  */
@@ -665,7 +686,7 @@ void	load_g_row(double x, double y, int n, double *gr)
 	}
 }
 
-void	calc_m_and_r(struct DATA *data, int n_data, double *model, int n_model, double *grow)
+void calc_m_and_r (struct TREND2D_DATA *data, int n_data, double *model, int n_model, double *grow)
 {
 	/*	model[n_model] holds solved coefficients of m_type model.
 		grow[n_model] is a vector for a row of G matrix.  */
@@ -681,7 +702,7 @@ void	calc_m_and_r(struct DATA *data, int n_data, double *model, int n_model, dou
 	}
 }
 
-void	move_model_a_to_b(double *model_a, double *model_b, int n_model, double *chisq_a, double *chisq_b)
+void move_model_a_to_b (double *model_a, double *model_b, int n_model, double *chisq_a, double *chisq_b)
 {
 	int	i;
 	for(i = 0; i<  n_model; i++) {
@@ -690,7 +711,7 @@ void	move_model_a_to_b(double *model_a, double *model_b, int n_model, double *ch
 	*chisq_b = *chisq_a;
 }
 
-void	load_gtg_and_gtd(struct DATA *data, int n_data, double *gtg, double *gtd, double *grow, int n_model, int mp)
+void load_gtg_and_gtd (struct TREND2D_DATA *data, int n_data, double *gtg, double *gtd, double *grow, int n_model, int mp)
       	    	      
       			  
    			    	/* mp is row dimension of gtg  */
@@ -731,7 +752,7 @@ void	load_gtg_and_gtd(struct DATA *data, int n_data, double *gtg, double *gtd, d
 	}
 }
 
-void	solve_system(double *gtg, double *gtd, double *model, int n_model, int mp, double *lambda, double *v, double *b, double *z, double c_no, int *ir)
+void solve_system (double *gtg, double *gtd, double *model, int n_model, int mp, double *lambda, double *v, double *b, double *z, double c_no, int *ir)
 {
 
 	int	i, j, k, rank = 0, n, m, nrots;
@@ -762,3 +783,18 @@ void	solve_system(double *gtg, double *gtd, double *model, int n_model, int mp,
 		*ir = rank;
 	}
 }
+
+void *New_Trend2d_Ctrl () {	/* Allocate and initialize a new control structure */
+	struct TREND2D_CTRL *C;
+	
+	C = (struct TREND2D_CTRL *) GMT_memory (VNULL, 1, sizeof (struct TREND2D_CTRL), "New_Trend2d_Ctrl");
+	
+	/* Initialize values whose defaults are not 0/FALSE/NULL */
+	C->C.value = 1.0e06;		/* Condition number for matrix solution  */	
+	C->I.value = 0.51;		/* Confidence interval for significance test  */
+	return ((void *)C);
+}
+
+void Free_Trend2d_Ctrl (struct TREND2D_CTRL *C) {	/* Deallocate control structure */
+	GMT_free ((void *)C);	
+}
