@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: triangulate.c,v 1.31 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: triangulate.c,v 1.39 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -163,7 +163,7 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr, "triangulate %s - Optimal (Delaunay) triangulation of xyz-data\n\n", GMT_VERSION);
+		fprintf (stderr, "triangulate %s - Optimal (Delaunay) triangulation of Cartesian xyz-data\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: triangulate <infiles> [-Dx|y] [-E<empty>] [-F] [-G<grdfile>]\n");
 		fprintf (stderr, "\t[%s] [%s] [%s] [%s]\n", GMT_H_OPT, GMT_I_OPT, GMT_J_OPT, GMT_M_OPT);
 		fprintf (stderr, "\t[%s] [-V] [%s] [%s]\n\t[%s]\n\n", GMT_Rgeo_OPT, GMT_t_OPT, GMT_b_OPT, GMT_f_OPT);
@@ -223,8 +223,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
 		char *type[2] = {"double", "single"};
 		fprintf (stderr, "%s: Expects %d-column %s-precision binary data\n", GMT_program, GMT_io.ncol[GMT_IN], type[GMT_io.single_precision[GMT_IN]]);
@@ -240,12 +238,12 @@ int main (int argc, char **argv)
 		header.x_inc = Ctrl->I.xinc;
 		header.y_inc = Ctrl->I.yinc;
 		GMT_RI_prepare (&header);	/* Ensure -R -I consistency and set nx, ny */
-		GMT_grd_RI_verify (&header, 1);
+		GMT_err_fail (GMT_grd_RI_verify (&header, 1), Ctrl->G.file);
 	}
 
 	if (project_info.region_supplied && project_info.projection > 0) { /* Gave -R -J */
 		map_them = TRUE;
-		GMT_map_setup (header.x_min, header.x_max, header.y_min, header.y_max);
+		GMT_err_fail (GMT_map_setup (header.x_min, header.x_max, header.y_min, header.y_max), "");
 	}
 
 	/* Now we are ready to take on some input values */
@@ -395,11 +393,7 @@ int main (int argc, char **argv)
 				}
 			}
 		}
-		if (GMT_write_grd (Ctrl->G.file, &header, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-			fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-			exit (EXIT_FAILURE);
-		}
-
+		GMT_err_fail (GMT_write_grd (Ctrl->G.file, &header, grd, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 	}
 	if (GMT_io.multi_segments[GMT_OUT]) {	/* Must find unique edges to output only once */
 		n_edge = 3 * np;
@@ -430,7 +424,7 @@ int main (int argc, char **argv)
 		GMT_free ((void *)edge);
 	}
 	else if (GMT_io.binary[GMT_OUT])
-		fwrite ((void *)link, sizeof (int), (size_t)(3*np), GMT_stdout);
+		GMT_fwrite ((void *)link, sizeof (int), (size_t)(3*np), GMT_stdout);
 	else
 		for (i = ij = 0; i < np; i++, ij += 3) fprintf (GMT_stdout, "%d\t%d\t%d\n", link[ij], link[ij+1], link[ij+2]);
 
