@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_get.c,v 1.27 2006/04/28 01:53:11 pwessel Exp $
+ *	$Id: x2sys_get.c,v 1.33 2007/03/24 01:42:07 pwessel Exp $
  *
- *      Copyright (c) 1999-2006 by P. Wessel
+ *      Copyright (c) 1999-2007 by P. Wessel
  *      See COPYING file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -116,7 +116,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	x2sys_set_system (TAG, &s, &B, &GMT_io);
+	x2sys_err_fail (x2sys_set_system (TAG, &s, &B, &GMT_io), TAG);
 
 	if (s->geographic) {
 		GMT_io.out_col_type[0] = GMT_IS_LON;
@@ -131,11 +131,11 @@ int main (int argc, char **argv)
 		south = B.y_min;	north = B.y_max;
 	}
 
-	if (fflags) x2sys_pick_fields (fflags, s);
+	if (fflags) x2sys_err_fail (x2sys_pick_fields (fflags, s), "-F");
 	for (i = combo = 0; i < s->n_out_columns; i++) combo |= (1 << s->out_order[i]);
 
 	if (nflags) {
-		x2sys_pick_fields (nflags, s);
+		x2sys_err_fail (x2sys_pick_fields (nflags, s), "-N");
 		for (i = missing = 0; i < s->n_out_columns; i++) missing |= (1 << s->out_order[i]);
 	}
 	
@@ -143,11 +143,11 @@ int main (int argc, char **argv)
 
 	/* Read existing track-information from <ID>_tracks.d file */
 
-	n_tracks = x2sys_bix_read_tracks (TAG, &B, 1);
+	x2sys_err_fail (x2sys_bix_read_tracks (TAG, &B, 1, &n_tracks), "");
 
 	/* Read geographical track-info from <ID>_index.b file */
 
-	x2sys_bix_read_index (TAG, &B);
+	x2sys_err_fail (x2sys_bix_read_index (TAG, &B), "");
 
 	if (x_setup) {
 		n_flags = (int)ceil (n_tracks / 32.0);
@@ -182,8 +182,8 @@ int main (int argc, char **argv)
 	
 	/* Ok, now we can start finding the tracks requested */
 
-	(void) x2sys_bix_get_ij (west, south, &start_i, &start_j, &B);
-	(void) x2sys_bix_get_ij (east, north, &stop_i, &stop_j, &B);
+	x2sys_err_fail (x2sys_bix_get_ij (west, south, &start_i, &start_j, &B, &j), "");
+	x2sys_err_fail (x2sys_bix_get_ij (east, north, &stop_i, &stop_j, &B, &j), "");
 
 	for (j = start_j; j <= stop_j; j++) {
 		for (i = start_i; i <= stop_i; i++) {
