@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_init.c,v 1.19 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: x2sys_init.c,v 1.24 2007/03/26 01:54:58 pwessel Exp $
  *
- *      Copyright (c) 1999-2006 by P. Wessel
+ *      Copyright (c) 1999-2007 by P. Wessel
  *      See COPYING file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@ int main (int argc, char **argv)
 {
 	char *sfile = CNULL, *TAG = CNULL, *suffix = NULL;
 	time_t right_now;
-	struct X2SYS_INFO *s;
+	struct X2SYS_INFO *s = NULL;
 #ifndef WIN32
 	struct passwd *pw;
 #endif
@@ -162,7 +162,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: -Idx/dy must be positive!\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-	s = x2sys_initialize (sfile, &GMT_io);	/* Initialize X2SYS and info structure */
+	x2sys_err_fail (x2sys_initialize (sfile, &GMT_io, s), sfile);	/* Initialize X2SYS and info structure */
 
 	if (geographic) {
 		s->geographic = TRUE;
@@ -241,7 +241,7 @@ int main (int argc, char **argv)
 	(i_entry) ? fprintf (fp, " %s", argv[i_entry]) : fprintf (fp, " -I1/1");
 	(r_entry) ? fprintf (fp, " %s", argv[r_entry]) : fprintf (fp, " -R0/360/-90/90");
 	fprintf (fp, "\n");
-	x2sys_fclose (tag_file, fp);
+	x2sys_err_fail (x2sys_fclose (tag_file, fp), tag_file);
 
 	/* Initialize the system's tracks data base  */
 
@@ -250,7 +250,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: Could not find %s\n", GMT_program, track_file);
 		exit (EXIT_FAILURE);
 	}
-	x2sys_fclose (track_file, fp);
+	x2sys_err_fail (x2sys_fclose (track_file, fp), track_file);
 
 	/* Initialize the system's index data base  */
 
@@ -259,7 +259,7 @@ int main (int argc, char **argv)
 		fprintf (stderr,"%s: Could not open %s\n", GMT_program, bin_file);
 		exit (EXIT_FAILURE);
 	}
-	x2sys_fclose (bin_file, fp);
+	x2sys_err_fail (x2sys_fclose (bin_file, fp), bin_file);
 
 	/* Initialize the system's crossover data base  */
 
