@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_put.c,v 1.14 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: x2sys_put.c,v 1.20 2007/03/24 01:42:07 pwessel Exp $
  *
- *      Copyright (c) 1999-2006 by P. Wessel
+ *      Copyright (c) 1999-2007 by P. Wessel
  *      See COPYING file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -109,7 +109,7 @@ int main (int argc, char **argv)
 
 	/* Open TAG file and set the operational parameters */
 
-	x2sys_set_system (TAG, &s, &B, &GMT_io);
+	x2sys_err_fail (x2sys_set_system (TAG, &s, &B, &GMT_io), TAG);
 
 	for (i = max_flag = 0, bit = 1; i < s->n_fields; i++, bit <<= 1) max_flag |= bit;
 
@@ -128,11 +128,12 @@ int main (int argc, char **argv)
 
 	/* Read existing track-information from <ID>_tracks.d file */
 
-	last_id = x2sys_bix_read_tracks (TAG, &B, 0) - 1;
+	 x2sys_err_fail (x2sys_bix_read_tracks (TAG, &B, 0, &last_id), "");
+	 last_id--;
 
 	/* Read geographical track-info from <ID>_index.b file */
 
-	x2sys_bix_read_index (TAG, &B);
+	x2sys_err_fail (x2sys_bix_read_index (TAG, &B), "");
 
 	/* Ok, now we can start reading new info */
 
@@ -212,11 +213,11 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if ((ftrack = GMT_fopen (track_path, "w")) == NULL) {
+	if ((ftrack = fopen (track_path, "w")) == NULL) {
 		fprintf (stderr, "%s: Failed to create %s. Aborts!\n", GMT_program, track_path);
 		exit (EXIT_FAILURE);
 	}
-	if ((fbin = GMT_fopen (index_path, "wb")) == NULL) {
+	if ((fbin = fopen (index_path, "wb")) == NULL) {
 		fprintf (stderr, "%s: Failed to create %s. Aborts!\n", GMT_program, index_path);
 		exit (EXIT_FAILURE);
 	}
