@@ -1,4 +1,4 @@
-/*	$Id: x_over.c,v 1.3 2001/12/21 03:50:38 ben Exp $
+/*	$Id: x_over.c,v 1.9 2007/03/14 23:11:11 pwessel Exp $
  *
  * X_OVER will compute cross-overs between 2 legs (or internal cross-overs
  * if both legs are the same) and write out time,lat,lon,cross-over values,
@@ -10,7 +10,7 @@
  *	NPOINTS	- (int)		Total number of records following rec #1
  *	INFO	- (char)	10 character info field.
  * Rec#2-(NPOINTS+1):
- * 	TIME	- (int)  	Stored as seconds from 00:00:00 on Jan. 1, YEAR.
+ * 	GMT_TIME	- (int)  	Stored as seconds from 00:00:00 on Jan. 1, YEAR.
  *	LAT	- (float)	Stored as degrees * 1.0E6 in the interval <-90.,+90.>
  *	LON	- (float)	Stored as degrees * 1.0E6 in the interval <0.,360.>
  *	GRAV	- (int)		Gravity in mGal * 10.
@@ -73,7 +73,7 @@ static float lon[MAXPOINTS];		/* longitude for each point */
 static float grid_section[4][MAXSECT+1][MAXBLOCK][2];
 BOOLEAN gmt_flag[3] = {FALSE, FALSE, FALSE};		/* TRUE (for each data type) if it exists */
 
-main (int argc, char *argv[])
+int main (int argc, char *argv[])
 {
   char legname[2][10];		/* Names of the legs */
   char legfile[100];		/* Filename for leg */
@@ -103,7 +103,7 @@ main (int argc, char *argv[])
   int arg, block, mode, i;		/* Misc. counters */
 
   BOOLEAN shift_lon = FALSE;	/* TRUE if areas cross datumline */
-  BOOLEAN internal;		/* TRUE if leg1 = leg2 */
+  BOOLEAN internal = FALSE;	/* TRUE if leg1 = leg2 */
   BOOLEAN x_flag;		/* TRUE if crossover is found */
   BOOLEAN error = FALSE;	/* TRUE for invalid arguments */
   BOOLEAN verbose = FALSE;	/* Work in silence */
@@ -217,10 +217,10 @@ main (int argc, char *argv[])
     	strcpy (legname[0], legname[1]);
     	strcpy (legname[1], tmp);
     }
-    	
+    
   }
 
-  gmtmggpath_init();
+  gmtmggpath_init(GMT_SHAREDIR);
 
   /* Read data for each leg (only 1 for internal) */
 
@@ -459,7 +459,7 @@ main (int argc, char *argv[])
     	        xm[1][leg] = grid_section[1][sct[leg]][blk[leg]][leg_no[leg]];
     	        ym[0][leg] = grid_section[2][sct[leg]][blk[leg]][leg_no[leg]];
     	        ym[1][leg] = grid_section[3][sct[leg]][blk[leg]][leg_no[leg]];
-          	if (xm[0][leg] > xm[1][leg]) xm[0][leg] = xm[1][leg];	
+          	if (xm[0][leg] > xm[1][leg]) xm[0][leg] = xm[1][leg];
           	if (ym[0][leg] > ym[1][leg]) ym[0][leg] = ym[1][leg];
               }
               if (over_lap(xm,ym)) {
