@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: xyz2grd.c,v 1.53 2006/04/24 21:32:42 pwessel Exp $
+ *	$Id: xyz2grd.c,v 1.67 2007/03/24 01:42:07 pwessel Exp $
  *
- *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2007 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -88,7 +88,7 @@ int main (int argc, char **argv)
 
 	char line[BUFSIZ];
 
-	FILE *fp = NULL, *fps = NULL;
+	FILE *fp = NULL;
 
 	struct GRD_HEADER grd;
 	struct GMT_Z_IO io;
@@ -196,7 +196,7 @@ int main (int argc, char **argv)
 
 		fprintf (stderr, "\txyzfile(s) is a 1- or 3-column file [or standard input] with [x,y,]z values\n");
 		fprintf (stderr, "\t-G to name the output grdfile.\n");
-		fprintf (stderr, "\t-I specifies grid size(s).  Append m [or c] to <dx> and/or <dy> for minutes [or seconds]\n");
+		GMT_inc_syntax ('I', 0);
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t-A (or -Az): Sum up multiple entries at the same node.\n");
@@ -293,8 +293,6 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
-	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
-
 	no_data_f = (float)Ctrl->N.value;
 	
 	if (do_grid) {
@@ -304,25 +302,27 @@ int main (int argc, char **argv)
 		GMT_RI_prepare (&grd);	/* Ensure -R -I consistency and set nx, ny */
 	}
 	
-	switch (Ctrl->A.mode) {
-		case 'n':	/* Count the number of values for each node */
-			count = TRUE;
-			average = FALSE;
-			break;
-		case 'l':	/* Return the lowest (minimum) value at each node */
-			high_low = -1;
-			break;
-		case 'u':	/* Return the upper (maximum)  value at each node */
-			high_low = +1;
-			break;
-		case 'z':	/* Return the sum of multiple values at each node */
-		case '\0':
-			average = count = FALSE;
-			break;
-		default:
-			fprintf (stderr, "%s: GMT SYNTAX ERROR -A option:  Select -An, -Al, -Au, or -A[z]\n", GMT_program);
-			error++;
-			break;
+	if (Ctrl->A.active) {
+		switch (Ctrl->A.mode) {
+			case 'n':	/* Count the number of values for each node */
+				count = TRUE;
+				average = FALSE;
+				break;
+			case 'l':	/* Return the lowest (minimum) value at each node */
+				high_low = -1;
+				break;
+			case 'u':	/* Return the upper (maximum)  value at each node */
+				high_low = +1;
+				break;
+			case 'z':	/* Return the sum of multiple values at each node */
+			case '\0':
+				average = count = FALSE;
+				break;
+			default:
+				fprintf (stderr, "%s: GMT SYNTAX ERROR -A option:  Select -An, -Al, -Au, or -A[z]\n", GMT_program);
+				error++;
+				break;
+		}
 	}
 	if (b_only && Ctrl->Z.active) fprintf (stderr, "%s: GMT Warning.  -Z overrides -bi\n", GMT_program);
 
@@ -343,7 +343,7 @@ int main (int argc, char **argv)
 	else if (!Ctrl->E.active) {
 		grd.xy_off = 0.5 * grd.node_offset;
 
-		GMT_grd_RI_verify (&grd, 1);
+		GMT_err_fail (GMT_grd_RI_verify (&grd, 1), Ctrl->G.file);
 
 		if (gmtdefs.verbose) fprintf (stderr, "%s: nx = %d  ny = %d\n", GMT_program, grd.nx, grd.ny);
 
@@ -356,7 +356,7 @@ int main (int argc, char **argv)
 		z = (Ctrl->Z.active) ? 0 : 2;
 	}
 
-	GMT_set_z_io (&io, &grd);
+	GMT_err_fail (GMT_set_z_io (&io, &grd), Ctrl->G.file);
 
 	GMT_set_xy_domain (wesn, &grd);	/* May include some padding if gridline-registered */
 
@@ -387,6 +387,7 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
 
 		if (Ctrl->S.active) {	/* Just swap data and exit */
+			FILE *fps = NULL;
 
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Swapping data bytes only\n", GMT_program);
 
@@ -401,7 +402,7 @@ int main (int argc, char **argv)
 				exit (EXIT_FAILURE);
 			}
 
-			if (io.skip) fseek (fp, (long)io.skip, SEEK_CUR);
+			if (io.skip) GMT_fseek (fp, (long)io.skip, SEEK_CUR);
 			while ((io.read_item) (fp, &d_value)) (io.write_item) (fps, d_value);
 
 			if (fp != GMT_stdin) GMT_fclose (fp);
@@ -412,7 +413,7 @@ int main (int argc, char **argv)
 
 		if (Ctrl->Z.active) {	/* Read separately because of all the possible formats */
 			if (Ctrl->N.active && GMT_is_dnan (Ctrl->N.value)) Ctrl->N.active = FALSE;	/* No point testing */
-			if (io.skip) fseek (fp, (long)io.skip, SEEK_CUR);
+			if (io.skip) GMT_fseek (fp, (long)io.skip, SEEK_CUR);
 			while ((io.read_item) (fp, &d_value)) {
 				ij++;
 				if (ij == io.n_expected) {
@@ -437,29 +438,37 @@ int main (int argc, char **argv)
 			int n_left, j;
 			float value;
 			
-			if (fscanf (fp, "%*s %d", &grd.nx) != 1) {
+			GMT_fgets (line, BUFSIZ, fp);
+			if (sscanf (line, "%*s %d", &grd.nx) != 1) {
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			if (fscanf (fp, "%*s %d", &grd.ny) != 1) {
+			GMT_fgets (line, BUFSIZ, fp);
+			if (sscanf (line, "%*s %d", &grd.ny) != 1) {
 				fprintf (stderr, "%s: Error decoding ncols record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			if (fscanf (fp, "%s %lf", line, &grd.x_min) != 2) {
+			GMT_fgets (line, BUFSIZ, fp);
+			if (sscanf (line, "%*s %lf", &grd.x_min) != 1) {
 				fprintf (stderr, "%s: Error decoding xll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			if (fscanf (fp, "%*s %lf", &grd.y_min) != 1) {
+			GMT_fgets (line, BUFSIZ, fp);
+			if (sscanf (line, "%*s %lf", &grd.y_min) != 1) {
 				fprintf (stderr, "%s: Error decoding yll record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			if (fscanf (fp, "%*s %lf", &grd.x_inc) != 1) {
+			GMT_fgets (line, BUFSIZ, fp);
+			if (sscanf (line, "%*s %lf", &grd.x_inc) != 1) {
 				fprintf (stderr, "%s: Error decoding cellsize record\n", GMT_program);
 				exit (EXIT_FAILURE);
 			}
-			if (!Ctrl->E.set && fscanf (fp, "%*s %lf", &Ctrl->E.nodata) != 1) {	/* Only read if not specified in -E */
-				fprintf (stderr, "%s: Error decoding nodata_value record\n", GMT_program);
-				exit (EXIT_FAILURE);
+			if (!Ctrl->E.set) {	/* Only read if not specified in -E */
+				GMT_fgets (line, BUFSIZ, fp);
+				if (sscanf (line, "%*s %lf", &Ctrl->E.nodata) != 1) {
+					fprintf (stderr, "%s: Error decoding nodata_value record\n", GMT_program);
+					exit (EXIT_FAILURE);
+				}
 			}
 			grd.y_inc = grd.x_inc;
 			grd.node_offset = 0;
@@ -468,7 +477,7 @@ int main (int argc, char **argv)
 			grd.x_max = grd.x_min + (grd.nx - 1 + grd.node_offset) * grd.x_inc;
 			grd.y_max = grd.y_min + (grd.ny - 1 + grd.node_offset) * grd.y_inc;
 			
-			GMT_grd_RI_verify (&grd, 1);
+			GMT_err_fail (GMT_grd_RI_verify (&grd, 1), Ctrl->G.file);
 
 			if (gmtdefs.verbose) fprintf (stderr, "%s: nx = %d  ny = %d\n", GMT_program, grd.nx, grd.ny);
 			nm = n_left = grd.nx * grd.ny;
@@ -504,9 +513,11 @@ int main (int argc, char **argv)
 				/* Ok, we are inside the region - process data */
 
 				ii = GMT_x_to_i (in[0], grd.x_min, grd.x_inc, grd.xy_off, grd.nx);
+				if (ii == -1) ii++, n_confused++;
 				if (ii == grd.nx) ii--, n_confused++;
 				jj = GMT_y_to_j (in[1], grd.y_min, grd.y_inc, grd.xy_off, grd.ny);
 				if (jj == -1) jj++, n_confused++;
+				if (jj == grd.ny) jj--, n_confused++;
 				ij = jj * grd.nx + ii;
 				if (high_low) {	/* Always come here if looking for extreme values */
 					if (flag[ij]) {	/* Already assigned the first value */
@@ -591,10 +602,7 @@ int main (int argc, char **argv)
 		}
 	}
 
-	if (GMT_write_grd (Ctrl->G.file, &grd, a, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
-		fprintf (stderr, "%s: Error writing file %s\n", GMT_program, Ctrl->G.file);
-		exit (EXIT_FAILURE);
-	}
+	GMT_err_fail (GMT_write_grd (Ctrl->G.file, &grd, a, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE), Ctrl->G.file);
 
 	GMT_free ((void *)a);
 
